UNIT plarl14;

{
version 1.4l for FPC (25 Jan 2000)
author: Franco Milani
email:  nadir@solaris.polarhome.com
        astlab@inwind.it
web sites:
http://www.polarhome.com/~franco
http://www.polarhome.com:723/~nadir/software
http://spazioinwind.libero.it/frm/software

Source released under the terms of the GNU General Public License
v. 2 as published by the Free Software Foundation.

This unit evaluates the ecliptic heliocentric spherical coordinates
of planets and earth, the velocity components of the earth relative
to the sun and the geocentric coordinates of the moon.
All the coordinates are geometric, and are relative to the equinox
J2000, except those of the moon which are referred to the mean
equinox and ecliptic of date.
The procedures pos_mer, pos_ven, pos_ear, pos_moo, pos_mar, pos_jup,
pos_sat, pos_ura, pos_nep, pos_plu return longitude and latitude in
radians and distance in AU, vel_ear returns the earth's velocity
components in radians/day and AU/day, at selected TDB Julian dates j.
Valid date ranges are: from 3000 B.C. to 3000 A.D. for the outer
planets, from 2000 B.C. to 6000 A.D. for the earth, and from 1350 B.C.
to 3000 A.D. for the inner planets and moon.
For planets and moon the unit uses the Steve Moshier's plan404
coefficients. References and notes may be found in the plan404 sources
at the Moshier's software site (http://moshier.ne.mediaone.net/index.html).
The earth's coefficients are taken from the VSOP87B.ear file located at
Bureau Des Longitudes site (ftp://ftp.bdl.fr/pub/ephem/planets/vsop87).
The file precis.txt contains the computed deviations from JPL's DE404
and DE405 ephemerides. The DE405 files are available at the Jet Propulsion
Laboratory site (ftp://navigator.jpl.nasa.gov/pub/ephem).
}

INTERFACE

PROCEDURE pos_mer (j: double; var a,b,c: double);  {Mercury coordinates}
PROCEDURE pos_ven (j: double; var a,b,c: double);  {Venus coordinates}
PROCEDURE pos_ear (j: double; var a,b,c: double);  {Earth coordinates}
PROCEDURE vel_ear (j: double; var a,b,c: double);  {Earth velocity}
PROCEDURE pos_moo (j: double; var a,b,c: double);  {Moon coordinates}
PROCEDURE pos_mar (j: double; var a,b,c: double);  {Mars coordinates}
PROCEDURE pos_jup (j: double; var a,b,c: double);  {Jupiter coordinates}
PROCEDURE pos_sat (j: double; var a,b,c: double);  {Saturn coordinates}
PROCEDURE pos_ura (j: double; var a,b,c: double);  {Uranus coordinates}
PROCEDURE pos_nep (j: double; var a,b,c: double);  {Neptune coordinates}
PROCEDURE pos_plu (j: double; var a,b,c: double);  {Pluto coordinates}

IMPLEMENTATION

CONST

mertabl: array[0..399] of double = 
(35.85255,           -163.26379,          53810162857.56026,  908082.18475,
  0.05214,           -0.07712,            1.07258,            0.04008,
  0.49259,            0.00230,            0.02324,            0.05869,
  0.24516,            0.22898,           -0.06037,            0.13023,
  0.00331,           -0.03576,            0.06464,            0.00089,
  0.03103,            0.05078,           -0.01133,            0.01520,
  0.14654,            0.07538,            0.25112,           -0.24473,
 -0.17928,           -0.53366,           -0.06367,            0.20458,
 -0.42985,            0.14848,           -0.35317,           -0.61364,
  0.00325,           -0.08617,           -0.23180,            0.08576,
  0.22995,            0.43569,            1.92114,            2.89319,
 -5.55637,            4.70329,           -4.91411,           -5.45521,
  0.02607,            0.04468,           -0.05439,            0.13476,
 -0.07329,           -0.00985,           -0.00278,            0.05377,
  0.07474,           -0.09658,            0.29818,            0.20422,
 -0.29074,            0.44962,           -0.15411,           -0.04287,
  0.29907,           -1.02948,            3.62183,            0.84869,
 -0.08157,            0.02754,           -0.03610,           -0.12909,
  0.09195,           -0.04424,           -0.08845,            0.09347,
 -0.27140,            0.08185,            0.24783,            0.19543,
 -0.25154,            0.41371,           -0.00046,            0.01524,
  0.04127,            0.06663,            0.43023,            0.11790,
  0.04427,            0.05329,            0.00411,           -0.71074,
 -0.07111,           -0.09824,            0.01264,           -0.02075,
 -0.00068,           -0.01678,            0.01186,            0.00181,
  0.00302,           -0.21963,           -0.06412,           -0.10155,
 -0.36856,            0.20240,            0.32282,            0.65133,
 -0.07178,           -0.01876,            0.13399,           -0.39522,
  1.28413,            0.33790,            0.05040,           -0.01679,
 -0.00794,            0.01117,            0.02630,            0.00575,
 -0.07113,           -0.11414,            0.16422,           -0.23060,
  0.35198,            0.05409,            1.11486,           -0.35833,
  0.87313,            1.66304,           -1.28434,            0.72067,
  0.01400,            0.00971,            0.21044,           -0.87385,
  3.20820,            0.67957,           -0.01716,            0.00111,
 -0.13776,           -0.02650,           -0.06778,            0.00908,
  0.00616,           -0.04520,           -0.31625,           -0.61913,
  0.36184,            0.09373,            0.00984,           -0.03292,
  0.01944,            0.00530,            0.00243,           -0.00123,
  0.01589,            0.02223,           -0.02992,           -0.01086,
  4356.04809,        -5859.86328,         2918.27323,        -4796.67315,
  510.24783,         -1220.02233,         127.48927,          250.10654,
  3250.43013,        -904.27614,         -5667.40042,        -22634.00922,
 -82471.79425,        18615.92342,        0.01941,            0.00372,
  0.01830,           -0.00652,           -0.02548,           -0.01157,
  0.00635,            0.02343,           -0.00980,            0.00961,
  0.12137,            0.10068,            0.16676,           -0.07257,
 -0.07267,           -0.13761,            0.25305,           -0.28112,
 -0.07974,            0.07866,           -0.41726,            0.49991,
 -1.55187,           -1.14150,            1.54754,           -2.35141,
 -0.00862,            0.00808,            0.00218,           -0.03726,
  0.06914,           -0.08986,           -0.00501,            2.09577,
 -0.01409,           -0.01842,            0.04138,            0.05961,
 -0.12276,           -0.04929,           -0.03963,           -0.06080,
 -0.27697,           -0.09329,           -0.01011,            0.00295,
 -0.01374,            0.01328,           -0.00171,            0.25815,
  0.01446,            0.00782,            0.17909,           -0.04683,
  0.03765,           -0.04990,            0.00036,            0.00528,
  0.05508,           -0.01369,           -0.11751,           -0.10624,
 -0.14448,            0.10522,           -0.00884,            0.43006,
  0.01162,            0.01659,           -0.00076,            0.10143,
  0.55779,            0.05510,            0.12350,           -0.34025,
  0.01320,            0.92985,           -0.00026,           -0.03426,
  0.01305,            0.00041,            0.13187,           -0.11903,
  0.00058,            0.09877,           -33.10230,          -41.96782,
 -268.28908,          174.29259,          731.20089,          1508.07639,
  5223.99114,        -3008.08849,        -3909.34957,        -9646.69156,
  0.02988,            0.03182,            0.07149,            0.04513,
 -0.02356,           -0.01641,           -0.03188,           -0.03711,
  0.15084,           -0.22436,            0.61987,            0.25706,
  0.02425,            0.01200,           -0.05543,           -0.14435,
 -0.53398,            0.10997,            0.00465,           -0.01893,
  0.01260,           -0.01314,            0.00650,           -0.05499,
 -0.06804,            0.01608,            0.02134,            0.04160,
  0.00636,            0.01293,           -0.03470,           -0.02697,
 -0.11323,            0.02409,           -0.02618,            0.00827,
  0.01879,            0.16838,            0.08978,            0.01934,
 -0.23564,            0.05565,            0.03686,            0.02644,
 -0.02471,            0.00558,           -140.22669,         -120.40692,
 -501.88143,          434.05868,          1044.54998,         1162.72084,
  1527.78437,        -882.37371,         -0.00768,            0.02213,
 -0.04090,            0.16718,           -0.05923,           -0.12595,
  0.01154,           -0.00025,           -0.00776,           -0.01653,
 -0.01213,           -0.02773,            0.00344,            0.02180,
 -0.02558,           -0.05682,           -0.00490,            0.01050,
  38.75496,          -78.17502,          -189.90700,         -136.33371,
 -249.94062,          319.76423,          205.73478,          272.64549,
 -0.01132,           -0.01071,           -0.04607,           -0.00390,
  0.02903,           -0.02070,            0.01326,           -0.00901,
  35.38435,           7.45358,            31.08987,          -70.52685,
 -92.13879,          -51.58876,          -51.80016,           48.98102,
 -0.00124,           -0.01159,            0.47335,            13.71886,
  23.71637,           5.55804,            10.06850,          -25.65292,
 -11.85300,          -10.20802,          -4.72861,            1.27151,
 -0.47322,            7.46754,            6.99528,            1.79089,
  2.05336,           -2.90866,           -1.97528,            0.72236,
 -0.25084,            1.90269,            0.72127,            0.41354,
 -0.30286,           -0.53125,           -0.50883,           -0.01200,
 -0.08301,            0.18083,           -0.04286,           -0.10963,
 -0.04544,           -0.01645,           -0.00013,           -0.00986);

mertabb: array[0..399] of double = 
(68.33369,            422.77623,         -2057.26405,        -2522.29068,
 -0.00030,           -0.00009,            0.02400,           -0.06471,
  0.02074,           -0.00904,            0.00044,            0.00261,
 -0.00174,           -0.00088,           -0.00027,            0.00003,
  0.00005,           -0.00004,           -0.00036,            0.00200,
  0.01432,            0.01199,            0.00006,           -0.00004,
  0.00236,            0.00803,            0.01235,            0.00406,
 -0.03253,            0.00179,           -0.00243,            0.00132,
 -0.00352,            0.00011,           -0.00146,           -0.01154,
  0.00824,           -0.01195,           -0.01829,           -0.00465,
  0.12540,            0.09997,            0.00400,            0.00288,
 -0.02848,            0.01094,           -0.02273,           -0.07051,
  0.01305,            0.01078,           -0.00119,            0.00136,
 -0.00107,           -0.00066,            0.00097,           -0.00315,
  0.00120,            0.00430,           -0.00710,           -0.00157,
  0.06052,           -0.04777,            0.00192,           -0.00229,
 -0.02077,            0.00647,            0.06907,            0.07644,
 -0.00717,            0.00451,            0.00052,           -0.00262,
  0.00345,            0.00039,           -0.00674,            0.00346,
 -0.02880,            0.00807,            0.00054,            0.00206,
 -0.01745,            0.00517,           -0.00044,            0.00049,
  0.01749,            0.01230,            0.01703,            0.01563,
  0.00934,            0.02372,            0.01610,           -0.01136,
  0.00186,           -0.00503,            0.00082,           -0.00673,
  0.00170,           -0.00539,            0.00042,            0.00037,
  0.00415,           -0.00430,            0.00258,           -0.00914,
 -0.01761,           -0.00251,            0.15909,            0.13276,
  0.02436,           -0.00791,            0.00491,            0.03890,
 -0.02982,            0.05645,           -0.00003,            0.00427,
 -0.00363,            0.00221,            0.00077,            0.00130,
  0.00131,           -0.00071,            0.00796,            0.00453,
  0.01186,            0.01631,            0.12949,           -0.02546,
  0.03613,            0.32854,           -0.43001,            0.01417,
  0.00034,            0.00095,           -0.03268,            0.04034,
  0.11407,            0.15049,           -0.00079,           -0.00052,
 -0.04009,            0.00988,           -0.00259,           -0.00085,
  0.00221,           -0.00133,            0.00003,           -0.01733,
  0.01055,            0.01976,            0.00222,            0.00085,
  0.00089,            0.00087,            0.00014,            0.00001,
  0.00145,            0.00802,            0.00122,            0.00068,
  947.79367,         -1654.39690,         542.00864,         -1281.09901,
  90.02068,          -318.36115,         -87.67090,           92.91960,
  376.98232,         -419.10705,          5094.60412,         2476.97098,
 -18160.57888,        16010.48165,        0.00621,           -0.00128,
  0.00186,           -0.00153,           -0.00790,            0.00011,
 -0.00032,            0.00165,           -0.00277,            0.00539,
  0.00552,            0.00682,            0.01086,           -0.00978,
 -0.02292,           -0.01300,            0.02940,           -0.04427,
 -0.02051,            0.04860,           -0.05020,            0.29089,
 -0.50763,           -0.04900,            0.11177,           -0.41357,
 -0.00222,            0.00504,           -0.00006,           -0.00459,
 -0.00175,           -0.02691,            0.05921,            0.18938,
 -0.00181,           -0.00154,            0.00322,            0.00586,
 -0.01098,           -0.00520,           -0.00861,           -0.01342,
 -0.02694,           -0.00706,           -0.00103,            0.00012,
 -0.00284,            0.00797,            0.00743,            0.02523,
  0.00872,            0.00096,            0.03155,           -0.01644,
  0.00414,           -0.00583,            0.00029,            0.00066,
  0.00935,           -0.00619,           -0.02498,           -0.01600,
 -0.03545,            0.07623,            0.01649,            0.06498,
  0.00148,            0.00209,            0.00621,            0.02014,
  0.17407,           -0.05022,           -0.03485,           -0.17012,
  0.06164,            0.20059,           -0.00804,           -0.01475,
  0.00296,           -0.00068,            0.01880,           -0.03797,
  0.00608,            0.02270,            5.89651,           -6.62562,
 -37.41057,          -10.51542,          -47.22373,           95.76862,
  494.45951,         -5.37252,           -3991.04809,        -2886.97750,
  0.01232,            0.00487,            0.03163,            0.00561,
 -0.01847,           -0.00207,           -0.10138,            0.01430,
 -0.04269,           -0.22338,            0.24955,           -0.02066,
  0.01119,           -0.00186,            0.03416,            0.01805,
 -0.12498,            0.10385,           -0.00210,           -0.01011,
  0.00346,           -0.00682,           -0.00683,           -0.02227,
 -0.01649,            0.01259,            0.01392,            0.01174,
  0.00440,            0.00351,           -0.02871,           -0.00375,
 -0.03170,            0.02246,           -0.00833,            0.00596,
  0.04081,            0.06666,            0.05400,           -0.02387,
 -0.07852,            0.05781,            0.01881,            0.00324,
 -0.00868,            0.00606,           -6.52157,           -19.74446,
 -72.46009,           43.12366,           321.78233,          215.45201,
  452.61804,         -1025.05619,         0.00119,            0.01169,
  0.02239,            0.09003,           -0.05329,           -0.03974,
  0.00688,           -0.00421,           -0.00676,           -0.00515,
 -0.01171,           -0.00952,            0.01337,            0.01270,
 -0.02791,           -0.02184,            0.00058,            0.00679,
  8.42102,           -11.87757,          -49.07247,          -25.34584,
 -43.54829,           161.26509,          261.70993,          56.25777,
  0.00568,            0.00871,           -0.02656,            0.01582,
  0.00875,           -0.02114,            0.00464,           -0.01075,
  9.08966,            1.37810,            3.44548,           -27.44651,
 -59.62749,          -0.73611,           -0.77613,            65.72607,
 -0.00664,           -0.00723,            1.04214,            4.78920,
  11.67397,          -1.84524,           -4.16685,           -19.14211,
 -16.14483,           3.02496,           -1.98140,            1.16261,
  1.81526,            4.21224,            5.59020,           -2.55741,
 -1.54151,           -3.85817,           -1.08723,            1.23372,
  1.12378,            1.51554,            0.88937,           -0.57631,
 -0.50549,           -0.25617,           -0.37618,            0.42163,
  0.18902,            0.19575,           -0.15402,           -0.04062,
 -0.04017,            0.05717,           -0.01665,           -0.00199);

mertabr: array[0..399] of double = 
(-8.30490,           -11.68232,           86.54880,           4361.05018,
  0.00002,           -0.00001,           -0.01102,            0.00410,
  0.00007,           -0.00276,            0.00117,            0.00082,
  0.00049,            0.00007,            0.00003,           -0.00001,
  0.00012,            0.00005,           -0.00186,           -0.00534,
 -0.03301,            0.01808,            0.00008,            0.00005,
 -0.00394,            0.00202,            0.02362,           -0.00359,
  0.00638,           -0.06767,            0.00422,           -0.00493,
  0.00660,            0.00513,           -0.00417,            0.00708,
  0.05849,           -0.00213,           -0.07647,           -0.16162,
 -0.30551,            0.13856,           -0.02789,            0.01811,
 -0.04155,           -0.06229,            0.05729,           -0.03694,
 -0.03087,            0.01610,           -0.00297,           -0.00167,
  0.00041,           -0.00157,           -0.00115,            0.00058,
  0.00796,            0.00436,           -0.01393,            0.02921,
 -0.05902,           -0.02363,            0.00459,           -0.01512,
  0.10038,            0.02964,           -0.08369,            0.34570,
 -0.00749,           -0.02653,            0.01361,           -0.00326,
  0.00406,            0.00952,           -0.00594,           -0.00829,
 -0.02763,           -0.09933,           -0.04143,            0.05152,
 -0.08436,           -0.05294,           -0.00329,           -0.00016,
 -0.04340,            0.02566,           -0.03027,            0.10904,
  0.03665,           -0.03070,            0.23525,            0.00182,
  0.03092,           -0.02212,            0.01255,            0.00777,
 -0.01025,            0.00042,           -0.00065,            0.00440,
  0.08688,            0.00136,            0.05700,           -0.03616,
 -0.11272,           -0.20838,           -0.37048,            0.18314,
  0.00717,           -0.02911,            0.15848,            0.05266,
 -0.13451,            0.51639,            0.00688,            0.02029,
  0.00596,            0.00423,           -0.00253,            0.01196,
  0.05264,           -0.03301,            0.10669,            0.07558,
 -0.02461,            0.16282,           -0.18481,           -0.57118,
  0.85303,           -0.44876,            0.37090,            0.65915,
 -0.00458,            0.00660,            0.41186,            0.09829,
 -0.31999,            1.51149,           -0.00052,           -0.00809,
  0.01384,           -0.07114,           -0.00435,           -0.03237,
  0.02162,            0.00294,            0.29742,           -0.15430,
 -0.04508,            0.17436,            0.01577,            0.00485,
 -0.00258,            0.00946,            0.00061,            0.00119,
  0.01095,           -0.00788,            0.00530,           -0.01478,
  2885.06380,         2152.76256,         2361.91098,         1442.28586,
  602.45147,          251.18991,         -121.68155,          71.20167,
  404.94753,          1607.37580,         11211.04090,       -2905.37340,
 -9066.27933,        -40747.62807,       -0.00189,            0.00957,
  0.00332,            0.00907,            0.00574,           -0.01255,
 -0.01134,            0.00291,           -0.00666,           -0.00615,
 -0.04947,            0.06182,            0.03965,            0.08091,
  0.06846,           -0.03612,            0.13966,            0.12543,
 -0.05494,           -0.05043,           -0.24454,           -0.20507,
  0.56201,           -0.75997,            1.15728,            0.76203,
 -0.00559,           -0.00536,            0.01872,            0.00104,
  0.03044,            0.02504,           -1.07241,           -0.00288,
  0.00950,           -0.00760,           -0.03211,            0.02261,
  0.02678,           -0.06868,            0.03008,           -0.02062,
  0.04997,           -0.15164,           -0.00176,           -0.00580,
 -0.00730,           -0.00676,           -0.13906,           -0.00089,
 -0.00362,            0.00817,            0.02021,            0.07719,
  0.02788,            0.02061,           -0.00274,            0.00016,
  0.00566,            0.02293,            0.04691,           -0.05005,
 -0.05095,           -0.06225,           -0.19770,           -0.00456,
 -0.00848,            0.00595,           -0.04506,           -0.00172,
 -0.01960,            0.22971,            0.14459,            0.04362,
 -0.40199,            0.00386,            0.01442,           -0.00088,
 -0.00020,            0.00544,            0.04768,            0.05222,
 -0.04069,           -0.00003,            15.71084,          -12.28846,
 -66.23443,          -109.83758,         -586.31996,          311.09606,
  1070.75040,         2094.34080,         3839.04103,        -1797.34193,
 -0.01216,            0.01244,           -0.01666,            0.02627,
  0.00687,           -0.01291,            0.00939,           -0.01905,
  0.09401,            0.05027,           -0.09398,            0.23942,
 -0.00379,            0.00834,            0.05632,           -0.01907,
 -0.04654,           -0.21243,            0.00255,            0.00179,
  0.00540,            0.00497,            0.01427,            0.00243,
 -0.00697,           -0.02792,           -0.01524,            0.00810,
 -0.00461,            0.00238,            0.00899,           -0.01515,
 -0.01011,           -0.04390,           -0.00447,           -0.00992,
 -0.06110,            0.00975,           -0.00261,            0.03415,
 -0.02336,           -0.08776,           -0.00883,            0.01346,
 -0.00229,           -0.00895,            42.18049,          -48.21316,
 -148.61588,         -171.57236,         -414.27195,          343.09118,
  394.59044,          511.79914,         -0.00911,           -0.00220,
 -0.06315,           -0.00988,            0.04357,           -0.02389,
  0.00004,            0.00232,            0.00581,           -0.00317,
  0.00948,           -0.00497,           -0.00734,            0.00300,
  0.01883,           -0.01055,           -0.00365,           -0.00126,
  24.18074,           12.28004,           43.18187,          -58.69806,
 -102.40566,         -79.48349,          -74.81060,           89.71332,
  0.00241,           -0.00135,           -0.00136,           -0.01617,
  0.00818,            0.00873,            0.00368,            0.00383,
 -2.25893,            10.18542,           20.73104,           9.07389,
  13.73458,          -29.10491,          -20.62071,          -10.63404,
  0.00382,           -0.00143,           -3.77385,            0.12725,
 -1.30842,            6.75795,            7.94463,            1.79092,
  1.24458,           -4.73211,           -0.36978,           -1.25710,
 -2.06373,            0.06194,           -0.00509,            2.08851,
  1.07491,            0.04112,           -0.28582,           -0.51413,
 -0.53312,            0.11936,            0.04447,            0.23945,
  0.12450,           -0.11821,           -0.06100,           -0.12924,
 -0.05193,            0.02219,            0.01977,           -0.02933,
 -0.00771,           -0.01077,            0.00109,           -0.00273);

ventabl: array[0..283] of double = 
( 9.08078,            55.42416,           21066413644.98911,  655127.20186,
  0.00329,            0.10408,            0.00268,           -0.01908,
  0.00653,            0.00183,            0.15083,           -0.21997,
  6.08596,            2.34841,            3.70668,           -0.22740,
 -2.29376,           -1.46741,           -0.03840,            0.01242,
  0.00176,            0.00913,            0.00121,           -0.01222,
 -1.22624,            0.65264,           -1.15974,           -1.28172,
  1.00656,           -0.66266,            0.01560,           -0.00654,
  0.00896,            0.00069,            0.21649,           -0.01786,
  0.01239,            0.00255,            0.00084,           -0.06086,
 -0.00041,            0.00887,            0.13453,           -0.20013,
  0.08234,            0.01575,            0.00658,           -0.00214,
  0.00254,            0.00857,           -0.01047,           -0.00519,
  0.63215,           -0.40914,            0.34271,           -1.53258,
  0.00038,           -0.01437,           -0.02599,           -2.27805,
 -0.36873,           -1.01799,           -0.36798,            1.41356,
 -0.08167,            0.01368,            0.20676,            0.06807,
  0.02282,           -0.04691,            0.30308,           -0.20218,
  0.24785,            0.27522,            0.00197,           -0.00499,
  1.43909,           -0.46154,            0.93459,            2.99583,
 -3.43274,            0.05672,           -0.06586,            0.12467,
  0.02505,           -0.08433,            0.00743,            0.00174,
 -0.04013,            0.17715,           -0.00603,           -0.01024,
  0.01542,           -0.02378,            0.00676,            0.00002,
 -0.00168,           -4.89487,            0.02393,           -0.03064,
  0.00090,            0.00977,            0.01223,            0.00381,
  0.28135,           -0.09158,            0.18550,            0.58372,
 -0.67437,            0.01409,           -0.25404,           -0.06863,
  0.06763,           -0.02939,           -0.00009,           -0.04888,
  0.01718,           -0.00978,           -0.01945,            0.08847,
 -0.00135,           -11.29920,           0.01689,           -0.04756,
  0.02075,           -0.01667,            0.01397,            0.00443,
 -0.28437,            0.07600,            0.17996,           -0.44326,
  0.29356,            1.41869,           -1.58617,            0.03206,
  0.00229,           -0.00753,           -0.03076,           -2.96766,
  0.00245,            0.00697,            0.01063,           -0.02468,
 -0.00351,           -0.18179,           -0.01088,            0.00380,
  0.00496,            0.02072,           -0.12890,            0.16719,
 -0.06820,           -0.03234,           -60.36135,          -11.74485,
 -11.03752,          -3.80145,           -21.33955,          -284.54495,
 -763.43839,          248.50823,          1493.02775,         1288.79621,
 -2091.10921,        -1851.15420,        -0.00922,            0.06233,
  0.00004,            0.00785,            0.10363,           -0.16770,
  0.45497,            0.24051,           -0.28057,            0.61126,
 -0.02057,            0.00010,            0.00561,            0.01994,
  0.01416,           -0.00442,            0.03073,           -0.14961,
 -0.06272,            0.08301,            0.02040,            7.12824,
 -0.00453,           -0.01815,            0.00004,           -0.00013,
 -0.03593,           -0.18147,            0.20353,           -0.00683,
  0.00003,            0.06226,           -0.00443,            0.00257,
  0.03194,            0.03254,            0.00282,           -0.01401,
  0.00422,            1.03169,           -0.00169,           -0.00591,
 -0.00307,            0.00540,            0.05511,            0.00347,
  0.07896,            0.06583,            0.00783,            0.01926,
  0.03109,            0.15967,            0.00343,            0.88734,
  0.01047,            0.32054,            0.00814,            0.00051,
  0.02474,            0.00047,            0.00052,            0.03763,
 -57.06618,           20.34614,          -45.06541,          -115.20465,
  136.46887,         -84.67046,           92.93308,           160.44644,
 -0.00020,           -0.00082,            0.02496,            0.00279,
  0.00849,            0.00195,           -0.05013,           -0.04331,
 -0.00136,            0.14491,           -0.00183,           -0.00406,
  0.01163,            0.00093,           -0.00604,           -0.00680,
 -0.00036,            0.06861,           -0.00450,           -0.00969,
  0.00171,            0.00979,           -0.00152,            0.03929,
  0.00631,            0.00048,           -0.00709,           -0.00864,
  1.51002,           -0.24657,            1.27338,            2.64699,
 -2.40990,           -0.57413,           -0.00023,            0.03528,
  0.00268,            0.00522,           -0.00010,            0.01933,
 -0.00006,            0.01100,            0.06313,           -0.09939,
  0.08571,            0.03206,           -0.00004,            0.00645);

ventabb: array[0..283] of double = 
(-23.91858,           31.44154,           25.93273,          -67.68643,
 -0.00171,            0.00123,            0.00001,           -0.00018,
 -0.00005,            0.00018,           -0.00001,            0.00019,
  0.00733,            0.00030,           -0.00038,            0.00011,
  0.00181,            0.00120,            0.00010,            0.00002,
 -0.00012,            0.00002,            0.00021,            0.00004,
 -0.00403,            0.00101,            0.00342,           -0.00328,
  0.01564,            0.01212,            0.00011,            0.00010,
 -0.00002,           -0.00004,           -0.00524,            0.00079,
  0.00011,            0.00002,           -0.00001,            0.00003,
  0.00001,            0.00000,            0.00108,            0.00035,
  0.00003,            0.00064,           -0.00000,           -0.00002,
 -0.00069,            0.00031,            0.00020,            0.00003,
  0.00768,            0.03697,           -0.07906,            0.01673,
 -0.00003,           -0.00001,           -0.00198,           -0.01045,
  0.01761,           -0.00803,           -0.00751,            0.04199,
  0.00280,           -0.00213,           -0.00482,           -0.00209,
 -0.01077,            0.00715,            0.00048,           -0.00004,
  0.00199,            0.00237,            0.00017,           -0.00032,
 -0.07513,           -0.00658,           -0.04213,            0.16065,
  0.27661,            0.06515,            0.02156,           -0.08144,
 -0.23994,           -0.05674,            0.00167,            0.00069,
  0.00244,           -0.01247,           -0.00100,            0.00036,
  0.00240,            0.00012,            0.00010,            0.00018,
  0.00208,           -0.00098,           -0.00217,            0.00707,
 -0.00338,            0.01260,           -0.00127,           -0.00039,
 -0.03516,           -0.00544,           -0.01746,            0.08258,
  0.10633,            0.02523,            0.00077,           -0.00214,
 -0.02335,            0.00976,           -0.00019,            0.00003,
  0.00041,            0.00039,            0.00199,           -0.01098,
  0.00813,           -0.00853,            0.02230,            0.00349,
 -0.02250,            0.08119,           -0.00214,           -0.00052,
 -0.00220,            0.15216,            0.17152,            0.08051,
 -0.01561,            0.27727,            0.25837,            0.07021,
 -0.00005,           -0.00000,           -0.02692,           -0.00047,
 -0.00007,           -0.00016,            0.01072,            0.01418,
 -0.00076,            0.00379,           -0.00807,            0.03463,
 -0.05199,            0.06680,           -0.00622,            0.00787,
  0.00672,            0.00453,           -10.69951,          -67.43445,
 -183.55956,         -37.87932,          -102.30497,         -780.40465,
  2572.21990,        -446.97798,          1665.42632,         5698.61327,
 -11889.66501,        2814.93799,         0.03204,           -0.09479,
  0.00014,           -0.00001,           -0.04118,           -0.04562,
  0.03435,           -0.05878,            0.01700,            0.02566,
 -0.00121,            0.00170,            0.02390,            0.00403,
  0.04629,            0.01896,           -0.00521,            0.03215,
 -0.01051,            0.00696,           -0.01332,           -0.08937,
 -0.00469,           -0.00751,            0.00016,           -0.00035,
  0.00492,           -0.03930,           -0.04742,           -0.01013,
  0.00065,            0.00021,           -0.00006,            0.00017,
  0.06768,           -0.01558,           -0.00055,            0.00322,
 -0.00287,           -0.01656,            0.00061,           -0.00041,
  0.00030,            0.00047,           -0.01436,           -0.00148,
  0.30302,           -0.05511,           -0.00020,           -0.00005,
  0.00042,           -0.00025,            0.01270,            0.00458,
 -0.00593,           -0.04480,            0.00005,           -0.00008,
  0.08457,           -0.01569,            0.00062,            0.00018,
  9.79942,           -2.48836,            4.17423,            6.72044,
 -63.33456,           34.63597,           39.11878,          -72.89581,
 -0.00066,            0.00036,           -0.00045,           -0.00062,
 -0.00287,           -0.00118,           -0.21879,            0.03947,
  0.00086,            0.00671,           -0.00113,            0.00122,
 -0.00193,           -0.00029,           -0.03612,            0.00635,
  0.00024,            0.00207,           -0.00273,            0.00443,
 -0.00055,            0.00030,           -0.00451,            0.00175,
 -0.00110,           -0.00015,           -0.02608,            0.00480,
  2.16555,           -0.70419,            1.74648,            0.97514,
 -1.15360,            1.73688,            0.00004,            0.00105,
  0.00187,           -0.00311,            0.00005,            0.00055,
  0.00004,            0.00032,           -0.04629,            0.02292,
 -0.00363,           -0.03807,            0.00002,            0.00020);

ventabr: array[0..283] of double = 
(-0.24459,            3.72698,           -6.67281,            5.24378,
  0.00030,            0.00003,           -0.00002,           -0.00000,
 -0.00000,            0.00001,            0.00032,            0.00021,
 -0.00326,            0.01002,            0.00067,            0.00653,
  0.00243,           -0.00417,           -0.00004,           -0.00010,
 -0.00002,           -0.00001,            0.00004,           -0.00002,
 -0.00638,           -0.01453,            0.01458,           -0.01235,
  0.00755,            0.01030,            0.00006,            0.00014,
  0.00000,            0.00009,            0.00063,            0.00176,
  0.00003,           -0.00022,            0.00112,            0.00001,
 -0.00014,           -0.00001,            0.00485,            0.00322,
 -0.00035,            0.00198,            0.00004,            0.00013,
 -0.00015,           -0.00003,            0.00011,           -0.00025,
  0.00634,            0.02207,            0.04620,            0.00160,
  0.00045,            0.00001,           -0.11563,            0.00643,
 -0.05947,            0.02018,            0.07704,            0.01574,
 -0.00090,           -0.00471,           -0.00322,            0.01104,
  0.00265,           -0.00038,            0.01395,            0.02165,
 -0.01948,            0.01713,           -0.00057,           -0.00019,
  0.04889,            0.13403,           -0.28327,            0.10597,
 -0.02325,           -0.35829,            0.01171,           -0.00904,
  0.00747,            0.02546,            0.00029,           -0.00190,
 -0.03408,           -0.00703,            0.00176,           -0.00109,
  0.00463,            0.00293,            0.00000,            0.00148,
  1.06691,           -0.00054,           -0.00935,           -0.00790,
  0.00552,           -0.00084,           -0.00100,            0.00336,
  0.02874,            0.08604,           -0.17876,            0.05973,
 -0.00720,           -0.21195,            0.02134,           -0.07980,
  0.01500,            0.01398,            0.01758,           -0.00004,
  0.00371,            0.00650,           -0.03375,           -0.00723,
  4.65465,           -0.00040,            0.02040,            0.00707,
 -0.00727,           -0.01144,           -0.00196,            0.00620,
 -0.03396,           -0.12904,            0.20160,            0.08092,
 -0.67045,            0.14014,           -0.01571,           -0.75141,
  0.00361,            0.00110,            1.42165,           -0.01499,
 -0.00334,            0.00117,            0.01187,            0.00507,
  0.08935,           -0.00174,           -0.00211,           -0.00525,
  0.01035,           -0.00252,           -0.08355,           -0.06442,
  0.01616,           -0.03409,            5.55241,           -30.62428,
  2.03824,           -6.26978,            143.07279,         -10.24734,
 -125.25411,         -380.85360,         -644.78411,          745.02852,
  926.70000,         -1045.09820,        -0.03124,           -0.00465,
 -0.00396,            0.00002,            0.08518,            0.05248,
 -0.12178,            0.23023,           -0.30943,           -0.14208,
 -0.00005,           -0.01054,           -0.00894,            0.00233,
 -0.00173,           -0.00768,            0.07881,            0.01633,
 -0.04463,           -0.03347,           -3.92991,            0.00945,
  0.01524,           -0.00422,           -0.00011,           -0.00005,
  0.10842,           -0.02126,            0.00349,            0.12097,
 -0.03752,            0.00001,           -0.00156,           -0.00270,
 -0.01520,            0.01349,            0.00895,            0.00186,
 -0.67751,            0.00180,            0.00516,           -0.00151,
 -0.00365,           -0.00210,           -0.00276,            0.03793,
 -0.02637,            0.03235,           -0.01343,            0.00541,
 -0.11270,            0.02169,           -0.63365,            0.00122,
 -0.24329,            0.00428,           -0.00040,            0.00586,
  0.00581,            0.01112,           -0.02731,            0.00008,
 -2.69091,            0.42729,            2.78805,            3.43849,
 -0.87998,           -6.62373,            0.56882,            4.69370,
  0.00005,           -0.00008,           -0.00181,            0.01767,
 -0.00168,            0.00660,            0.01802,           -0.01836,
 -0.11245,           -0.00061,            0.00199,           -0.00070,
 -0.00076,            0.00919,            0.00311,           -0.00165,
 -0.05650,           -0.00018,            0.00121,           -0.00069,
 -0.00803,            0.00146,           -0.03260,           -0.00072,
 -0.00042,            0.00524,            0.00464,           -0.00339,
 -0.06203,           -0.00278,            0.04145,            0.02871,
 -0.01962,           -0.01362,           -0.03040,           -0.00010,
  0.00085,           -0.00001,           -0.01712,           -0.00006,
 -0.00996,           -0.00003,           -0.00029,            0.00026,
  0.00016,           -0.00005,           -0.00594,           -0.00003);

martabl: array[0..676] of double = 
( 43471.66140,        21291.11063,        2033.37848,         6890507597.78366,
  1279543.73631,      317.74183,          730.69258,         -15.26502,
  277.56960,         -62.96711,           20.96285,           1.01857,
 -2.19395,            3.75708,            3.65854,            0.01049,
  1.09183,           -0.00605,           -0.04769,            0.41839,
  0.10091,            0.03887,            0.11666,           -0.03301,
  0.02664,            0.38777,           -0.56974,            0.02974,
 -0.15041,            0.02179,           -0.00808,            0.08594,
  0.09773,           -0.00902,           -0.04597,            0.00762,
 -0.03858,           -0.00139,            0.01562,            0.02019,
  0.01878,           -0.01244,            0.00795,            0.00815,
  0.03501,           -0.00335,           -0.02970,           -0.00518,
 -0.01763,            0.17257,            0.14698,           -0.14417,
  0.26028,            0.00062,           -0.00180,            13.35262,
  39.38771,          -15.49558,           22.00150,          -7.71321,
 -4.20035,            0.62074,           -1.42376,            0.07043,
 -0.06670,            0.16960,           -0.06859,            0.07787,
  0.01845,           -0.01608,           -0.00914,            5.60438,
 -3.44436,            5.88876,            6.77238,           -5.29704,
  3.48944,            0.01291,            0.01280,           -0.53532,
  0.86584,            0.79604,            0.31635,           -3.92977,
 -0.94829,           -0.74254,           -1.37947,            0.17871,
 -0.12477,            0.00171,            0.11537,            0.02281,
 -0.03922,           -0.00165,            0.02965,            1.59773,
  1.24565,           -0.35802,            1.37272,           -0.44811,
 -0.08611,            3.04184,           -3.39729,            8.86270,
  6.65967,           -9.10580,            10.66103,           0.02015,
 -0.00902,           -0.01166,           -0.23957,           -0.12128,
 -0.04640,           -0.07114,            0.14053,           -0.04966,
 -0.01665,            0.28411,           -0.37754,           -1.26265,
  1.01377,            3.70433,           -0.21025,           -0.00972,
  0.00350,            0.00997,            0.00450,           -2.15305,
  3.18147,           -1.81957,           -0.02321,           -0.02560,
 -0.35188,            0.00003,           -0.01110,            0.00244,
 -0.05083,           -0.00216,           -0.02026,            0.05179,
  0.04188,            5.92031,           -1.61316,            3.72001,
  6.98783,           -4.17690,            2.61250,            0.04157,
  2.76453,           -1.34043,            0.74586,           -0.20258,
 -0.30467,            0.00733,            0.00376,            1.72800,
  0.76593,            1.26577,           -2.02682,           -1.14637,
 -0.91894,           -0.00002,            0.00036,            2.54213,
  0.89533,           -0.04166,            2.36838,           -0.97069,
  0.05486,            0.46927,            0.04500,            0.23388,
  0.35005,            1.61402,            2.30209,           -0.99859,
  1.63349,           -0.51490,           -0.26112,            0.27848,
 -0.26100,           -0.07645,           -0.22001,            0.92901,
  1.12627,           -0.39829,            0.77120,           -0.23716,
 -0.11245,           -0.02387,            0.03960,           -0.00802,
  0.02179,            2.86448,            1.00246,           -0.14647,
  2.80278,           -1.14143,            0.05177,            1.68671,
 -1.23451,            3.16285,            0.70070,            0.25817,
  3.17416,            0.07447,           -0.08116,           -0.03029,
 -0.02795,            0.00816,            0.01023,            0.00685,
 -0.01075,           -0.34268,            0.03680,           -0.05488,
 -0.07430,           -0.00041,           -0.02968,            3.13228,
 -0.83209,            1.95765,            3.78394,           -2.26196,
  1.38520,           -0.00401,           -0.01397,            1.01604,
 -0.99485,            0.62465,            0.22431,           -0.05076,
  0.12025,            4.35229,           -5.04483,            14.87533,
  9.00826,           -10.37595,           19.26596,           0.40352,
  0.19895,            0.09463,           -0.10774,           -0.17809,
 -0.08979,           -0.00796,           -0.04313,            0.01520,
 -0.03538,            1.53301,           -1.75553,            4.87236,
  3.23662,           -3.62305,            6.42351,           -0.00439,
 -0.01305,            0.17194,           -0.64003,            0.26609,
  0.06600,            0.01767,           -0.00251,           -0.08871,
 -0.15523,            0.01201,           -0.03408,           -0.29126,
 -0.07093,           -0.00998,           -0.07876,            1.05932,
 -25.38650,          -0.29354,            0.04179,           -0.01726,
  0.07473,           -0.07607,           -0.08859,            0.00842,
 -0.02359,            0.47858,           -0.39809,            1.25061,
  0.87017,           -0.82453,            1.56864,           -0.00463,
  0.02385,           -0.29070,            8.56535,           -0.12495,
  0.06580,           -0.03395,           -0.02465,           -1.06759,
  0.47004,           -0.40281,           -0.23957,            0.03572,
 -0.07012,            0.00571,           -0.00731,            0.18601,
 -1.34068,            0.03798,           -0.00532,            0.00448,
 -0.01147,            1.41208,           -0.00668,            0.25883,
  1.23788,           -0.57774,            0.09166,           -2.49664,
 -0.25235,           -0.53582,           -0.80126,            0.10827,
 -0.08861,           -0.03577,            0.06825,           -0.00143,
  0.04633,            0.01586,           -0.01056,           -0.02106,
  0.03804,           -0.00088,           -0.03458,           -0.00033,
 -0.01079,            0.05821,           -0.02445,            0.00602,
  0.00721,           -0.00315,           -0.01021,           -0.65454,
  1.08478,           -0.44593,           -0.21492,           -1.35004,
  4.47299,           -4.19170,            3.51236,            1946.04629,
  13960.88247,        576.24572,          8023.81797,         2402.48512,
 -753.87007,         -6376.99217,        -10278.88014,       -25743.89874,
  15506.87748,        15609.59853,        35173.63133,       -3.70370,
  6.29538,           -4.84183,           -0.76942,           -0.02465,
 -0.03840,            0.00565,           -0.06071,            0.01174,
  0.00253,           -0.00230,            0.05252,           -0.02813,
  0.01359,            0.23208,            0.03393,            0.01734,
  0.04838,           -0.46340,           -0.18941,            0.25428,
 -0.56925,            0.05213,            0.24704,            0.12922,
 -0.01531,            0.06885,           -0.08510,            0.01853,
 -0.00390,            0.01196,           -0.30530,            0.13117,
 -0.03533,            1.79597,           -0.42743,            0.98545,
  2.13503,           -1.32942,            0.68005,           -0.01226,
  0.00571,            0.31081,            0.34932,            0.34531,
 -0.32947,           -0.00548,            0.00186,           -0.00157,
 -0.00065,            0.30877,           -0.03864,            0.04921,
  0.06693,            0.01761,           -0.04119,            1.28318,
  0.38546,            0.06462,            1.18337,           -0.48698,
  0.07086,            0.26031,           -0.22813,            0.10272,
  0.04737,           -0.04506,           -0.38581,           -0.16624,
 -0.04588,            0.00992,            0.00722,           -0.21041,
  0.20560,           -0.09267,           -0.03438,            0.32264,
 -0.07383,            0.09553,           -0.38730,            0.17109,
 -0.01342,           -0.02336,           -0.01286,            0.00230,
  0.04626,            0.01176,            0.01868,           -0.15411,
 -0.32799,            0.22083,           -0.14077,            1.98392,
  1.68058,           -0.02526,           -0.13164,           -0.04447,
 -0.00153,            0.01277,            0.00553,           -0.26035,
 -0.11362,            0.14672,           -0.32242,            0.16686,
 -0.69957,            0.40091,           -0.06721,            0.00837,
  0.09635,           -0.08545,            0.25178,           -0.22486,
  16.03256,           0.34130,           -0.06313,            0.01469,
 -0.09012,           -0.00744,           -0.02510,           -0.08492,
 -0.13733,           -0.07620,           -0.15329,            0.13716,
 -0.03769,            2.01176,           -1.35991,           -1.04319,
 -2.97226,           -0.01433,            0.61219,           -0.55522,
  0.38579,            0.31831,            0.81843,           -0.04583,
 -0.14585,           -0.10218,            0.16039,           -0.06552,
 -0.01802,            0.06480,           -0.06641,            0.01672,
 -0.00287,            0.00308,            0.09982,           -0.05679,
 -0.00249,           -0.36034,            0.52385,           -0.29759,
  0.59539,           -3.59641,           -1.02499,           -547.53774,
  734.11470,          441.86760,         -626.68255,         -2255.81376,
 -1309.01028,        -2025.69590,         2774.69901,         1711.21478,
  1509.99797,        -0.99274,            0.61858,           -0.47634,
 -0.33034,            0.00261,            0.01183,           -0.00038,
  0.11687,            0.00994,           -0.01122,            0.03482,
 -0.01942,           -0.11557,            0.38237,           -0.17826,
  0.00830,            0.01193,           -0.05469,            0.01557,
  0.01747,            0.02730,           -0.01182,           -0.11284,
  0.12939,           -0.05621,           -0.01615,            0.04258,
  0.01058,           -0.01723,            0.00963,            0.20666,
  0.11742,            0.07830,           -0.02922,           -0.10659,
 -0.05407,            0.07254,           -0.13005,           -0.02365,
  0.24583,            0.31915,            1.27060,            0.00009,
 -0.21541,           -0.55324,           -0.45999,           -1.45885,
  0.86530,            0.85932,            1.92999,           -0.00755,
 -0.00715,           -0.02004,           -0.00788,            0.01539,
  0.00837,            0.27652,           -0.50297,           -0.26703,
 -0.28159,            0.03950,            0.07182,           -0.07177,
  0.14140,            0.07693,            0.07564,           -0.01316,
 -0.01259,            0.01529,            0.07773,           -90.74225,
 -378.15784,         -510.30190,         -52.35396,          -89.15267,
  415.56828,          181.52119,          54.01570,          -0.01093,
 -0.05931,           -0.01344,           -0.02390,            0.01432,
 -0.02470,           -0.01509,           -0.01346,            0.03352,
  0.02248,            0.02588,           -0.00948,            0.03610,
  0.17238,            0.02909,           -0.04065,            0.00155,
 -0.07025,           -0.09508,            0.14487,            0.12441,
  0.16451,            0.00001,           -0.00005,           -0.00982,
 -0.01895,           -0.16968,            0.36565,            0.20234,
  0.17789,           -0.04519,           -0.00588,            0.01268,
  0.00107,           -56.32137,          -58.22145,          -80.55270,
  28.14532,           11.43301,           52.05752,           17.79480,
 -2.61997,           -0.00005,           -0.02629,            0.01080,
 -0.00390,            0.00744,            0.03132,            0.01156,
 -0.01621,            0.02162,            0.02552,            0.00075,
 -0.02497,            0.02495,            0.00830,            0.03230,
  0.00103,           -14.84965,          -4.50200,           -9.73043,
  9.40426,            4.08054,            5.38571,            1.53731,
 -1.01288,            0.21076,            1.74227,            0.79760,
  0.39583,            0.09879,           -0.16736,           -0.00723,
-0.01536);

martabb: array[0..676] of double = 
(-364.49380,         -47.17612,          -554.97858,         -430.63121,
  596.44312,         -3.94434,           -7.43169,           -0.06665,
 -2.23987,            0.10366,           -0.05567,           -0.01463,
  0.01908,           -0.02611,           -0.00350,           -0.01057,
 -0.00610,           -0.00015,            0.00002,            0.00010,
  0.00033,            0.00007,           -0.00000,           -0.00010,
 -0.00004,            0.00012,            0.00002,           -0.00014,
 -0.00048,           -0.00003,           -0.00007,            0.00008,
 -0.00005,           -0.00043,           -0.00003,           -0.00010,
 -0.00004,            0.00001,            0.00001,           -0.00003,
 -0.00003,            0.00004,            0.00007,           -0.00041,
  0.00031,            0.00076,            0.00062,            0.00001,
 -0.00002,            0.00035,            0.00053,            0.00026,
  0.00019,            0.00020,            0.00010,            0.02936,
  0.09624,           -0.01153,            0.01386,            0.00551,
 -0.00690,            0.00196,            0.00148,           -0.00408,
 -0.00673,           -0.00067,           -0.00152,           -0.00014,
 -0.00005,            0.00000,            0.00005,           -0.00116,
  0.00276,           -0.00391,            0.00983,           -0.01327,
 -0.01986,           -0.00003,            0.00001,            0.01104,
  0.00631,           -0.01364,            0.01152,           -0.00439,
  0.01103,           -0.00546,            0.00181,           -0.00039,
 -0.00083,            0.00007,            0.00002,           -0.00010,
 -0.00008,            0.00005,            0.00002,           -0.00584,
  0.00512,           -0.00722,           -0.00174,            0.00101,
 -0.00316,           -0.02229,           -0.02797,           -0.10718,
  0.05741,            0.11403,            0.10033,            0.00036,
 -0.00022,            0.00787,            0.01191,            0.01756,
 -0.02121,           -0.00169,           -0.00364,            0.00070,
 -0.00051,            0.01850,           -0.06836,            0.21471,
  0.00162,           -0.29165,            0.16799,           -0.00002,
  0.00011,           -0.00075,           -0.00077,           -0.00675,
 -0.00814,            0.00029,           -0.00599,            0.00107,
  0.00013,            0.00010,           -0.00002,            0.00005,
  0.00020,            0.00355,            0.00306,           -0.00013,
 -0.00061,           -0.02950,           -0.00847,            0.01037,
 -0.04783,            0.04237,            0.11662,           -0.00331,
  0.00207,           -0.00107,           -0.00264,            0.00072,
 -0.00023,           -0.00151,            0.00146,           -0.12847,
  0.02294,            0.03611,            0.19705,            0.16855,
 -0.28279,           -0.00000,           -0.00002,           -0.00525,
 -0.03619,            0.05048,           -0.00481,           -0.00745,
  0.04618,            0.00286,            0.00443,            0.00521,
 -0.00351,            0.00200,            0.00474,           -0.00149,
  0.00031,           -0.00003,            0.00029,            0.00686,
  0.02467,            0.04275,           -0.02223,            0.02282,
 -0.04228,            0.03312,            0.01847,           -0.01253,
  0.01601,            0.00076,            0.00091,            0.00045,
  0.00035,            0.00658,            0.01586,           -0.00310,
  0.00628,           -0.00045,            0.00316,           -0.01602,
 -0.00340,           -0.01744,            0.04907,            0.06426,
  0.02275,           -0.00217,           -0.00377,           -0.00091,
  0.00037,            0.00040,           -0.00003,           -0.00017,
 -0.00027,            0.00366,            0.02693,           -0.00934,
  0.00386,            0.00616,           -0.00037,            0.02028,
  0.02120,           -0.01768,            0.02421,            0.00102,
  0.00877,            0.00012,            0.00030,           -0.00019,
 -0.02165,            0.01245,           -0.00742,            0.00172,
  0.00320,           -0.17117,           -0.12908,           -0.43134,
  0.15617,            0.21216,            0.56432,            0.01139,
 -0.00937,           -0.00058,           -0.00337,           -0.00999,
  0.01862,           -0.00621,           -0.00080,           -0.00025,
 -0.00140,            0.09250,            0.01173,           -0.03549,
  0.14651,           -0.01784,            0.00945,            0.00000,
 -0.00006,           -0.00500,            0.00086,            0.01079,
 -0.00002,           -0.00012,           -0.00029,           -0.02661,
  0.00140,           -0.00524,           -0.00460,           -0.00352,
 -0.00563,           -0.00277,           -0.00052,           -0.10171,
 -0.02001,            0.00045,            0.00265,           -0.00082,
  0.00160,           -0.00302,           -0.00434,           -0.00022,
 -0.00134,            0.03285,            0.02964,           -0.05612,
 -0.00668,           -0.01821,            0.06590,            0.00039,
  0.00061,           -0.13531,           -0.03831,            0.02553,
  0.02130,           -0.00336,            0.00468,           -0.04522,
 -0.05540,            0.00129,           -0.01767,            0.00181,
  0.00031,           -0.00011,           -0.00034,           -0.00146,
  0.01101,           -0.00030,            0.00240,           -0.00039,
  0.00072,           -0.01954,           -0.03822,            0.09682,
 -0.04541,           -0.01567,            0.09617,           -0.03371,
  0.33028,           -0.12102,            0.05874,           -0.00990,
 -0.02236,            0.00109,            0.00158,           -0.00482,
  0.00019,           -0.00036,            0.00004,            0.00024,
  0.00201,            0.00017,            0.00011,           -0.00012,
  0.00002,           -0.00323,           -0.01062,           -0.00130,
  0.00091,            0.00056,           -0.00017,            0.00774,
  0.00601,            0.02550,            0.01700,           -0.84327,
  0.77533,           -0.71414,           -0.50643,           -473.30877,
 -1504.79179,        -458.52274,         -865.82237,         -417.34994,
 -681.03976,          765.50697,         -1653.67165,         4427.33176,
  710.53895,         -5016.39367,         4280.60361,         0.33957,
  0.38390,           -0.38631,            0.81193,            0.00154,
 -0.00043,            0.01103,           -0.00017,           -0.00046,
  0.00221,            0.00059,            0.00014,            0.00160,
  0.00475,            0.06191,           -0.13289,            0.02884,
 -0.00566,           -0.01572,            0.23780,           -0.05140,
 -0.03228,           -0.00716,           -0.00978,           -0.01048,
  0.01317,           -0.01267,           -0.01198,            0.00037,
 -0.00330,           -0.02305,            0.00355,           -0.00121,
 -0.00496,           -0.04369,           -0.01343,            0.05347,
 -0.12433,            0.02090,            0.17683,            0.00028,
 -0.00490,           -0.02778,           -0.05587,           -0.01658,
  0.05655,            0.00204,           -0.00092,            0.00020,
  0.00014,           -0.00603,           -0.03829,            0.00778,
 -0.00588,           -0.00266,            0.00097,           -0.02158,
 -0.07742,            0.09306,           -0.01827,           -0.01048,
  0.07885,           -0.02485,           -0.02505,            0.00471,
 -0.01026,            0.06663,            0.01110,            0.00469,
 -0.05347,           -0.00016,           -0.00013,            0.02622,
  0.02273,           -0.01009,            0.01391,           -0.01042,
 -0.00444,           -0.04293,           -0.00767,           -0.00154,
 -0.01739,            0.00353,           -0.00763,           -0.00060,
  0.00010,           -0.00053,           -0.00146,           -0.05317,
  0.05760,           -0.01801,           -0.02099,           -0.02611,
 -0.01836,           -0.00256,            0.00812,           -0.00145,
  0.00054,           -0.00008,            0.00015,           -0.04087,
  0.08860,           -0.05385,           -0.02134,            0.02771,
  0.02441,           -0.00234,            0.01571,           -0.00260,
  0.00097,            0.10151,            0.49378,           -0.28555,
  0.11428,           -0.00286,            0.01224,            0.00160,
  0.00069,            0.00000,           -0.00040,           -0.13286,
  0.00448,            0.01225,           -0.00568,            0.00341,
  0.00224,           -0.23483,           -0.07859,            0.30733,
 -0.21548,           -0.02608,            0.00756,            0.09789,
  0.02878,           -0.11968,            0.08981,            0.02046,
 -0.00888,            0.02955,            0.01486,           -0.00981,
  0.01542,           -0.01674,           -0.01540,            0.00019,
 -0.00449,           -0.02140,            0.00638,            0.00112,
 -0.00730,           -0.08571,            0.13811,           -0.16951,
 -0.02917,           -0.03931,           -0.32643,           -68.64541,
 -81.00521,          -47.97737,           15.75290,           181.76392,
 -36.00647,          -48.32098,          -259.02226,         -265.57466,
  554.05904,          0.09017,            0.18803,           -0.12459,
  0.10852,            0.00211,            0.00002,            0.00304,
 -0.00370,            0.00174,            0.00279,            0.00139,
  0.00095,            0.04881,            0.00262,           -0.01020,
  0.03762,            0.00987,            0.00612,            0.00054,
 -0.00036,            0.00009,           -0.00094,            0.02279,
  0.01785,           -0.00778,            0.01263,            0.00040,
 -0.00112,           -0.00452,           -0.00662,            0.00483,
 -0.00030,           -0.00054,           -0.00205,           -0.00052,
 -0.00362,           -0.00215,           -0.00247,            0.02893,
 -0.01965,           -0.00004,            0.04114,           -0.00284,
 -0.00103,            0.01827,           -0.07822,            0.18010,
  0.04805,           -0.21702,            0.18808,            0.00095,
 -0.00132,           -0.01488,            0.00746,            0.00198,
  0.00190,            0.01032,            0.03392,            0.04318,
 -0.07332,           -0.01004,            0.00787,           -0.00308,
 -0.01177,           -0.01431,            0.02659,            0.00273,
 -0.00374,           -0.02545,            0.00644,            28.68376,
  13.74978,           29.60401,          -47.98255,          -65.91944,
 -18.48404,          -1.73580,            64.67487,          -0.02492,
  0.00104,           -0.00829,           -0.00134,            0.00077,
  0.00005,           -0.00513,            0.00403,            0.00071,
 -0.00047,           -0.00023,           -0.00063,            0.00120,
  0.00370,           -0.00038,           -0.00037,            0.00080,
 -0.00018,            0.00866,            0.00156,           -0.01064,
  0.02131,            0.00000,           -0.00001,            0.00038,
 -0.00068,           -0.00909,           -0.02187,           -0.02599,
  0.05507,           -0.00022,           -0.01468,            0.00032,
  0.00500,            9.86233,           -2.85314,           -2.25791,
 -13.83444,          -12.38794,           3.79861,            2.76343,
  6.63505,            0.00066,            0.00007,           -0.00016,
 -0.00039,            0.00014,            0.00059,           -0.00031,
 -0.00024,           -0.00168,            0.00259,            0.00007,
 -0.00005,           -0.00052,            0.00558,            0.00110,
  0.01037,            1.59224,           -2.37284,           -2.00023,
 -2.28280,           -1.49571,            1.48293,            0.60041,
  0.56376,           -0.54386,            0.03568,           -0.10392,
  0.31005,            0.09104,            0.03015,            0.00826,
-0.00524);

martabr: array[0..676] of double = 
(-816.07287,         -381.41365,         -33.69436,           177.22955,
  0.18630,           -8.29605,           -11.15519,          -0.57407,
 -3.53642,            0.16663,           -0.06334,           -0.03056,
  0.02767,           -0.04161,            0.03917,           -0.02425,
  0.00204,           -0.00034,            0.00023,            0.00058,
 -0.00111,            0.00039,           -0.00015,            0.00006,
 -0.00023,            0.00237,            0.00191,            0.00154,
 -0.00029,            0.00009,            0.00011,           -0.00041,
  0.00037,           -0.00010,           -0.00064,            0.00015,
 -0.00005,            0.00012,           -0.00003,           -0.00034,
  0.00026,            0.00011,           -0.00007,           -0.00158,
  0.00087,            0.00278,            0.00137,            0.00024,
 -0.00020,            0.00530,           -0.00448,            0.00780,
  0.00408,            0.00062,            0.00035,           -1.35261,
  0.79891,           -0.81597,           -0.43774,            0.14713,
 -0.27415,            0.05298,            0.02230,           -0.02089,
 -0.01070,           -0.00374,            0.00342,           -0.00142,
  0.00270,           -0.00039,            0.00063,            0.16024,
  0.27088,           -0.32127,            0.27467,           -0.16615,
 -0.24460,           -0.00073,            0.00032,           -0.05710,
 -0.05265,           -0.06025,            0.05120,           -0.05295,
  0.23477,           -0.08211,            0.04575,           -0.00769,
 -0.01067,           -0.00570,            0.00015,           -0.00251,
 -0.00140,           -0.00131,           -0.00018,           -0.12246,
  0.15836,           -0.13065,           -0.03222,            0.00795,
 -0.04232,           -0.36585,           -0.31154,            0.68504,
 -0.96006,            1.19304,            0.88631,            0.00132,
  0.00046,            0.13105,            0.04252,            0.05164,
 -0.06837,           -0.01351,           -0.01458,            0.00376,
 -0.00557,            0.28532,           -0.17290,           -0.53946,
 -0.79365,           -0.95246,            0.74984,            0.00019,
  0.00132,           -0.00163,           -0.00295,           -0.40106,
 -0.26573,           -0.00155,           -0.22655,            0.04349,
 -0.00376,            0.00149,           -0.00001,            0.00523,
  0.00078,            0.01203,            0.00558,           -0.00708,
  0.00520,           -0.36428,           -1.28827,            1.50845,
 -0.83063,            0.58802,            0.89998,           -0.55256,
  0.01255,           -0.15169,           -0.26715,            0.06061,
 -0.04122,           -0.00397,            0.00534,           -0.52576,
  1.22031,            1.44098,            0.92406,            0.67214,
 -0.85486,           -0.00010,            0.00001,            0.28820,
 -0.84198,            0.78291,            0.00251,            0.02398,
  0.32093,           -0.02331,            0.10109,           -0.07555,
  0.03557,           -0.61580,            0.43399,           -0.43779,
 -0.26390,            0.06885,           -0.13803,            0.17694,
  0.19245,            0.15119,           -0.05100,            0.49469,
 -0.45028,            0.33590,            0.15677,           -0.04702,
  0.10265,           -0.00942,           -0.00580,           -0.00555,
 -0.00252,           -0.32933,            0.92539,           -0.91004,
 -0.04490,           -0.01812,           -0.37121,            0.34695,
  0.50855,           -0.24721,            0.86063,           -0.84747,
  0.01983,            0.01948,            0.02039,            0.00748,
 -0.00727,           -0.00271,            0.00220,            0.00309,
  0.00196,            0.02030,            0.17201,           -0.03716,
  0.02801,            0.01871,            0.00002,            0.31736,
  1.17319,           -1.42245,            0.73416,           -0.52302,
 -0.85056,            0.00522,           -0.00126,            0.33571,
  0.34594,           -0.07709,            0.21114,           -0.04066,
 -0.01742,            1.72228,            1.46934,           -3.06437,
  5.06723,           -6.53800,           -3.55839,           -0.06933,
  0.13815,            0.03684,            0.03284,           -0.04841,
  0.09571,           -0.02350,            0.00418,            0.01302,
  0.00579,            0.73408,            0.64718,           -1.37437,
  2.04816,           -2.70756,           -1.52808,            0.00523,
 -0.00166,            0.25915,            0.06900,           -0.02758,
  0.10707,            0.00062,            0.00744,           -0.08117,
  0.04840,           -0.01806,           -0.00637,            0.03034,
 -0.12414,            0.03419,           -0.00388,            10.92603,
  0.48169,           -0.01753,           -0.12853,           -0.03207,
 -0.00801,            0.03904,           -0.03326,            0.01033,
  0.00366,            0.17249,            0.20846,           -0.38157,
  0.54639,           -0.68518,           -0.36121,           -0.01043,
 -0.00186,           -3.33843,           -0.16353,            0.03462,
  0.06669,           -0.01305,            0.01803,           -0.22703,
 -0.52219,            0.11709,           -0.19628,            0.03410,
  0.01741,            0.00338,            0.00265,            0.63213,
  0.08944,            0.00236,            0.01829,            0.00546,
  0.00218,            0.00073,           -0.72570,            0.63698,
 -0.13340,            0.04698,            0.29716,           -0.13126,
  1.27705,           -0.40980,            0.27400,           -0.04525,
 -0.05529,           -0.03249,           -0.01696,           -0.02314,
 -0.00076,            0.00510,            0.00764,           -0.01847,
 -0.01021,            0.01688,           -0.00044,            0.00531,
 -0.00016,           -0.01219,           -0.02903,           -0.00361,
  0.00299,            0.00504,           -0.00153,           -0.53625,
 -0.32460,            0.10642,           -0.22070,           -2.21651,
 -0.66036,           -1.74652,           -2.08198,           -6810.78679,
  967.02869,         -3915.97140,         291.65905,          372.99563,
  1196.01966,         5108.01033,        -3172.64698,        -7685.78246,
 -12789.43898,       -17474.50562,        7757.84703,         3.13224,
  1.84743,           -0.38257,            2.40590,            0.01860,
 -0.01217,            0.03004,            0.00278,           -0.00125,
  0.00579,           -0.02673,           -0.00112,            0.00662,
  0.01374,           -0.02729,            0.13109,           -0.02836,
  0.00877,            0.12171,           -0.27475,            0.34765,
  0.15882,           -0.12548,            0.02603,            0.00710,
  0.06538,           -0.04039,           -0.03257,           -0.00186,
 -0.00880,            0.16643,            0.00707,            0.01918,
  0.07156,           -0.20459,           -0.85107,            1.01832,
 -0.47158,            0.32582,            0.63002,           -0.00282,
 -0.00711,           -0.19695,            0.15053,            0.15676,
  0.17847,            0.00071,            0.00286,           -0.00039,
  0.00083,            0.02009,            0.17859,           -0.03894,
  0.02805,            0.02379,            0.00752,            0.17529,
 -0.57783,            0.53257,           -0.02829,            0.03211,
  0.21777,            0.13813,            0.16305,           -0.02996,
  0.06303,            0.21058,           -0.02659,            0.02596,
 -0.08808,           -0.00389,            0.00586,            0.08986,
  0.09204,           -0.01480,            0.04031,            0.06115,
  0.18366,            0.25636,            0.06905,            0.00719,
  0.11391,            0.00636,           -0.01113,           -0.02808,
  0.00150,           -0.01219,            0.00832,            0.28626,
 -0.09573,            0.10481,            0.16559,           -0.94578,
  1.26394,            0.08846,           -0.01623,            0.00082,
 -0.02640,           -0.00347,            0.00798,            0.12873,
 -0.21248,            0.27999,            0.14348,            0.44082,
  0.10453,            0.04362,            0.25332,           -0.06077,
  0.00555,           -0.06947,           -0.05511,           -10.08703,
 -0.10614,            0.04059,            0.21355,            0.05632,
  0.00871,            0.01599,           -0.00531,            0.36835,
 -0.03530,            0.09519,           -0.04961,            0.02568,
  0.08613,            0.57033,            0.84599,            1.27123,
 -0.41266,           -0.36937,           -0.00655,           -0.16547,
 -0.24000,           -0.35213,            0.13345,            0.05870,
 -0.01524,            0.06419,            0.04136,           -0.00681,
  0.02606,           -0.02519,           -0.02732,           -0.00105,
 -0.00677,           -0.03891,            0.00106,            0.00087,
 -0.02256,           -0.20834,           -0.14624,           -0.23178,
 -0.11786,            0.32479,           -1.41222,           -303.74549,
 -202.79324,          260.20290,          184.84320,          536.68016,
 -881.56427,         -1125.64824,        -791.09928,         -596.61162,
  659.35664,          0.24561,            0.39519,           -0.12601,
  0.18709,           -0.00700,            0.00136,            0.30750,
  0.00009,            0.00443,            0.00384,            0.01170,
  0.02078,            0.15043,            0.04802,            0.00386,
  0.06942,            0.02107,            0.00495,           -0.01067,
  0.00951,            0.00937,            0.01996,            0.04922,
  0.04337,           -0.00583,            0.02110,           -0.00691,
  0.02793,           -0.00364,           -0.00682,           -0.09143,
  0.15369,            0.02043,            0.05451,            0.04053,
 -0.08179,            0.09645,            0.05330,           -0.10149,
 -0.01594,           -0.96773,            0.13660,            0.17326,
  0.00013,            0.20990,           -0.23184,           -0.38407,
 -0.64733,           -0.84754,            0.38889,            0.00310,
 -0.00340,            0.00970,           -0.00788,           -0.01111,
  0.00677,            0.18147,            0.09968,            0.10170,
 -0.09233,           -0.03165,            0.01790,           -0.04727,
 -0.02364,           -0.02546,            0.02451,            0.00442,
 -0.00426,           -0.02540,            0.00471,            130.42585,
 -31.30051,           17.99957,          -174.75585,         -142.96798,
 -27.89752,          -19.42122,           59.14872,          -0.01899,
  0.00388,           -0.01265,            0.00694,            0.01966,
  0.01140,           -0.00439,            0.00503,           -0.01867,
  0.02826,            0.00752,            0.02012,           -0.14734,
  0.01909,            0.03312,            0.02327,            0.05843,
  0.00061,           -0.06958,           -0.05798,           -0.09174,
  0.06242,            0.00003,            0.00001,            0.00670,
 -0.00305,           -0.13637,           -0.06058,           -0.06372,
  0.07257,            0.00209,           -0.01369,           -0.00044,
  0.00355,            17.90079,          -17.48270,          -8.77915,
 -24.54483,          -15.67123,           3.62668,            0.52038,
  5.13220,            0.02574,            0.00003,            0.00339,
  0.00919,           -0.02778,            0.00464,            0.01429,
  0.01003,           -0.01661,            0.01327,            0.02216,
  0.00034,           -0.00389,            0.01076,           -0.00035,
  0.00983,            1.23731,           -4.18017,           -2.61932,
 -2.66346,           -1.45540,            1.10310,            0.23322,
  0.40775,           -0.43623,            0.06212,           -0.09900,
  0.19456,            0.03639,            0.02566,            0.00309,
-0.00116);

juptabl: array[0..594] of double = 
( 153429.13855,       130818.16897,       18120.42948,       -8463.12663,
 -5058.91447,         1092566021.02148,   123671.25097,      -5.43364,
  12.06012,           30428.31077,       -74667.61443,        46848.16236,
 -66373.44474,        24312.54264,       -26045.64766,        18353.92564,
 -4022.13679,         4037.97936,         10059.82468,       -4622.55896,
  1383.21617,        -187.25468,         -1171.66028,        -0.00062,
 -0.21713,           -1198.83945,         1178.62445,        -1492.07393,
  153.07155,         -245.57966,         -391.94010,          82.26400,
 -40.92104,           3.72520,            10.57242,          -0.04720,
 -0.04448,           -0.04329,           -0.06043,           -0.03905,
  0.15712,           -0.05644,           -0.00129,           -0.00342,
  0.02473,            0.00434,           -0.01862,            0.00431,
 -0.03993,           -0.03159,           -0.15982,           -0.09928,
  0.04430,           -0.00357,            0.31312,           -0.01346,
 -0.00180,           -0.09107,            0.01215,            0.02485,
  0.01024,            27.29869,           2.70896,            12.91956,
  19.21726,          -6.91384,            5.12954,           -1.07533,
 -1.71691,           -0.01423,            0.03121,           -32.48652,
 -26.13483,           46.78162,          -62.02701,           94.96809,
  81.73791,          -20.13673,           131.05065,         -0.00798,
  0.01786,            13.99591,           16.87756,          -8.51726,
  21.59490,          -14.28833,          -9.45530,            7.73954,
 -6.53078,            0.03175,           -0.04295,            3.06742,
 -0.11838,            1.03630,            0.94004,           -0.14085,
  0.14434,           -0.03363,            0.00993,           -0.00007,
 -0.02748,            26.01507,          -7.37178,            16.96955,
  6.24203,           -0.40481,            3.72456,           -0.53597,
 -0.14938,            37.82081,           26.15887,          -2.82115,
  78.26478,          -63.39155,          -5.52419,            13.11482,
 -43.54977,           15.64940,           6.67505,           -10.25616,
 -7.39672,           -12.37441,           12.24417,           8.54922,
  9.68451,           -0.03658,           -0.00963,            1.65523,
  0.43093,            0.32023,            0.71365,           -0.12226,
  0.03759,            0.10388,            0.47212,           -0.02791,
  0.09929,           -0.04116,           -0.03125,           -0.10240,
 -0.23199,           -0.03524,           -0.13625,            7.52726,
  6.86314,            0.01239,            13.46530,          -5.22256,
  1.56116,           -0.15925,           -1.19571,            3.26302,
  0.06097,           -0.14444,           -0.20301,            1.93822,
 -80.12566,           0.98665,           -7.52986,            3.86703,
 -2.43028,            0.64180,            0.78351,            0.00190,
 -0.00633,           -0.00321,           -0.04403,            0.19018,
  0.14335,            0.10315,            0.53154,           -0.00062,
 -0.00464,           -0.00109,            0.02150,            1.19993,
  47.21638,          -24.56067,           25.06332,          -7.50751,
 -6.36250,            1.39443,           -1.23806,            0.04951,
  0.02176,            0.02802,           -0.01665,           -0.10698,
 -0.13635,            73.54797,          -52.34968,           74.98754,
  86.56283,          -69.01463,           44.56866,           0.04387,
 -0.05925,           -0.03732,           -0.03264,            0.00967,
  0.02143,            10.59429,           26.48226,           34.03470,
  3.96160,            4.15919,           -20.22616,          -5.25903,
 -3.40177,            0.05111,           -0.06788,            0.06497,
  1.21024,           -0.29607,            0.49991,           -0.06055,
 -0.03464,            0.02950,            0.16429,            0.00722,
 -0.90806,           -0.02161,            0.00902,           -0.00261,
  0.00077,            0.00434,           -0.29231,            0.00456,
  0.04781,            1.33214,           -2.62015,            0.79761,
 -0.81850,            0.06371,            0.00119,            0.03049,
 -0.03553,            0.02373,           -0.01411,           -189.06132,
 -169.17940,          5.27464,           -227.72664,          83.72511,
 -12.04794,           0.23965,            23.75496,          -3.43532,
 -0.34276,           -1.35880,            0.45053,           -0.34298,
 -0.11441,           -0.16328,            0.07423,            481.48150,
  79.82461,           453.82764,          941.94205,         -635.83924,
  397.29087,         -81.54066,          -417.22420,          149.91822,
  10.53490,          -0.13210,            0.36740,            0.33777,
  0.15893,           -2562.04968,         2442.77844,        -2602.66709,
  2838.87348,         723.50715,         -1284.58208,        -4557.23362,
 -4514.61100,        -8960.81693,         4663.55087,        -4947.61530,
  19377.42027,       -0.16786,           -0.19514,            0.32100,
  0.91502,            4.96600,           -1.11836,            307.38057,
  175.14618,          16.02093,           444.42376,         -219.80047,
  62.39286,          -18.14266,          -52.23698,           0.02111,
  0.00469,           -20.97409,          -34.48296,          -2.03906,
 -27.07560,           3.73818,           -3.00599,            0.24112,
  0.41430,           -0.03552,            0.00394,           -0.00217,
  0.02307,            0.03686,            0.00510,            34.46537,
  10.23293,           9.99520,            28.88781,          -11.31210,
  3.52646,           -0.48062,           -2.93641,           -0.00987,
 -0.05310,           -38.39539,           0.04568,           -31.73684,
 -1.83151,           -24.97332,          -1.71244,            0.33498,
  7.03899,           -4.15247,            200.43434,         -0.00800,
  0.04462,            37.83113,          -13.40661,           9.49434,
 -35.41588,          -14.72767,          -3.84674,           -0.31412,
  3.97734,            0.02908,           -0.00353,            1.89935,
 -14.31774,           7.77051,           -7.08945,            1.90915,
  1.78908,           -0.41445,            0.30506,           -14.43121,
  7.30707,           -11.97842,          -17.64121,           13.38962,
 -7.20982,           -5.23362,            2.11364,           -0.45605,
  4.08835,            1.42683,            0.24838,           -0.00605,
  0.03199,           -0.17609,           -1.43091,            0.32444,
 -0.51371,            0.06182,            0.03733,            0.00696,
 -0.13438,            4.67581,            4.42379,           -1.52602,
  4.20659,           -1.31757,           -0.72910,            1.29012,
  0.97780,            2.25895,           -0.85306,            1.74120,
 -5.09507,            0.28107,           -0.05040,            0.05508,
 -0.06349,           -0.00061,            0.48249,           -2.37749,
  1.78180,           -1.67423,           -0.35618,            0.05789,
 -0.35287,            0.56252,           -0.66584,            0.61979,
  4.84016,           -4.64462,            17.48002,           0.40982,
 -4.19214,           -1.55252,           -1.87505,           -0.31070,
  0.15554,           -0.00034,            0.11102,            0.01116,
 -0.04166,            9.27689,           -4.32090,            6.84888,
  1.78741,           -0.09306,            1.68391,           -0.27482,
 -0.04197,           -7.83068,            37.71086,          -37.53346,
  7.18559,            0.74427,           -24.29751,           10.87837,
  1.35503,            0.00998,           -0.03395,           -133.52206,
 -150.11329,          4.27494,           -173.79469,          150.87961,
 -356.29181,         -330.17873,         -426.29809,         -607.98186,
  126.35464,         -299.69623,          556.41055,         -0.00342,
  0.04411,            44.65946,           42.07312,           85.71397,
  5.95130,            24.98064,          -41.20026,          -14.05970,
 -10.46101,          -2.24038,            2.89211,            0.06175,
  0.08128,            0.00705,            0.01939,           -1.08361,
 -0.08213,           -0.20868,           -0.36268,           -4.96489,
 -2.05966,           -6.16586,            3.65514,           -3.12555,
  12.20821,          -1.11236,           -1.73772,           -1.34045,
 -0.22774,           -0.08639,            0.27355,           -0.07700,
  1.06260,           -0.46013,            0.31916,           -0.04969,
 -0.09488,           -1.54000,            0.04949,           -0.07616,
 -0.95933,            0.93303,            3.43183,           -0.82917,
 -0.82042,           -0.68158,            0.17083,            0.06942,
  0.17491,           -0.02699,           -0.01051,            0.00657,
  0.03063,           -0.52595,            0.84035,           -0.88323,
 -0.70188,            0.60928,           -0.48179,            0.38290,
  0.04482,            0.26456,           -0.32369,           -0.00615,
  0.03218,           -0.32943,            0.14675,           -0.10782,
 -0.09036,           -0.58003,            0.72888,           -0.46654,
  1.17977,            0.00222,            0.01541,           -0.19226,
 -0.07770,           -0.01829,           -0.05070,           -1.75385,
 -1.32969,            0.52361,           -1.36036,            0.67222,
  1.34612,            6.96841,           -29.24025,          -23.76900,
 -39.91647,          -41.01215,          -2.23638,           -18.81024,
  20.77095,          -0.68592,           -2.26212,           -1.14065,
 -0.76493,           -0.18044,            0.15193,           -0.20669,
 -0.44387,            0.25697,           -0.17880,           -0.53097,
  0.43181,           -0.35187,            0.71934,           -0.14962,
  0.09220,           -0.05031,           -0.03924,            0.06571,
  0.29487,            0.05170,            0.36847,            0.02754,
 -0.00411,           -0.08313,           -0.16907,            0.10273,
 -0.07315,           -0.02312,            0.04912,           -0.01062,
 -0.02713,            0.03806,            0.13401,           -1.79865,
 -2.04540,           -2.69965,           -0.65706,           -1.17916,
  0.79292,            0.02415,            0.14001,           -0.01767,
  0.04209,            0.05212,           -0.01795,            0.01285,
  0.04028,            0.01075,            0.05533,            0.02323,
 -0.00864,           -0.04691,            0.03128,            0.00548,
  0.02254,            0.00011,            0.12033);

juptabb: array[0..594] of double = 
( 548.59659,          594.29629,          219.97664,          59.71822,
  23.62157,           40.77732,           227.07380,          0.00293,
 -0.00745,           -307.33226,         -347.92807,         -309.49383,
 -428.18929,         -96.59506,          -191.36254,          2.11014,
 -34.44145,           2.23085,            6.77110,           -5.43468,
 -0.28391,            0.28355,           -1.81690,            0.00036,
  0.00078,           -1.83259,            1.17464,           -2.66976,
 -0.92339,           -0.23645,           -1.20623,            0.25248,
 -0.04958,            0.00064,            0.03599,           -0.00079,
  0.00004,           -0.00005,           -0.00010,           -0.00024,
  0.00051,            0.00001,            0.00005,            0.00015,
  0.00010,            0.00017,           -0.00004,            0.00113,
 -0.00011,            0.00021,            0.00087,            0.00120,
 -0.00114,           -0.00881,           -0.00020,           -0.00005,
  0.00009,            0.00005,            0.00007,            0.00002,
 -0.00033,           -0.00554,           -0.32274,            0.23695,
 -0.11184,            0.04050,            0.09929,           -0.02189,
  0.00305,           -0.00142,           -0.00055,            0.66623,
  0.34590,            0.74913,           -0.23202,           -1.08316,
 -1.40407,            1.72287,           -0.07604,            0.00024,
  0.00004,            0.03592,            0.91143,           -1.11848,
 -0.17473,            0.91500,           -1.34912,            0.85229,
  0.69029,           -0.00019,            0.00075,            0.03615,
  0.30768,           -0.08733,            0.12016,           -0.01716,
 -0.01138,            0.00021,            0.00004,            0.00531,
  0.00098,           -0.14354,           -0.02364,           -0.05559,
 -0.07561,            0.01419,           -0.01141,            0.00014,
  0.00218,           -0.36564,            0.13498,           -0.13283,
 -0.11462,            0.23741,            0.14960,           -0.23173,
  0.25148,            0.00763,           -0.05987,           -0.00857,
  0.20312,           -0.29399,            0.34831,           -1.33166,
 -0.46808,           -0.00027,            0.00046,            0.15729,
  0.01367,            0.04093,            0.07447,           -0.01598,
  0.00785,            0.00583,            0.00324,            0.00053,
  0.00160,           -0.00030,            0.00043,           -0.00208,
  0.00334,           -0.00316,            0.00136,            0.23086,
  0.05711,            0.19558,            0.05897,            0.01070,
  0.05021,           -0.00818,           -0.02242,            0.06301,
 -0.26483,            0.66177,            0.02125,            0.13477,
  0.19376,           -0.36520,            0.83588,           -0.69848,
 -0.00877,            0.01626,           -0.23878,           -0.00373,
  0.00044,            0.00008,           -0.00004,           -0.00374,
 -0.00283,            0.01104,           -0.00619,            0.00004,
  0.00015,            0.00026,            0.00013,            0.04630,
 -0.11815,            0.00773,            0.03796,           -0.05172,
  0.00149,            0.00444,           -0.01493,           -0.00064,
 -0.00044,           -0.00033,            0.00002,           -0.00012,
  0.00284,           -0.15622,           -0.92158,           -0.82690,
 -1.52101,           -0.55934,            0.69375,           -0.00171,
  0.00031,            0.00129,           -0.00013,           -0.00024,
 -0.00083,            0.66101,           -0.21764,           -0.43967,
  0.30157,            0.53389,            1.59141,            1.94286,
  0.14146,           -0.00064,           -0.00006,            0.21850,
 -0.02912,            0.08594,            0.08734,           -0.01678,
  0.01629,            0.00133,            0.00562,            0.00128,
 -0.00025,           -0.00005,            0.00027,            0.00032,
  0.00001,            0.00037,            0.00042,            0.00070,
  0.00003,            0.00275,           -0.13096,            0.02329,
 -0.05582,            0.00405,           -0.00251,            0.01316,
 -0.01165,            0.00279,           -0.00374,           -39.62783,
  20.91467,          -28.97236,           3.77560,           -3.30029,
  0.11472,           -0.48216,            1.05814,           -0.21607,
 -0.03055,           -0.64162,           -0.57355,           -0.05861,
 -0.18592,           -0.12207,           -0.06279,           -38.55325,
 -125.74207,         -47.22357,           41.75842,          -119.38841,
  18.88515,          -11.04830,          -50.98851,           16.64895,
  1.76553,            0.09474,            0.03714,            0.02593,
  0.07967,           -1187.61854,        -1094.91786,        -1011.21939,
 -1102.25998,        -575.88672,         -107.84860,         -890.58889,
 -807.06589,          971.78461,         -1287.24560,        -4601.44669,
 -849.54329,         -0.00904,            0.06233,           -0.19456,
 -0.05521,           -0.36915,            1.15363,            32.64763,
 -85.19705,           114.34437,         -13.37747,           15.92865,
  55.84857,          -13.10538,           3.07629,           -0.00327,
  0.00104,           -7.81035,            6.19960,           -6.36096,
  1.00493,           -0.66971,           -0.84572,            0.09943,
 -0.04583,            0.00200,           -0.00032,           -0.00265,
  0.00047,           -0.00053,            0.00046,           -0.24396,
  0.20664,           -0.30820,           -0.04917,            0.06184,
 -0.12642,            0.03053,            0.05054,            0.00035,
  0.00012,            0.42063,           -0.58254,            0.90517,
 -0.66276,            0.64765,            0.39338,           -1.40645,
  0.33017,           -1.43377,           -0.67089,           -0.00045,
 -0.00036,            0.23690,            0.07185,            0.28386,
 -0.04397,            0.02836,           -0.13082,           -0.00978,
  0.00108,            0.00046,            0.00083,           -0.01665,
  0.32499,           -0.09980,            0.18611,           -0.02561,
  0.00239,           -0.00084,           -0.00110,            0.46854,
 -0.35113,            0.69908,            0.53244,            0.12875,
  0.01115,            0.13930,            0.02747,           -0.10587,
 -0.17759,           -0.26850,            0.04400,            0.00010,
 -0.00015,            0.00164,           -0.01308,            0.00488,
 -0.01046,            0.00170,            0.00024,            0.00084,
  0.00014,           -0.08481,           -0.02547,           -0.02290,
 -0.02281,           -0.03946,           -0.02810,            0.01298,
  0.08658,            0.05575,           -0.01081,            1.09695,
  0.35441,           -0.03127,            0.07946,            0.01245,
  0.02578,           -0.00524,           -0.00027,            0.08217,
 -0.31742,            0.15273,           -0.07804,            0.01197,
  0.03053,            0.81596,            0.38640,           -0.89777,
  0.59499,           -0.39581,           -0.87375,            0.02096,
  0.49772,            0.29986,            0.24210,            0.14038,
 -0.03016,           -0.00208,            0.00045,            0.01024,
  0.00114,            1.23010,            1.75663,           -0.12741,
  1.44996,           -0.31607,            0.03151,            0.00259,
 -0.04741,           -11.57091,           8.00331,           -9.24028,
 -6.36906,            4.71248,           -2.43695,            0.38630,
  1.90625,            0.01401,            0.00114,            33.56690,
 -55.17784,           33.21425,          -52.57002,           27.04138,
  13.78610,           69.60307,          -81.16312,           27.53960,
 -158.28336,         -205.94418,         -95.08051,          -0.01407,
 -0.00364,           -18.56128,           6.02270,           -10.11059,
  24.69471,           12.31878,           9.94393,            3.81994,
 -4.84109,           -1.08440,           -0.72136,            0.03731,
 -0.02094,            0.00789,           -0.00176,            0.09673,
 -0.11181,            0.03112,           -0.00065,           -0.29167,
 -0.82083,            0.40866,           -0.77487,           -2.23349,
 -0.46973,            0.41024,           -0.14274,            0.07755,
 -0.24895,           -0.04965,           -0.01197,           -0.02264,
  0.05917,           -0.02817,            0.01242,           -0.00250,
 -0.00247,           -0.14414,           -0.03739,            0.14708,
 -0.07908,            0.05843,            0.15173,           -0.01601,
 -0.07844,           -0.05957,           -0.03143,           -0.01830,
  0.01257,           -0.00109,           -0.00000,            0.00174,
  0.00050,           -0.02119,            0.06918,           -0.02470,
  0.00185,            0.02372,           -0.02417,            0.01081,
  0.05222,            0.09820,            0.05931,           -0.00588,
 -0.00086,            0.01688,           -0.00133,           -0.00073,
  0.00041,           -0.02280,           -0.05706,           -0.17694,
 -0.12027,            0.00196,           -0.00060,            0.00051,
 -0.02426,            0.00314,           -0.00302,            0.17923,
 -0.78343,            0.52073,           -0.02398,           -0.03978,
  0.20841,            6.51325,            3.37139,            12.88844,
 -6.72098,            3.40949,           -14.34313,          -9.68278,
 -7.85143,            1.06886,           -0.21727,            0.36675,
 -0.49815,           -0.07289,           -0.07537,            0.01107,
 -0.00644,            0.01013,           -0.00306,           -0.00708,
 -0.13488,           -0.23041,           -0.10698,           -0.00049,
 -0.00692,           -0.00142,           -0.00211,           -0.04021,
  0.01805,            0.00479,            0.00620,            0.00739,
  0.00566,           -0.00101,           -0.00022,            0.00261,
 -0.00188,           -0.01812,           -0.01205,           -0.00061,
 -0.00061,           -0.02479,            0.01157,            0.91642,
 -0.65781,            0.39969,           -1.13699,           -0.43337,
 -0.57828,            0.00145,            0.00281,           -0.01675,
 -0.00975,            0.00119,           -0.00074,           -0.00343,
  0.00139,            0.00061,            0.00086,            0.00054,
 -0.00046,           -0.01996,           -0.02689,            0.00034,
  0.00037,           -0.00006,            0.00001);

juptabr: array[0..594] of double = 
(-734.58857,         -1081.04460,        -551.65750,         -148.79782,
 -25.23171,           164.64781,          248.64813,         -0.05163,
 -0.02413,           -1306.61004,         560.02437,         -1622.58047,
  589.92513,         -812.39674,          166.85340,         -157.92826,
 -107.14755,          68.98900,          -18.95875,          -0.16183,
  36.24345,          -9.19972,           -2.29315,           -0.00316,
  0.00222,            10.95234,           21.37177,          -6.29550,
  21.83656,          -7.70755,            1.38228,           -0.21770,
 -1.49525,            0.17951,            0.01043,            0.00062,
  0.00208,           -0.00066,            0.00050,            0.00313,
  0.00187,            0.00010,            0.00131,            0.00102,
  0.00047,            0.00102,            0.00012,            0.00012,
 -0.00037,            0.00808,            0.00027,           -0.01219,
 -0.00961,           -0.04166,           -0.00327,           -0.00001,
 -0.00146,           -0.00092,           -0.00989,           -0.00135,
  0.00196,            0.19216,            2.48442,           -1.43599,
  1.39651,           -0.48549,           -0.53272,            0.14066,
 -0.10352,            0.00141,            0.00066,            2.96838,
 -3.09575,            6.27741,            5.24306,           -8.77080,
  9.03247,           -10.98350,          -3.58579,           -0.00168,
 -0.00100,            0.20234,           -0.75737,            0.36838,
 -0.58241,            0.41430,           -0.35784,            0.47038,
 -0.10586,            0.00539,            0.00490,           -0.01375,
 -0.01950,            0.00145,            0.00723,           -0.00391,
  0.00391,           -0.00131,           -0.00568,            0.01317,
  0.00319,            1.31006,            5.89394,           -1.61753,
  3.68814,           -0.80644,           -0.14747,            0.04481,
 -0.11361,           -4.36130,            7.92488,           -16.29047,
 -1.52163,            2.14492,           -14.38028,           9.65573,
  3.56881,           -1.87208,            3.36213,            1.84499,
 -2.41575,           -2.77076,           -3.23915,           -3.34573,
  1.40979,            0.00217,           -0.00841,            0.29313,
 -0.36246,            0.22043,            0.02328,           -0.01182,
  0.04074,           -0.15728,            0.02468,           -0.03185,
 -0.01099,            0.01059,           -0.01274,            0.07362,
 -0.02642,            0.04035,           -0.00968,           -2.14457,
  2.53297,           -4.34196,           -0.11421,           -0.38757,
 -1.73872,            0.39784,           -0.01397,           -0.03311,
  0.97723,            0.16060,           -0.07486,            25.96413,
  0.75088,           -3.04736,            0.30340,           -1.43451,
 -1.35136,            0.26526,           -0.40247,           -0.00460,
 -0.00056,            0.01633,           -0.00128,           -0.05197,
  0.07002,           -0.19450,            0.03737,            0.00188,
 -0.00037,           -0.00903,           -0.00059,           -19.73809,
  0.58424,           -10.42034,          -10.14579,           2.65990,
 -3.07889,            0.50884,            0.58508,           -0.00970,
  0.02099,            0.00716,            0.01161,            0.05751,
 -0.04515,            22.08042,           30.82415,          -36.27430,
  31.40265,          -18.30150,          -29.16403,           0.02454,
  0.01834,           -0.01312,            0.01576,           -0.00928,
  0.00330,           -11.78094,           4.06738,           -2.51590,
  15.05277,           9.12747,            2.88088,            2.32916,
 -2.08271,            0.02872,            0.02194,            0.60494,
 -0.04597,            0.24749,            0.15971,           -0.02185,
  0.03384,           -0.07075,            0.01287,            0.40201,
  0.00347,           -0.00410,           -0.00998,           -0.00005,
 -0.00121,            0.13770,            0.00186,           -0.02268,
  0.00210,            1.26291,            0.65546,            0.38885,
  0.38880,           -0.00184,            0.03067,            0.01273,
  0.01136,            0.00557,            0.01117,            94.13171,
 -88.37882,           120.53292,          8.32903,            7.77313,
  43.46523,          -11.66698,           0.44639,            0.15092,
 -1.68367,           -0.30833,           -0.49030,            0.01971,
 -0.14144,           -0.04019,           -0.05110,           -39.70024,
  272.91667,         -468.46263,          256.77696,         -200.63130,
 -307.98554,          206.56301,         -41.76039,          -4.74242,
  74.19909,           0.18474,            0.05547,           -0.06732,
  0.16515,           -1156.31285,        -1102.97666,        -1346.99288,
 -1121.01090,         666.84550,          421.92305,          2259.49740,
 -2268.69758,        -2325.87639,        -4476.46256,        -9683.77583,
 -2472.92565,        -0.10400,            0.08075,           -0.45225,
  0.16621,            0.57789,            2.43804,            85.21675,
 -154.17208,          219.91042,         -9.71116,            31.13240,
  108.60117,         -25.85622,           8.98402,           -0.00233,
  0.01030,           -17.01324,           10.41588,          -13.34449,
  1.08782,           -1.48199,           -1.81734,            0.20334,
 -0.11734,           -0.00230,           -0.01869,           -0.01182,
 -0.00129,           -0.00281,            0.02021,           -5.75973,
  19.13309,          -16.13690,           5.53382,           -1.96585,
 -6.29211,            1.63105,           -0.26089,            0.02935,
 -0.00555,            0.30700,           -19.96182,           0.99825,
 -16.32664,           0.83052,           -13.76201,          -3.15609,
  0.17360,           -111.81423,         -2.05419,           -0.02455,
 -0.00478,            7.45114,            21.53296,           19.90263,
  5.69420,            2.31253,           -8.15116,           -2.17440,
 -0.23014,            0.00168,            0.01590,            8.78005,
  0.71418,            4.48561,            4.50680,           -1.05713,
  1.17880,           -0.19327,           -0.24877,           -5.00870,
 -8.66354,            10.51902,          -7.71011,            4.65486,
  8.05673,           -1.39635,           -3.07669,           -2.40347,
 -0.11167,           -0.04064,            0.83512,           -0.02041,
 -0.00351,            0.97375,           -0.15795,            0.36361,
  0.19913,           -0.02142,            0.04193,            0.08801,
  0.00475,           -2.81010,            3.11341,           -2.79191,
 -0.93313,            0.44570,           -0.88287,           -0.51815,
  0.54776,            0.29736,            0.99779,            2.28957,
  0.82183,            0.03386,            0.12855,            0.03124,
  0.02454,           -0.31958,            0.00070,           -1.48184,
 -1.28195,            0.03965,           -1.12026,            0.23910,
  0.01293,            0.36146,           -0.64483,           -1.88470,
  0.21469,           -11.79819,          -1.87287,            2.65699,
 -0.36287,            0.88148,           -1.26883,           -0.19657,
 -0.14279,           -0.07536,           -0.00004,            0.01496,
  0.00537,            2.48352,            3.75581,           -0.34909,
  3.26696,           -0.82105,            0.11287,           -0.00755,
 -0.13764,           -15.34429,          -2.79957,           -3.22976,
 -15.46084,           10.66793,          -0.26054,           -0.12188,
  5.06211,            0.01313,            0.00424,            84.34332,
 -57.05646,           92.68150,          -0.02024,            149.62698,
  59.14407,           174.04569,         -129.26785,         -55.99789,
 -238.01484,         -212.51618,         -115.94914,         -0.01720,
 -0.00158,           -13.65602,           17.47396,           0.16714,
  32.66367,           16.30095,           9.18345,            3.98555,
 -5.39985,           -1.09958,           -0.86072,            0.02752,
 -0.02474,            0.00671,           -0.00278,           -0.21030,
 -0.73658,            0.20708,           -0.21378,            0.78462,
 -2.14051,           -1.60070,           -2.60915,           -5.02441,
 -1.19246,            0.67622,           -0.41889,            0.07430,
 -0.53204,           -0.11214,           -0.03417,           -0.72636,
 -0.15535,           -0.16815,           -0.35603,            0.07530,
 -0.02521,           -0.01261,           -0.94883,            0.39930,
 -0.05370,           -2.77309,            0.38431,            0.72127,
 -0.52030,           -0.01804,           -0.51188,           -0.11993,
  0.02189,            0.00928,           -0.02129,           -0.02760,
  0.00441,           -0.56832,           -0.48114,            0.64192,
 -0.65656,            0.37483,            0.51883,           -0.08474,
  0.20324,            0.12783,            0.13041,           -0.01545,
 -0.00282,           -0.16196,           -0.26980,            0.06584,
 -0.09987,           -0.36305,           -0.27610,           -0.57074,
 -0.13607,           -0.00824,            0.00369,            0.06094,
 -0.12214,            0.03581,           -0.00876,            0.49346,
 -0.74596,            0.47814,            0.18201,           -1.00640,
  0.24465,            10.09808,           2.30496,            13.63359,
 -7.94007,            0.29792,           -13.55724,          -6.48556,
 -5.99581,            0.69686,           -0.22434,            0.23198,
 -0.35579,           -0.04736,           -0.05683,            0.36710,
 -0.16571,            0.14876,            0.21824,           -0.18940,
 -0.15063,           -0.23692,           -0.09990,           -0.08923,
 -0.12222,            0.02998,           -0.04560,           -0.16229,
  0.04552,           -0.33051,            0.02585,           -0.00622,
  0.01583,            0.15436,           -0.07109,            0.06429,
  0.09218,           -0.01277,           -0.00019,            0.02345,
 -0.01057,           -0.07294,            0.02506,            0.62063,
 -0.52533,            0.16814,           -0.77168,           -0.20614,
 -0.31828,           -0.12856,            0.01316,           -0.01522,
 -0.00126,            0.01558,            0.04765,           -0.02776,
  0.01166,           -0.05185,            0.00674,            0.00754,
  0.02183,           -0.00645,           -0.01050,           -0.02155,
  0.00375,            0.12040,           -0.00004);

sattabl: array[0..787] of double = 
( 1788381.26240,      2460423.68044,      1370113.15868,      415406.99187,
  72040.39885,        12669.58806,        439960754.85333,    180256.80433,
  18.71177,          -40.37092,           66531.01889,       -195702.70142,
  57188.02694,       -179110.60982,      -19803.06520,       -58084.15705,
 -9055.13344,        -31146.10779,        11245.43286,       -3247.59575,
  459.48670,          2912.82402,        -4.06749,           -13.53763,
 -30.55598,          -4.51172,            1.48832,            0.37139,
  597.35433,          1193.44545,        -297.50957,          976.38608,
 -263.26842,          34.84354,          -6.77785,           -29.92106,
 -0.16325,           -0.18346,           -0.15364,           -0.08227,
  0.20180,            0.02244,            0.04672,           -0.29867,
 -0.04143,           -0.00760,           -0.17046,           -0.00778,
  0.04200,            0.23937,           -0.00098,           -0.05236,
 -0.02749,           -0.01813,            0.00637,            0.01256,
 -0.04506,            0.04448,           -0.00105,            0.06224,
  0.01157,            0.17057,           -0.03214,            0.18178,
 -0.22059,           -0.01472,           -0.24213,            0.04309,
  0.03436,            0.44873,            0.01350,           -0.01931,
 -0.80618,           -0.56864,            0.29223,           -0.03101,
  0.04171,            0.02264,           -0.01264,           -0.01645,
  0.01774,            0.06374,           -0.01925,           -0.03552,
  0.10473,           -0.04119,            0.08045,            0.04635,
 -3.01112,           -9.26158,            8.13745,            1.88838,
 -0.15184,            0.16898,           -0.22091,            0.29070,
 -0.03259,            0.06938,           -0.08499,           -0.21688,
  0.01848,           -0.05594,            0.50100,           -0.00027,
  0.13300,            0.12055,            0.03039,            0.03854,
 -1.55287,            2.55618,           -0.45497,           -0.29895,
 -0.93268,            0.83518,           -0.32785,            7.03878,
 -1.66649,            2.75564,           -0.29459,            0.01050,
  0.08293,           -0.03161,           -0.12750,           -0.04359,
  0.04217,            0.07480,           -114.43467,          49.47867,
 -66.52340,          -26.27841,           15.48190,          -13.06589,
  3.28365,            5.02286,           -0.17155,           -0.07404,
  0.00924,           -0.07407,           -0.02922,            0.06184,
  108.04882,          86.09791,          -155.12793,          208.10044,
 -311.72810,         -268.92703,          74.57561,          -420.03057,
 -0.07893,            0.09246,           -0.66033,           -0.39026,
 -0.13816,           -0.08490,           -36.79241,          -78.88254,
  71.88167,          -68.05297,           51.71616,           65.77970,
 -43.59328,           23.51076,          -0.02029,           -0.32943,
 -8.82754,            1.48646,           -3.12794,            2.12866,
 -0.06926,            0.44979,            0.00621,           -0.51720,
 -3.82964,           -1.48596,           -0.11277,           -3.21677,
  0.81705,           -0.19487,           -0.06195,            0.10005,
 -0.02208,            0.00108,            0.00455,           -0.03825,
  0.01217,           -0.00599,           -0.17479,           -0.47290,
  0.85469,            1.12548,           -0.80648,           -0.44134,
 -0.01559,           -0.07061,            0.01268,           -0.01773,
  0.01308,           -0.03461,           -0.71114,            1.97680,
 -0.78306,           -0.23052,            0.94475,           -0.10743,
  0.18252,           -8.03174,            0.00734,            0.04779,
  0.12334,           -0.03513,            0.01341,            0.02461,
  0.02047,           -0.03454,            0.02169,           -0.01921,
 -1.12789,            0.09304,            0.14585,            0.36365,
  0.03702,            0.10661,           -0.00464,           -1.72706,
 -0.00769,           -0.04635,           -0.01157,            0.00099,
  10.92646,           1.96174,            2.91142,            4.74585,
 -0.29832,            0.75543,            0.05411,            1.05850,
  0.38846,           -0.16265,            1.52209,            0.12185,
  0.18650,            0.35535,           -278.33587,         -82.58648,
 -160.00093,         -225.55776,          35.17458,          -77.56672,
  10.61975,           3.33907,            0.06090,            2.17429,
 -4.32981,           -5.84246,            11.43116,           20.61395,
 -0.65772,            1.28796,            1224.46687,        -3113.15508,
  3798.33409,        -137.28735,         -256.89302,          2227.35649,
 -779.78215,         -260.37372,          11.73617,          -13.25050,
 -0.75248,           -2.87527,           -8.38102,            17.21321,
 -61784.69616,        39475.02257,       -54086.68308,        54550.85490,
 -16403.69351,        29602.70098,        14672.06363,        16234.17489,
  15702.37109,       -22086.30300,       -22889.89844,       -1245.88352,
  1.48864,            19.75000,           0.78646,            3.29343,
 -1058.13125,         4095.02368,        -2793.78506,         1381.93282,
 -409.19381,         -772.54270,          161.67509,         -34.15910,
 -514.27437,          27.34222,          -311.04046,          48.01030,
 -43.36486,           16.19535,          -0.73816,           -0.81422,
  287.32231,         -110.44135,          200.43610,          37.98170,
  17.73719,           34.40023,          -2.46337,            1.48125,
  0.09042,           -0.11788,            0.37284,            0.51725,
  0.00597,            0.14590,           -0.01536,            0.00980,
  0.00721,            0.02023,            0.00027,            0.02451,
 -0.72448,           -0.71371,            0.29322,            0.18359,
  0.72719,           -0.37154,            0.14854,           -0.02530,
  0.23052,            0.04258,            4.82082,            0.01885,
  3.11279,           -0.63338,            0.10559,           -0.02146,
 -0.01672,            0.03412,            0.00605,            0.06415,
 -0.89085,            1.51929,           -0.36571,            0.39317,
  12.05250,          -3.79392,            3.96557,           -3.51272,
 -0.17953,            12.30669,          -0.05083,           -0.11442,
  0.02013,           -0.02837,           -0.02087,           -0.01599,
  0.49190,            0.30360,            0.01316,            0.17649,
  0.21193,           -0.09149,           -0.07173,           -0.05707,
  4.24196,           -1.25155,            1.81336,            0.68887,
 -0.01675,            0.20772,           -0.04117,           -0.03531,
 -0.02690,           -0.02766,            37.54264,           10.95327,
  8.05610,            30.58210,          -12.68257,           1.72831,
  0.13466,           -3.27007,            0.01864,           -0.00595,
  0.03676,            0.14857,           -0.07223,            0.06179,
  0.44878,           -1.64901,           -20.06001,           0.63384,
 -4.97849,            4.78627,            29.87370,           7.29899,
  0.00047,           -0.00155,            0.00314,            0.01425,
 -0.17842,           -0.08461,           -1.61020,           -8.47710,
  6.85048,           -4.38196,            1.05809,            2.68088,
 -0.01027,           -0.00833,            0.06834,           -0.04205,
  0.03330,           -0.01271,            0.01301,           -0.01358,
  0.03537,            0.03612,            0.02962,            0.62471,
 -0.30400,           -0.64857,            0.01773,            0.01890,
  0.01426,           -0.00226,           -0.50957,           -0.01955,
 -0.09702,            1.09983,            0.64387,           -0.02755,
  0.26604,            0.30684,            0.06354,            0.05114,
 -0.00058,           -0.04672,           -0.00828,            0.00712,
 -0.00440,            0.00029,           -0.01601,            0.03566,
  0.13398,           -0.02666,           -0.06752,           -0.43044,
  0.07172,           -0.01999,           -0.01761,           -0.05357,
  0.06104,            0.29742,           -0.08785,            0.05241,
 -6.57162,           -4.20103,            0.03199,           -6.46187,
  1.32846,           -0.51137,            0.06358,            0.37309,
 -1.46946,            2.34981,           -0.18712,            0.11618,
  240.62965,         -107.21962,          219.81977,          84.04246,
 -62.22931,           68.35902,          -9.48460,           -32.62906,
  5.57483,           -1.82396,            1.00095,           -0.39774,
  7.87054,            11.45449,          -432.67155,          55064.72398,
  12444.62359,        54215.28871,        8486.03749,         12297.48243,
 -333.27968,          1147.93192,         1403.73797,         990.40885,
 -3.84938,           -722.43963,          16.83276,           96.48787,
  7.04834,            38.22208,           0.63843,            2.61007,
  230.73221,          171.64166,          1.96751,            287.80846,
 -85.21762,           31.33649,          -2.25739,           -11.28441,
  0.04699,            0.06555,           -0.08887,            1.70919,
  0.09477,            0.26291,           -0.15490,            0.16009,
  1.93274,            1.01953,            0.36380,            1.29582,
 -0.13911,            0.14169,           -0.00491,           -0.00030,
 -0.08908,           -0.10216,           -0.03265,           -0.03889,
  0.40413,           -1.12715,           -0.94687,           -0.04514,
  0.02487,           -0.01048,            0.39729,            2.82305,
 -0.61100,            1.11728,           -0.13083,           -0.04965,
 -0.00602,           -0.02952,           -6.13507,            13.73998,
 -15.70559,          -1.28059,            2.64422,           -9.33798,
  3.26470,            1.56984,           -0.00572,            0.09992,
 -8.80458,           -8.23890,           -11.51628,           9.47904,
  11.31646,           4.29587,           -2.41367,           -0.05883,
 -0.80022,           -1.02706,            0.21461,           -0.06864,
  0.01882,            0.01798,            0.27614,           -0.01007,
  0.04362,            0.07560,            0.05519,            0.23435,
 -0.09389,            0.01613,            0.01298,            0.04691,
 -0.02665,           -0.03582,            0.60080,           -4.28673,
  1.87316,           -1.05840,            0.13248,            0.40887,
 -0.67657,            0.67732,            0.05522,            0.07812,
 -0.17707,           -0.07510,            0.24885,            10.63974,
 -7.40226,           -2.33827,            2.75463,           -32.51518,
  0.05140,            0.01555,            180.43808,          263.28252,
  384.50646,         -76.53434,          -93.50706,          -220.50123,
 -81.91610,           103.92061,          30.90305,          -2.89292,
 -0.06634,           -0.37717,           -0.01945,           -0.05936,
  29.27877,          -59.73705,           35.86569,          -18.36556,
  3.88812,            4.82090,           -0.70903,            0.06615,
  0.01558,           -0.01854,            0.16209,            0.12682,
  0.02508,            0.02406,           -0.03078,           -0.01737,
 -0.00033,           -0.00020,            0.01023,            0.05972,
 -0.03373,           -0.07289,           -2.08162,           -0.14717,
 -0.64233,           -0.75397,            0.11752,           -0.09202,
  4.42981,           -4.19241,            5.02542,            5.03467,
 -4.22983,            2.80794,            3.03016,           -2.74373,
 -1.11490,           -2.72378,           -0.63131,            0.74864,
 -0.00759,           -0.00675,            0.03615,           -0.01806,
 -2.71920,           -1.50954,            0.54479,           -1.92088,
  0.66427,            0.32228,           -2.55188,           -0.65332,
 -2.73798,            2.10182,            1.54407,            3.01357,
  38.76777,           23.54578,           27.29884,          -14.93005,
 -7.50931,           -5.66773,            0.30142,            1.52416,
  0.00634,            0.09697,           -0.00748,            0.01433,
  0.02936,            0.53228,           -0.03603,            0.06345,
  0.30816,           -1.07925,            0.46709,           -0.21568,
  0.01663,            0.10810,           -0.42511,            0.35872,
 -0.19662,           -6.74031,            1.05776,            1.86205,
  1.08919,            0.10483,           -0.03368,           -0.21535,
  0.07556,           -0.27104,            0.05142,           -0.03812,
  1.20189,           -1.36782,            1.35764,            1.39387,
 -1.19124,            0.77347,           -0.54760,           -0.26295,
 -0.07473,            0.23043,            2.82621,           -0.23524,
  0.47352,           -0.81672,           -0.08515,            0.04700,
  0.55355,           -0.40138,            0.22255,            0.12236,
 -0.09110,            0.31982,            0.39404,           -0.17898,
 -0.00056,            0.00014,           -0.02012,            0.03102,
  0.43236,           -0.10037,           -0.00961,            0.07440,
 -0.07076,           -1.97272,            0.25555,           -0.21832,
 -0.00837,           -0.08393,            0.01531,            0.00627,
  0.33193,            0.70765,           -0.43556,            0.28542,
 -0.23190,           -0.04293,           -0.08062,            0.13427,
  0.23763,           -0.17092,            0.09259,            0.05155,
  0.08065,           -0.11943,           -0.02174,           -0.68899,
 -0.01875,           -0.01746,            0.13604,            0.29280,
 -0.17871,            0.11799,            0.02003,            0.04065,
  0.01343,           -0.06060,           -0.01290,           -0.26068,
 -0.09033,            0.02649,           -0.00092,           -0.03094,
 -0.00770,           -0.10447,           -0.04113,            0.01259,
 -0.00469,           -0.04346,           -0.00010,            0.06547);

sattabb: array[0..787] of double = 
(-567865.62548,      -796277.29029,      -410804.00791,      -91793.12562,
 -6268.13975,         398.64391,         -710.67442,          175.29456,
 -0.87260,            0.18444,           -1314.88121,         20709.97394,
 -1850.41481,         20670.34255,       -896.96283,          6597.16433,
 -179.80702,          613.45468,          17.37823,          -13.62177,
 -0.36348,            12.34740,           0.47532,            0.48189,
  0.27162,           -0.20655,           -0.23268,            0.05992,
  46.94511,           15.78836,           21.57439,           23.11342,
 -0.25862,            5.21410,           -0.22612,           -0.05822,
 -0.00439,           -0.01641,           -0.01108,           -0.00608,
  0.00957,            0.00272,           -0.00217,            0.00001,
 -0.00534,           -0.00545,            0.00277,           -0.00843,
  0.00167,           -0.00794,            0.00032,           -0.00242,
 -0.00002,           -0.00041,           -0.00025,            0.00031,
  0.00062,           -0.00060,            0.00083,            0.00032,
  0.00527,           -0.00211,            0.00054,            0.00004,
 -0.02769,           -0.01777,            0.00247,            0.00097,
  0.00020,           -0.00232,            0.00044,           -0.00035,
 -0.00072,            0.01341,            0.00325,           -0.01159,
  0.00079,           -0.00078,           -0.00009,            0.00066,
  0.00222,            0.00002,            0.00013,           -0.00161,
  0.01374,           -0.05305,            0.00478,           -0.00283,
  0.16033,            0.13859,            0.33288,           -0.16932,
 -0.00316,            0.00625,           -0.00309,            0.01687,
  0.00001,            0.00486,            0.00401,           -0.01805,
 -0.00048,           -0.00407,           -0.01329,            0.01311,
 -0.00591,            0.00166,            0.00830,            0.00665,
 -0.80207,            0.22994,           -0.34687,            0.08460,
 -0.11499,           -0.01449,           -0.01574,            0.78813,
 -0.03063,            0.28872,           -0.00337,            0.01801,
 -0.01703,           -0.00929,           -0.00738,            0.03938,
  0.05616,           -0.00516,           -3.09497,            30.13091,
 -3.14968,            17.62201,          -0.73728,            2.46962,
 -0.11233,            0.03450,           -0.07837,           -0.01573,
 -0.01595,            0.00394,            0.00174,            0.01470,
  6.83560,           -2.37594,            4.95125,            3.24711,
  2.44781,            5.17159,            1.99820,           -2.38419,
  0.00840,            0.03614,           -0.00209,           -0.30407,
 -0.02681,           -0.06128,            1.50134,            11.82856,
  4.39644,            6.98850,           -4.17679,            5.73436,
 -9.66087,            1.98221,           -0.29755,            0.08019,
 -0.24766,           -8.54956,           -1.74494,           -3.36794,
 -0.32661,           -0.00722,            0.14141,            0.01023,
 -1.21541,           -2.58470,            0.38983,           -1.70307,
  0.31209,           -0.10345,            0.02593,            0.02178,
  0.00289,            0.00393,           -0.00236,           -0.00373,
 -0.00270,           -0.00049,           -0.06282,           -0.00443,
 -0.02439,           -0.02254,           -0.02220,            0.03532,
 -0.00072,            0.00010,           -0.00049,           -0.00112,
  0.00086,            0.00112,            0.10135,           -0.10972,
  0.08357,            0.00155,            0.04363,           -0.00201,
 -0.01996,           -0.01341,           -0.00039,           -0.00042,
 -0.00294,            0.00070,            0.00005,           -0.00027,
  0.00070,           -0.00076,            0.00234,           -0.00239,
 -0.08365,           -0.08531,           -0.03531,            0.15012,
 -0.01995,           -0.01731,           -0.00370,           -0.00745,
 -0.00315,           -0.00079,           -0.00120,           -0.00145,
 -0.99404,           -1.31859,            0.03584,           -0.83421,
  0.10720,           -0.05768,            0.06664,           -0.09338,
 -0.01814,           -0.00003,           -0.05371,           -0.06458,
 -0.00100,           -0.01298,           -7.08710,           -23.13374,
  4.18669,           -19.94756,           4.85584,           -3.37187,
  0.58851,            0.31363,            0.01994,            0.27494,
 -1.37112,            2.61742,            0.52477,           -0.46520,
 -0.13183,            0.26777,            836.90400,         -484.65861,
  815.99098,          236.54649,         -32.38814,           288.95705,
 -68.17178,          -18.87875,          -1.79782,           -3.68662,
 -1.27310,           -0.65697,           -3.67530,            2.10471,
 -13758.97795,        4807.62301,        -14582.14552,        9019.73021,
 -3202.60105,         4570.16895,         2078.68911,         2892.62326,
 -2399.35382,         3253.16198,        -8182.38152,        -3588.77680,
 -0.16505,            1.08603,            0.53388,            0.87152,
  61.53677,           538.43813,         -407.32927,          322.27446,
 -148.71585,         -179.37765,          54.07268,          -34.12281,
 -14.76569,          -17.95681,          -10.82061,          -6.39954,
 -2.10954,            0.67063,            0.22607,           -0.43648,
  20.90476,          -45.48667,           30.39436,          -14.20077,
  5.17385,            5.12726,           -0.66319,            0.55668,
  0.02269,           -0.00016,            0.07811,            0.00111,
  0.01603,            0.01020,           -0.00107,            0.00494,
 -0.00077,           -0.00084,           -0.00196,            0.00081,
 -0.03776,            0.01286,           -0.00652,           -0.01450,
  0.05942,           -0.08612,            0.01093,           -0.01644,
  0.02147,           -0.00592,            0.36350,           -0.00201,
  0.14419,           -0.10070,           -0.00491,           -0.01771,
 -0.00053,           -0.00033,            0.00146,            0.00048,
  0.00582,            0.04423,           -0.00549,            0.00983,
  0.27355,           -0.38057,            0.24001,           -0.05441,
 -0.07706,            0.14269,           -0.00059,           -0.00154,
 -0.00013,           -0.00088,           -0.00046,            0.00029,
 -0.00276,           -0.00507,            0.00075,           -0.00076,
  0.01806,            0.00862,           -0.00510,           -0.01364,
 -0.00029,           -0.12664,            0.03899,           -0.03562,
  0.00318,            0.00514,            0.00057,            0.00201,
  0.00028,            0.00014,           -0.47022,           -0.74561,
  0.40155,           -0.16471,           -0.18445,            0.34425,
 -0.07464,           -0.13709,           -0.01018,           -0.00748,
 -0.01210,           -0.04274,           -0.00579,           -0.00692,
 -11.09188,          -1.67755,           -6.62063,           -13.84023,
  12.75563,          -6.73501,            8.31662,            5.40196,
  0.00052,            0.00034,            0.00128,            0.00085,
 -0.02202,           -0.00599,           -0.33458,           -1.65852,
  1.47003,           -1.02434,            0.87885,            1.15334,
 -0.00241,           -0.00721,            0.03154,            0.00612,
  0.00318,           -0.02521,            0.00042,            0.00213,
 -0.01094,            0.05417,           -0.03989,           -0.00567,
  0.00123,           -0.00244,            0.00108,            0.00242,
 -0.00138,           -0.00099,            0.04967,            0.01643,
 -0.00133,            0.02296,            0.12207,            0.05584,
  0.00437,           -0.04432,           -0.00176,           -0.00922,
 -0.00252,            0.00326,           -0.00020,           -0.00050,
 -0.00263,           -0.00084,           -0.01971,            0.00297,
  0.03076,            0.01736,           -0.01331,            0.01121,
 -0.00675,            0.00340,           -0.00256,            0.00327,
 -0.00946,            0.03377,           -0.00770,            0.00337,
  0.61383,            0.71128,           -0.02018,            0.62097,
 -0.07247,            0.04418,           -0.02886,           -0.03848,
 -0.44062,            0.03973,           -0.00999,           -0.04382,
  57.94459,           117.45112,         -71.22893,           126.39415,
 -62.33152,          -31.90754,           12.17738,          -16.46809,
 -1.13298,            0.08962,           -0.20532,            0.16320,
 -1.55110,           -1.44757,           -3102.08749,        -7452.61957,
 -5009.53858,        -7216.29165,        -2476.87148,        -1880.58197,
 -574.49433,          227.45615,          144.50228,          379.15791,
  225.36130,         -443.47371,         -8.51989,           -3.75208,
 -4.25415,           -1.59741,           -0.43946,           -0.06595,
  150.42986,          6.54937,            87.67736,           92.32332,
 -21.97187,           29.87097,          -4.21636,           -5.72955,
 -0.03879,           -0.01071,           -0.45985,            0.02679,
 -0.02448,            0.02397,           -0.06551,           -0.01154,
  1.97905,           -0.82292,            1.10140,            0.30924,
  0.03389,            0.14230,            0.00003,            0.00119,
 -0.01117,            0.00665,           -0.00132,           -0.00576,
 -0.08356,            0.08556,           -0.26362,           -0.12450,
  0.00509,            0.00165,            0.02591,            0.16200,
 -0.03318,            0.06463,           -0.00899,           -0.00462,
  0.00102,            0.00004,           -0.73102,            0.08299,
 -0.52957,           -0.35744,            0.14119,           -0.24903,
  0.20843,            0.14143,            0.00031,           -0.00234,
 -0.42643,           -2.02084,            1.58848,           -1.57963,
  0.68418,            2.07749,           -0.45888,            0.19859,
 -0.30277,           -0.22591,            0.11607,           -0.09705,
  0.00040,            0.00431,           -0.02683,            0.03158,
 -0.01302,           -0.00541,            0.01742,           -0.00006,
 -0.02231,           -0.01128,           -0.00800,            0.02055,
 -0.00346,            0.00151,            0.56732,           -0.68995,
  0.27701,           -0.16748,            0.01002,            0.00043,
  0.26916,           -0.57751,            0.15547,           -0.15825,
 -0.02074,           -0.07722,           -8.23483,           -4.02022,
  0.69327,           -5.91543,            1.72440,            1.02090,
  0.00024,           -0.00053,            20.03959,           14.79136,
  76.43531,          -14.42019,          -7.82608,           -69.96121,
 -54.94229,           23.55140,           26.60767,           14.68275,
  0.05118,           -0.10401,           -0.00075,           -0.01942,
 -3.84266,           -26.23442,           10.20395,          -14.77139,
  3.40853,            2.07297,           -0.53348,            0.40635,
  0.00716,           -0.00189,            0.12472,           -0.02903,
  0.02254,           -0.00183,           -0.00175,           -0.01522,
  0.00003,           -0.00339,            0.00383,           -0.00168,
  0.01327,           -0.03657,           -0.08458,           -0.00115,
 -0.03991,           -0.02629,            0.00243,           -0.00505,
  0.33875,           -0.16744,            0.05183,            0.01744,
 -0.24427,            0.15271,            0.37550,           -0.17378,
  0.09198,           -0.27966,           -0.22160,            0.16426,
  0.00032,           -0.00310,           -0.00022,           -0.00144,
 -0.06170,           -0.01195,           -0.00918,            0.02538,
  0.03602,            0.03414,           -0.14998,           -0.44351,
  0.45512,           -0.11766,            0.35638,            0.27539,
  5.93405,            10.55777,           12.42596,          -1.82530,
 -2.36124,           -6.04176,           -0.98609,            1.67652,
 -0.09271,            0.03448,           -0.01951,            0.00108,
  0.33862,            0.21461,            0.02564,            0.06924,
  0.01126,           -0.01168,           -0.00829,           -0.00740,
  0.00106,           -0.00854,           -0.08404,            0.02508,
 -0.02722,           -0.06537,            0.01662,            0.11454,
  0.06747,            0.00742,           -0.01975,           -0.02597,
 -0.00097,           -0.01154,            0.00164,           -0.00274,
  0.02954,           -0.05161,           -0.02162,           -0.02069,
 -0.06369,            0.03846,            0.00219,           -0.01634,
 -0.04518,            0.06696,            1.21537,            0.99500,
  0.68376,           -0.28709,           -0.11397,           -0.06468,
  0.00607,           -0.00744,            0.01531,            0.00975,
 -0.03983,            0.02405,            0.07563,            0.00356,
 -0.00018,           -0.00009,            0.00172,           -0.00331,
  0.01565,           -0.03466,           -0.00230,            0.00142,
 -0.00788,           -0.01019,            0.01411,           -0.01456,
 -0.00672,           -0.00543,            0.00059,           -0.00011,
 -0.00661,           -0.00496,           -0.01986,            0.01271,
 -0.01323,           -0.00764,            0.00041,            0.01145,
  0.00378,           -0.00137,            0.00652,            0.00412,
  0.01946,           -0.00573,           -0.00326,           -0.00257,
 -0.00225,            0.00090,           -0.00292,           -0.00317,
 -0.00719,            0.00468,            0.00245,            0.00189,
  0.00565,           -0.00330,           -0.00168,           -0.00047,
 -0.00256,            0.00220,            0.00180,           -0.00162,
 -0.00085,           -0.00003,           -0.00100,            0.00098,
 -0.00043,            0.00007,           -0.00003,           -0.00013);

sattabr: array[0..787] of double = 
(-38127.94034,       -48221.08524,       -20986.93487,       -3422.75861,
 -8.97362,            53.34259,          -404.15708,         -0.05434,
  0.46327,            0.16968,           -387.16771,         -146.07622,
  103.77956,          19.11054,          -40.21762,           996.16803,
 -702.22737,          246.36496,         -63.89626,          -304.82756,
  78.23653,          -2.58314,           -0.11368,           -0.06541,
 -0.34321,            0.33039,            0.05652,           -0.16493,
  67.44536,          -29.43578,           50.85074,           18.68861,
  0.39742,            13.64587,          -1.61284,            0.11482,
  0.01668,           -0.01182,           -0.00386,            0.01025,
  0.00234,           -0.01530,           -0.02569,           -0.00799,
 -0.00429,           -0.00217,           -0.00672,            0.00650,
  0.01154,            0.00120,           -0.00515,            0.00125,
  0.00236,           -0.00216,           -0.00098,            0.00009,
 -0.00460,           -0.00518,            0.00600,            0.00003,
  0.00834,            0.00095,            0.01967,            0.00637,
 -0.00558,           -0.06911,           -0.01344,           -0.06589,
 -0.05425,           -0.00607,           -0.00247,           -0.00266,
  0.08790,           -0.08537,           -0.00647,            0.04028,
 -0.00325,            0.00488,            0.00111,           -0.00044,
 -0.00731,            0.00127,           -0.00417,            0.00303,
  0.05261,            0.01858,           -0.00807,            0.01195,
  1.26352,           -0.38591,           -0.34825,            1.10733,
 -0.02815,           -0.02148,           -0.05083,           -0.04377,
 -0.01206,           -0.00586,            0.03158,           -0.01117,
  0.00643,            0.00306,           -0.01186,           -0.05161,
  0.01136,           -0.00976,           -0.00536,            0.01949,
 -1.41680,           -0.81290,           -0.09254,           -0.24347,
 -0.14831,           -0.34381,           -2.44464,            0.41202,
 -0.99240,           -0.33707,           -0.01930,           -0.08473,
  0.00830,            0.01165,           -0.01604,           -0.02439,
  0.00227,            0.04493,           -42.75310,          -22.65155,
 -9.93679,           -18.36179,           2.73773,            3.24126,
 -1.20698,            1.07731,            0.00434,           -0.10360,
 -0.02359,            0.00054,           -0.02664,           -0.00122,
 -19.79520,           33.11770,          -53.56452,          -35.41902,
  67.95039,          -82.46551,           117.31843,          14.08609,
  0.06447,            0.03289,            0.40365,           -0.33397,
  0.07079,           -0.09504,           -30.36873,           6.23538,
 -14.25988,          -44.91408,           38.53146,          -16.31919,
  6.99584,            22.47169,          -0.13313,            0.28016,
  6.83715,           -6.01384,            1.68531,           -3.62443,
 -0.22469,           -0.29718,            0.25169,            0.13780,
 -3.64824,            1.22420,           -2.48963,           -1.12515,
 -0.01510,           -0.56180,           -0.03306,            0.01848,
 -0.00103,           -0.00077,           -0.01681,           -0.00227,
 -0.00402,           -0.00287,            0.04965,           -0.16190,
 -0.40025,            0.20734,            0.15819,           -0.25451,
  0.02467,           -0.00495,            0.00597,            0.00490,
 -0.01085,           -0.00460,           -0.71564,           -0.26624,
  0.03797,           -0.28263,            0.03510,            0.30014,
  2.79810,            0.07258,           -0.01618,            0.00337,
  0.00876,            0.04438,            0.00742,           -0.00455,
 -0.01163,           -0.00683,            0.00950,            0.01275,
 -0.02124,           -0.67527,           -0.23635,            0.06298,
 -0.03844,            0.01010,            0.73588,           -0.00271,
  0.01742,           -0.00467,            0.00017,           -0.00505,
 -0.27482,            5.00521,           -1.92099,            1.55295,
 -0.35919,           -0.09314,           -0.47002,            0.06826,
  0.07924,            0.16838,           -0.04221,            0.71510,
 -0.16482,            0.08809,            41.76829,          -125.79427,
  106.65271,         -71.30642,           36.18112,           17.36143,
 -1.63846,            5.02215,           -1.08404,            0.00061,
  2.45567,           -2.42818,           -9.88756,            5.36587,
 -0.61253,           -0.35003,            1523.54790,         602.82184,
  68.66902,           1878.26100,        -1098.78095,        -120.72600,
  127.30918,         -383.96064,         -7.00838,           -6.09942,
 -1.54187,            0.34883,           -9.47561,           -4.35408,
 -21541.63676,       -32542.09807,       -29720.82604,       -28072.21231,
 -15755.56255,       -8084.58657,        -8148.87315,         7434.89857,
  11033.30133,        7827.94658,         610.18256,         -11411.93624,
 -9.87426,            0.94865,           -1.63656,            0.41275,
  1996.57150,         511.48468,          669.78228,          1363.67610,
 -379.72037,          198.84438,         -16.63126,          -79.37624,
 -2.30776,           -246.07820,         -16.85846,          -148.18168,
 -6.89632,           -20.49587,           0.39892,           -0.34627,
 -57.81309,          -136.96971,          15.25671,          -96.61153,
  16.09785,          -8.79091,            0.70515,            1.16197,
  0.05647,            0.04684,            0.25032,           -0.19951,
  0.07282,           -0.00696,            0.00493,            0.00733,
 -0.01085,            0.00422,           -0.01309,            0.00262,
  0.37616,           -0.36203,           -0.11154,            0.18213,
  0.15691,            0.29343,            0.00485,            0.06106,
 -0.01492,            0.09954,            0.28486,            2.27190,
  0.33102,            1.50696,           -0.01926,            0.04901,
  0.01827,            0.00863,           -0.03315,            0.00178,
 -0.77600,           -0.48576,           -0.21111,           -0.19485,
  1.90295,            6.44856,            1.71638,            2.12980,
 -7.19585,           -0.08043,            0.07004,           -0.02764,
  0.01604,            0.01158,            0.00936,           -0.01199,
  0.18396,           -0.29234,            0.10422,           -0.00720,
  0.05196,            0.10753,            0.02859,           -0.03602,
  0.63828,            1.96280,           -0.31919,            0.85859,
 -0.10218,           -0.00673,            0.01748,           -0.02190,
  0.01266,           -0.02729,           -4.80220,            8.90557,
 -5.94059,            2.28577,           -0.19687,           -1.28666,
  0.32398,            0.14879,           -0.02619,           -0.02056,
 -0.04872,           -0.07011,           -0.04082,           -0.04740,
  0.60167,           -2.20365,           -0.27919,           -0.45957,
 -1.31664,           -2.22682,            176.89871,          13.03918,
  0.00568,            0.00560,            0.01093,            0.00486,
 -0.00948,           -0.31272,           -11.87638,          -3.68471,
 -1.74977,           -9.60468,            2.94988,           -0.57118,
  0.00307,           -0.01636,            0.02624,            0.03032,
 -0.00464,           -0.01338,            0.00935,            0.00530,
 -0.11822,            0.03328,           -0.41854,            0.04331,
  0.41340,           -0.21657,           -0.00865,            0.00849,
 -0.00374,           -0.00899,            0.01227,           -0.23462,
 -0.71894,           -0.04515,            0.00047,            0.28112,
 -0.12788,            0.11698,           -0.02030,            0.02759,
  0.02967,           -0.00092,            0.00454,            0.00565,
 -0.00026,            0.00164,           -0.01405,           -0.00862,
  0.01088,            0.05589,            0.18248,           -0.06931,
 -0.00011,            0.03713,            0.01932,           -0.00982,
 -0.13861,            0.09853,           -0.03441,           -0.02492,
  2.26163,           -5.94453,            4.14361,           -0.94105,
  0.39561,            0.75414,           -0.17642,            0.03724,
 -1.32978,           -0.56610,           -0.03259,           -0.06752,
  39.07495,           80.25429,          -28.15558,           82.69851,
 -37.53894,          -17.88963,           6.98299,           -13.04691,
 -0.48675,           -1.84530,           -0.07985,           -0.33004,
 -3.39292,            2.73153,           -17268.46134,        1144.22336,
 -16658.48585,        5252.94094,        -3461.47865,         2910.56452,
 -433.49442,         -305.74268,         -383.45023,          545.16136,
  313.83376,          27.00533,          -31.41075,           7.90570,
 -12.40592,           3.01833,           -0.83334,            0.23404,
  59.26487,          -112.74279,          113.29402,         -15.37579,
  14.03282,           32.74482,          -4.73299,            1.30224,
 -0.00866,            0.01232,           -0.53797,            0.00238,
 -0.07979,            0.04443,           -0.05617,           -0.05396,
  0.10185,           -1.05476,            0.43791,           -0.32302,
  0.06465,            0.03815,            0.00028,           -0.00446,
  0.09289,           -0.06389,            0.01701,           -0.01409,
  0.47101,            0.16158,            0.01036,           -0.39836,
  0.00477,            0.01101,           -2.06535,            0.33197,
 -0.82468,           -0.41414,            0.03209,           -0.09348,
  0.00843,           -0.00030,           -9.49517,           -3.82206,
  0.66899,           -10.28786,           6.33435,            1.73684,
 -0.98164,            2.25164,           -0.07577,           -0.00277,
  1.02122,            0.75747,            1.79155,           -0.77789,
 -2.56780,           -2.07807,            0.19528,            0.77118,
 -0.28083,            0.32130,           -0.04350,           -0.07428,
 -0.01161,            0.01387,            0.02074,            0.19802,
 -0.03600,            0.04922,           -0.19837,            0.02572,
 -0.00682,           -0.04277,           -0.01805,            0.00299,
  0.03283,           -0.02099,            3.57307,            1.17468,
  0.65769,            1.88181,           -0.39215,            0.08415,
 -0.53635,           -0.19087,           -0.12456,            0.02176,
  0.01182,           -0.07941,           -2.43731,            2.44464,
  1.03961,           -1.81936,            30.33140,           0.92645,
  0.00508,           -0.01771,           -81.06338,           66.43957,
  33.16729,           131.44697,          76.63344,          -34.34324,
 -35.33012,          -28.04413,          -1.47440,            13.09015,
  0.13253,           -0.01629,            0.02187,           -0.00963,
 -21.47470,          -9.44332,           -7.21711,           -12.59472,
  1.76195,           -1.63911,            0.09060,            0.28656,
  0.00635,            0.00536,            0.03470,           -0.06493,
  0.00666,           -0.01084,            0.01116,           -0.01612,
 -0.00102,            0.00208,           -0.05568,            0.00628,
  0.02665,           -0.01032,            0.21261,           -1.90651,
  0.72728,           -0.57788,            0.08662,            0.10918,
  3.39133,            3.97302,           -4.63381,            4.26670,
 -2.50873,           -3.76064,            1.28114,            1.81919,
  1.48064,           -0.37578,           -0.26209,           -0.47187,
  0.00282,           -0.00499,            0.01749,            0.03222,
  1.60521,           -1.79705,            1.61453,            0.68886,
 -0.29909,            0.55025,           -0.07894,            0.19880,
 -0.15635,            0.46159,            2.09769,            1.52742,
 -7.60312,            11.34886,           4.35640,            8.61048,
  2.15001,           -2.15303,           -0.61587,           -0.11950,
 -0.03289,           -0.00520,           -0.00501,           -0.00445,
  0.15294,           -0.05277,            0.02455,            0.00408,
  1.19601,            0.43479,            0.20422,            0.57125,
 -0.12790,            0.01318,           -0.15275,           -0.43856,
  6.99144,           -0.08794,           -1.69865,            0.82589,
 -0.20235,            0.97040,            0.20903,            0.00675,
  0.26943,            0.08281,            0.03686,            0.05311,
  1.28468,            1.21735,           -1.38174,            1.29570,
 -0.75899,           -1.17168,            0.44696,           -0.32341,
 -0.06378,           -0.27573,           -0.06406,            0.87186,
  0.21069,            0.19724,            0.00119,           -0.04147,
  0.39279,            0.51437,           -0.11035,            0.21450,
 -0.04309,            0.02359,            0.20490,            0.14210,
  0.00007,           -0.00017,           -0.03529,           -0.02644,
  0.10710,            0.44476,           -0.02632,           -0.01817,
  2.11335,           -0.04432,            0.18206,            0.27335,
  0.08867,            0.00313,           -0.00692,            0.01595,
 -0.72957,            0.32080,           -0.29291,           -0.44764,
  0.12767,           -0.05778,            0.04797,           -0.00223,
  0.17661,            0.22427,           -0.04914,            0.09114,
  0.12236,            0.00708,            0.74315,           -0.01346,
  0.02245,           -0.02555,           -0.30446,            0.13947,
 -0.12340,           -0.18498,           -0.04099,            0.02103,
  0.06337,           -0.01224,            0.28181,           -0.01019,
 -0.02794,           -0.09412,            0.03272,           -0.01095,
  0.11247,           -0.00650,           -0.01319,           -0.04296,
  0.04653,           -0.00423,            0.06535,            0.00014);

uratabl: array[0..531] of double = 
( 21.56000,          -4652.06828,         154246324.90417,    1130486.05080,
  330.11531,         -3020.20235,        -8.03769,           -122.02019,
  212.45130,          254.23866,          25.39758,           60.08296,
  6949.85053,         51951.42606,       -1834.66531,         44481.91144,
 -3267.45825,         10776.65972,       -628.05388,          532.83011,
 -16.80583,          -30.05544,           1420.33767,         2007.21040,
  592.32842,          1541.61732,        -163.55984,          121.14134,
  114.74969,         -16.04944,           0.06069,            0.00725,
 -0.16861,            0.28785,            0.07399,           -0.09680,
  0.19936,           -0.41620,            0.02922,            0.07398,
  0.17272,            0.05602,            1.65461,           -0.68278,
 -2.18745,           -0.85327,            0.52467,           -0.30863,
  0.01598,            0.30017,           -0.04190,           -0.03288,
 -0.02013,            0.02257,           -0.54883,           -0.22701,
 -0.09257,           -0.03921,            0.02644,            0.04667,
  0.24773,           -0.16562,            44242.85814,       -223163.54065,
  123776.84417,      -206375.74884,       70472.73820,       -27456.55173,
  4065.74401,         13202.39154,       -3260.72648,         802.50579,
 -153.13236,         -503.81026,          30.17812,          -31.91893,
 -65.14719,           77.78417,          -37.38185,           19.13337,
 -3.14043,           -0.21147,            0.27143,            0.17424,
  0.04458,            0.10976,           -0.41841,           -0.21887,
 -0.09194,           -0.02303,            0.02896,            0.10044,
  0.01385,            0.01723,           -0.01126,           -0.09318,
 -57.95890,           29.69059,          -46.41390,           3.07177,
  0.42494,            2.33678,           -3.09621,            0.05256,
 -0.02134,           -0.35202,           -0.44475,           -0.83135,
  1318.18265,         25605.86848,       -9168.38371,         18917.31507,
 -5145.74480,         2130.77612,        -485.25920,         -438.44867,
  19.97802,          -33.14800,          -23383.91826,       -45133.19122,
 -18520.80729,       -26549.95198,       -2276.70124,        -2974.01604,
  603.23665,          306.87616,         -87.73070,          -32.49134,
  549975.14525,       261920.31896,       526261.09735,       362619.26839,
  150616.68873,       164643.90808,       9550.02662,         27381.83042,
 -1065.89047,         1024.20231,        -66.63822,          -44.75169,
 -92.10532,          -20.26930,          -313205.95341,       1462242.64616,
  112982.53079,       1865690.41965,      308844.30901,       639864.93227,
  89716.32843,        10378.80773,        4395.08428,        -14565.35913,
 -3016.07754,        -19348.64612,        3838.36899,        -9813.42713,
  6883.58821,        -6064.92588,         2740.47455,        -176.29547,
  241.91895,          268.44181,         -6.13397,            17.92503,
 -0.01377,           -0.08742,            387.51915,          257.03872,
  152.81792,          221.56197,         -22.94836,           29.56640,
 -2.27801,            4.72805,           -6.03420,           -0.36763,
  0.00667,            0.00443,           -0.01405,            0.04658,
 -0.06533,           -0.01966,            0.10738,            0.00443,
  0.02889,            0.01056,            0.00900,           -0.02206,
  0.00013,            0.05281,            0.03035,            0.34793,
  0.19460,            2.47360,            0.18189,           -0.83895,
  0.24983,            15.32050,           0.46010,            2.79643,
 -0.45793,            0.96707,           -0.31226,            0.51911,
  0.04071,            0.39399,            0.00038,            0.03854,
  0.22446,            0.13630,           -0.04357,            0.03635,
  0.00202,           -0.04502,           -0.00458,           -0.03884,
  1.32597,            3.40849,           -1.67839,           -0.95411,
 -1.00116,           -0.72744,           -0.22484,           -0.27682,
 -0.18069,            0.00405,           -0.01000,            0.27523,
 -0.07038,           -0.01051,           -0.09064,            0.08518,
  0.02083,           -0.25406,            0.17745,           -0.00944,
  0.21326,            0.20454,            18.84894,          -7.64400,
  0.62670,           -11.02728,           8.91329,            20.67190,
  0.17757,           -0.15471,           -0.11385,           -0.46057,
  6.23014,           -14.46025,           2.30012,           -2.22677,
  5.16823,           -1.64235,           -274.58413,          833.33247,
 -191.26241,          269.90157,         -17.25965,           9.11368,
 -261.65136,         -18274.45858,       -2553.83872,        -10039.10490,
 -508.52567,          336.18172,          14.88587,           421.35954,
  162.43462,          544.92580,         -0.44246,            0.23216,
 -0.29024,           -0.13057,           -1.58438,            0.34032,
 -0.31604,           -0.01166,           -0.07112,            0.05721,
 -0.10813,            0.01064,           -0.05413,            0.06705,
 -0.41582,           -0.47725,            0.31031,            0.08605,
  0.00409,            0.02373,            0.08092,            0.06247,
 -0.01026,            0.05863,           -0.00238,            0.02948,
  0.00117,            0.02714,            0.01720,            0.18261,
 -0.04067,            0.88639,           -0.15502,           -0.96383,
 -0.05307,           -0.17319,           -0.00486,           -0.02373,
 -0.14748,           -0.11884,            0.07798,           -0.00358,
  0.01104,            0.00805,            0.15099,           -0.03453,
  0.01846,            0.03459,            0.02197,            0.07012,
 -0.43677,           -1.87445,            1.35202,            2.28294,
 -0.03592,            0.07679,            0.16427,            0.03014,
  0.02472,            0.05549,           -0.04985,            0.05874,
  0.35361,            0.01144,           -0.57400,            1.34898,
  0.00265,            0.01540,            0.00951,            0.08159,
 -0.00435,            0.34759,           -0.12413,           -0.49848,
 -0.77075,           -2.73810,           -31.77702,           12.16042,
 -14.87605,           11.98287,           12.69358,           1.31307,
 -8.22911,           -21.47437,          -0.24051,           -0.38332,
 -0.01162,           -0.03175,            0.00556,            0.02454,
 -0.02297,           -0.01654,            0.00707,            0.04828,
 -0.00309,            0.17381,           -0.00500,           -0.07579,
  0.02008,            0.05356,            0.00702,            0.01133,
 -0.00237,           -0.00612,            0.18551,            0.22799,
 -0.14194,           -0.08593,            0.00002,           -0.01049,
 -0.17363,           -0.13986,            0.00078,           -0.06993,
 -0.00430,           -0.07795,           -0.03232,           -4.13170,
  0.00311,            0.05356,           -0.17324,           -0.15505,
 -0.00590,           -0.06608,            0.04257,           -0.04571,
  0.00501,            0.02141,           -0.00037,            0.07845,
 -0.00381,           -0.03417,            0.01834,            0.03349,
  0.07994,            0.15297,           -0.82299,            0.24672,
  0.51764,            0.96379,            0.01729,            0.02489,
 -0.08581,            0.13252,            0.00538,            0.01995,
 -0.00148,           -0.02261,            0.00534,            0.01565,
 -0.07518,           -0.28114,            0.22386,            0.39023,
 -0.00864,            0.00964,           -0.01923,           -0.02426,
 -0.00112,            0.00923,           -0.00685,            0.02450,
  0.26733,           -0.99972,           -0.82005,            0.13725,
  0.01520,           -0.00790,            0.00358,            0.00751,
 -0.00648,           -0.00605,           -0.04966,           -0.04633,
  0.06394,           -0.01965,            0.50185,            0.40553,
 -0.25809,            0.28853,            0.52545,           -3.41675,
 -0.00347,           -0.11848,            0.02945,           -0.01061,
 -0.04160,           -0.03519,           -0.03234,           -0.81852,
 -0.02156,           -0.00841,            0.00029,            0.00020,
 -0.02281,           -0.00364,            0.04738,           -0.04504,
 -0.19161,            0.37225,            0.05765,            0.11987,
  0.00050,            0.02012,           -0.03806,            0.39498,
  0.29982,            0.00886,            0.01671,            53.04042,
 -0.04160,           -0.38856,           -0.00174,           -0.01773,
 -0.47661,           -0.32010,           -0.01088,           -0.16231,
 -0.01584,           -0.00144,            0.06659,            0.12734,
  0.04884,            0.02236,            0.00146,            0.06030,
 -0.20660,           -0.03982,            0.15091,            1.24562,
 -0.01303,           -0.22426,           -0.01518,           -0.03922,
 -0.00043,           -0.00047,            0.02451,            0.04437,
  0.02380,           -0.00189,           -0.00640,           -0.07114,
 -0.00320,           -0.02491,           -0.00829,            0.07284,
  0.02846,           -0.28034,           -0.00268,            0.00256,
 -0.43420,            0.39645,           -0.31053,            1.25916,
 -0.00371,           -0.00651,           -0.00096,            0.02762,
 -0.00067,           -0.02503,           -0.01517,            0.03748);

uratabb: array[0..531] of double = 
( 0.00000,            107.91527,          83.39404,          -124.29804,
 -7.73277,           -3.99442,           -0.08328,           -1.74251,
 -9.05659,           -22.88559,          -2.30655,           -4.40259,
 -470.94604,         -3648.43408,         326.28960,         -2972.91303,
  337.37285,         -650.33570,          57.18479,          -18.29130,
  1.13897,            2.70158,           -13.64388,          -71.88619,
  7.36408,           -43.79994,           6.57463,           -5.81111,
 -0.06451,            0.73379,            0.00574,           -0.01635,
  0.00074,           -0.01496,           -0.00418,            0.00647,
 -0.00407,            0.00548,            0.00002,            0.00187,
 -0.00591,            0.00557,            0.32568,           -0.01574,
  0.19347,           -0.01705,            0.00173,            0.02384,
 -0.00248,           -0.00103,            0.00227,            0.00146,
  0.00307,           -0.00040,            0.03886,            0.01987,
  0.00546,            0.00345,            0.00134,           -0.00609,
 -0.01502,           -0.01569,           -10080.59325,        10806.67752,
 -14013.76861,        9928.38683,        -6540.83480,         2084.91597,
 -1093.05006,        -305.34266,         -9.04558,           -110.32310,
  9.26094,           -3.93195,            0.25552,            0.50327,
 -13.12170,          -4.19317,           -4.50857,           -3.37626,
 -0.26850,           -0.36028,           -0.00357,            0.05862,
 -0.00828,            0.00926,           -0.01515,           -0.03687,
 -0.00224,           -0.00802,           -0.00225,           -0.00158,
 -0.00022,           -0.00044,           -0.00281,            0.00371,
  2.28259,           -4.29888,            1.74622,           -2.13604,
  0.37023,           -0.37022,            0.00886,            0.07081,
  0.01669,            0.00056,           -0.02020,            0.01586,
 -4255.31929,         5978.03267,        -7264.48027,         1884.12585,
 -2353.93882,        -1593.23001,         17.57205,          -498.54139,
  33.28704,          -13.79498,          -38416.64883,       -13774.09664,
 -32822.03952,       -3983.42726,        -7538.09822,         1906.66915,
 -221.24439,          512.77046,          32.26101,           12.46483,
  142710.47871,      -96584.83892,        145395.05981,      -86630.96423,
  48202.96749,       -23596.77676,        5286.16967,        -1626.44031,
 -16.53568,           95.15428,          -15.19472,           5.69207,
 -6.72181,            7.28683,            9515.16142,        -166495.49381,
  5588.84271,        -146260.29445,       2023.55881,        -30687.22422,
  243.64741,          971.58076,          390.73247,         -236.13754,
 -2684.56349,         739.81087,         -597.39429,          474.89313,
 -631.69166,          213.04947,         -204.89515,         -33.09139,
 -17.78004,          -22.21866,           0.61083,           -1.41177,
 -0.00070,           -0.00501,           -58.24552,           25.27978,
 -36.39386,           0.36376,           -2.21030,           -6.46685,
 -0.58473,           -0.09357,            0.12829,           -0.94855,
  0.00042,            0.00048,            0.00411,            0.00101,
  0.00249,           -0.00865,            0.00223,            0.00293,
  0.00041,           -0.00042,            0.00104,           -0.00086,
  0.00126,           -0.00380,            0.00906,           -0.02253,
  0.05998,           -0.10318,            0.00004,           -0.03225,
  0.14303,           -0.05273,            0.32683,            0.09386,
 -0.17053,            0.60847,           -0.06190,            0.28166,
  0.06411,            0.05289,            0.01138,            0.00128,
 -0.00930,            0.00272,            0.00037,            0.00215,
  0.00004,            0.00050,            0.00114,           -0.00217,
  0.05358,           -0.06413,           -0.00124,            0.03842,
  0.01006,            0.22479,            0.00412,            0.04040,
  0.01708,            0.02164,            0.02484,           -0.02463,
 -0.00103,            0.02633,           -0.01303,           -0.03214,
  0.03613,            0.02205,           -0.02677,           -0.02522,
 -0.00293,            0.03130,           -1.87255,           -2.50308,
 -1.53715,            0.36859,           -0.17829,           -1.12095,
 -0.05652,           -0.00786,           -0.06992,            0.07279,
 -2.95896,            0.55138,           -0.61498,           -0.11008,
 -0.87790,           -0.50965,            119.73553,         -35.18217,
  44.78683,          -4.22438,            1.95723,            0.58033,
 -4077.02379,        -353.39110,         -2781.63273,        -75.23318,
 -312.50478,         -23.86495,           24.59887,           32.56837,
  120.09593,         -51.00495,           0.09737,            0.09111,
  0.04799,           -0.05029,            0.08351,           -0.33726,
  0.03158,           -0.06435,           -0.00523,           -0.01736,
  0.00751,           -0.01757,           -0.00406,           -0.01198,
  0.16402,           -0.10986,           -0.02024,            0.07205,
 -0.00440,           -0.00072,           -0.00465,            0.00310,
 -0.00121,           -0.00121,            0.00083,            0.00020,
  0.00140,           -0.00176,            0.00381,           -0.00731,
 -0.01618,            0.01570,           -0.10201,            0.05809,
 -0.03359,            0.01024,           -0.00535,            0.00018,
  0.00024,            0.00509,           -0.00158,           -0.00466,
  0.00009,           -0.00083,           -0.00700,           -0.00090,
 -0.00011,           -0.00079,            0.00133,           -0.00126,
  0.01416,            0.05553,            0.04283,           -0.06719,
  0.00119,            0.00291,           -0.00263,            0.01282,
 -0.00040,            0.00188,           -0.00237,            0.00973,
 -0.39533,            0.18773,           -0.79821,           -0.40168,
  0.00151,           -0.00161,            0.00123,           -0.00516,
 -0.01432,           -0.00293,           -0.05477,            0.04130,
 -0.48837,            0.18944,           -0.12552,            9.37098,
  1.02045,            5.11382,            0.72098,           -3.70049,
 -5.80982,            3.30105,           -0.09682,            0.09696,
 -0.00876,            0.00504,            0.00318,            0.00245,
  0.00563,           -0.00665,            0.00108,           -0.00233,
 -0.00117,            0.00177,           -0.00343,            0.00503,
  0.01044,           -0.00651,            0.00296,           -0.00162,
  0.00037,            0.00028,           -0.00020,           -0.00786,
  0.00029,            0.00836,            0.00004,            0.00033,
 -0.00309,           -0.00086,           -0.00157,           -0.00086,
 -0.00058,            0.00105,           -0.04557,            0.01794,
 -0.00122,           -0.00086,            0.00420,           -0.00285,
  0.00118,           -0.00020,            0.00743,           -0.01217,
  0.00053,           -0.00084,           -0.00075,            0.00097,
 -0.00107,            0.00314,            0.00576,           -0.00505,
  0.03624,           -0.02546,            0.05379,            0.30081,
  0.29870,           -0.22106,            0.00696,           -0.00801,
 -0.03995,           -0.01808,           -0.00139,            0.00102,
 -0.00059,            0.00138,            0.00019,           -0.00037,
  0.00274,            0.00658,            0.00672,           -0.01132,
  0.00023,            0.00051,            0.00031,            0.00090,
 -0.00017,           -0.00001,            0.00085,            0.00004,
  0.02221,           -0.01977,            0.07498,            0.03025,
 -0.00082,           -0.00022,           -0.00073,           -0.00028,
 -0.00253,            0.00259,           -0.01329,            0.01805,
  0.00096,            0.00833,           -0.11836,            0.04277,
 -0.10820,           -0.03018,            0.34504,            0.09834,
 -0.00538,           -0.00231,            0.00036,            0.00042,
 -0.00023,            0.00260,           -0.01137,            0.00036,
  0.01081,           -0.03271,           -0.00029,           -0.00028,
  0.00018,           -0.00003,            0.00009,            0.00012,
  0.00127,            0.00343,            0.00100,           -0.00064,
  0.00014,            0.00004,            0.00150,            0.00069,
 -0.01484,            0.00135,            0.03930,            0.01405,
  0.00064,            0.00029,            0.00009,            0.00009,
  0.00054,           -0.00048,            0.00019,            0.00005,
 -0.00009,            0.00018,            0.00192,           -0.00333,
  0.01824,            0.01071,            0.00107,           -0.00341,
  0.25530,           -0.18414,           -0.84151,           -0.31475,
 -0.00400,           -0.00010,           -0.00174,            0.00019,
  0.00006,           -0.00079,            0.00066,           -0.00070,
  0.00599,            0.00330,           -0.00160,           -0.00013,
 -0.00067,           -0.00006,           -0.00176,           -0.00111,
  0.00652,            0.00368,            0.00004,            0.00001,
 -0.00081,            0.00089,            0.00366,            0.00139,
  0.00002,            0.00001,           -0.01870,           -0.00998,
 -0.00020,           -0.00007,            0.00005,            0.00003);

uratabr: array[0..531] of double = 
( 0.00000,           -53.23277,          -44.70609,          -62.54432,
 -19.15218,           0.10867,           -1.91911,            1.47517,
  16.51994,           5.00458,            3.88980,            1.55740,
  3598.17109,         1831.07574,         2633.34851,         1775.69482,
  497.10486,          488.77343,          6.03892,            31.08365,
 -2.06585,           -1.12599,            230.37762,         -113.95449,
  162.40244,         -46.57185,           6.70207,            17.27241,
 -0.66092,           -14.42065,          -0.01044,           -0.00287,
 -0.03894,           -0.01663,            0.01629,            0.00496,
  0.08411,            0.02855,            0.01795,           -0.00695,
  0.02426,           -0.03921,           -0.24495,           -0.77369,
 -0.31404,            0.38668,           -0.05682,           -0.17197,
  0.06145,           -0.00510,            0.00606,           -0.00886,
 -0.00370,           -0.00588,            0.02173,           -0.11909,
  0.00302,           -0.01796,           -0.01067,            0.00990,
  0.05283,            0.06517,            59710.89716,       -491.12783,
  58672.38609,        19564.41947,        10597.99050,        14313.02561,
 -2585.52040,         766.78396,         -138.39893,         -802.43403,
  131.35006,         -31.97561,           7.95978,            8.16075,
  28.72669,           31.72473,           6.45792,            16.50701,
  0.01066,            1.29718,            0.11565,           -0.13240,
  0.05110,           -0.01543,           -0.09994,            0.18864,
 -0.01330,            0.04148,            0.03510,           -0.00366,
  0.00604,           -0.00604,            0.03752,           -0.00256,
 -7.00488,           -21.63748,           1.43064,           -17.10914,
 -0.62987,            0.48719,            0.00697,           -1.22665,
 -0.14435,           -0.00550,            0.32008,           -0.19855,
 -13976.73731,       -3559.49432,        -7709.90803,        -9310.80334,
  749.31835,         -3491.50696,         540.94979,         -84.57550,
  16.96663,           35.53930,           37214.64771,       -36361.15845,
  21093.74492,       -31855.33076,        1500.84653,        -7031.97901,
 -453.40865,         -18.36692,          -2.07726,           -17.92336,
 -56348.30507,        378512.71483,      -111444.43340,       370543.95160,
 -61893.70301,        112131.05507,      -11977.44617,        9156.15245,
 -567.61838,         -495.25760,          16.96202,          -44.06279,
  4.24760,           -48.83674,          -643705.49516,      -131013.09649,
 -838580.02217,       67627.11556,       -288441.70339,       150227.25291,
 -2500.57537,         42676.19888,        7084.60505,         2043.65642,
  9639.56835,        -1502.03390,        -4126.00409,        -828.73564,
 -2801.35204,        -2293.77751,        -209.23365,         -1045.31476,
  95.57334,          -102.74623,          7.19216,            1.89593,
 -0.05661,            0.02166,            120.38332,         -141.16507,
  98.31386,          -40.23448,           10.84269,           17.57713,
  1.69239,            1.45065,           -0.19626,            2.76108,
 -0.00270,            0.00360,           -0.02333,           -0.00710,
 -0.01035,            0.02950,            0.00737,           -0.06311,
 -0.00613,            0.01407,            0.01377,            0.00879,
 -0.03287,            0.00012,           -0.21667,            0.01793,
 -1.54865,            0.10953,            0.54543,            0.12102,
 -9.48047,            0.11477,           -1.34966,            0.23199,
 -1.50834,            0.26567,           -0.64503,            0.10742,
 -0.21452,            0.04428,           -0.01920,           -0.00906,
 -0.09378,            0.12773,           -0.02787,           -0.03090,
  0.03111,            0.00140,            0.03771,           -0.01269,
 -1.94794,            1.22823,            0.64183,           -1.11467,
 -0.19301,           -0.27357,            0.05710,           -0.08115,
 -0.07318,            0.00806,            0.14286,            0.20297,
  0.14920,           -0.07897,            0.09682,            0.02379,
 -0.13928,            0.01679,           -0.00774,            0.10060,
  0.24433,            0.16760,           -2.88905,           -1.61439,
  2.83052,           -3.41031,            36.37048,           3.37867,
  0.29321,            0.09687,            0.29324,           -0.14651,
  8.11116,            1.79211,            1.36421,            0.88111,
  1.21683,            2.37950,           -357.76211,         -87.84636,
 -117.55745,         -67.18338,          -5.26029,           -6.27559,
  7509.94562,         3.68942,            4223.62097,        -1041.13557,
 -74.64464,          -251.41613,         -166.22180,         -1.68190,
 -214.55340,          62.79593,          -0.08250,           -0.15936,
 -0.03830,            0.10857,            0.21368,            0.50812,
  0.00869,            0.09832,            0.02158,            0.02045,
  0.01407,            0.03591,            0.03460,            0.01171,
 -0.16400,            0.09751,            0.03521,           -0.12858,
  0.00700,           -0.00524,            0.01698,           -0.04796,
  0.04006,            0.00565,           -0.02783,           -0.00205,
 -0.02296,            0.00153,           -0.16139,            0.01514,
 -0.78136,           -0.01546,            0.40374,           -0.06014,
  0.06212,           -0.01828,            0.00831,           -0.00173,
  0.06857,           -0.11677,            0.00028,            0.05765,
 -0.00796,            0.00691,            0.03764,            0.14902,
 -0.02653,            0.02122,           -0.05503,            0.01549,
  1.56630,           -0.35551,           -1.87960,            1.14303,
 -0.06063,           -0.03425,            0.03367,           -0.11969,
  0.04485,           -0.01651,            0.04647,           -0.02097,
  0.22841,            0.47362,            0.99226,           -0.60660,
 -0.01249,            0.00134,           -0.07435,            0.00722,
 -0.31796,           -0.00015,            0.20533,           -0.04398,
  0.93944,           -0.26710,           -5.60051,           -9.32918,
 -5.13538,           -4.05130,           -0.56529,            4.34112,
  7.18308,           -2.66103,            0.13241,           -0.07999,
  0.01046,           -0.00535,           -0.04037,           -0.00455,
 -0.00510,            0.00731,           -0.04576,            0.00513,
 -0.15846,           -0.00236,            0.04628,           -0.00463,
 -0.01585,            0.00585,           -0.00213,            0.00283,
  0.00778,           -0.00198,           -0.17803,            0.18321,
  0.07702,           -0.12325,            0.01091,            0.00349,
  0.14211,           -0.21830,            0.07289,           -0.00994,
  0.07090,           -0.00079,            4.18441,           -0.07413,
 -0.06247,           -0.00011,           -0.15453,            0.14499,
 -0.06557,           -0.00098,            0.00290,            0.02921,
 -0.01923,            0.00457,           -0.07538,           -0.00120,
  0.02263,           -0.00037,           -0.01061,            0.00591,
 -0.04725,            0.02364,           -0.07460,           -0.24108,
 -0.28310,            0.14643,           -0.00700,            0.00427,
  0.22963,            0.03713,           -0.02062,            0.00478,
  0.01434,            0.00095,           -0.01425,            0.00376,
  0.29611,           -0.08038,           -0.37811,            0.21703,
 -0.00723,           -0.00924,           -0.02736,            0.01814,
  0.00934,            0.00731,            0.00613,            0.00686,
 -0.91503,           -0.32009,           -0.15505,            0.79589,
 -0.00555,           -0.01536,           -0.00698,            0.00480,
  0.00373,           -0.00046,            0.00715,           -0.00470,
 -0.01970,           -0.05238,            0.60649,           -0.32669,
  0.17790,            0.33383,           -2.74922,           -0.25827,
 -0.07862,            0.00406,           -0.00948,           -0.02117,
  0.03127,           -0.04199,            0.89670,           -0.02413,
  0.01954,            0.03990,            0.00063,           -0.00071,
 -0.00226,            0.02009,           -0.04407,           -0.05069,
  0.38230,            0.16101,            0.11893,           -0.06125,
  0.02051,           -0.00046,            0.39211,            0.03679,
  0.01666,           -0.31336,            53.28735,          -0.01791,
 -0.39414,            0.04181,           -0.01885,            0.00165,
  0.31349,           -0.47359,            0.16133,           -0.01023,
  0.00007,            0.01758,           -0.13351,            0.07249,
  0.00977,            0.05445,            0.11650,           -0.00191,
 -0.09824,            0.40106,            2.41155,           -0.30655,
  0.24975,           -0.01248,           -0.03688,            0.01097,
  0.00038,           -0.00051,           -0.04736,            0.02610,
  0.00968,            0.02634,            0.07918,           -0.00606,
  0.02735,           -0.00320,           -0.07544,           -0.00468,
  0.19996,           -0.01964,            0.00201,            0.00267,
  0.39562,            0.43289,            1.24743,            0.31084,
 -0.00666,            0.00377,            0.05668,            0.00148,
  0.03220,           -0.00026,            0.03717,            0.01509);

neptabl: array[0..161] of double = 
(-1376.86480,         730.38970,          78655362.50948,     1095691.38676,
 -196.19023,          2086.77782,        -122.04650,         -276.81592,
  184.56164,         -148.08924,          3.39142,           -14.75027,
 -9.22741,            0.87688,           -0.13903,           -0.44707,
 -0.17668,           -0.36299,           -0.12682,           -0.26636,
 -0.51426,           -0.24667,           -0.04965,           -0.03177,
  0.05050,           -0.00249,           -0.80362,           -0.07363,
 -0.15436,           -0.07180,            2.45034,           -3.50145,
  0.86698,            0.09777,            7.72386,            7.16565,
  2.10273,            8.86682,            2.44705,            77.90155,
  0.28323,           -11.87157,          -13.64083,           252.70556,
 -4.94214,           -6.17988,           -305.60504,          51.23962,
 -2759.81719,         2476.20912,         12.65762,           13.31543,
  0.36996,           -0.19077,            0.67363,            0.36737,
  0.02312,            0.02216,            0.09953,            0.04777,
 -0.00572,           -0.02772,           -0.02478,           -0.21920,
 -0.15289,           -1.50784,           -0.17822,            0.34638,
 -0.70473,           -8.61559,           -2.65756,            1.25632,
 -0.31453,           -1.40348,           -4.02571,           -1.50467,
 -69.62308,           3.21315,            0.69973,            0.08832,
 -0.00551,           -0.04964,           -0.02264,           -0.34881,
  0.00762,           -1.85072,            0.01407,           -0.30457,
 -0.09851,           -0.02372,           -0.07729,           -0.11602,
 -0.75995,           -0.71884,           -0.08585,           -0.30406,
  0.45818,            0.14921,           -0.01033,           -0.11776,
  0.00640,           -0.57717,           -0.01014,           -0.01357,
 -0.00544,           -0.02168,            0.40468,            0.28195,
  0.00668,            0.14448,            0.01245,           -0.08956,
 -0.26283,            0.01864,           -0.00641,            18.55347,
  0.01460,            0.08284,           -0.04785,            0.11360,
 -0.33861,            0.01327,           -0.06392,           -0.18758,
  0.05449,           -0.05583,           -0.00435,           -0.09869,
 -0.00286,           -0.04613,           -0.00395,           -0.14564,
 -0.01385,           -0.01762,            0.21160,           -0.61631,
 -0.52100,           -0.04583,            0.32812,            0.32138,
  0.04749,           -0.05724,            0.11239,            0.13216,
 -0.01203,            0.40084,           -0.05207,            34.07903,
 -0.21457,           -0.34938,           -0.04594,            0.11198,
 -0.30662,           -0.20776,           -0.01076,           -0.10959,
  0.10891,           -0.10304,           -0.28141,            0.25061,
 -0.20293,            0.79930);

neptabb: array[0..161] of double = 
(-391.05987,         -243.95958,         -23.83558,           58.13857,
  5.04859,           -3.93183,           -14.21914,           7.14247,
 -12.09415,          -9.70132,            1.04307,            0.47323,
 -0.07504,            0.70575,           -0.05239,            0.00482,
 -0.02916,            0.00877,           -0.00528,           -0.00286,
  0.00028,           -0.00228,           -0.00056,           -0.00149,
  0.00049,            0.00047,           -0.18765,           -0.59571,
  0.03742,           -0.14653,            2.30535,            0.65092,
  0.42216,            0.24521,           -2.86932,            2.37808,
 -0.58456,            0.27446,           -1.12264,           -2.04413,
 -11.71318,          -1.41554,           -23.30671,          -24.70499,
  8.82738,            85.64657,          -90.02223,           22.42604,
 -4749.41359,        -4244.46820,         25.20811,          -18.51469,
 -1.19892,           -0.61067,            0.67734,           -1.08912,
 -0.01607,            0.00626,           -0.00008,            0.00126,
 -0.00330,           -0.00078,           -0.01503,            0.00758,
 -0.13208,           -0.00218,           -0.04522,            0.20297,
 -0.94708,           -0.77897,           -2.74075,           -3.01122,
 -1.03394,            0.00886,            1.55485,           -4.68416,
 -0.13244,           -57.26983,           0.05589,           -0.55396,
 -0.00130,            0.00526,           -0.01028,            0.02086,
  0.01334,            0.00699,            0.08565,            0.02020,
  0.01001,           -0.08402,            0.08558,           -0.04488,
  0.57268,           -0.59574,            0.00807,            0.00492,
  0.21993,           -0.18949,           -0.00396,            0.00735,
  0.00487,            0.00230,            0.00699,           -0.00473,
  0.01406,           -0.00139,            0.00738,            0.00099,
  0.00161,            0.00019,           -0.00067,           -0.00047,
  0.00572,           -0.00486,           -0.00842,            0.00322,
  0.00018,           -0.00109,           -0.00272,            0.00112,
 -0.00041,            0.00763,            0.00211,            0.00118,
 -0.46842,           -0.17877,            0.00209,           -0.00179,
  0.00090,           -0.00075,            0.00618,            0.00610,
  0.00015,            0.00032,           -0.00123,            0.00026,
  0.00332,            0.00135,            0.39130,           -0.34727,
  0.00015,           -0.00027,           -0.00026,           -0.00052,
  0.00162,            0.00913,           -0.00697,            0.00308,
 -0.00333,           -0.00258,           -0.00117,            0.00035,
  0.00766,            0.00194,            0.00135,            0.00067,
 -0.41171,            0.24241,            0.00106,            0.00025,
  0.00013,           -0.00019);

neptabr: array[0..161] of double = 
(-767.68936,         -460.59576,         -52.41861,          -273.85897,
  59.52489,           1.85006,           -39.64750,           23.63348,
 -34.60399,          -23.41681,           2.74937,            1.55389,
  0.20343,            2.15502,           -0.12846,            0.07199,
 -0.07555,            0.05582,           -0.04354,            0.01546,
 -0.03931,            0.07623,           -0.00491,            0.00661,
  0.00322,            0.01540,           -0.06741,           -0.35343,
  0.00469,           -0.08073,            1.94975,            0.66376,
  0.06137,            0.31426,           -2.93841,            4.27732,
 -4.00342,            1.11157,           -36.87785,           1.24960,
  4.69573,            2.15164,           -114.24899,         -6.69320,
  12.99919,          -9.47795,           -21.82350,          -156.88624,
 -1237.19769,        -1379.88864,         6.54369,           -6.20873,
 -0.14163,           -0.32700,            0.17937,           -0.34864,
  0.01393,           -0.01286,            0.02876,           -0.05767,
  0.02210,           -0.00128,            0.16495,           -0.01242,
  1.15915,           -0.10365,           -0.33224,           -0.10045,
  6.83719,           -0.27499,           -0.31284,           -0.94332,
  1.63704,           -0.33318,            1.48134,           -1.32257,
  0.96498,           -8.31047,           -0.00402,           -0.09441,
  0.04292,           -0.00444,            0.30325,           -0.02012,
  1.67999,            0.00353,            0.00467,            0.03556,
  0.01393,           -0.01229,            0.01188,           -0.01390,
  0.04615,           -0.03509,            0.32423,           -0.12491,
  0.13682,            0.15131,            0.11221,           -0.01201,
  0.57239,            0.00093,            0.02068,           -0.01162,
  0.00647,           -0.00325,            0.27010,           -0.42993,
  0.14314,           -0.01353,           -0.08757,           -0.00699,
  0.00199,            0.31873,            18.80329,           0.01681,
  0.08009,           -0.00998,           -0.14421,           -0.15912,
  0.37208,            0.49744,            0.35144,            0.06582,
 -0.11501,           -0.14037,            0.10352,           -0.00768,
  0.04826,           -0.00423,            0.19850,            0.00310,
 -0.01780,            0.01350,           -0.61106,           -0.20525,
 -0.04388,            0.52143,            0.19300,           -0.21446,
 -0.05749,           -0.04776,            0.12877,           -0.10908,
  0.39821,            0.00627,            34.03956,           0.04392,
 -0.34455,            0.22015,            0.11743,            0.04638,
  0.20723,           -0.30447,            0.10976,           -0.01008,
 -0.20778,           -0.21822,            0.24939,            0.27976,
  0.79790,            0.20200);

plutabl: array[0..603] of double = 
( 74986469.33577,     100898343.73690,    48199471.54076,     9520076.03177,
  690431.67340,      -427355.12716,       52266623.77862,     860190.70714,
 -21.08511,          -143.39295,         -126.71124,          48.18528,
 -88.74508,           40.50942,           51.29367,          -10.24075,
  0.63094,            32.03258,          -410.00781,          399.90234,
 -116.54319,          51.50329,           116.84565,          687.76781,
 -13.38605,           182.70107,         -1668.12226,        -5162.22648,
 -585.68297,         -2247.56041,        -20.95875,          -193.13703,
 -57.12097,          -10.35058,          -1778.01442,        -6463.73779,
 -657.86093,         -2713.44436,        -41.32560,          -211.82042,
 -107.16513,         -36.58628,           97929588.08231,    -33582903.63417,
  143382679.31770,   -47411568.92345,     79428827.73581,    -24658834.87499,
  19861233.17488,    -5755585.62084,      1995060.95931,     -693507.08147,
  135176.31467,       109360.38672,      -8188.00598,        -1680.95072,
  71020.19608,       -70785.39049,       -24.56034,          -20.34919,
  1618.45976,        -2079.48538,         635.62954,         -850.87068,
  44.95257,          -64.04459,          -18.61475,          -1.77734,
  9.38079,            5.19958,            17422.08783,       -4872.53852,
  10985.76629,       -1137.68569,         1771.28893,         288.93745,
  40.22664,           37.90027,           6.81361,           -32.65868,
  16.97268,           11.76152,           29.33024,          -12.92289,
 -55.13187,          -14.73791,           7.52474,           -102.05060,
  182.53144,         -20.18960,          -490237997.49400,    486646248.63360,
 -781277018.26430,    602300460.57290,   -463787999.46420,    249529525.96100,
 -123964746.86420,    31353019.97807,    -13353800.92159,    -3463382.63269,
 -35469.17654,       -1035343.45385,      65076.64025,       -38181.61312,
 -16473.33813,        3928.44674,         188.60263,          1000.42530,
 -208376.39376,      -700566.62363,       114839.84613,      -342407.71113,
  39467.04812,       -14553.84849,        581895.26100,       1012499.16715,
  406317.22416,       310804.78515,       43625.07033,       -4157.26545,
 -5930.13795,        -2070.62413,         3348.17582,        -10871.23729,
  144609.18550,       60383.63650,        27912.02226,        15254.61228,
 -98561.37758,       -67442.28158,       -15573.63338,       -19931.99773,
  24323.06905,       -37473.32558,        2840.64042,        -8911.23694,
 -19636.31898,        71725.21946,       -12280.54554,        12251.00101,
  88626.52260,        5513.68450,         18506.41546,       -6513.87434,
 -83350.14621,        44300.00743,       -22075.37353,        3731.57531,
 -29167.76020,       -21642.67384,        56602666.72177,    -22225578.01823,
  50576897.80669,    -50319847.79086,     5689259.25622,     -29585299.79697,
 -4249711.27661,     -4490830.29568,     -727678.08724,       366050.85631,
  19183.62792,        55647.98226,        1897.78091,        -1091.03988,
  432.38158,         -138.62556,          101.38743,          25.67379,
  320.20735,          362.16615,          85.06067,           54.02616,
  2.39460,            18.70004,          -8.43353,            2.72100,
 -3.11205,           -3.06201,            136.31503,         -28.33620,
  48.68781,          -18.45285,           1.15302,           -1.52360,
 -0.13706,           -0.37489,            0.08750,           -0.14579,
 -0.07051,           -0.06518,            0.30237,           -0.00448,
  4.83172,            6.83684,            1752447.78043,     -945086.75857,
  2340978.12819,     -1963675.42559,      1254147.25257,     -1274861.91191,
  279459.60237,      -263954.01378,       11835.62290,       -16344.44434,
  9119.98960,        -2390.44218,        -23.67909,           86.73916,
 -642.78635,         -1290.12208,        -0.43345,           -1.85348,
  0.03094,           -0.01655,            0.12380,            0.31834,
  5.54756,           -1.63109,            1.10598,           -0.17578,
  2.66994,           -2.17573,            0.97360,           -0.92226,
 -0.18533,           -0.39747,            0.45809,           -0.65286,
  0.26129,            0.91922,            0.81068,            0.11183,
  6.32182,            14.16786,           0.20872,            3.28489,
 -1.47458,           -2.11724,            1.70020,           -1.99889,
  3.13003,            1.90638,           -4483669.52795,     -446454.90158,
 -6586256.67478,     -671890.16779,      -3620444.55554,     -499672.41074,
 -855998.32655,      -191073.94266,      -73186.69110,       -22649.38582,
 -2414.81729,        -1294.40542,         436.80907,          125.48109,
 -81.16877,           458.86508,         -11.57414,          -26.39114,
 -4.00801,           -5.01054,           -18.17569,           20.86879,
 -4.80965,            3.10535,           -4.71122,            1.18169,
  74.75544,           649.21464,         -26.55060,           272.35592,
 -8.06982,            16.86110,          -26.54868,           26.75711,
 -35.82910,           38.51063,           22.22814,           19.38336,
 -6.30462,            0.90602,            0.62856,           -0.34981,
 -0.10232,           -0.00939,            0.04439,           -0.18875,
  0.16025,            0.11306,           -0.06803,            0.06004,
 -91305.66728,        262370.61704,      -194633.44577,       304838.17733,
 -124505.90904,       94111.75602,       -22317.18255,        1575.23438,
  748.66316,         -349.78711,          166.64450,         -89.05045,
  120.76207,         -100.26715,          3.13806,            3.71747,
 -1.44731,           -0.35235,           -0.51660,           -1.50621,
  2.81310,           -3.93573,            1.20292,           -0.36412,
 -0.03340,           -0.00561,           -5.29764,            26.02941,
  1.91382,            3.30686,           -3.35265,           -3.20868,
  0.05807,           -0.11885,           -0.78588,            0.34807,
 -0.19038,            0.11295,           -0.03642,           -0.03794,
  0.00251,            0.03449,           -0.08426,           -0.00310,
  0.05297,           -0.09278,            0.10941,            0.00099,
 -228688.56632,       312567.73069,      -331458.31119,       328200.19460,
 -143760.57524,       104182.01134,      -17313.30132,        12591.15513,
 -440.32735,         -105.67674,          104.35854,         -852.84590,
  0.95527,            0.30212,           -54.63983,           4.06948,
  0.07545,           -0.13429,            16.21005,           29.24658,
  9.23410,            50.48867,           30.55641,           12.76809,
  0.11781,            0.70929,           -0.04100,            13.60859,
  0.04976,           -0.02083,            0.36279,            0.30130,
 -0.02129,            0.09363,           -0.07812,            0.01570,
 -0.06217,           -0.37181,           -29348.55031,        43889.87672,
 -35765.41577,        33855.90070,       -10128.69894,        4535.32148,
  281.75353,         -218.49194,         -7.55224,            134.28640,
  2.11319,           -2.13109,            15.71244,           11.07183,
 -0.05406,           -0.23337,           -1.28949,            1.34281,
  0.04212,           -0.02080,            0.08109,            0.14820,
 -6010.46564,         3639.41780,        -5973.16000,         1381.66999,
 -1177.36865,        -501.06937,          166.14792,         -103.36431,
  14.92766,           4.12877,           -2.20893,           -6.32033,
 -0.29038,           -0.43172,           -0.59341,            0.20477,
 -0.13143,           -0.03150,            0.10992,            0.01976,
 -0.00254,            0.02028,           -0.30044,           -0.44658,
 -0.03409,           -0.10758,            0.08349,            0.06153,
 -0.06055,            0.18249,           -1.15341,           -8.68699,
 -0.11348,           -3.30688,            1.08604,            1.04018,
 -0.46892,           -0.69765,            0.21504,            0.01968,
 -0.00455,           -0.01678,            3.95643,           -3.17191,
  3.95220,           -2.12670,            0.99305,           -0.16651,
  0.34839,           -0.49162,            0.85744,            0.20173,
 -0.00975,            0.20225,           -0.02627,           -0.02281,
 -0.18002,           -0.01803,           -0.06144,           -0.21510,
  0.15935,           -0.01251,           -0.21378,            0.44806,
 -0.01174,            0.05779,            0.07646,           -0.19656,
 -0.04044,           -0.02521,            0.02996,            0.06169,
  0.16698,           -0.04710,           -0.06506,           -0.02114,
  0.05500,            0.00276,            0.08433,            0.03160,
  0.08193,            0.35773,            0.05454,            0.10718,
 -0.02823,           -0.00839,            0.54078,            0.49347,
  0.09609,            0.11825,           -0.16092,           -0.11897,
  0.09059,            0.08254,            0.16712,            0.05860,
 -0.09547,           -0.03206,            0.03876,            0.04719,
 -0.02345,            0.02240,           -0.00609,           -0.00649,
  0.03859,            0.00077,            0.47819,            0.26196,
  0.09780,            0.08104,           -0.16919,            0.05042,
 -0.42652,            0.30810,           -0.03409,           -0.51452,
 -0.23120,           -0.01380,           -0.01157,           -0.00143,
 -0.00512,           -0.01628,           -0.00189,            0.00183,
 -0.01427,           -0.02861,            0.00618,           -0.00015,
  0.13087,            0.13870,            0.15158,           -0.21056,
 -3.94829,           -1.06028,           -1.36602,            0.77954,
  0.08709,           -0.03118,           -44.74949,           91.17393,
  8.78173,            45.84010,           1.97560,           -15.02849,
 -0.10755,           -0.02884,            3.38670,            0.30615,
  130.92778,         -24.33209,           43.01636,          -40.81327,
 -19.43900,           22.18162,          -0.12691,            0.33795,
 -6.44790,           -6.23145,            0.00319,            0.01141,
 -0.03252,            0.03872,            0.04467,            0.01614,
 -0.00382,           -0.00019,            0.05955,            0.01533,
  16.11371,           41.37565,           61.44963,           6.90615,
  1.41326,           -0.73920,           -0.03871,            24.81978,
 -0.10229,           -0.32775,           -0.05188,           -0.05628,
 -2.33618,            2.39053,           -0.00584,            0.00436,
  0.20903,            0.02220,           -0.01738,           -0.02765,
 -0.00217,            0.00613,           -0.01772,            0.01903,
  0.07075,           -0.00530,            0.15234,           -0.37760,
 -0.11641,           -0.20102,           -0.63675,            0.20525,
 -0.15783,            0.58945,           -0.06243,            0.04306);

plutabb: array[0..603] of double = 
(-35042727.30412,    -49049197.81293,    -25374963.60995,    -5761406.03035,
 -467370.57540,       14040.11453,        2329.15763,        -13978.69390,
  45.43441,           29.70305,           32.33772,          -38.34012,
  26.43575,          -28.76136,          -18.59040,           12.64837,
  5.56569,           -12.51581,           248.37350,         -64.44466,
  54.02618,           4.39466,           -269.35114,         -290.63134,
 -48.03841,          -52.83576,           1508.94995,         1682.78967,
  554.02336,          715.65819,          34.37602,           58.44397,
  16.63685,           16.10176,          -1069.51609,         2300.89166,
 -437.16796,          927.89245,         -33.17679,           68.74495,
  18.72022,           32.97640,          -34004958.12619,    -17758805.77098,
 -48416073.75788,    -24973405.03542,    -25374996.23732,    -13351084.97340,
 -5738294.54942,     -3082092.63350,     -519989.39256,      -206440.89101,
  44186.23548,       -87639.22630,        2506.47602,         2327.01164,
 -53878.47903,       -19670.13471,        2.66934,           -3.86086,
  106.32427,          576.47944,          46.56388,           218.28339,
  4.35402,            15.04642,           2.68717,           -2.86835,
  0.81728,           -2.34417,           -1604.85823,        -1999.24986,
 -631.47343,         -1382.19156,        -15.74075,          -256.97077,
  6.99648,           -4.54257,            2.63478,            1.88838,
  0.17628,           -2.11518,           -2.46735,           -1.48743,
  1.83456,            4.68487,           -7.10919,            3.57046,
 -5.36342,           -7.70367,            28395956.20816,    -37176795.74372,
  48969952.83034,    -48145798.96248,     31155823.23557,    -21163596.14822,
  9057634.38260,     -3167688.51696,      1167488.70078,      219103.97591,
 -19017.97335,        107849.61195,      -3814.43474,         4405.92120,
  5800.13959,         12619.88708,        22.18168,          -89.47801,
  52202.81929,        55119.44083,        5082.58907,         37955.06062,
 -3165.24355,         3316.67588,        -113906.43970,      -69279.41495,
 -57358.07767,       -10176.17329,       -4179.79867,         2495.99374,
  787.87180,         -154.35591,         -1148.62509,         1034.58199,
 -22194.95235,        3341.97949,        -4578.53994,         108.30832,
  7444.39789,         16646.40725,        509.75430,          3808.92686,
 -179.85869,          7408.76716,         340.65366,          1504.64227,
 -3783.09873,        -13505.60867,        875.74489,         -3181.27898,
 -16220.93983,        8041.37347,        -2631.07448,         2899.50781,
  18894.92095,       -20072.81471,        5925.05701,        -1947.91902,
 -6731.56601,         8014.52403,        -987793.49463,       6491762.34471,
 -279205.73643,       6117135.96868,     -140925.91402,       2259422.06929,
  114028.61646,       605600.90358,       91858.00186,        56506.65187,
  8949.15777,        -9782.67413,        -394.66541,         -105.19208,
 -76.54752,          -32.59411,          -19.28741,           10.40013,
 -107.64003,         -7.36229,           -22.25126,           4.05952,
 -3.74402,           -2.79308,            1.03337,           -2.13968,
  1.53794,           -0.02617,            35.70756,           12.97733,
  14.46213,           6.20518,            1.79381,            1.65422,
 -0.31216,            0.29053,           -0.03538,           -0.01584,
 -0.08934,            0.00079,            0.05539,           -0.21591,
  2.86929,           -2.24724,            320797.07455,       93342.16556,
 -20903.39115,        79523.22083,       -226588.37473,      -121017.23944,
 -48472.25935,       -74195.36778,       -7962.48081,        -4607.76339,
 -4597.33274,        -7983.12541,        -20.34500,           56.82999,
 -1038.19507,         619.69624,          1.08907,           -0.91278,
 -0.13391,            0.34956,           -0.19982,           -0.18296,
 -0.97688,            2.36806,           -0.30127,            0.50980,
  0.96103,            1.96432,            0.43338,            0.87317,
  0.36997,           -0.01583,           -0.44692,           -0.25159,
 -0.53525,            0.01154,           -0.13231,            0.35562,
  3.88928,           -4.02882,            1.06967,           -0.56305,
 -0.45204,            0.77213,           -0.82873,           -0.25854,
  0.21136,           -1.06696,            458529.05491,       616790.47568,
  698431.01349,       1124501.41713,      300226.10339,       766533.33698,
  26896.22954,        207880.75720,       1116.29607,         21793.26153,
 -850.64044,          3528.95568,         29.61278,          -120.13367,
  376.95131,          66.45758,          -3.64868,            2.76062,
 -0.85352,            0.95115,            5.35056,            2.52803,
  0.90026,            0.76403,            0.43191,            0.83605,
  125.81792,         -39.65364,           50.14425,          -5.75891,
  2.78555,            2.05055,           -4.27266,           -4.92428,
  6.78868,            5.73537,            3.35229,           -3.70143,
  0.08488,            1.07465,            0.10227,            0.06074,
  0.00291,            0.01522,           -0.02274,            0.00297,
  0.01095,           -0.01856,           -0.02862,            0.00178,
  143640.07486,       707.21331,          177163.08586,       53386.52697,
  56856.89297,        48268.74645,        1764.52814,         7711.76224,
  352.34159,         -968.03169,         -45.16568,          -81.60481,
 -76.35993,          -98.06932,          -1.42185,            1.81425,
 -0.23427,            0.59023,            0.57127,           -0.36335,
  1.89975,            0.66890,            0.28797,            0.43592,
 -0.03769,            0.03273,           -6.06571,           -2.68515,
 -0.55315,            0.86977,            1.53840,           -0.59422,
 -0.05453,            0.02447,           -0.12658,            0.22814,
 -0.01715,            0.08497,           -0.01288,           -0.00606,
  0.01547,           -0.00692,            0.01157,            0.02407,
 -0.03883,            0.00835,           -0.01542,           -0.04761,
  174386.39024,       158048.26273,       159192.81681,       220154.55148,
  33716.11953,        87537.86597,       -116.90381,          7535.83928,
 -962.06994,         -132.28837,         -644.90482,         -110.52332,
  3.42499,            3.74660,           -0.94008,            41.55548,
 -0.03824,           -0.05607,            28.74787,          -37.31399,
  30.87853,          -26.11940,           10.79742,          -5.97905,
  1.01237,           -0.04429,            0.54402,            0.41905,
 -0.02440,           -0.03991,           -0.00347,           -0.04362,
 -0.00347,           -0.00469,           -0.02707,            0.02761,
 -0.17773,           -0.11789,            26475.02580,        35363.04345,
  19877.11475,        41430.35940,        2948.09998,         12983.41406,
  281.93744,          570.70054,          147.83157,          16.00090,
 -1.62814,           -8.30846,            9.29131,           -10.16496,
 -0.15799,            0.03843,            1.44716,            0.46953,
 -0.02150,           -0.02502,            0.08861,           -0.06690,
  2237.41551,         3739.08722,         753.74867,          3460.41553,
 -298.69226,          520.47031,         -33.62615,          -138.12767,
  3.61843,           -8.29860,           -4.56656,            0.79553,
  0.20041,           -0.25771,           -0.35233,           -0.27913,
 -0.02799,           -0.08328,           -0.06889,           -0.16853,
  0.01701,           -0.00964,           -0.37737,            0.18030,
 -0.08525,            0.01906,            0.05236,           -0.05155,
  0.11320,            0.05991,           -5.66926,           -0.54402,
 -2.08508,           -0.39407,            0.82155,           -0.55975,
  0.39168,           -0.25551,            0.00623,            0.16162,
 -0.02519,            0.02420,           -1.23293,           -3.19649,
 -0.60519,           -2.79729,            0.05362,           -0.61569,
 -0.25638,           -0.27033,           -0.03987,            0.46623,
 -0.12070,            0.00643,            0.00849,           -0.00768,
 -0.03687,            0.10445,           -0.13544,           -0.00592,
  0.02078,            0.09172,            0.15824,            0.15815,
  0.02020,            0.00747,            0.10919,            0.09553,
  0.01953,           -0.00135,            0.04266,           -0.00218,
  0.02182,           -0.13742,           -0.01249,            0.01724,
 -0.02200,            0.02975,           -0.01401,            0.03416,
 -0.28873,            0.04235,           -0.08137,            0.04223,
 -0.00326,            0.02144,           -0.40423,            0.14281,
 -0.08256,            0.02142,            0.08116,           -0.03680,
 -0.02324,            0.07260,           -0.06746,            0.11645,
  0.03233,           -0.05997,           -0.03101,            0.02197,
 -0.00896,           -0.00491,            0.00574,            0.00855,
  0.00052,            0.01209,           -0.31828,            0.29955,
 -0.08133,            0.04318,            0.06787,           -0.08865,
 -0.13228,           -0.06507,            0.34008,            0.06417,
 -0.00177,           -0.15116,           -0.00553,           -0.01950,
  0.01144,           -0.00309,           -0.00115,           -0.00153,
  0.02063,           -0.00791,           -0.00314,            0.00493,
 -0.10614,            0.08338,            0.08845,            0.20168,
  1.38955,           -2.52285,           -0.30475,           -1.05787,
  0.00580,            0.06623,           -44.33263,          -47.70073,
 -29.80583,          -8.77838,            7.02948,            2.77221,
  0.05248,           -0.13702,           -0.78176,            1.77489,
 -16.32831,           46.68457,           2.54516,            21.78145,
 -5.09080,           -8.42611,           -0.24419,           -0.03315,
  2.80629,           -1.12755,           -0.00402,            0.00053,
  0.00024,           -0.00043,            0.00403,           -0.00210,
  0.00603,            0.00411,           -0.00260,            0.00416,
  2.29235,            3.05992,            2.36465,           -0.58750,
  0.14030,            0.13523,            0.89998,            0.70156,
 -0.02188,            0.02003,           -0.00533,            0.00447,
  2.96411,            1.30183,            0.01422,            0.00624,
 -0.10737,           -0.38316,           -0.05968,            0.04379,
  0.01171,            0.01180,           -0.00989,           -0.01375,
 -0.00845,            0.03782,            0.09484,            0.09909,
  0.07640,           -0.00898,           -0.01076,            0.02760,
  0.01630,            0.02198,            0.05985,            0.04130);

plutabr: array[0..603] of double = 
( 17990649.12487,     24806479.30874,     12690953.00645,     2892671.69562,
  249947.71316,      -5138.71425,         1142.68629,         6075.25751,
 -34.76785,          -19.72399,          -15.81516,           30.47718,
 -11.73638,           21.87955,           9.42107,           -10.40957,
 -5.59670,            6.85778,           -167.06735,         -2.31999,
 -32.42575,          -13.72714,           130.16635,          117.97555,
  31.33915,           39.64331,          -1378.54934,        -395.83244,
 -562.79856,         -167.74359,         -45.12476,          -17.08986,
 -4.20576,           -16.56724,           1762.12089,        -1148.86987,
  736.55320,         -423.09108,          56.13621,          -26.26674,
  9.77810,           -38.05151,           4702224.98754,      27254904.94363,
  5306232.25993,      39518429.29982,     1725110.05669,      21833263.27069,
  46010.62605,        5425411.66252,      17238.09865,        536771.62156,
 -61263.36051,        66270.70142,        2084.66296,        -1936.71208,
  35898.49503,        34885.28549,        1.93276,            10.66292,
 -665.11445,          3.70467,           -265.68478,          16.16272,
 -19.45954,           2.32738,            3.04237,            3.97339,
 -2.64312,            0.66308,           -3207.68754,         3418.03720,
 -2342.62310,         1729.15030,        -450.84643,          179.00943,
 -13.20367,          -1.86087,           -4.95659,            7.22347,
 -5.08890,           -1.28891,           -6.21713,            5.10551,
  13.97276,           0.44529,            3.25177,            25.02775,
 -45.56672,           11.58470,           124443355.55450,   -100018293.41775,
  190506421.77863,   -118262753.40162,    108199328.45091,   -45247957.63323,
  27272084.41143,    -4125106.01144,      2583469.66051,      1024678.12935,
 -22702.55109,        199269.51481,      -15783.14789,        5564.52481,
 -427.22231,         -6330.86079,        -97.50757,          -204.32241,
 -9060.54822,         156661.77631,      -47791.83678,        59725.58975,
 -8807.74881,        -92.38886,          -28886.11572,       -244419.59744,
 -53336.36915,       -92232.16479,       -8724.89354,        -2446.76739,
  889.71335,          936.51108,          494.80305,          2252.83602,
 -18326.60823,       -25443.13554,       -3130.86382,        -5426.29135,
  23494.08846,        91.28882,           4664.14726,         1552.06143,
 -8090.43357,         2843.48366,        -1445.73506,         1023.11482,
  11664.20863,       -7020.08612,         3100.21504,        -64.16577,
 -9724.97938,        -12261.47155,       -3008.08276,        -1523.06301,
  6788.74046,         10708.27853,        343.09434,          1701.52760,
  14743.99857,       -4781.96586,        -15922236.41469,     1825172.51825,
 -14006084.36972,     10363332.64447,    -979550.91360,       6542446.18797,
  1160614.26915,      570804.88172,       89912.68112,       -171247.08757,
 -13899.52899,       -6182.25841,        -240.64725,          412.42581,
 -66.24510,           71.30726,          -15.81125,          -15.76899,
 -21.85515,          -102.12717,         -10.18287,          -19.38527,
  1.43749,           -3.87533,            1.97109,            0.20138,
  0.32012,            1.02928,           -40.22077,           20.80684,
 -15.69766,           9.63663,           -1.26010,            0.56197,
  0.08592,            0.18540,           -0.07303,            0.03897,
  0.01438,           -0.08809,            0.15479,            0.10354,
  0.19052,            2.08790,            405480.24475,      -607986.83623,
  582811.58843,      -915111.10396,       258696.21023,      -493391.09443,
  23403.62628,       -119503.67282,      -4036.86957,        -9766.17805,
 -663.93268,          2544.07799,         40.36638,           76.26390,
  246.67716,         -13.93440,           0.12403,            0.25378,
  0.14004,           -0.08501,            0.07904,            0.12731,
  1.02117,           -1.34663,            0.25142,           -0.26903,
  0.18135,           -0.57683,           -0.30092,           -0.36121,
 -0.09623,            0.05873,           -0.05803,            0.02869,
 -0.01194,            0.04983,            0.04250,            0.04894,
  1.34245,            0.70137,            0.24217,            0.25912,
 -0.32759,           -0.03575,            0.06780,           -0.41277,
  0.43865,            0.17857,           -763933.02226,       465658.17048,
 -1082753.91241,      593319.68634,      -553911.89340,       274748.95145,
 -122250.71547,       56608.95768,       -9914.17300,         2988.43709,
  707.94605,         -765.01470,          52.73260,          -34.22263,
 -43.58300,          -38.43647,          -4.95939,           -1.97173,
 -1.04406,           -0.13072,           -0.34281,            4.75202,
 -0.35513,            0.93597,           -0.54380,            0.70536,
  84.83116,           102.93003,          26.34884,           48.57746,
  0.02853,            2.91676,           -8.07116,            1.66613,
 -2.07908,            11.62592,           6.64704,            0.98291,
 -1.19192,            0.93791,            0.18822,            0.00900,
 -0.03181,           -0.02000,            0.02755,           -0.01398,
 -0.03971,           -0.03756,            0.13454,           -0.04193,
 -18672.98484,        28230.75834,       -28371.58823,        26448.45214,
 -13352.09393,        7461.71279,        -2609.33578,         726.50321,
 -309.72942,         -86.71982,           12.48589,          -9.69726,
  1.82185,            14.92220,          -0.04748,            0.42510,
 -0.20047,            0.00154,            0.00176,           -0.26262,
  0.78218,           -0.73243,            0.23694,           -0.03132,
 -0.00290,           -0.03678,            14.03094,           4.25948,
  0.79368,           -0.78489,           -2.30962,            2.31946,
  0.00158,           -0.04125,           -0.01387,            0.28503,
  0.00892,            0.05154,            0.00184,           -0.01727,
 -0.00889,            0.03526,           -0.00521,           -0.02093,
  0.00200,            0.04872,           -0.02163,            0.00578,
  20699.27413,       -2175.57827,         31177.33085,        4572.02063,
  15486.28190,        8747.74091,         2455.51737,         3839.83609,
  51.31433,           507.91086,          15.90082,           44.75942,
 -0.98374,           -2.64477,            2.52336,           -3.09203,
 -0.08897,           -0.00083,           -15.91892,           0.72597,
  14.04523,          -3.16525,            4.33379,           -30.82980,
  0.40462,           -0.75845,            13.14831,          -0.02721,
 -0.01779,            0.00481,            0.42365,           -0.09048,
  0.08653,            0.04391,            0.00846,            0.01082,
 -0.04736,            0.02308,            6282.21778,        -4952.70286,
  7886.57505,        -5328.36122,         3113.76826,        -1696.84590,
  330.70011,         -155.51989,         -18.31559,          -3.90798,
 -3.11242,            1.87818,           -1.05578,            0.11198,
  0.05077,           -0.01571,            2.41291,            2.40568,
 -0.01136,           -0.00076,           -0.00392,           -0.02774,
  634.85065,         -352.21937,          674.31665,         -260.73473,
  199.16422,         -28.44198,           6.54187,            6.44960,
 -1.55155,            0.29755,            0.16977,            0.17540,
 -0.02652,            0.03726,           -0.00623,            0.11777,
 -0.00933,            0.02602,           -0.13943,           -0.24818,
  0.02876,           -0.01463,           -0.07166,            0.06747,
 -0.01578,            0.01628,            0.00233,           -0.00686,
  0.00431,           -0.00276,            0.21774,            0.09735,
  0.07894,            0.07279,           -0.01300,           -0.00268,
  0.10824,            0.09435,            0.00720,            0.02111,
 -0.01960,            0.06154,            0.56867,           -0.07544,
  0.18210,            0.06343,           -0.00906,            0.01942,
 -0.00850,           -0.00351,           -0.06988,            0.01713,
 -0.01110,           -0.00663,            0.00196,           -0.02064,
 -0.00008,            0.00043,            0.00375,            0.00084,
 -0.00279,            0.00100,            0.00271,           -0.02017,
 -0.00074,           -0.00357,            0.03793,           -0.10108,
 -0.01083,           -0.03952,            0.00030,            0.00012,
  0.01576,            0.01142,            0.00351,            0.00277,
  0.01409,           -0.00774,           -0.00065,            0.01895,
  0.07350,           -0.02519,            0.01528,           -0.01057,
 -0.00099,           -0.00295,            0.21347,           -0.17458,
  0.04940,           -0.02757,           -0.06243,            0.05203,
  0.01055,           -0.00109,            0.00003,           -0.04201,
 -0.00263,            0.02387,            0.00886,           -0.01168,
  0.00479,            0.00204,           -0.00239,            0.00022,
 -0.00223,           -0.02029,           -0.14130,           -0.15237,
 -0.01827,           -0.04877,            0.12104,            0.06796,
  0.16379,            0.31892,           -0.15605,            0.07048,
 -0.00700,            0.07481,           -0.00370,           -0.00142,
 -0.00446,            0.00329,           -0.00018,            0.00117,
 -0.00910,            0.00510,           -0.00055,           -0.00114,
  0.04131,           -0.04013,           -0.13238,            0.02680,
 -0.10369,            1.38709,            0.35515,            0.41437,
 -0.01327,           -0.02692,            38.02603,           13.38166,
  15.33389,          -7.40145,           -8.55293,           -0.13185,
 -0.03316,            0.13016,            0.04428,           -1.60953,
 -12.87829,          -76.97922,          -23.96039,          -22.45636,
  14.83309,           14.09854,           0.24252,            0.13850,
 -4.16582,            4.08846,            0.00751,           -0.00051,
  0.03456,            0.02900,            0.01625,           -0.04660,
  0.01390,           -0.00530,            0.01665,           -0.04571,
  40.90768,          -14.11641,           7.46071,           -58.07356,
 -0.27859,           -1.33816,            23.76074,          -0.03124,
 -0.27860,            0.13654,           -0.04800,            0.05375,
  4.38091,            4.39337,            0.02233,            0.00514,
 -0.25616,           -0.54439,           -0.05155,            0.11553,
  0.02944,           -0.00818,            0.00570,            0.00119,
 -0.00733,           -0.02700,           -0.23759,           -0.08712,
 -0.12433,            0.07397,            0.20629,            0.60251,
  0.56512,            0.14790,            0.07778,            0.11614);

mlattabl: array[0..849] of double = 
(-3,                 -4,                  4,                 -1856,
  0,                  8043,              -9,                 -1082,
 -1,                 -310,               -1,                 -522,
 -330,               -1449,              -853,                4656,
 -66,                 7,                 -1,                  9996928,
 -66,                 6,                  23,                 183,
  0,                  173,                0,                 -56,
  0,                  50,                 0,                 -785,
  1,                  51,                 0,                 -60,
  1,                  11843,              0,                 -50754,
  0,                  1834,               1,                 -7910,
  0,                 -48060,              1,                  56,
  0,                  13141,             -1,                 -56318,
  0,                  2541,              -1,                 -649,
 -133,                778,               -46,                 8,
  1,                  1665737,           -47,                 7,
  0,                  65,                 0,                  45,
  0,                 -138,                0,                 -1005,
  0,                 -2911,               0,                 -47,
  0,                  96,                 0,                 -394,
  2,                  76,                 2,                 -17302,
  0,                  74337,              0,                 -101,
  0,                  58,                 0,                 -171,
  0,                 -77,                 0,                 -1283,
  0,                  2686,               0,                 -55,
  0,                  99,                 0,                  55,
  0,                  397,                0,                  540,
  0,                  626,               -1,                 -5188,
  0,                  10857,              0,                 -216,
 -2,                 -123,                0,                  6337,
  2,                  224,               -152,               -23472,
 -29,                -74336,              0,                  295775,
 -20,                 149,               -2,                  84,
  9,                  304,                0,                 -3051,
 -70,                -6,                 -57,                 34,
  0,                 -638,                0,                 -201,
 -73,                 9,                  0,                 -100,
 -101,               -8,                  0,                 -57,
  0,                 -207,               -3,                  80,
 -45,                 45,                -5,                  102,
 -59,                -23,                 52,                 201,
 -48,                 233,               -220,                71,
  4,                  2810,               0,                  6236541,
 -61,                 218,               -216,                67,
  51,                 201,               -59,                -23,
 -144,               -837,               -457,                3029,
 -45,                 42,                -15,                 73,
 -6,                 -169,                0,                  135,
 -64,                -7,                  0,                 -16245,
  0,                 -81,                -74,                -10,
  0,                  702,                0,                 -3013,
  0,                 -5889,               1,                  141,
  58,                 9598,               12,                 30443,
  1,                 -120946,            -1,                 -84,
 -2,                  11246,             -1,                 -48391,
  0,                  1393,               0,                  200,
 -136,               -17,                 0,                  558,
 -64,                -8,                  0,                 -71,
  0,                  317577,            -28,                 183,
  1,                  219,                0,                  421,
  0,                 -133,                501,               -139,
  3,                  354,               -101,               -13,
  74,                 7,                  144,               -84,
  59,                -2,                  1,                  64,
 -2931,               12559,             -4641,               2638,
 -303,               -2058,              -13,                -100,
 -123,               -79,                -19214,              6084,
  1494,               26993,              15213,             -82219,
  42,                 52,                 48,                -101,
 -53,                -4,                  4,                  47,
  58,                -131,                46,                 14,
 -21,                -6,                 -1311,              -8791,
  10198,             -4185,               2815,               5640,
  167,                422,               -229,                83,
  3140,               39,                 1221,               120,
  96,                -30,                -1,                  184612405,
  187,                416,               -226,                81,
 -1985,              -10083,              9983,              -4464,
  2807,               5643,              -21,                -9,
  113,               -367,                120,                580,
 -667,                27,                 8,                  66,
 -56,                -6,                  337,                95,
 -87,                 3303,              -1,                  65,
  68,                -374,                0,                 -574,
  15,                -94,                 0,                 -53,
  0,                 -1303,               0,                 -236,
  283,                36,                -1,                 -54,
  269,               -35,                 0,                 -83,
  0,                 -52,                 0,                  730,
  0,                 -3129,               0,                  813,
  0,                 -4299,               1,                  59,
 -6,                  5130,               1,                  16239,
 -1,                 -64603,              0,                 -80,
  91,                 12,                 0,                 -561,
  133,               -17,                 0,                  250,
 -12,                 71,                 0,                  155664,
  82,                -11,                 0,                  106,
  0,                 -604,                0,                  21862,
  55,                -7,                  0,                 -1514,
  0,                  6501,               0,                  906,
  0,                 -68,                 0,                  241,
  0,                  366,                0,                  70,
  0,                 -1382,               0,                  5957,
  0,                  113,                0,                 -51,
  0,                 -55,                 0,                  731,
  0,                 -264,                0,                  65788,
  1,                 -1504,               0,                  3147,
  0,                  217,                0,                 -4105,
  0,                  17658,              1,                  69,
  0,                 -3518,               0,                 -1767,
 -43,                -7044,              -10,                -22304,
  0,                  88685,              3,                  91,
  0,                 -485,                0,                 -57,
 -1,                  333548,            -24,                 172,
  11,                 544,                1,                 -1132,
  0,                  353,                0,                 -188,
  0,                  53,                 0,                  77,
  158,               -887,                35,                 131,
 -54,                 13,                 0,                  1994821,
 -53,                 14,                 36,                 125,
  2,                  56,                 0,                 -243,
  0,                 -364,               -2,                  1916,
  0,                 -8227,               0,                  15700,
 -1,                 -67308,              1,                  66,
  0,                 -53686,              1,                  3058,
  1,                 -13177,              0,                 -72,
  0,                 -72,                 0,                  61,
  0,                  15812,              0,                  165,
  8,                 -96,                 318,                1341,
  803,               -4252,               24,                 193,
  1137,              -226,                310,                622,
 -56,                 30,                -3,                  10101666,
 -56,                 30,                 1096,              -225,
  300,                600,               -31,                 409,
 -1,                 -507,                0,                 -287,
  0,                 -1869,               0,                  8026,
  1,                  544,               -1,                 -1133,
  0,                  27984,              0,                 -62,
  0,                 -249,                0,                  187,
  0,                 -1096,               1,                  53,
  2,                  12388,              0,                 -53107,
  0,                 -322,                0,                 -94,
  0,                  15157,              0,                 -582,
  0,                  3291,               0,                  565,
  0,                  106,                0,                  112,
  0,                  306,                0,                  809,
  0,                  130,                0,                 -961,
  0,                  4149,               0,                  174,
  0,                 -105,                0,                  2196,
  0,                  59,                 0,                  36737,
 -1,                 -1832,               0,                  3835,
  0,                 -139,                0,                  24138,
  0,                  1325,               1,                  64,
  0,                 -361,                0,                 -1162,
 -44,                -6320,              -10,                -20003,
  0,                  79588,              2,                  80,
  0,                 -2059,               0,                 -304,
  0,                  21460,              0,                 -166,
  0,                 -87,                 89,                -493,
  32,                 114,                34,                 510,
  1,                  1172616,            31,                 113,
 -1,                  57,                 0,                  214,
  0,                 -656,                0,                 -646,
  0,                  1850,               0,                 -7931,
  0,                 -6674,               0,                  2944,
  0,                 -12641,              0,                  916,
  45,                -255,                16,                 60,
 -1,                  619116,             16,                 57,
  0,                 -58,                 0,                  1045,
  0,                 -156,               -15,                 88,
  0,                 -62964,              0,                 -126,
  0,                  1490,               0,                 -6387,
  0,                  119,                0,                  1338,
  0,                 -56,                 0,                  204,
  0,                  153,                0,                  940,
  0,                  251,                0,                  312,
  0,                  584,                0,                 -786,
  0,                  3388,               0,                 -52,
  0,                  4733,               0,                  618,
  0,                  29982,              0,                  101,
  0,                 -174,                0,                 -2637,
  0,                  11345,              0,                 -284,
  0,                 -524,                0,                 -121,
  0,                  1464,               11,                -60,
 -1,                  151205,             0,                  139,
  0,                 -2448,               0,                 -51,
  0,                 -768,                0,                 -638,
  0,                  552,                0,                 -2370,
  0,                  70,                 0,                  64,
  0,                  57,                 0,                  39840,
  0,                  104,                0,                 -10194,
  0,                 -635,                0,                  69,
  0,                  113,                0,                  67,
  0,                  96,                 0,                  367,
  0,                  134,                0,                  596,
  0,                  63,                 0,                  1622,
  0,                  483,                0,                  72,
  0,                  11917,              0,                 -63,
  0,                  1273,               0,                 -66,
  0,                 -262,                0,                 -97,
  0,                  103,                0,                  15196,
  0,                 -1445,               0,                 -66,
  0,                 -55,                 0,                 -323,
  0,                  2632,               0,                 -1179,
  0,                  59,                 0,                 -56,
  0,                  78,                 0,                  65,
  0,                  422,                0,                  309,
  0,                  2125,               0,                 -66,
  0,                  124,                0,                 -57,
  0,                  1379,               0,                 -304,
  0,                  177,                0,                 -118,
  0,                  146,                0,                  283,
  0,                  119);

mlrtabl: array[0..1561] of double = 
( 175667,             66453,              5249,              -42,
  20057,              403,               -2360,               6148,
 -7644,               24646,             -1273,               9127,
 -1395,               1958,               232,               -289,
 -97,                 553,                69,                 130,
 -80,                 6,                  129,               -868,
  26,                -89,                 1042,               1172,
  194,               -112,               -47433,             -241666,
  224626,            -103752,             63419,              127606,
  2294,              -691,               -1827,              -1254,
 -1,                 -119,                1057,               324,
  505,               -195,                254,               -641,
 -36,                 1008,              -1082,              -3,
 -87,                 122,                161,                11,
  2,                 -106,                29,                -123,
 -32,                 41,                -524,               -35,
  133,               -595,                225,                837,
 -108,               -191,               -2294,               841,
 -340,               -394,               -351,               -1039,
  238,               -108,               -66,                 21,
  1405,               869,                520,                2776,
 -174,                71,                 425,                652,
 -1260,              -80,                 249,                77,
 -192,               -17,                -97,                 134,
 -7,                 -54,                -802,               -7436,
 -2824,               70869,             -35,                 2481,
  1865,               1749,              -2166,               2415,
  33,                -183,               -835,                283,
  27,                -45,                 56,                 235,
  2,                  718,               -1206,               275,
 -87,                -158,               -7,                 -2534,
  0,                  10774,              1,                 -324,
 -208,                821,                281,                1340,
 -797,                440,                224,                72,
 -65,                -5,                 -7,                 -44,
 -48,                 66,                -151,               -40,
 -41,                -45,                 76,                -108,
 -18,                 1202,               0,                 -2501,
  1438,              -595,                900,                3040,
 -3435,              -5,                 -100,               -26,
  0,                 -13714,             -183,                68,
  453,               -83,                -228,                325,
  97,                 13,                 2,                  105,
 -61,                 257,                0,                  57,
  88,                -11,                -1,                 -8220,
  0,                  275,               -43,                -10,
 -199,                105,                1,                 -5849,
  2,                  24887,             -128,                48,
  712,                970,               -1407,               845,
 -266,                378,                311,                1526,
 -1751,               27,                 0,                 -185858,
  133,                6383,              -108,                25,
 -7,                  1944,               5,                  390,
 -11,                 31,                 277,               -384,
  158,                72,                -81,                -41,
 -13,                -111,               -2332,              -65804,
 -698,                505812,             34,                 1676716,
 -72,                -6664384,            154,               -57,
  52,                 95,                -4,                 -5,
 -7,                  37,                -63,                -32,
  4,                  3349,               1,                 -14370,
  16,                -83,                 0,                 -401,
  13,                 3013,               48,                -20,
  0,                  250,                51,                -79,
 -7,                 -146,                148,                9,
  0,                 -64,                -17,                -59,
 -67,                -492,               -2,                  2116601,
 -12,                -1848,               8,                 -436,
 -6,                  324,                0,                 -1363,
 -163,                9,                  0,                 -74,
  63,                 8167,              -29,                 37587,
 -22,                -74501,             -71,                 497,
 -1,                  551747,            -87,                -22,
  0,                 -51,                -1,                 -463,
  0,                 -444,                3,                  89,
  15,                -84,                -36,                -6829,
 -5,                 -21663,              0,                  86058,
  0,                 -298,               -2,                  751,
 -2,                 -1015,               0,                  69,
  1,                 -4989,               0,                  21458,
  0,                 -330,                0,                 -7,
  0,                 -226,                0,                 -1407,
  0,                  2942,               0,                  66,
  0,                  667,                0,                 -155,
  0,                  105,                0,                 -107,
  0,                 -74,                 0,                 -52,
  0,                  91,                 0,                  59,
  0,                  235,               -1,                 -1819,
  0,                  2470,               71,                 13,
  0,                  1026,               14,                -54,
  0,                 -174,               -121,               -19,
  0,                 -200,                0,                  3008,
 -16,                -8043,              -10,                -37136,
 -3,                  73724,             -157,               -5,
  0,                 -854,                8,                  147,
 -13,                -893,                0,                  11869,
 -23,                -172,                89,                 14,
 -1,                  872,                0,                 -3744,
  11,                 1606,               0,                 -559,
 -1,                 -2530,               0,                  454,
  0,                 -193,               -60,                -10,
 -82,                -13,                -75,                 6,
  36,                 81,                 354,               -162836,
  148,               -516569,             4,                  2054441,
  4,                 -94,                 39,                 38,
  61,                -30,                 2,                  121,
 -11,                 590,                62,                 2108,
  0,                 -12242,             -476,               -42,
 -84,                 113,               -394,                236,
  0,                  276,               -49,                 31,
  0,                  86,                 1,                 -1313,
  1,                  69,                -60,                 88,
 -46,                 18,                 0,                 -63818,
  14,                -93,                 113,                547,
 -618,                17,                -7,                  12290,
 -1,                 -25679,              0,                  92,
 -115,                50,                -48,                 233,
  4,                  1311,               1,                 -5567,
  3,                  1251,               29,                 548,
 -244,                257,               -2,                  1825,
  42,                 637,               -46,                 68,
 -62,                 8,                  3,                  110,
  445,               -100,               -316,               -202,
  2925,              -621,                763,                1495,
 -169,               -184,                20,                -76,
 -475,               -138,                8,                 -141,
 -197,                1351,              -1284,               422,
 -129,                1879,              -102,                8382,
 -9,                  45864958,          -215,                1350,
 -1285,               422,               -481,               -136,
  8,                 -140,                40,                -53,
  2622,              -543,                700,                1406,
  402,               -95,                -318,               -194,
  122,                13,                -30,                 147,
 -121,               -902,                61,                -23,
 -63,                 7,                  69,                 479,
 -224,                228,               -7,                  500,
  0,                 -429,               -42,                 193,
 -92,                 37,                 67,                 5,
 -350,               -31,                 0,                  67,
 -55,                -5,                  0,                  47,
 -36,                 53,                 5,                  561,
  0,                 -126,                0,                  871,
 -52,                 4,                 -201,                116922,
 -22,                 371352,            -12,                -1473285,
  0,                  87,                -164,                84,
 -3,                  422,                30,                 1434,
 -26,                 38,                 2,                 -1249943,
 -404,               -34,                -57,                 79,
  5,                  509,                1,                  131,
 -344,                168,                112,                22540,
  30,                 71218,              18,                -283983,
  0,                 -851,                0,                 -1538,
  0,                  1360,              -12,                 51,
 -48,                 68,                 88,                -20,
  1,                  63,                 0,                 -568,
  303,                25,                 0,                 -122,
  87,                 586,               -606,               -14,
  0,                 -100,               -85,                 8,
 -165,                54,                -45,                 140,
  0,                 -54,                 4,                 -831,
  1,                  3495,               31,                 116,
 -46,                -11,                -371,                190,
 -507,                399,               -2,                  57,
 -60,                 36,                -198,               -1174,
 -613,                4988,              -87,                -4,
  141,                560,               -276,                187,
  1876,               1379,               778,                4386,
  24,                -15,                 167,               -774,
 -71,                -9,                 -62,                 90,
  98,                 580,               -663,               -7,
  34,                -112,                57,                 15,
 -355,               -214,               -3240,              -13605,
  12229,             -5723,               3496,               7063,
  33,                -51,                 1908,               1160,
 -226,                715,                964,                1170,
 -1264,               623,                14071,              5280,
  5614,               3026,               488,                1576,
 -2,                  226395859,          824,                1106,
 -1287,               617,                1917,               1156,
 -214,                718,                90,                -97,
  12078,             -2366,               3282,               6668,
 -219,                9179,               593,                2015,
 -282,               -186,                57,                 25,
  31,                -102,               -77,                -4,
 -268,               -341,               -7,                 -45,
 -3,                  74,                 15,                -615,
 -88,                -7,                  234,               -353,
  1,                 -119,               -163,               -1159,
 -601,                4969,               22,                -58,
 -17,                -11434,              17,                 54,
  348,                348,               -460,                434,
 -371,                175,               -11,                -204,
  4,                 -6440,              -5,                 -53,
 -4,                 -14388,             -37,                -45231,
 -7,                  179562,            -44,                 136,
 -160,                49,                -101,                81,
 -1,                 -188,                0,                  2,
 -4,                  12124,             -11,                -25217,
  71,                 543,               -557,               -14,
 -75,                 526,                0,                  395274,
 -233,               -16,                 93,                -20,
 -43,                 61,                 0,                 -1275,
  0,                 -824,                1,                 -415,
  0,                  1762,              -261,                131,
 -45,                 64,                -297,               -25,
  0,                 -17533,             -6,                 -56,
  21,                 1100,               1,                  327,
  1,                  66,                 23,                -217,
 -83,                -7,                  83,                 86847,
  49,                 275754,            -4,                 -1093857,
 -46,                 2,                  0,                 -24,
  0,                 -419,                0,                 -5833,
  1,                  506,                0,                 -827,
 -1,                 -377,               -11,                -78,
  0,                  131945,            -2,                 -334,
  1,                 -75,                 0,                 -72,
  0,                 -213,               -6,                  5564,
 -2,                 -11618,              0,                  1790,
  0,                 -131,                0,                  6,
  0,                 -76,                 0,                 -130,
  0,                 -1115,               0,                  4783,
  0,                 -195,                0,                 -627,
  0,                 -55,                 0,                 -83,
  0,                  163,                0,                 -54,
  0,                  82,                 0,                  149,
  0,                 -754,                0,                  1578,
  0,                  138,                0,                  68,
  2,                 -2506,               0,                  3399,
  0,                 -125,                86,                 16,
  0,                 -6350,               0,                  27316,
  18,                -63,                 0,                 -169,
 -1,                  46,                -136,               -21,
  0,                 -239,               -30,                -8788,
 -15,                -40549,             -4,                  80514,
 -46,                -8,                 -168,               -6,
 -1,                  536,                0,                 -2314,
  9,                  148,               -13,                -842,
 -1,                  307713,            -23,                -175,
  95,                 15,                 0,                 -297,
  11,                 1341,               0,                 -106,
  0,                  5,                 -4,                  68,
 -114,                10,                 32,                 75,
  159,               -130487,             98,                -413967,
  2,                  1647339,           -4,                 -85,
  100,               -46,                 2,                  95,
 -11,                 461,                51,                 1647,
  0,                 -32090,             -375,               -33,
 -65,                 86,                -300,                180,
  0,                  836,                0,                 -3576,
  0,                 -222,                0,                 -993,
 -41,                 60,                 0,                 -4537,
 -431,               -34,                 2,                  927,
  0,                 -1931,              -79,                 33,
 -31,                 144,               -1,                  284,
  0,                 -1207,               0,                  88,
 -11,                 315,               -178,                177,
 -1,                  144,               -58,                 986,
  11,                 86,                -228,               -110,
  2636,              -494,                718,                1474,
  28,                -35,                -24,                 782,
 -797,                277,                2142,              -1231,
  856,                1853,               74,                 10797,
  0,                  23699298,          -21,                 786,
 -796,                277,                27,                -34,
  2615,              -494,                712,                1461,
 -226,               -109,               -11,                 663,
  0,                 -123,               -169,                157,
 -54,                 266,                0,                 -76,
  1,                 -634,                0,                  2738,
 -25,                 106,               -63,                 24,
  0,                 -372,               -221,               -24,
  0,                 -5356,               0,                 -219,
  0,                  91,                -28,                 7684,
 -6,                  24391,             -1,                 -96795,
 -77,                 43,                 2,                  95,
 -47,                -3,                  0,                 -84530,
  2,                  310,                1,                  88,
  111,                19331,              32,                 61306,
  4,                 -243595,             0,                  770,
  0,                 -103,                0,                  160,
  0,                  356,                0,                  236,
 -41,                 354,                39,                 303,
  12,                -56,                 873,               -143,
  238,                482,               -28,                 35,
 -93,                 31,                -3,                  7690211,
 -91,                 33,                -34,                 43,
  824,               -130,                226,                450,
 -39,                 341,               -1,                 -687,
  0,                 -303,                11,                -2935,
  1,                  12618,              121,                924,
  9,                 -1836,              -268,               -1144,
 -678,                3685,              -69,                -261,
  0,                 -4115951,           -69,                -261,
  5,                 -151,                0,                 -88,
  0,                  91,                 0,                  187,
  0,                 -1281,               1,                  77,
  1,                  6059,               3,                  19238,
  0,                 -76305,              0,                 -90,
  0,                 -238,                0,                 -962,
  0,                  4133,               0,                  96,
  0,                  9483,               0,                  85,
  0,                 -688,                0,                 -5607,
  0,                  55,                 0,                 -752,
  0,                  71,                 0,                  303,
  0,                 -288,                0,                  57,
  0,                  45,                 0,                  189,
  0,                  401,                0,                 -1474,
  0,                  3087,               0,                 -71,
  0,                  2925,               0,                 -75,
  0,                  359,                0,                  55,
  1,                 -10155,              0,                  43735,
  0,                 -572,                0,                 -49,
  0,                 -660,                0,                 -3591,
  0,                  7516,               0,                  668,
 -1,                 -53,                -2,                  384259,
  0,                 -163,                0,                 -93,
  1,                  112,               -95,                -11528,
 -22,                -36505,             -1,                  145308,
  5,                  145,                0,                  4047,
  1,                  1483,               0,                 -6352,
  0,                  991,                0,                 -4262,
  0,                 -93,                 0,                 -334,
  0,                 -160,                0,                 -153,
 -10,                 127,                51,                 185,
 -77,                 18,                 56,                 1217,
  6,                  1919574,           -74,                 17,
  50,                 180,               -5,                  93,
  0,                 -104,                0,                 -58,
 -3,                 -353,               -1,                  1499,
  0,                 -229,               -15,                 86,
  0,                 -93657,              0,                  1561,
  0,                 -6693,               0,                 -5839,
  1,                  6791,               0,                 -29143,
  1,                 -701,                0,                  3015,
  0,                  2543,               0,                  693,
 -1,                  361233,             0,                 -50,
  0,                  946,               -1,                 -140,
 -70,                 407,                0,                 -450995,
  0,                 -368,                0,                  54,
  0,                 -802,                0,                 -96,
  0,                  1274,               0,                 -5459,
  0,                 -614,                0,                  2633,
  0,                  685,                0,                 -915,
  0,                 -85,                 0,                  88,
  0,                  106,                0,                  928,
  0,                 -726,                0,                  1523,
  0,                  5715,               0,                 -4338,
  0,                  18706,              0,                 -135,
  0,                 -132,                0,                 -158,
  0,                 -98,                 0,                  680,
 -1,                  138968,             0,                 -192,
  0,                 -1698,               0,                 -2734,
  0,                  11769,              0,                  4,
  0,                  673,                0,                 -2891,
  0,                  889,                0,                 -3821,
  0,                  121,               -1,                  143783,
  0,                  231,               -9,                  51,
  0,                 -57413,              0,                 -483,
  0,                 -407,                0,                  676,
  0,                 -2902,               0,                  531,
  0,                  445,                0,                  672,
  0,                  19336,              0,                  70,
  0,                 -39976,              0,                 -68,
  0,                  4203,               0,                 -406,
  0,                  446,                0,                 -108,
  0,                  79,                 0,                  84,
  0,                  734,                0,                  255,
  0,                  3944,               0,                 -655,
  0,                  2825,               0,                 -109,
  0,                 -234,                0,                  57,
  0,                  19773,              0,                 -2013,
  0,                  958,                0,                 -521,
  0,                 -757,                0,                  10594,
  0,                 -9901,               0,                  199,
  0,                 -275,                0,                  64,
  0,                  54,                 0,                  165,
  0,                  1110,               0,                 -3286,
  0,                  909,                0,                  54,
  0,                  87,                 0,                  258,
  0,                  1261,               0,                 -51,
  0,                  336,                0,                 -114,
  0,                  2185,               0,                 -850,
  0,                  75,                 0,                 -69,
  0,                 -103,                0,                  776,
  0,                 -1238,               0,                  137,
  0,                  67,                 0,                 -260,
  0,                  130,                0,                  49,
  0,                  228,                0,                  215,
  0,                 -178,                0,                  57,
  0,                 -133);

mlrtabr: array[0..1561] of double = 
(-5422,              -2120,               1077,               772,
  39,                 75,                 3,                  10,
 -468,               -326,               -113,               -78,
 -4,                 -2,                  1,                  3,
  29,                 24,                 4,                  2,
  1,                  0,                 -9,                  7,
 -2,                  0,                 -32,                -13,
 -3,                 -3,                  233,                126,
  89,                 77,                -33,                 16,
  3,                 -3,                  0,                 -1,
  2,                  0,                  0,                  1,
  4,                  9,                  1,                  1,
  16,                -1,                  0,                  18,
  3,                  2,                  0,                  0,
  0,                  0,                  0,                  0,
  0,                  0,                  0,                 -1,
 -22,                -5,                  10,                 3,
  1,                  1,                 -15,                 7,
 -2,                  1,                 -8,                 -11,
 -1,                 -2,                 -1,                  1,
  46,                -58,                 126,               -23,
  4,                  8,                  35,                 8,
  10,                -17,                 0,                  0,
  0,                  0,                 -10,                -7,
  0,                  0,                 -23,                 3,
  151,                10,                -327,                0,
  4,                 -5,                  6,                  5,
  1,                  0,                 -1,                 -3,
  0,                  0,                  0,                  1,
 -185,                0,                 -3,                 -24,
 -5,                 -2,                 -1062,               3,
  4560,               0,                 -3,                  0,
  4,                  1,                  8,                 -1,
  2,                  4,                  0,                  1,
  0,                 -1,                  0,                  0,
 -1,                  0,                  0,                  1,
  0,                  0,                 -1,                 -1,
  277,                3,                 -583,                1,
 -1,                  4,                 -32,                 7,
  0,                 -34,                 1,                 -1,
 -23685,              0,                 -1,                 -2,
 -1,                 -7,                 -5,                 -4,
  0,                  2,                 -2,                  0,
 -5,                 -1,                  35,                 0,
  0,                  2,                  202,                0,
  180,                0,                  0,                 -1,
 -3,                 -6,                 -193,                0,
  770,               -1,                 -2,                 -4,
 -32,                 23,                -28,                -46,
 -13,                -9,                 -54,                 10,
 -1,                 -61,                -44895,              0,
 -230,                5,                 -1,                 -4,
 -71,                 0,                 -15,                 0,
  1,                  0,                  15,                 11,
 -3,                  6,                  2,                 -3,
  4,                 -1,                  2576,              -138,
 -19881,             -47,                -65906,             -1,
  261925,            -4,                 -2,                 -7,
  4,                 -2,                  0,                  0,
 -1,                  0,                  1,                 -3,
  172,               -2,                 -727,                0,
  4,                  1,                  324,                0,
 -139,                1,                  1,                  3,
 -276,                0,                  5,                  3,
  9,                  0,                 -1,                  10,
 -37,                 0,                  5,                 -1,
  76,                -10,                 1318810,            1,
  12,                -1,                 -38,                 1,
 -141,                0,                  611,                0,
  0,                 -11,                 4,                  0,
 -627,                2,                 -2882,              -3,
  5711,              -2,                 -48,                -7,
  55294,              0,                  2,                 -7,
  31,                 0,                  34,                 0,
 -259,                0,                 -55,                 2,
  6,                  3,                 -4273,               20,
 -13554,              3,                  53878,              0,
 -46,                 0,                 -85,                 0,
  114,                0,                 -45,                 0,
 -818,                0,                  3520,               0,
  34,                 0,                 -157,                0,
  29,                 0,                 -878,                0,
  1838,               0,                 -428,                0,
  161,                0,                  24,                 0,
  65,                 0,                  19,                 0,
  15,                 0,                  12,                 0,
 -26,                 0,                 -14,                 0,
 -149,                0,                  584,                0,
 -793,                0,                  4,                 -23,
 -238,                0,                 -18,                -5,
  45,                 0,                 -7,                  42,
  79,                 0,                 -1723,               0,
  2895,              -6,                  13362,             -4,
 -26525,             -1,                 -2,                  57,
  291,                0,                  52,                -3,
 -327,                5,                 -2755,               0,
 -63,                 9,                  5,                 -33,
 -261,               -1,                  1122,               0,
  621,               -4,                 -227,                0,
  1077,               0,                 -167,                0,
  85,                 0,                 -4,                  23,
 -5,                  32,                 3,                  30,
 -32,                 14,                 64607,              141,
  204958,             59,                -815115,             2,
 -37,                -1,                  15,                -15,
  12,                 24,                 48,                -1,
  235,                4,                  843,               -25,
  4621,               0,                 -17,                 191,
  45,                 34,                 95,                 159,
 -132,                0,                  13,                 20,
  32,                 0,                 -540,                0,
  29,                 0,                  37,                 25,
  8,                  19,                 22127,              0,
 -35,                -5,                  232,               -48,
  7,                  262,                5428,               3,
 -11342,              1,                 -45,                 0,
 -21,                -49,                -100,               -21,
 -626,                1,                  2665,               0,
  532,               -2,                  235,               -12,
 -111,               -105,                774,                1,
 -283,                17,                 29,                 20,
  3,                  27,                 47,                -2,
 -43,                -192,               -87,                 136,
 -269,               -1264,               646,               -330,
 -79,                 73,                -33,                -9,
  60,                -205,                61,                 4,
 -584,               -85,                -182,               -555,
 -780,               -57,                -3488,              -45,
 -19818328,          -4,                  583,                93,
  182,                555,               -59,                 208,
 -60,                -4,                  23,                 17,
  235,                1133,              -608,                302,
  41,                 174,                84,                -137,
  6,                 -53,                 63,                 13,
 -392,                52,                -10,                -27,
 -3,                 -27,                 199,               -31,
  99,                 97,                -218,               -3,
  209,                0,                  84,                 18,
  16,                 40,                 2,                 -30,
  14,                -154,                30,                 0,
 -2,                  24,                -108,                0,
 -24,                -16,                 262,               -2,
  55,                 0,                 -304,                0,
  2,                  25,                 55112,              95,
  175036,             11,                -694477,             5,
  41,                 0,                 -38,                -76,
  199,                1,                  679,               -14,
 -17,                -12,                 582619,             1,
 -16,                 191,                38,                 27,
 -234,                2,                 -60,                 0,
  80,                 163,               -10296,              48,
 -32526,              13,                 129703,             8,
 -1366,               0,                 -741,                0,
 -646,                0,                  25,                 6,
  33,                 23,                 10,                 43,
 -31,                 0,                 -6,                  0,
 -12,                 147,                59,                 0,
  287,               -42,                -7,                  297,
 -59,                 0,                 -4,                 -42,
 -27,                -81,                -69,                -22,
  27,                 0,                 -423,               -2,
  1779,              -1,                 -57,                 15,
  5,                 -23,                 94,                 182,
 -197,               -250,                24,                 1,
 -18,                -30,                 581,               -98,
 -2473,              -303,               -2,                  43,
 -277,                70,                -92,                -136,
 -681,                925,               -2165,               384,
 -8,                 -12,                 382,                82,
 -4,                  35,                -45,                -31,
 -286,                48,                 3,                 -328,
 -55,                -17,                 8,                 -28,
 -106,                175,               -6735,               1601,
 -2832,              -6052,               3495,              -1730,
 -25,                -17,                -574,                944,
 -354,               -112,               -579,                476,
 -308,               -625,               -2411,               7074,
 -1529,               2828,              -1335,               247,
 -112000844,         -1,                  545,               -409,
  305,                637,                572,               -950,
  356,                106,                48,                 44,
  1170,               5974,              -3298,               1624,
 -4538,              -106,               -996,                294,
  92,                -139,               -12,                 28,
  50,                 16,                 2,                 -38,
  169,               -133,                22,                -3,
  38,                 1,                  305,                7,
  4,                 -44,                 175,                116,
  59,                 1,                 -573,                81,
  2453,               297,                29,                 11,
  5674,              -8,                 -27,                 9,
  173,               -173,                215,                228,
 -87,                -184,                102,               -5,
  3206,               2,                 -53,                 2,
  7159,              -7,                  22505,             -19,
 -89344,             -3,                  67,                 22,
  24,                 79,                -40,                -50,
  94,                 0,                  186,                0,
 -6063,               0,                  12612,             -5,
 -271,                35,                 7,                 -278,
 -479,               -74,                 426754,             0,
  8,                 -116,               -10,                -47,
 -31,                -22,                 645,                0,
  426,                0,                 -213,                0,
  903,                0,                 -67,                -133,
 -33,                -23,                 13,                -152,
 -9316,               0,                  29,                -3,
 -564,                11,                -167,                0,
 -34,                 0,                  114,                12,
  4,                 -44,                -44561,              42,
 -141493,             25,                 561256,            -2,
 -1,                 -24,                -261,                0,
  211,                0,                 -4263,               0,
 -262,                1,                  1842,               0,
  202,                0,                  41,                -6,
  77165,              0,                  176,               -1,
  39,                 1,                 -24,                 0,
  118,                0,                 -2991,              -4,
  6245,              -1,                  46886,              0,
 -75,                 0,                 -100,                0,
  40,                 0,                  75,                 0,
 -618,                0,                  2652,               0,
  112,                0,                  1780,               0,
  30,                 0,                  49,                 0,
  86,                 0,                  33,                 0,
 -30,                 0,                 -95,                 0,
  277,                0,                 -580,                0,
 -35,                 0,                 -319,                0,
  1622,               1,                 -2201,               0,
  79,                 0,                  10,                -57,
  2363,               0,                 -10162,              0,
 -41,                -12,                 62,                 0,
  30,                 1,                 -14,                 89,
 -2721,               0,                  5780,              -19,
  26674,             -10,                -52964,             -2,
 -5,                  30,                -4,                  111,
 -317,               -1,                  1369,               0,
  93,                -6,                 -564,                9,
 -115913,             0,                 -113,                15,
  10,                -62,                 99,                 0,
  891,               -7,                  36,                 0,
  108,                0,                 -42,                -2,
  7,                  75,                -50,                 21,
  86822,              104,                275441,             65,
 -1096109,            1,                 -56,                 3,
  31,                 66,                 63,                -1,
  307,                7,                  1097,              -34,
  17453,              0,                 -22,                 250,
  57,                 43,                 120,                200,
 -297,                0,                  1269,               0,
  166,                0,                 -662,                0,
  40,                 28,                 1521,               0,
 -23,                 288,                351,               -2,
 -729,                0,                 -22,                -52,
 -96,                -21,                -139,               -1,
  589,                0,                  35,                 0,
  210,                7,                 -118,               -119,
  62,                 0,                 -583,               -26,
 -42,                 5,                 -73,                 152,
 -330,               -1759,               983,               -479,
 -23,                -19,                -522,               -15,
 -185,               -533,                739,                1559,
 -1300,               614,               -7332,               52,
 -15836758,           0,                  524,                16,
  185,                532,                23,                 18,
  330,                1751,              -978,                476,
  73,                -151,                519,                18,
  38,                 0,                  105,                113,
 -178,               -37,                 26,                 0,
  262,                1,                 -1139,               0,
  71,                 17,                 16,                 42,
  151,                0,                  16,                -148,
  4147,               0,                  149,                0,
 -30,                 0,                  2980,               9,
  9454,               2,                 -37519,              0,
 -28,                -49,                 37,                -1,
  2,                 -31,                 33870,              0,
 -208,                1,                 -59,                 1,
 -13105,              68,                -41564,              21,
  165148,             3,                 -1022,               0,
 -40,                 0,                 -132,                0,
 -228,                0,                  95,                 0,
 -138,               -16,                -126,                16,
  24,                 5,                 -57,                -346,
  191,               -94,                -14,                -11,
 -12,                -37,                -3053364,           -1,
  13,                 36,                 17,                 13,
  51,                 327,               -179,                90,
  138,                16,                 233,                0,
  62,                 0,                  1164,               0,
 -5000,               0,                 -407,                117,
  770,                9,                 -4,                  1,
  21,                 2,                  1,                  0,
 -16869,              0,                 -1,                  0,
  1,                  0,                  35,                 0,
 -78,                 0,                  78,                 0,
 -533,                0,                 -31,                 1,
 -2448,              -6,                 -7768,              -1,
  30812,              0,                  37,                 0,
 -227,                0,                  197,                0,
 -846,                0,                 -77,                 0,
  4171,               0,                 -67,                 0,
  287,                0,                  2532,               0,
 -19,                 0,                 -40,                 0,
 -56,                 0,                  128,                0,
  83,                 0,                 -45,                 0,
 -36,                 0,                 -92,                 0,
 -134,                0,                  714,                0,
 -1495,               0,                  32,                 0,
 -981,                0,                  15,                 0,
 -166,                0,                 -59,                 0,
  4923,               0,                 -21203,              0,
  246,                0,                  15,                 0,
  104,                0,                  1683,               0,
 -3523,               0,                 -865,                0,
 -25,                 1,                 -186329,            -1,
  10,                 0,                  50,                 0,
  53,                 0,                  5455,              -45,
  17271,             -10,                -68747,              0,
  69,                -2,                 -7604,               0,
 -724,                1,                  3101,               0,
 -46,                 0,                  200,                0,
 -44,                 0,                  97,                 0,
 -53,                 0,                  62,                 0,
 -54,                -4,                  88,                -24,
 -9,                 -36,                -581,                27,
 -914711,             3,                  8,                  35,
 -86,                 24,                 51,                 3,
  48,                 0,                  26,                 0,
  133,                1,                 -577,                0,
  105,                0,                 -3,                 -1,
  3194,               0,                  528,                0,
 -2263,               0,                  2028,               0,
 -3266,               1,                  14016,              0,
  10,                 0,                 -41,                 0,
 -100,                0,                 -32,                 0,
 -124348,             0,                  16,                 0,
 -325,                0,                  50,                -1,
  1,                  0,                 -553,                0,
  0,                  0,                  0,                  0,
  2,                  0,                 -34,                 0,
 -444,                0,                  1902,               0,
  9,                  0,                 -37,                 0,
  254,                0,                  156,                0,
 -2,                  0,                 -35,                 0,
 -48,                 0,                 -368,                0,
  327,                0,                 -686,                0,
 -2263,               0,                  1952,               0,
 -8418,               0,                 -13,                 0,
  52,                 0,                  9,                  0,
  21,                 0,                 -261,                0,
 -62404,              0,                  0,                  0,
  79,                 0,                  1056,               0,
 -4547,               0,                 -351,                0,
 -305,                0,                  1310,               0,
 -1,                  0,                  6,                  0,
  0,                  0,                 -55953,              0,
 -80,                 0,                  0,                  0,
  168,                0,                 -147,                0,
  127,                0,                 -265,                0,
  1138,               0,                 -1,                  0,
 -9,                  0,                 -8,                  0,
 -5984,               0,                 -22,                 0,
 -5,                  0,                  0,                  0,
  0,                  0,                  127,                0,
 -2,                  0,                  10,                 0,
 -31,                 0,                 -29,                 0,
 -286,                0,                 -98,                 0,
 -1535,               0,                  252,                0,
 -1087,               0,                  43,                 0,
  4,                  0,                 -19,                 0,
 -7620,               0,                  29,                 0,
 -322,                0,                  203,                0,
  0,                  0,                 -3587,               0,
  10,                 0,                  0,                  0,
  94,                 0,                  0,                  0,
 -1,                  0,                 -1,                  0,
 -315,                0,                  1,                  0,
  0,                  0,                  0,                  0,
 -30,                 0,                 -94,                 0,
 -460,                0,                  1,                  0,
 -114,                0,                  0,                  0,
 -746,                0,                  4,                  0,
 -23,                 0,                  24,                 0,
  0,                  0,                 -237,                0,
  1,                  0,                  0,                  0,
 -18,                 0,                  0,                  0,
  0,                  0,                 -16,                 0,
 -76,                 0,                 -67,                 0,
  0,                  0,                 -16,                 0,
  0,                  0);

merargs: array[0..746] of shortint =
( 0,  3,  3,  1,  1,-10,  3, 11,  4,  0,  2,  2,  5, -5,  6,  2,  3,  5,  1,
-14,  2,  2,  3,  1,  3,  1,  1, -5,  2,  4,  3,  0,  1,  1,  6,  0,  1,  2,
  6,  0,  3,  2,  1, -7,  2,  3,  3,  0,  1,  1,  5,  2,  2,  1,  1, -4,  3,
  2,  1,  2,  5,  2,  2,  2,  1, -5,  2,  2,  1,  3,  5,  0,  2,  4,  1,-10,
  2,  1,  2,  3,  1, -8,  2,  0,  2,  1,  1, -3,  2,  2,  2,  1,  1, -2,  2,
  2,  1,  1,  3,  0,  2,  3,  1, -7,  2,  1,  2,  1,  1, -3,  3,  0,  1,  1,
  2,  0,  2,  2,  1, -4,  2,  1,  2,  4,  1, -9,  2,  0,  1,  2,  3,  0,  2,
  1,  1, -2,  3,  0,  2,  1,  1, -4,  2,  0,  2,  1,  1, -1,  2,  0,  2,  3,
  1, -6,  2,  0,  1,  3,  3,  0,  2,  2,  1, -7,  2,  0,  2,  1,  1, -2,  4,
  0,  2,  1,  1, -1,  3,  0,  1,  2,  2,  2,  2,  2,  1, -3,  2,  2,  2,  4,
  1, -8,  2,  0,  2,  3,  1,-10,  2,  0,  2,  1,  1, -4,  5,  0,  2,  1,  1,
 -3,  5,  2,  2,  1,  1, -5,  2,  2,  2,  1,  1, -5,  6,  0,  2,  1,  1, -2,
  5,  1,  3,  1,  1, -4,  5,  5,  6,  0,  1,  4,  3,  0,  2,  1,  1, -3,  6,
  1,  2,  1,  1, -1,  5,  0,  2,  1,  1, -2,  6,  0,  2,  1,  1, -1,  6,  0,
  2,  1,  1, -2,  7,  0,  2,  1,  1, -1,  7,  0,  3,  4,  1,-14,  2,  2,  3,
  0,  3,  1,  1,  2,  5, -5,  6,  0,  1,  1,  1,  6,  3,  2,  1,-10,  3, 11,
  4,  0,  3,  1,  1, -2,  5,  5,  6,  0,  3,  6,  1,-14,  2,  2,  3,  0,  2,
  1,  1,  1,  6,  0,  2,  1,  1,  2,  6,  0,  2,  1,  1,  1,  5,  1,  2,  2,
  1, -4,  3,  1,  2,  1,  1,  2,  5,  0,  2,  3,  1, -5,  2,  2,  2,  1,  1,
  3,  5,  0,  2,  5,  1,-10,  2,  0,  1,  3,  2,  0,  2,  2,  1, -2,  2,  0,
  2,  1,  1,  1,  3,  0,  2,  4,  1, -7,  2,  0,  2,  2,  1, -3,  3,  0,  2,
  1,  1,  1,  2,  0,  2,  3,  1, -4,  2,  0,  2,  5,  1, -9,  2,  0,  2,  1,
  1,  2,  3,  0,  2,  2,  1, -2,  3,  0,  1,  4,  2,  0,  2,  2,  1, -1,  2,
  0,  2,  4,  1, -6,  2,  0,  2,  2,  1, -2,  4,  0,  2,  2,  1, -1,  3,  0,
  2,  1,  1,  2,  2,  1,  2,  3,  1, -3,  2,  0,  2,  5,  1, -8,  2,  0,  2,
  2,  1, -3,  5,  0,  1,  5,  2,  1,  2,  2,  1, -2,  5,  0,  2,  1,  1,  4,
  3,  0,  2,  2,  1, -3,  6,  0,  2,  2,  1, -1,  5,  0,  2,  2,  1, -2,  6,
  0,  1,  2,  1,  4,  2,  2,  1,  1,  5,  0,  2,  3,  1, -4,  3,  0,  2,  2,
  1,  2,  5,  0,  2,  4,  1, -5,  2,  2,  2,  1,  1,  3,  2,  0,  2,  3,  1,
 -2,  2,  1,  2,  3,  1, -3,  3,  0,  2,  2,  1,  1,  2,  0,  2,  4,  1, -4,
  2,  0,  2,  3,  1, -2,  3,  0,  2,  3,  1, -1,  2,  0,  2,  3,  1, -1,  3,
  0,  2,  2,  1,  2,  2,  0,  2,  4,  1, -3,  2,  0,  2,  3,  1, -3,  5,  0,
  2,  1,  1,  5,  2,  1,  2,  3,  1, -2,  5,  0,  2,  3,  1, -1,  5,  0,  2,
  3,  1, -2,  6,  0,  1,  3,  1,  3,  2,  4,  1, -4,  3,  0,  2,  5,  1, -5,
  2,  0,  2,  4,  1, -2,  2,  0,  2,  5,  1, -4,  2,  0,  2,  4,  1, -2,  3,
  0,  2,  5,  1, -3,  2,  0,  2,  2,  1,  5,  2,  0,  2,  4,  1, -2,  5,  0,
  2,  4,  1, -1,  5,  0,  1,  4,  1,  3,  2,  6,  1, -5,  2,  1,  2,  5,  1,
 -2,  2,  0,  2,  5,  1, -2,  5,  0,  1,  5,  1,  3,  2,  7,  1, -5,  2,  0,
  1,  6,  1,  3,  1,  7,  1,  3,  1,  8,  1,  2,  1,  9,  1,  2,  1, 10,  1,
  1,  1, 11,  1,  0, -1);

venargs: array[0..638] of shortint =
( 0,  3,  2,  2,  5, -5,  6,  0,  3,  2,  2,  1,  3, -8,  4,  0,  3,  5,  1,
-14,  2,  2,  3,  0,  3,  3,  2, -7,  3,  4,  4,  0,  2,  8,  2,-13,  3,  2,
  3,  6,  2,-10,  3,  3,  5,  0,  1,  1,  7,  0,  2,  1,  5, -2,  6,  0,  2,
  1,  2, -3,  4,  2,  2,  2,  5, -4,  6,  1,  1,  1,  6,  0,  3,  3,  2, -5,
  3,  1,  5,  0,  3,  3,  2, -5,  3,  2,  5,  0,  2,  1,  5, -1,  6,  0,  2,
  2,  2, -6,  4,  1,  2,  2,  5, -3,  6,  0,  1,  2,  6,  0,  2,  3,  5, -5,
  6,  0,  1,  1,  5,  1,  2,  2,  5, -2,  6,  0,  2,  3,  2, -5,  3,  2,  2,
  5,  2, -8,  3,  1,  1,  2,  5,  0,  2,  2,  1, -5,  2,  1,  2,  6,  2,-10,
  3,  0,  2,  2,  2, -3,  3,  2,  2,  1,  2, -2,  3,  1,  2,  4,  2, -7,  3,
  0,  2,  4,  2, -6,  3,  0,  1,  1,  4,  0,  2,  1,  2, -2,  4,  0,  2,  2,
  2, -5,  4,  0,  2,  1,  2, -1,  3,  0,  2,  1,  1, -3,  2,  0,  2,  2,  2,
 -4,  3,  0,  2,  6,  2, -9,  3,  0,  2,  3,  2, -4,  3,  2,  2,  1,  1, -2,
  2,  0,  1,  1,  3,  0,  2,  1,  2, -1,  4,  0,  2,  2,  2, -4,  4,  0,  2,
  5,  2, -7,  3,  0,  2,  2,  2, -2,  3,  0,  2,  1,  2, -3,  5,  0,  2,  1,
  2, -3,  3,  0,  2,  7,  2,-10,  3,  0,  2,  1,  2, -2,  5,  1,  2,  4,  2,
 -5,  3,  1,  3,  1,  2,  1,  5, -5,  6,  0,  2,  1,  2, -1,  5,  0,  3,  1,
  2, -3,  5,  5,  6,  0,  2,  1,  2, -2,  6,  0,  2,  1,  2, -1,  6,  0,  1,
  3,  4,  0,  2,  7,  2,-13,  3,  0,  3,  1,  2,  2,  5, -5,  6,  1,  1,  1,
  2,  5,  2,  9,  2,-13,  3,  0,  3,  1,  2,  1,  5, -2,  6,  0,  2,  2,  2,
 -3,  4,  2,  2,  3,  2, -6,  4,  0,  2,  1,  2,  1,  5,  0,  2,  2,  2, -5,
  3,  0,  2,  6,  2, -8,  3,  0,  2,  2,  1, -4,  2,  0,  2,  3,  2, -3,  3,
  0,  1,  2,  3,  0,  2,  3,  2, -7,  3,  0,  2,  5,  2, -6,  3,  1,  2,  2,
  2, -2,  4,  0,  2,  3,  2, -5,  4,  0,  2,  2,  2, -1,  3,  0,  2,  7,  2,
 -9,  3,  0,  2,  4,  2, -4,  3,  0,  2,  1,  2,  1,  3,  0,  2,  3,  2, -4,
  4,  0,  2,  6,  2, -7,  3,  0,  2,  3,  2, -2,  3,  0,  2,  2,  2, -4,  5,
  0,  2,  2,  2, -3,  5,  0,  2,  2,  2, -2,  5,  0,  2,  5,  2, -5,  3,  0,
  2,  2,  2, -3,  6,  0,  2,  2,  2, -1,  5,  0,  2,  2,  2, -2,  6,  0,  1,
  2,  2,  3,  2,  2,  2,  1,  5,  0,  2,  7,  2, -8,  3,  0,  2,  2,  1, -3,
  2,  0,  2,  4,  2, -3,  3,  0,  2,  6,  2, -6,  3,  0,  2,  3,  2, -1,  3,
  0,  2,  8,  2, -9,  3,  0,  2,  5,  2, -4,  3,  0,  2,  7,  2, -7,  3,  0,
  2,  4,  2, -2,  3,  0,  2,  3,  2, -4,  5,  0,  2,  3,  2, -3,  5,  0,  2,
  9,  2,-10,  3,  0,  2,  3,  2, -2,  5,  0,  1,  3,  2,  2,  2,  8,  2, -8,
  3,  0,  2,  5,  2, -3,  3,  0,  2,  9,  2, -9,  3,  0,  2, 10,  2,-10,  3,
  0,  1,  4,  2,  1,  2, 11,  2,-11,  3,  0, -1);

marargs: array[0..1290] of shortint =
( 0,  4,  3,  4,  3, -8,  4,  3,  5,  2,  3,  5,  2, -6,  3, -4,  4,  0,  2,
  2,  5, -5,  6,  1,  3, 12,  3,-24,  4,  9,  5,  0,  3,  2,  2,  1,  3, -8,
  4,  1,  3, 11,  3,-21,  4,  2,  5,  0,  3,  3,  2, -7,  3,  4,  4,  0,  3,
  7,  3,-13,  4, -1,  5,  1,  3,  1,  3, -2,  4,  2,  6,  0,  3,  1,  2, -8,
  3, 12,  4,  1,  3,  1,  4, -8,  5,  4,  6,  0,  3,  1,  4, -7,  5,  2,  6,
  0,  3,  1,  4, -9,  5,  7,  6,  0,  1,  1,  7,  0,  2,  1,  5, -2,  6,  0,
  3,  1,  3, -2,  4,  1,  5,  0,  3,  3,  3, -6,  4,  2,  5,  1,  3, 12,  3,
-23,  4,  3,  5,  0,  2,  8,  3,-15,  4,  3,  2,  1,  4, -6,  5,  2,  3,  2,
  2, -7,  3,  7,  4,  0,  2,  1,  2, -3,  4,  2,  2,  2,  5, -4,  6,  0,  1,
  1,  6,  1,  2,  9,  3,-17,  4,  2,  3,  2,  3, -4,  4,  2,  5,  0,  3,  2,
  3, -4,  4,  1,  5,  0,  2,  1,  5, -1,  6,  0,  2,  2,  2, -6,  4,  2,  2,
  1,  3, -2,  4,  2,  2,  2,  5, -3,  6,  0,  1,  2,  6,  1,  2,  3,  5, -5,
  6,  1,  1,  1,  5,  2,  3,  4,  3, -8,  4,  2,  5,  0,  2,  1,  5, -5,  6,
  0,  2,  7,  3,-13,  4,  2,  2,  3,  2, -9,  4,  0,  2,  2,  5, -2,  6,  0,
  1,  3,  6,  0,  2,  1,  4, -5,  5,  0,  2,  2,  3, -4,  4,  2,  2,  6,  3,
-11,  4,  2,  2,  4,  5, -5,  6,  0,  1,  2,  5,  2,  3,  1,  4, -3,  5, -3,
  6,  0,  2,  3,  3, -6,  4,  2,  2,  1,  4, -4,  5,  1,  2,  5,  3, -9,  4,
  2,  1,  3,  5,  1,  2,  4,  3, -8,  4,  2,  3,  1,  4, -4,  5,  2,  6,  0,
  3,  1,  4, -1,  5, -5,  6,  0,  2,  4,  3, -7,  4,  2,  2,  1,  4, -3,  5,
  2,  3,  1,  4, -5,  5,  5,  6,  1,  3,  1,  4, -4,  5,  3,  6,  0,  3,  1,
  4, -3,  5,  1,  6,  0,  2,  5,  3,-10,  4,  1,  1,  4,  5,  0,  2,  3,  3,
 -5,  4,  2,  3,  1,  4, -3,  5,  2,  6,  0,  2,  1,  4, -5,  6,  2,  2,  1,
  4, -2,  5,  2,  3,  1,  4, -4,  5,  5,  6,  1,  2,  6,  3,-12,  4,  1,  2,
  1,  4, -4,  6,  0,  2,  2,  3, -3,  4,  2,  2, 10,  3,-18,  4,  0,  2,  1,
  4, -3,  6,  1,  3,  1,  4, -2,  5,  2,  6,  0,  2,  7,  3,-14,  4,  1,  3,
  1,  4,  1,  5, -5,  6,  1,  2,  1,  4, -1,  5,  0,  3,  1,  4, -3,  5,  5,
  6,  1,  3,  1,  4,  2,  5, -7,  6,  1,  2,  1,  4, -2,  6,  2,  3,  1,  4,
 -2,  5,  3,  6,  0,  2,  1,  3, -1,  4,  0,  2,  2,  2, -7,  4,  1,  2,  9,
  3,-16,  4,  2,  2,  1,  4, -3,  7,  0,  2,  1,  4, -1,  6,  0,  3,  1,  4,
 -2,  5,  4,  6,  1,  2,  1,  2, -4,  4,  2,  2,  8,  3,-16,  4,  2,  2,  1,
  4, -2,  7,  0,  3,  3,  3, -5,  4,  2,  5,  0,  3,  1,  4,  1,  5, -3,  6,
  0,  2,  1,  4, -2,  8,  0,  2,  1,  4, -1,  7,  0,  2,  1,  4, -1,  8,  0,
  3,  3,  2, -7,  3,  3,  4,  0,  3,  2,  2,  1,  3, -7,  4,  0,  3,  1,  4,
  1,  6, -3,  7,  0,  3,  1,  4,  2,  5, -5,  6,  1,  3,  4,  3, -7,  4,  3,
  5,  1,  1,  1,  4,  5,  3,  4,  3, -9,  4,  3,  5,  1,  3,  1,  4, -2,  5,
  5,  6,  0,  3,  3,  2, -7,  3,  5,  4,  0,  3,  1,  3, -1,  4,  2,  6,  0,
  3,  1,  4,  1,  5, -2,  6,  0,  3,  3,  3, -7,  4,  2,  5,  0,  2,  8,  3,
-14,  4,  1,  2,  1,  2, -2,  4,  1,  2,  1,  4,  1,  6,  1,  2,  9,  3,-18,
  4,  1,  2,  2,  2, -5,  4,  1,  2,  1,  3, -3,  4,  2,  2,  1,  4,  2,  6,
  0,  2,  1,  4,  1,  5,  1,  3,  4,  3, -9,  4,  2,  5,  1,  2,  7,  3,-12,
  4,  1,  2,  2,  4, -5,  5,  0,  2,  2,  3, -5,  4,  2,  2,  6,  3,-10,  4,
  1,  2,  1,  4,  2,  5,  1,  3,  2,  4, -5,  5,  2,  6,  0,  2,  3,  3, -7,
  4,  1,  2,  2,  4, -4,  5,  0,  2,  5,  3, -8,  4,  1,  2,  1,  4,  3,  5,
  0,  3,  2,  4, -4,  5,  2,  6,  0,  3,  2,  4, -1,  5, -5,  6,  0,  2,  4,
  3, -6,  4,  1,  2,  2,  4, -3,  5,  0,  3,  2,  4, -5,  5,  5,  6,  1,  3,
  2,  4, -4,  5,  3,  6,  0,  2,  3,  3, -4,  4,  1,  2,  2,  4, -5,  6,  2,
  2,  2,  4, -2,  5,  1,  3,  2,  4, -4,  5,  5,  6,  1,  2,  2,  4, -4,  6,
  0,  2,  2,  3, -2,  4,  0,  2,  2,  4, -3,  6,  1,  2,  2,  4, -1,  5,  1,
  2,  2,  4, -2,  6,  0,  1,  1,  3,  1,  2,  2,  4, -1,  6,  0,  2,  1,  2,
 -5,  4,  1,  2,  8,  3,-17,  4,  1,  3,  2,  4,  2,  5, -5,  6,  1,  3,  4,
  3, -6,  4,  3,  5,  1,  3, 10,  3,-17,  4,  3,  6,  0,  1,  2,  4,  4,  3,
  4,  3,-10,  4,  3,  5,  1,  2,  8,  3,-13,  4,  0,  2,  1,  2, -1,  4,  0,
  2,  2,  4,  1,  6,  0,  2,  2,  2, -4,  4,  0,  2,  1,  3, -4,  4,  1,  2,
  2,  4,  1,  5,  0,  2,  7,  3,-11,  4,  0,  2,  3,  4, -5,  5,  0,  2,  2,
  3, -6,  4,  1,  2,  6,  3, -9,  4,  0,  2,  2,  4,  2,  5,  0,  2,  3,  4,
 -4,  5,  0,  2,  5,  3, -7,  4,  0,  2,  4,  3, -5,  4,  1,  2,  3,  4, -3,
  5,  1,  2,  3,  3, -3,  4,  0,  2,  3,  4, -2,  5,  2,  3,  3,  4, -4,  5,
  5,  6,  0,  2,  2,  3, -1,  4,  0,  2,  3,  4, -3,  6,  0,  2,  3,  4, -1,
  5,  1,  2,  3,  4, -2,  6,  0,  2,  1,  3,  1,  4,  1,  2,  3,  4, -1,  6,
  0,  3,  4,  3, -5,  4,  3,  5,  0,  1,  3,  4,  3,  3,  4,  3,-11,  4,  3,
  5,  0,  1,  1,  2,  0,  2,  2,  2, -3,  4,  0,  2,  1,  3, -5,  4,  0,  2,
  4,  4, -5,  5,  0,  2,  6,  3, -8,  4,  0,  2,  4,  4, -4,  5,  0,  2,  5,
  3, -6,  4,  0,  2,  4,  3, -4,  4,  0,  2,  4,  4, -3,  5,  1,  3,  6,  3,
 -8,  4,  2,  5,  0,  2,  3,  3, -2,  4,  0,  2,  4,  4, -2,  5,  1,  2,  4,
  4, -1,  5,  0,  2,  1,  3,  2,  4,  0,  1,  4,  4,  3,  2,  2,  2, -2,  4,
  0,  2,  7,  3, -9,  4,  0,  2,  5,  4, -5,  5,  0,  2,  6,  3, -7,  4,  0,
  2,  5,  4, -4,  5,  0,  2,  5,  3, -5,  4,  0,  2,  5,  4, -3,  5,  0,  2,
  5,  4, -2,  5,  0,  1,  5,  4,  3,  1,  6,  4,  2,  1,  7,  4,  0, -1);

jupargs: array[0..904] of shortint =
( 0,  6,  3,  2,  5, -6,  6,  3,  7,  0,  2,  2,  5, -5,  6,  6,  3,  1,  5,
 -2,  6, -3,  8,  0,  2,  4,  5,-10,  6,  4,  3,  2,  5, -4,  6, -3,  7,  1,
  3,  3,  5,-10,  6,  7,  7,  0,  2,  6,  5,-15,  6,  0,  3,  1,  5, -4,  6,
  4,  7,  0,  3,  3,  5, -8,  6,  2,  7,  0,  3,  1,  5, -3,  6,  1,  7,  0,
  3,  1,  5, -3,  6,  2,  7,  0,  1,  1,  7,  1,  2,  5,  5,-12,  6,  0,  3,
  2,  5, -7,  6,  7,  7,  0,  3,  1,  5, -1,  6, -3,  7,  0,  2,  3,  5, -7,
  6,  3,  3,  1,  5, -4,  6,  3,  7,  0,  2,  1,  5, -2,  6,  3,  3,  3,  5,
 -8,  6,  3,  7,  0,  2,  1,  5, -3,  6,  3,  3,  1,  5, -3,  6,  3,  7,  0,
  2,  3,  5, -8,  6,  2,  3,  2,  5, -5,  6,  2,  7,  0,  1,  2,  7,  0,  2,
  4,  5, -9,  6,  3,  2,  2,  5, -4,  6,  4,  1,  1,  6,  2,  3,  2,  5, -5,
  6,  3,  7,  0,  2,  2,  5, -6,  6,  2,  2,  5,  5,-11,  6,  1,  3,  1,  5,
 -2,  7, -2,  8,  0,  2,  1,  5, -3,  7,  1,  2,  3,  5, -6,  6,  3,  2,  1,
  5, -1,  6,  2,  2,  1,  5, -4,  6,  2,  2,  3,  5, -9,  6,  0,  3,  2,  5,
 -4,  6,  2,  7,  0,  2,  1,  5, -2,  7,  1,  2,  6,  5,-13,  6,  0,  3,  2,
  5, -2,  6, -3,  7,  0,  2,  4,  5, -8,  6,  3,  2,  3,  6, -3,  7,  0,  3,
  6,  5,-14,  6,  3,  7,  0,  3,  1,  5, -2,  7,  1,  8,  0,  2,  2,  5, -3,
  6,  2,  3,  1,  5, -4,  7,  5,  8,  0,  3,  2,  5, -8,  6,  3,  7,  0,  3,
  4,  5, -9,  6,  3,  7,  0,  1,  2,  6,  3,  3,  2,  5, -4,  6,  3,  7,  0,
  2,  2,  5, -7,  6,  2,  2,  1,  5, -2,  8,  0,  2,  1,  5, -1,  7,  0,  3,
  3,  5, -6,  6,  2,  7,  0,  3,  4,  5, -8,  6,  2,  8,  0,  2,  1,  5, -1,
  8,  0,  3,  2,  5, -3,  6,  1,  7,  0,  2,  7,  5,-15,  6,  2,  3,  3,  5,
 -4,  6, -3,  7,  1,  2,  5,  5,-10,  6,  4,  3,  1,  5,  1,  6, -3,  7,  1,
  3,  7,  5,-16,  6,  3,  7,  0,  2,  3,  5, -5,  6,  4,  3,  1,  5, -6,  6,
  3,  7,  0,  3,  5,  5,-11,  6,  3,  7,  0,  1,  1,  5,  5,  3,  3,  5,-11,
  6,  3,  7,  0,  3,  3,  5, -6,  6,  3,  7,  0,  2,  2,  5, -7,  7,  0,  2,
  1,  5, -5,  6,  3,  3,  1,  5, -1,  6,  3,  7,  0,  2,  3,  5,-10,  6,  3,
  3,  2,  5, -3,  6,  2,  7,  0,  2,  1,  5,  1,  7,  0,  3,  2,  5, -1,  6,
 -3,  7,  0,  2,  4,  5, -7,  6,  3,  2,  4,  6, -3,  7,  0,  2,  2,  5, -2,
  6,  4,  3,  4,  5, -8,  6,  3,  7,  0,  1,  3,  6,  3,  3,  2,  5, -3,  6,
  3,  7,  0,  2,  5,  5, -9,  6,  3,  2,  3,  5, -4,  6,  2,  2,  1,  5,  1,
  6,  2,  2,  2,  5, -4,  7,  0,  2,  6,  5,-11,  6,  2,  2,  2,  5, -3,  7,
  0,  2,  4,  5, -6,  6,  2,  2,  2,  5, -1,  6,  2,  1,  4,  6,  1,  2,  2,
  5, -2,  7,  0,  2,  5,  5, -8,  6,  2,  2,  3,  5, -3,  6,  2,  2,  1,  5,
  2,  6,  2,  2,  2,  5, -2,  8,  0,  2,  2,  5, -1,  7,  0,  2,  6,  5,-10,
  6,  3,  2,  4,  5, -5,  6,  3,  2,  6,  6, -3,  7,  0,  1,  2,  5,  5,  3,
  4,  5, -6,  6,  3,  7,  0,  1,  5,  6,  4,  2,  2,  5,-10,  6,  1,  2,  5,
  5, -7,  6,  1,  2,  3,  5, -2,  6,  2,  2,  1,  5,  3,  6,  2,  2,  6,  5,
 -9,  6,  2,  2,  4,  5, -4,  6,  2,  2,  2,  5,  1,  6,  2,  2,  7,  5,-11,
  6,  0,  2,  3,  5, -3,  7,  0,  2,  5,  5, -6,  6,  2,  2,  3,  5, -1,  6,
  1,  2,  3,  5, -2,  7,  0,  2,  6,  5, -8,  6,  1,  2,  4,  5, -3,  6,  1,
  2,  2,  5,  2,  6,  0,  2,  7,  5,-10,  6,  1,  2,  5,  5, -5,  6,  2,  1,
  3,  5,  3,  2,  1,  5,  5,  6,  2,  2,  6,  5, -7,  6,  1,  2,  4,  5, -2,
  6,  1,  2,  7,  5, -9,  6,  1,  2,  5,  5, -4,  6,  0,  2,  6,  5, -6,  6,
  0,  2,  4,  5, -1,  6,  0,  2,  7,  5, -8,  6,  1,  2,  5,  5, -3,  6,  0,
  2,  8,  5,-10,  6,  0,  2,  6,  5, -5,  6,  0,  1,  4,  5,  2,  2,  7,  5,
 -7,  6,  0,  2,  5,  5, -2,  6,  0,  2,  8,  5, -9,  6,  0,  2,  7,  5, -6,
  6,  0,  2,  8,  5, -8,  6,  0,  2,  9,  5,-10,  6,  0,  1,  5,  5,  0,  2,
  9,  5, -9,  6,  0,  2,  1,  3, -1,  5,  0, -1);

satargs: array[0..1452] of shortint =
( 0,  7,  3,  2,  5, -6,  6,  3,  7,  0,  2,  2,  5, -5,  6,  5,  3,  1,  6,
 -4,  7,  2,  8,  0,  2,  1,  6, -3,  7,  0,  3,  1,  6, -2,  7, -2,  8,  0,
  2,  4,  5,-10,  6,  3,  3,  1,  5, -1,  6, -4,  7,  0,  3,  2,  5, -4,  6,
 -3,  7,  0,  3,  2,  6, -8,  7,  4,  8,  0,  3,  3,  5,-10,  6,  7,  7,  0,
  2,  6,  5,-15,  6,  0,  2,  2,  6, -6,  7,  0,  3,  1,  5, -4,  6,  4,  7,
  1,  3,  1,  5, -2,  6, -1,  7,  0,  3,  2,  5, -5,  6,  1,  8,  0,  3,  3,
  5, -8,  6,  2,  7,  0,  3,  1,  5, -3,  6,  2,  8,  0,  3,  1,  5, -3,  6,
  1,  7,  1,  1,  1,  8,  0,  3,  1,  5, -3,  6,  2,  7,  1,  3,  1,  5, -2,
  6, -2,  7,  0,  2,  2,  6, -5,  7,  1,  3,  2,  6, -6,  7,  2,  8,  0,  3,
  2,  6, -7,  7,  4,  8,  0,  3,  2,  5, -4,  6, -2,  7,  0,  3,  1,  5, -1,
  6, -5,  7,  0,  3,  2,  6, -7,  7,  5,  8,  0,  3,  1,  6, -1,  7, -2,  8,
  0,  2,  1,  6, -2,  7,  1,  3,  1,  6, -3,  7,  2,  8,  0,  3,  1,  6, -4,
  7,  4,  8,  1,  3,  2,  5, -5,  6,  2,  8,  1,  3,  2,  5, -6,  6,  2,  7,
  1,  2,  2,  7, -2,  8,  0,  1,  1,  7,  2,  2,  5,  5,-12,  6,  2,  3,  2,
  6, -5,  7,  1,  8,  0,  3,  1,  5, -1,  6, -3,  7,  0,  3,  7,  5,-18,  6,
  3,  7,  0,  2,  3,  5, -7,  6,  3,  3,  1,  6,  1,  7, -5,  8,  0,  3,  1,
  5, -4,  6,  3,  7,  0,  3,  5,  5,-13,  6,  3,  7,  0,  2,  1,  5, -2,  6,
  3,  3,  3,  5, -9,  6,  3,  7,  0,  3,  3,  5, -8,  6,  3,  7,  1,  2,  1,
  5, -3,  6,  3,  3,  5,  5,-14,  6,  3,  7,  0,  3,  1,  5, -3,  6,  3,  7,
  2,  2,  3,  6, -7,  7,  0,  2,  3,  5, -8,  6,  2,  3,  2,  5, -3,  6, -4,
  7,  1,  3,  2,  5, -8,  6,  7,  7,  0,  2,  5,  5,-13,  6,  0,  2,  2,  6,
 -4,  7,  2,  3,  2,  6, -5,  7,  2,  8,  0,  3,  2,  5, -4,  6, -1,  7,  0,
  3,  2,  5, -7,  6,  4,  7,  0,  2,  1,  6, -2,  8,  2,  2,  1,  6, -1,  7,
  0,  3,  1,  6, -2,  7,  2,  8,  0,  3,  2,  5, -5,  6,  2,  7,  0,  3,  2,
  5, -6,  6,  2,  8,  0,  3,  2,  5, -6,  6,  1,  7,  0,  2,  3,  7, -2,  8,
  0,  1,  2,  7,  1,  2,  1,  6, -1,  8,  1,  3,  1,  5, -2,  6,  1,  7,  0,
  3,  1,  5, -2,  6,  2,  8,  0,  2,  3,  6, -6,  7,  2,  2,  6,  5,-14,  6,
  0,  3,  3,  6, -7,  7,  2,  8,  0,  3,  2,  5, -3,  6, -3,  7,  1,  2,  4,
  5, -9,  6,  3,  3,  2,  6, -2,  7, -2,  8,  0,  2,  2,  6, -3,  7,  1,  3,
  2,  6, -4,  7,  2,  8,  0,  2,  2,  5, -4,  6,  3,  3,  2,  5, -7,  6,  3,
  7,  1,  3,  1,  6,  1,  7, -2,  8,  0,  1,  1,  6,  5,  3,  2,  5, -5,  6,
  3,  7,  1,  2,  2,  5, -6,  6,  3,  1,  3,  7,  3,  2,  4,  5,-11,  6,  3,
  2,  1,  5, -4,  7,  0,  3,  2,  5, -5,  6, -3,  7,  1,  2,  6,  5,-16,  6,
  0,  3,  3,  5, -7,  6,  2,  7,  0,  3,  3,  6, -4,  7, -2,  8,  0,  2,  3,
  6, -5,  7,  1,  3,  3,  6, -6,  7,  2,  8,  1,  3,  3,  6, -7,  7,  4,  8,
  0,  3,  2,  5, -3,  6, -2,  7,  2,  3,  2,  5, -8,  6,  5,  7,  0,  2,  2,
  6, -4,  8,  0,  3,  2,  6, -1,  7, -2,  8,  1,  2,  2,  6, -2,  7,  2,  3,
  2,  6, -3,  7,  2,  8,  0,  3,  2,  5, -4,  6,  1,  7,  0,  3,  2,  5, -4,
  6,  2,  8,  0,  3,  2,  5, -7,  6,  2,  7,  1,  2,  1,  6,  1,  7,  1,  2,
  5,  5,-11,  6,  2,  3,  1,  5, -2,  7, -2,  8,  0,  2,  1,  5, -3,  7,  0,
  2,  3,  5, -6,  6,  3,  3,  2,  6,  1,  7, -5,  8,  0,  2,  2,  6, -3,  8,
  1,  2,  1,  5, -1,  6,  3,  3,  2,  5, -7,  6,  3,  8,  0,  3,  3,  5, -7,
  6,  3,  7,  0,  3,  2,  5, -1,  6, -7,  7,  0,  2,  1,  5, -4,  6,  2,  3,
  1,  5, -2,  6,  3,  7,  0,  2,  4,  6, -7,  7,  0,  2,  3,  5, -9,  6,  0,
  3,  2,  5, -2,  6, -4,  7,  0,  2,  3,  6, -4,  7,  2,  3,  2,  5, -3,  6,
 -1,  7,  0,  3,  2,  5, -8,  6,  4,  7,  0,  2,  2,  6, -2,  8,  1,  2,  2,
  6, -1,  7,  0,  3,  2,  6, -2,  7,  2,  8,  1,  3,  2,  5, -4,  6,  2,  7,
  0,  3,  2,  5, -7,  6,  2,  8,  0,  3,  2,  5, -7,  6,  1,  7,  0,  2,  1,
  6,  2,  7,  0,  2,  2,  6, -1,  8,  0,  2,  4,  6, -6,  7,  1,  2,  6,  5,
-13,  6,  0,  3,  2,  5, -2,  6, -3,  7,  1,  2,  4,  5, -8,  6,  2,  3,  3,
  6, -2,  7, -2,  8,  0,  2,  3,  6, -3,  7,  0,  3,  3,  6, -4,  7,  2,  8,
  0,  2,  2,  5, -3,  6,  3,  3,  2,  5, -8,  6,  3,  7,  1,  3,  2,  6,  1,
  7, -2,  8,  0,  1,  2,  6,  5,  3,  2,  5, -4,  6,  3,  7,  2,  2,  2,  5,
 -7,  6,  3,  3,  1,  6,  4,  7, -2,  8,  0,  2,  1,  6,  3,  7,  1,  3,  1,
  6,  2,  7,  2,  8,  0,  2,  4,  5,-12,  6,  2,  2,  5,  6, -8,  7,  0,  2,
  4,  6, -5,  7,  0,  3,  2,  5, -2,  6, -2,  7,  0,  2,  3,  6, -2,  7,  1,
  3,  3,  6, -3,  7,  2,  8,  0,  2,  5,  5,-10,  6,  2,  3,  1,  5,  1,  6,
 -3,  7,  0,  2,  3,  5, -5,  6,  3,  2,  3,  6, -3,  8,  0,  1,  1,  5,  2,
  2,  1,  5, -5,  6,  2,  2,  5,  6, -7,  7,  0,  2,  4,  6, -4,  7,  2,  2,
  3,  6, -2,  8,  0,  2,  3,  6, -1,  7,  0,  2,  5,  6, -6,  7,  0,  2,  4,
  5, -7,  6,  2,  2,  4,  6, -3,  7,  2,  2,  2,  5, -2,  6,  2,  3,  2,  6,
 -9,  7,  3,  8,  0,  1,  3,  6,  4,  3,  2,  5, -3,  6,  3,  7,  1,  2,  2,
  5, -8,  6,  3,  3,  2,  6,  4,  7, -2,  8,  0,  2,  4,  5,-13,  6,  1,  2,
  6,  6, -8,  7,  1,  2,  5,  6, -5,  7,  0,  2,  4,  6, -2,  7,  0,  2,  5,
  5, -9,  6,  2,  2,  3,  5, -4,  6,  2,  2,  1,  5,  1,  6,  2,  2,  6,  5,
-11,  6,  0,  3,  6,  6, -7,  7,  2,  8,  0,  2,  4,  5, -6,  6,  2,  2,  2,
  5, -1,  6,  2,  1,  4,  6,  3,  3,  2,  5, -2,  6,  3,  7,  1,  2,  2,  5,
 -9,  6,  1,  2,  5,  5, -8,  6,  2,  2,  3,  5, -3,  6,  1,  2,  1,  5,  2,
  6,  2,  2,  6,  5,-10,  6,  1,  2,  4,  5, -5,  6,  2,  1,  2,  5,  1,  1,
  5,  6,  2,  2,  5,  5, -7,  6,  1,  2,  3,  5, -2,  6,  1,  3,  1,  5,  2,
  6,  3,  7,  0,  2,  6,  5, -9,  6,  0,  2,  4,  5, -4,  6,  2,  2,  2,  5,
  1,  6,  1,  2,  7,  5,-11,  6,  0,  2,  5,  5, -6,  6,  1,  2,  3,  5, -1,
  6,  1,  2,  6,  5, -8,  6,  1,  2,  4,  5, -3,  6,  0,  2,  5,  5, -5,  6,
  0,  1,  3,  5,  0,  2,  6,  5, -7,  6,  1,  2,  7,  5, -9,  6,  0,  2,  5,
  5, -4,  6,  0,  2,  6,  5, -6,  6,  0,  2,  7,  5, -8,  6,  0,  2,  6,  5,
 -5,  6,  0,  2,  7,  5, -7,  6,  0,  2,  8,  5, -9,  6,  0,  2,  8,  5, -8,
  6,  0,  2,  1,  3, -1,  6,  0, -1);

uraargs: array[0..1166] of shortint =
( 0,  3,  2,  1,  7, -2,  8,  0,  2,  2,  7, -4,  8,  0,  2,  3,  7, -6,  8,
  1,  2,  2,  5, -5,  6,  4,  2,  1,  6, -3,  7,  3,  3,  1,  6, -1,  7, -4,
  8,  0,  3,  2,  5, -7,  6,  6,  7,  0,  3,  2,  6, -6,  7,  1,  8,  0,  3,
  2,  6, -7,  7,  3,  8,  0,  3,  2,  6, -8,  7,  4,  8,  0,  3,  2,  6, -7,
  7,  2,  8,  0,  2,  2,  6, -6,  7,  2,  3,  1,  5, -4,  6,  4,  7,  0,  3,
  1,  6, -2,  7, -1,  8,  0,  3,  1,  6, -3,  7,  1,  8,  0,  3,  1,  6, -4,
  7,  3,  8,  1,  2,  5,  7, -9,  8,  0,  2,  4,  7, -7,  8,  0,  2,  2,  7,
 -3,  8,  6,  2,  1,  7, -3,  8,  2,  2,  2,  7, -5,  8,  0,  2,  3,  7, -7,
  8,  0,  3,  1,  6, -6,  7,  5,  8,  1,  3,  1,  6, -5,  7,  3,  8,  0,  3,
  2,  5, -8,  6,  8,  7,  0,  3,  1,  5, -4,  6,  5,  7,  0,  2,  2,  6, -5,
  7,  3,  3,  1,  6,  1,  7, -9,  8,  0,  3,  2,  5, -4,  6, -2,  7,  0,  2,
  1,  6, -4,  8,  4,  2,  1,  6, -2,  7,  4,  2,  5,  7, -8,  8,  5,  2,  3,
  7, -4,  8,  0,  1,  1,  7,  5,  2,  2,  7, -6,  8,  4,  3,  1,  6, -6,  7,
  4,  8,  0,  2,  1,  6, -4,  7,  4,  3,  2,  6, -5,  7,  1,  8,  0,  3,  2,
  6, -6,  7,  3,  8,  0,  2,  2,  6, -7,  7,  0,  3,  1,  5, -4,  6,  3,  7,
  0,  3,  1,  6, -1,  7, -1,  8,  0,  2,  1,  5, -2,  6,  0,  2,  6,  7, -9,
  8,  0,  2,  5,  7, -7,  8,  0,  2,  4,  7, -5,  8,  0,  2,  3,  7, -3,  8,
  1,  2,  2,  7, -1,  8,  0,  2,  1,  7,  1,  8,  2,  1,  3,  8,  0,  2,  3,
  6, -7,  7,  1,  3,  2,  5, -3,  6, -4,  7,  0,  3,  2,  6, -3,  7, -2,  8,
  0,  2,  2,  6, -4,  7,  1,  3,  2,  6, -5,  7,  2,  8,  1,  3,  5,  5, -9,
  6, -8,  7,  0,  3,  2,  5, -4,  6, -1,  7,  0,  3,  1,  6,  3,  7, -8,  8,
  0,  3,  2,  6, -8,  7,  1,  8,  0,  3,  2,  5, -7,  6,  4,  7,  0,  3,  4,
  5,-10,  6,  2,  7,  0,  2,  1,  6, -2,  8,  0,  2,  1,  6, -1,  7,  2,  2,
  8,  7,-12,  8,  0,  2,  7,  7,-10,  8,  0,  2,  6,  7, -8,  8,  1,  2,  5,
  7, -6,  8,  0,  2,  4,  7, -4,  8,  2,  1,  2,  7,  4,  1,  4,  8,  0,  2,
  1,  7, -6,  8,  0,  2,  2,  7, -8,  8,  1,  2,  3,  7,-10,  8,  0,  2,  4,
  7,-12,  8,  0,  3,  1,  6, -6,  7,  2,  8,  0,  2,  1,  6, -5,  7,  1,  3,
  1,  6, -4,  7, -2,  8,  0,  3,  1,  5, -4,  6,  2,  7,  1,  3,  1,  5, -2,
  6,  1,  7,  0,  2,  7,  7, -9,  8,  0,  2,  6,  7, -7,  8,  0,  2,  5,  7,
 -5,  8,  0,  2,  4,  7, -3,  8,  0,  2,  3,  7, -1,  8,  0,  2,  2,  7,  1,
  8,  0,  2,  3,  6, -6,  7,  1,  3,  3,  6, -7,  7,  2,  8,  0,  3,  2,  5,
 -3,  6, -3,  7,  1,  3,  2,  6, -2,  7, -2,  8,  0,  2,  2,  6, -3,  7,  1,
  3,  2,  6, -4,  7,  2,  8,  0,  3,  2,  5, -7,  6,  3,  7,  1,  3,  1,  6,
  1,  7, -2,  8,  0,  1,  1,  6,  1,  2,  8,  7,-10,  8,  0,  2,  7,  7, -8,
  8,  0,  2,  6,  7, -6,  8,  0,  2,  5,  7, -4,  8,  0,  2,  4,  7, -2,  8,
  0,  1,  3,  7,  3,  2,  2,  7,  2,  8,  0,  2,  1,  7,  4,  8,  0,  2,  1,
  5, -4,  7,  0,  2,  1,  6, -6,  7,  0,  2,  8,  7, -9,  8,  0,  2,  7,  7,
 -7,  8,  0,  2,  6,  7, -5,  8,  0,  2,  5,  7, -3,  8,  0,  2,  4,  7, -1,
  8,  0,  3,  3,  6, -4,  7, -2,  8,  0,  2,  3,  6, -5,  7,  1,  3,  3,  6,
 -6,  7,  2,  8,  0,  3,  2,  5, -3,  6, -2,  7,  1,  3,  2,  6, -1,  7, -2,
  8,  0,  2,  2,  6, -2,  7,  0,  3,  2,  6, -3,  7,  2,  8,  0,  3,  2,  5,
 -7,  6,  2,  7,  1,  2,  1,  6,  1,  7,  0,  2,  9,  7,-10,  8,  0,  2,  8,
  7, -8,  8,  0,  2,  7,  7, -6,  8,  0,  2,  6,  7, -4,  8,  0,  2,  5,  7,
 -2,  8,  0,  1,  4,  7,  1,  2,  3,  7,  2,  8,  0,  2,  1,  5, -3,  7,  0,
  2,  9,  7, -9,  8,  0,  2,  8,  7, -7,  8,  0,  3,  3,  6, -3,  7, -2,  8,
  0,  2,  3,  6, -4,  7,  1,  3,  3,  6, -5,  7,  2,  8,  0,  3,  2,  5, -3,
  6, -1,  7,  0,  3,  2,  5, -8,  6,  4,  7,  0,  2,  2,  6, -2,  8,  0,  2,
  2,  6, -1,  7,  1,  3,  2,  6, -2,  7,  2,  8,  0,  3,  2,  5, -7,  6,  1,
  7,  0,  2,  6,  7, -2,  8,  0,  1,  5,  7,  0,  3,  3,  6, -4,  7,  1,  8,
  0,  2,  1,  5, -2,  7,  2,  3,  1,  5, -3,  7,  2,  8,  0,  3,  1,  5, -1,
  6,  1,  7,  0,  2,  4,  6, -6,  7,  0,  2,  3,  6, -3,  7,  0,  1,  2,  6,
  0,  3,  2,  5, -4,  6,  3,  7,  0,  3,  1,  5,  1,  6, -4,  7,  0,  3,  3,
  5, -5,  6, -1,  7,  0,  1,  6,  7,  1,  3,  1,  5,  1,  7, -4,  8,  0,  2,
  1,  5, -2,  8,  0,  2,  1,  5, -1,  7,  1,  3,  1,  5, -2,  7,  2,  8,  0,
  3,  1,  5, -3,  7,  4,  8,  0,  3,  1,  5, -5,  6,  1,  7,  1,  3,  1,  5,
 -1,  6,  2,  7,  0,  2,  4,  6, -5,  7,  0,  2,  3,  6, -2,  7,  0,  3,  1,
  5,  1,  7, -2,  8,  0,  1,  1,  5,  1,  2,  4,  6, -4,  7,  0,  2,  3,  6,
 -1,  7,  0,  3,  3,  5, -5,  6,  1,  7,  0,  2,  5,  6, -6,  7,  0,  2,  4,
  6, -3,  7,  0,  2,  5,  6, -5,  7,  0,  2,  6,  6, -6,  7,  0,  2,  2,  5,
 -3,  7,  0,  2,  2,  5, -2,  7,  0,  2,  2,  5, -2,  8,  0,  2,  2,  5, -1,
  7,  1,  3,  2,  5, -2,  7,  2,  8,  0,  1,  2,  5,  0,  2,  3,  5, -3,  7,
  0,  2,  3,  5, -1,  7,  0, -1);

nepargs: array[0..368] of shortint =
( 0,  3,  2,  1,  7, -2,  8,  0,  3,  3,  5, -8,  6,  3,  8,  0,  2,  2,  7,
 -4,  8,  0,  3,  1,  5, -3,  6,  3,  8,  0,  2,  3,  7, -6,  8,  0,  2,  4,
  7, -8,  8,  0,  3,  1,  6, -6,  7,  6,  8,  0,  3,  1,  6, -5,  7,  4,  8,
  0,  3,  1,  6, -4,  7,  2,  8,  0,  2,  1,  6, -3,  7,  0,  3,  1,  6, -2,
  7, -1,  8,  0,  2,  5,  7, -9,  8,  1,  2,  4,  7, -7,  8,  1,  2,  3,  7,
 -5,  8,  1,  2,  2,  7, -3,  8,  0,  2,  1,  7, -1,  8,  1,  1,  1,  8,  2,
  2,  1,  7, -3,  8,  0,  2,  2,  7, -5,  8,  1,  3,  1,  6, -6,  7,  5,  8,
  0,  3,  1,  6, -5,  7,  3,  8,  0,  2,  5,  7, -8,  8,  0,  2,  4,  7, -6,
  8,  0,  2,  3,  7, -4,  8,  0,  2,  2,  7, -2,  8,  1,  1,  1,  7,  0,  1,
  2,  8,  2,  2,  1,  7, -4,  8,  0,  2,  5,  7, -7,  8,  0,  2,  4,  7, -5,
  8,  0,  2,  3,  7, -3,  8,  0,  2,  2,  7, -1,  8,  0,  2,  1,  7,  1,  8,
  0,  1,  3,  8,  1,  2,  1,  6, -2,  8,  1,  2,  5,  7, -6,  8,  0,  2,  4,
  7, -4,  8,  0,  1,  4,  8,  1,  3,  2,  5, -4,  6, -1,  8,  1,  3,  1,  6,
  1,  7, -3,  8,  0,  2,  1,  6, -1,  8,  1,  3,  1,  6, -1,  7,  1,  8,  0,
  3,  2,  5, -6,  6,  1,  8,  0,  2,  5,  7, -5,  8,  1,  1,  1,  6,  0,  2,
  6,  7, -6,  8,  0,  2,  7,  7, -7,  8,  0,  2,  2,  6, -2,  8,  0,  3,  2,
  5, -3,  6, -1,  8,  0,  2,  2,  6, -1,  8,  1,  2,  1,  5, -2,  8,  0,  3,
  3,  5, -5,  6, -1,  8,  0,  2,  4,  7,  5,  8,  0,  2,  1,  5, -1,  8,  1,
  3,  1,  5, -1,  7,  1,  8,  1,  3,  1,  5, -5,  6,  1,  8,  1,  1,  1,  5,
  0,  2,  2,  5, -1,  8,  1, -1);

pluargs: array[0..1086] of shortint =
( 0,  7,  2,  3,  7, -9,  9,  0,  2,  4,  7,-12,  9,  0,  2,  4,  7, -8,  8,
  0,  3, -4,  7,  5,  8,  4,  9,  0,  3,  3,  7, -5,  8, -1,  9,  0,  2,  1,
  6, -8,  9,  1,  2,  3,  8, -5,  9,  1,  2,  1,  6, -9,  9,  2,  3,  6,  7,
 -6,  8, -8,  9,  0,  3,  4,  7,-10,  8,  4,  9,  2,  2,  3,  7, -8,  9,  0,
  1,  1,  9,  7,  2,  3,  7,-10,  9,  0,  3,  4,  7,-10,  8,  2,  9,  2,  3,
  5,  7,-12,  8,  2,  9,  0,  2,  1,  6, -7,  9,  0,  1,  1,  8,  3,  2,  1,
  6,-10,  9,  0,  3,  6,  7,-12,  8,  2,  9,  0,  3,  5,  7,-10,  8,  2,  9,
  0,  2,  5,  7,-13,  9,  0,  2,  4,  7,-10,  9,  0,  2,  3,  7, -7,  9,  0,
  1,  2,  9,  7,  2,  3,  7,-11,  9,  0,  3,  4,  7, -9,  8,  4,  9,  2,  3,
  3,  7, -5,  8,  1,  9,  2,  2,  1,  6, -6,  9,  0,  2,  7,  8,-13,  9,  0,
  2,  3,  8, -2,  9,  1,  3,  1,  7, -5,  8,  2,  9,  1,  3,  6,  7,-12,  8,
  3,  9,  1,  2,  5,  7,-12,  9,  1,  2,  4,  7, -9,  9,  1,  2,  2,  7, -3,
  9,  1,  1,  1,  7,  0,  1,  3,  9,  5,  2,  3,  7,-12,  9,  1,  3,  5,  7,
 -9,  8,  2,  9,  0,  3,  4,  7, -7,  8,  2,  9,  1,  3,  3,  7, -5,  8,  2,
  9,  0,  3,  2,  7, -5,  8,  5,  9,  0,  2,  1,  6, -5,  9,  0,  2,  3,  8,
 -1,  9,  2,  2,  1,  6,-12,  9,  0,  3,  2,  7, -7,  8,  1,  9,  0,  2,  5,
  7,-11,  9,  0,  2,  4,  7, -8,  9,  0,  2,  2,  7, -2,  9,  0,  1,  4,  9,
  7,  3,  2,  7, -8,  8,  2,  9,  0,  3,  5,  7, -9,  8,  3,  9,  0,  3,  4,
  7, -9,  8,  6,  9,  0,  3,  3,  7, -5,  8,  3,  9,  1,  2,  2,  7, -1,  8,
  1,  2,  3,  8, -9,  9,  0,  2,  9,  8, -9,  9,  0,  2,  1,  6,-13,  9,  0,
  3,  2,  7, -5,  8, -3,  9,  0,  2,  6,  7,-13,  9,  1,  2,  5,  7,-10,  9,
  0,  2,  4,  7, -7,  9,  0,  2,  3,  7, -4,  9,  0,  1,  5,  9,  7,  3,  6,
  7, -9,  8,  1,  9,  1,  3,  4,  7, -5,  8,  1,  9,  1,  3,  3,  7, -3,  8,
  1,  9,  0,  2,  1,  6, -3,  9,  2,  2,  3,  8,-10,  9,  0,  2,  1,  8,  4,
  9,  0,  2,  5,  8, -2,  9,  0,  2, 11,  8,-11,  9,  0,  3,  1,  7, -9,  8,
  5,  9,  0,  2,  6,  7,-12,  9,  0,  2,  5,  7, -9,  9,  0,  2,  4,  7, -6,
  9,  0,  2,  3,  7, -3,  9,  0,  1,  6,  9,  6,  2,  2,  7,-12,  9,  0,  3,
  6,  7, -9,  8,  2,  9,  0,  3,  3,  7,-12,  8,  3,  9,  0,  3,  4,  7,-10,
  8, -3,  9,  1,  3,  3,  7, -3,  8,  2,  9,  0,  2,  1,  6, -2,  9,  2,  2,
  1,  8,  5,  9,  0,  2, 13,  8,-13,  9,  1,  3,  2,  7, -9,  8,  1,  9,  0,
  2,  6,  7,-11,  9,  0,  2,  5,  7, -8,  9,  0,  2,  4,  7, -5,  9,  0,  2,
  3,  7, -2,  9,  0,  1,  7,  9,  7,  3,  6,  7, -9,  8,  3,  9,  0,  2,  1,
  6, -1,  9,  4,  2,  3,  8,  3,  9,  0,  2,  7,  7,-13,  9,  1,  2,  3,  7,
 -1,  9,  0,  2,  2,  7,  2,  9,  0,  1,  8,  9,  6,  3,  7,  7, -9,  8,  1,
  9,  0,  1,  1,  6,  0,  1,  3,  7,  0,  2,  2,  7,  3,  9,  0,  1,  9,  9,
  5,  3,  1,  7,-10,  8,  3,  9,  0,  3,  2,  7,-12,  8,  3,  9,  1,  2,  1,
  6,  1,  9,  0,  3,  1,  7, -1,  8,  8,  9,  0,  2,  3,  7,  1,  9,  1,  2,
  2,  7,  4,  9,  0,  2,  1,  7,  7,  9,  0,  2,  4,  8,  4,  9,  1,  2, 12,
  8, -8,  9,  0,  3,  1,  7,-10,  8,  2,  9,  1,  2,  1,  6,  2,  9,  0,  1,
 11,  9,  2,  2, 12,  8, -7,  9,  0,  3,  1,  7,-10,  8,  1,  9,  1,  1,  4,
  7,  0,  1, 12,  9,  0,  2,  6,  8,  3,  9,  0,  3,  1,  7, -2,  8,-12,  9,
  0,  3,  7,  7, -7,  8,  2,  9,  1,  2,  2,  6, -4,  9,  1,  1, 13,  9,  0,
  2, 10,  8, -2,  9,  1,  2,  4,  7,  2,  9,  0,  2,  2,  6, -3,  9,  0,  2,
  2,  7,  8,  9,  1,  2,  8,  8,  2,  9,  0,  1,  5,  7,  1,  2,  4,  7,  3,
  9,  0,  2,  3,  7,  6,  9,  0,  2,  1,  5, -6,  9,  0,  3,  2,  7,  8,  8,
 -3,  9,  0,  3,  1,  7,  6,  8,  3,  9,  0,  2,  6,  8,  6,  9,  0,  3,  8,
  7, -7,  8,  2,  9,  0,  2,  9,  7,-11,  9,  0,  2,  5,  7,  1,  9,  1,  2,
  4,  7,  4,  9,  0,  2,  2,  6, -1,  9,  0,  3,  2,  6, -1,  7,  2,  9,  0,
  2,  2,  7, 10,  9,  0,  2,  1,  7, 13,  9,  0,  2,  8,  7, -7,  9,  0,  2,
  7,  7, -4,  9,  0,  2,  6,  7, -1,  9,  0,  2,  5,  7,  3,  9,  0,  2,  4,
  7,  5,  9,  0,  1,  2,  6,  0,  2,  1,  5, -4,  9,  1,  3,  1,  6,  9,  8,
 -5,  9,  0,  2,  1,  5, -3,  9,  4,  2,  1,  5, -2,  9,  4,  3,  9,  7, -9,
  8,  6,  9,  0,  2,  8,  7, -4,  9,  0,  2,  7,  7, -1,  9,  0,  2,  1,  6,
  3,  9,  0,  2,  2,  6,  3,  9,  0,  2,  1,  5, -1,  9,  3,  3,  6,  7, -3,
  8,  7,  9,  1,  1,  1,  5,  0,  2,  2,  6,  5,  9,  0,  2,  1,  5,  1,  9,
  0,  2,  1,  5,  2,  9,  0,  2,  1,  5,  3,  9,  0,  2,  2,  5, -4,  9,  0,
  2,  2,  5, -3,  9,  0,  2,  2,  5, -2,  9,  1,  2,  2,  5, -1,  9,  1,  1,
  2,  5,  0, -1);

mlatargs: array[0..3156] of shortint =
( 0,  1,  3,  1, 10,  1, 12, -1, 11,  1,  4,  2, 10,  2, 12, -1, 13, -1, 11,
  0,  5,  2, 10, -1, 13, -1, 11,  3,  2, -3,  3,  0,  5,  2, 10, -1, 13, -1,
 11,  2,  3, -2,  5,  0,  2, -1, 13,  1, 14,  1,  5, -1, 13,  1, 11,  4,  3,
 -8,  4,  3,  5,  0,  2,  1, 13, -1, 11,  0,  5,  1, 13, -1, 11,  4,  3, -8,
  4,  3,  5,  0,  5,  2, 10, -1, 13, -1, 11,  2,  3, -3,  5,  0,  4,  1, 10,
  1, 12, -2, 13,  1, 11,  0,  4,  1, 13, -1, 11,  1,  2, -1,  3,  0,  5,  2,
 10, -1, 13, -1, 11,  2,  2, -2,  3,  0,  3,  1, 10, -2, 13,  1, 11,  0,  4,
  1, 13, -1, 11,  1,  3, -1,  5,  0,  4, -1, 13,  1, 11,  1,  2, -1,  3,  0,
  3,  1, 12,  1, 13, -1, 11,  1,  4,  2, 10,  1, 12, -1, 13, -1, 11,  1,  2,
  1, 10, -1, 11,  0,  4, -1, 13,  1, 11,  1,  3, -1,  5,  0,  3,  1, 12, -1,
 13,  1, 11,  1,  3,  2, 10, -3, 13,  1, 11,  0,  3,  2, 12,  1, 13, -1, 11,
  0,  3, -2, 10,  1, 13,  1, 14,  0,  6, -2, 10,  1, 13,  1, 11,  4,  3, -8,
  4,  3,  5,  0,  3,  2, 10, -1, 13, -1, 11,  0,  6,  2, 10, -1, 13, -1, 11,
  4,  3, -8,  4,  3,  5,  0,  4, -1, 13,  1, 11,  2,  3, -2,  5,  0,  4, -1,
 13,  1, 11,  3,  2, -3,  3,  0,  3,  1, 10, -1, 12, -1, 11,  0,  3,  2, 12,
 -1, 13,  1, 11,  0,  3,  2, 10,  1, 13, -3, 11,  0,  5, -2, 10,  1, 13,  1,
 11,  1,  2, -1,  3,  0,  4,  2, 10, -1, 12, -3, 13,  1, 11,  0,  3,  3, 10,
 -2, 13, -1, 11,  0,  5, -2, 10,  1, 13,  1, 11,  1,  3, -1,  5,  0,  4,  2,
 10, -1, 12, -1, 13, -1, 11,  1,  2,  3, 10, -3, 11,  0,  5, -2, 10,  1, 13,
  1, 11,  2,  2, -2,  3,  0,  4,  2, 10, -1, 12,  1, 13, -3, 11,  0,  3,  4,
 10, -3, 13, -1, 11,  0,  4,  2, 10, -2, 12, -1, 13, -1, 11,  1,  3,  4, 10,
 -1, 13, -3, 11,  0,  4,  2, 10, -3, 12, -1, 13, -1, 11,  0,  3,  4, 10, -1,
 12, -3, 11,  0,  3,  2, 10, -3, 12, -1, 11,  0,  4,  4, 10, -1, 12, -2, 13,
 -1, 11,  0,  2,  4, 10, -3, 11,  0,  3,  2, 10, -2, 12, -1, 11,  1,  4,  3,
 10, -1, 12, -1, 13, -1, 11,  0,  4, -2, 10,  1, 11,  2,  3, -2,  5,  0,  3,
  4, 10, -2, 13, -1, 11,  0,  4, -2, 10,  1, 11,  2,  2, -2,  3,  0,  3,  2,
 10, -1, 12, -1, 11,  2,  3, -2, 10,  1, 12,  1, 14,  0,  4, -2, 10,  1, 11,
  2,  3, -2,  4,  0,  4, -2, 10,  1, 11,  1,  3, -1,  5,  0,  3,  3, 10, -1,
 13, -1, 11,  0,  4, -2, 10,  1, 11,  3,  2, -4,  3,  0,  4, -2, 10,  1, 11,
  1,  3, -2,  5,  0,  4,  2, 10, -1, 12, -2, 13,  1, 11,  0,  4, -2, 10,  1,
 11,  1,  2, -1,  3,  0,  2, -1, 10,  1,  2,  0,  3,  2, 10,  2, 13, -3, 11,
  0,  4, -2, 10,  1, 11,  2,  2, -3,  3,  0,  3,  2, 12, -2, 13,  1, 11,  0,
  4,  1, 10, -1, 12,  1, 13, -1, 11,  0,  3, -2, 10,  1, 11,  1,  5,  0,  4,
  2, 10, -1, 11,  1,  3, -2,  4,  0,  3,  2, 10, -2, 11,  1, 14,  0,  4, -2,
 10,  1, 11,  8,  2,-13,  3,  0,  5, -2, 10, -1, 13,  1, 11, 18,  2,-16,  3,
  0,  5,  2, 10, -1, 11,  4,  3, -8,  4,  3,  5,  1,  2,  2, 10, -1, 11,  1,
  5, -2, 10,  1, 11,  4,  3, -8,  4,  3,  5,  1,  5,  2, 10, -1, 13, -1, 11,
 18,  2,-16,  3,  0,  4,  2, 10, -1, 11,  8,  2,-13,  3,  0,  2, -2, 10,  1,
 14,  1,  4, -2, 10,  1, 11,  1,  3, -2,  4,  0,  3,  2, 10, -1, 11,  1,  5,
  0,  2,  2, 12, -1, 11,  0,  4,  3, 10,  1, 12, -1, 13, -1, 11,  0,  4,  2,
 10, -1, 11,  2,  2, -3,  3,  0,  3,  2, 10, -2, 13,  1, 11,  0,  4,  2, 10,
 -1, 11,  1,  2, -1,  3,  0,  3,  1, 10,  1,  2, -2,  3,  0,  3,  1, 12, -2,
 13,  1, 11,  1,  3,  1, 10,  1, 13, -1, 11,  0,  4,  2, 10, -1, 11,  1,  3,
 -1,  5,  0,  3,  2, 10,  1, 12, -1, 11,  2,  3, -2, 10, -1, 12,  1, 14,  0,
  2,  1, 12, -1, 11,  1,  3,  1, 10, -1, 13,  1, 11,  0,  4,  2, 10, -1, 11,
  2,  2, -2,  3,  0,  3,  1, 10,  2,  2, -3,  3,  0,  4,  2, 10,  1, 12, -2,
 13,  1, 11,  0,  3, -1, 10,  1,  2, -2,  3,  0,  3, -1, 11,  1,  2, -1,  3,
  0,  2,  2, 13, -1, 11,  0,  2, -2, 13,  1, 14,  0,  4,  2, 10, -1, 11,  2,
  3, -2,  5,  0,  4,  2, 10, -1, 11,  3,  2, -3,  3,  0,  4,  2, 10,  2, 12,
 -2, 13, -1, 11,  0,  3,  1, 10,  1,  3, -2,  5,  0,  4,  1, 10,  1, 12,  1,
 13, -1, 11,  0,  3,  1, 10,  3,  2, -4,  3,  0,  3,  1, 10,  1,  3, -1,  5,
  0,  3,  1, 10,  1,  3, -2,  6,  0,  3,  1, 10,  2,  3, -2,  4,  0,  4,  1,
 10,  1, 12, -1, 13, -1, 11,  0,  3,  2, 10,  2, 12, -1, 11,  2,  4,  1, 10,
  1,  3,  2,  5, -5,  6,  1,  1,  1, 14,  2,  3,  1, 10,  8,  2,-12,  3,  1,
  5, -2, 10,  1, 13, -1, 11, 20,  2,-21,  3,  0,  5,  2, 10, -2, 13,  1, 11,
  2,  3, -3,  5,  0,  3,  1, 10,  1,  3,  1,  6,  0,  4, -1, 13, -1, 11, 26,
  2,-29,  3,  0,  3, -1, 11,  8,  2,-13,  3,  0,  4, -1, 13, -1, 11, 18,  2,
-16,  3,  2,  4, -1, 13,  1, 11, 10,  2, -3,  3,  1,  1,  1, 11,  3,  4, -1,
 13, -1, 11, 10,  2, -3,  3,  1,  4, -1, 13,  1, 11, 18,  2,-16,  3,  2,  3,
  1, 11,  8,  2,-13,  3,  0,  2,  1, 10,  2,  4,  0,  4,  2, 10, -1, 11,  5,
  2, -6,  3,  1,  5,  2, 10, -2, 13, -1, 11,  2,  3, -3,  5,  0,  5, -2, 10,
  1, 13,  1, 11, 20,  2,-21,  3,  0,  3,  1, 10,  1,  3,  1,  5,  0,  2, -2,
 11,  1, 14,  0,  5,  2, 10, -2, 13,  1, 11,  2,  3, -2,  5,  0,  3,  1, 10,
  5,  2, -7,  3,  0,  4,  1, 10,  1, 12, -1, 13,  1, 11,  0,  3,  1, 10,  2,
  2, -2,  3,  0,  4,  2, 10,  2, 12, -2, 13,  1, 11,  0,  2,  2, 13, -3, 11,
  0,  4,  2, 10, -1, 11,  4,  2, -4,  3,  0,  3,  1, 10,  4,  2, -5,  3,  0,
  3,  1, 10, -3, 13,  1, 11,  0,  2,  1, 10,  1,  2,  0,  3,  1, 11,  1,  2,
 -1,  3,  0,  4,  2, 10, -1, 11,  3,  3, -3,  5,  0,  3,  1, 12,  2, 13, -1,
 11,  1,  4,  2, 10,  1, 12, -2, 13, -1, 11,  0,  3,  1, 10, -1, 13, -1, 11,
  0,  3,  1, 11,  1,  3, -1,  5,  0,  2,  1, 12,  1, 11,  2,  4,  2, 10, -1,
 11,  5,  2, -5,  3,  0,  3,  1, 10,  5,  2, -6,  3,  0,  3,  2, 10,  1, 12,
 -3, 11,  0,  3,  1, 10,  2,  2, -1,  3,  0,  3,  2, 10, -4, 13,  1, 11,  0,
  3, -2, 10,  2, 13,  1, 14,  0,  3,  2, 10, -2, 13, -1, 11,  0,  3,  1, 10,
  3,  2, -2,  3,  0,  4,  1, 10, -1, 12, -1, 13, -1, 11,  0,  2,  2, 12,  1,
 11,  0,  2,  2, 10, -3, 11,  0,  3,  1, 10,  4,  2, -3,  3,  0,  4,  2, 10,
 -1, 12, -2, 13, -1, 11,  1,  3,  2, 10, -1, 12, -3, 11,  0,  3,  4, 10, -4,
 13, -1, 11,  0,  4,  2, 10, -2, 12, -2, 13, -1, 11,  0,  4,  4, 10, -2, 12,
 -1, 13, -1, 11,  0,  3,  6, 10, -3, 13, -1, 11,  0,  4,  4, 10, -1, 12, -1,
 13, -1, 11,  1,  4,  2, 10, -3, 12, -1, 13,  1, 11,  0,  3,  5, 10, -2, 13,
 -1, 11,  0,  3,  4, 10,  1, 13, -3, 11,  0,  4,  2, 10, -2, 12,  1, 13, -1,
 11,  0,  3,  3, 10, -1, 12, -1, 11,  0,  3,  4, 10, -1, 13, -1, 11,  0,  4,
  2, 10, -2, 12, -1, 13,  1, 11,  1,  3,  4, 10, -3, 13,  1, 11,  0,  4,  2,
 10, -1, 12,  1, 13, -1, 11,  1,  5, -2, 10,  1, 13, -1, 11,  2,  2, -2,  3,
  0,  2,  3, 10, -1, 11,  0,  4,  4, 10,  1, 12, -1, 13, -1, 11,  0,  4,  2,
 10, -1, 12, -1, 13,  1, 11,  2,  5, -2, 10,  1, 13, -1, 11,  1,  3, -1,  5,
  0,  3,  3, 10, -2, 13,  1, 11,  0,  5, -2, 10,  1, 13, -1, 11,  1,  2, -1,
  3,  0,  3,  2, 10,  1, 13, -1, 11,  0,  3, -2, 10, -1, 13,  1, 14,  0,  3,
  2, 12, -1, 13, -1, 11,  1,  3,  3, 10,  1, 12, -1, 11,  0,  3,  1, 10, -1,
 12,  1, 11,  0,  4, -1, 13, -1, 11,  3,  2, -3,  3,  0,  4, -1, 13, -1, 11,
  2,  3, -2,  5,  0,  3,  2, 10, -1, 13,  1, 14,  0,  4, -2, 10, -1, 11, 18,
  2,-16,  3,  0,  6,  2, 10, -1, 13,  1, 11,  4,  3, -8,  4,  3,  5,  0,  3,
  2, 10, -1, 13,  1, 11,  0,  6, -2, 10,  1, 13, -1, 11,  4,  3, -8,  4,  3,
  5,  0,  5,  2, 10, -2, 13,  1, 11, 18,  2,-16,  3,  0,  4, -2, 10,  1, 13,
 -2, 11,  1, 14,  0,  3,  1, 12, -3, 13,  1, 11,  0,  3,  1, 10,  2, 13, -1,
 11,  0,  4,  2, 10,  1, 12,  1, 13, -1, 11,  1,  3,  1, 12, -1, 13, -1, 11,
  1,  4, -1, 13, -1, 11,  1,  3, -1,  5,  0,  2,  1, 10,  1, 11,  0,  4,  2,
 10,  1, 12, -1, 13,  1, 11,  1,  3,  1, 12,  1, 13, -3, 11,  0,  4, -1, 13,
 -1, 11,  1,  2, -1,  3,  0,  5,  2, 10, -1, 13,  1, 11,  2,  2, -2,  3,  0,
  2,  3, 13, -1, 11,  0,  4,  1, 10,  1, 12, -2, 13, -1, 11,  0,  4,  2, 10,
  2, 12,  1, 13, -1, 11,  0,  2,  1, 13,  1, 14,  1,  5,  2, 10, -1, 13,  1,
 11,  2,  3, -3,  5,  0,  4, -2, 13, -1, 11, 18,  2,-16,  3,  1,  5,  1, 13,
  1, 11,  4,  3, -8,  4,  3,  5,  0,  2,  1, 13,  1, 11,  0,  5, -1, 13, -1,
 11,  4,  3, -8,  4,  3,  5,  0,  3,  1, 11, 18,  2,-16,  3,  1,  3, -1, 13,
 -2, 11,  1, 14,  0,  5,  2, 10, -1, 13,  1, 11,  2,  3, -2,  5,  0,  5,  2,
 10, -1, 13,  1, 11,  3,  2, -3,  3,  0,  3,  1, 10,  1, 12,  1, 11,  1,  4,
  2, 10,  2, 12, -1, 13,  1, 11,  1,  2,  1, 13, -3, 11,  0,  4,  1, 13,  1,
 11,  1,  2, -1,  3,  0,  3,  1, 12,  3, 13, -1, 11,  0,  4,  2, 10,  1, 12,
 -3, 13, -1, 11,  0,  3,  1, 10, -2, 13, -1, 11,  0,  4,  1, 13,  1, 11,  1,
  3, -1,  5,  0,  3,  1, 12,  1, 13,  1, 11,  1,  2,  1, 10, -3, 11,  0,  3,
  1, 12, -1, 13,  3, 11,  0,  3,  2, 10, -3, 13, -1, 11,  0,  3,  2, 12,  1,
 13,  1, 11,  0,  3,  2, 10, -1, 13, -3, 11,  0,  4,  2, 10, -1, 12, -3, 13,
 -1, 11,  0,  4,  2, 10, -1, 12, -1, 13, -3, 11,  0,  4,  6, 10, -1, 12, -2,
 13, -1, 11,  0,  3,  4, 10, -2, 12, -1, 11,  0,  3,  6, 10, -2, 13, -1, 11,
  0,  4,  4, 10, -2, 12, -2, 13,  1, 11,  0,  3,  4, 10, -1, 12, -1, 11,  1,
  3,  2, 10, -3, 12,  1, 11,  0,  3,  5, 10, -1, 13, -1, 11,  0,  4,  4, 10,
 -1, 12, -2, 13,  1, 11,  0,  4,  2, 10, -2, 12,  2, 13, -1, 11,  0,  2,  4,
 10, -1, 11,  0,  3,  2, 10, -2, 12,  1, 11,  1,  4,  3, 10, -1, 12, -1, 13,
  1, 11,  0,  3,  4, 10, -2, 13,  1, 11,  0,  4,  2, 10, -1, 12,  2, 13, -1,
 11,  0,  4, -2, 10, -1, 11,  2,  2, -2,  3,  0,  3,  3, 10,  1, 13, -1, 11,
  0,  3,  4, 10,  1, 12, -1, 11,  0,  3,  2, 10, -1, 12,  1, 11,  2,  4, -2,
 10, -1, 11,  1,  3, -1,  5,  0,  3,  3, 10, -1, 13,  1, 11,  0,  4,  4, 10,
  1, 12, -2, 13,  1, 11,  0,  3,  2, 10,  2, 13, -1, 11,  0,  3,  2, 12, -2,
 13, -1, 11,  0,  4,  1, 10, -1, 12,  1, 13,  1, 11,  0,  2,  2, 10,  1, 14,
  0,  5, -2, 10, -1, 13, -1, 11, 18,  2,-16,  3,  0,  2,  2, 10,  1, 11,  1,
  5,  2, 10, -1, 13,  1, 11, 18,  2,-16,  3,  0,  3, -2, 10, -2, 11,  1, 14,
  0,  4,  3, 10,  1, 12, -1, 13,  1, 11,  0,  3,  2, 10, -2, 13,  3, 11,  0,
  4,  2, 10,  1, 12,  2, 13, -1, 11,  0,  3,  1, 12, -2, 13, -1, 11,  1,  3,
  1, 10,  1, 13,  1, 11,  0,  3,  2, 10,  1, 12,  1, 11,  1,  2,  4, 13, -1,
 11,  0,  2,  2, 13,  1, 14,  0,  4, -3, 13, -1, 11, 18,  2,-16,  3,  0,  2,
  2, 13,  1, 11,  0,  4,  1, 13,  1, 11, 18,  2,-16,  3,  0,  4,  2, 10,  1,
 11,  2,  3, -2,  5,  0,  4,  1, 10,  1, 12,  1, 13,  1, 11,  0,  3,  2, 10,
  2, 12,  1, 11,  0,  2,  2, 11,  1, 14,  0,  1,  3, 11,  0,  3,  1, 10, -3,
 13, -1, 11,  0,  3,  1, 12,  2, 13,  1, 11,  1,  2,  1, 12,  3, 11,  0,  3,
  2, 10, -4, 13, -1, 11,  0,  3,  2, 12,  2, 13,  1, 11,  0,  3,  2, 10, -2,
 13, -3, 11,  0,  4,  6, 10, -1, 12, -1, 13, -1, 11,  0,  3,  6, 10, -1, 13,
 -1, 11,  0,  4,  4, 10, -2, 12, -1, 13,  1, 11,  0,  3,  6, 10, -3, 13,  1,
 11,  0,  4,  4, 10, -1, 12,  1, 13, -1, 11,  0,  4,  4, 10, -1, 12, -1, 13,
  1, 11,  1,  3,  5, 10, -2, 13,  1, 11,  0,  3,  4, 10,  1, 13, -1, 11,  0,
  4,  2, 10, -2, 12,  1, 13,  1, 11,  0,  3,  4, 10, -1, 13,  1, 11,  0,  4,
  2, 10, -1, 12,  3, 13, -1, 11,  0,  4,  4, 10,  1, 12,  1, 13, -1, 11,  0,
  4,  2, 10, -1, 12,  1, 13,  1, 11,  1,  2,  3, 10,  1, 11,  0,  4,  4, 10,
  1, 12, -1, 13,  1, 11,  0,  4,  2, 10, -1, 12, -1, 13,  3, 11,  0,  3,  2,
 10,  3, 13, -1, 11,  0,  3,  2, 10,  1, 13,  1, 14,  0,  3,  2, 10,  1, 13,
  1, 11,  0,  3,  3, 10,  1, 12,  1, 11,  0,  3,  2, 10, -1, 13,  3, 11,  0,
  4,  2, 10,  1, 12,  3, 13, -1, 11,  0,  3,  1, 12, -3, 13, -1, 11,  0,  3,
  1, 10,  2, 13,  1, 11,  0,  4,  2, 10,  1, 12,  1, 13,  1, 11,  1,  3,  1,
 12, -1, 13, -3, 11,  0,  2,  1, 10,  3, 11,  0,  2,  5, 13, -1, 11,  0,  2,
  3, 13,  1, 11,  0,  4,  1, 10,  1, 12,  2, 13,  1, 11,  0,  2,  1, 13,  3,
 11,  0,  3,  1, 12,  3, 13,  1, 11,  0,  3,  1, 12,  1, 13,  3, 11,  0,  3,
  2, 10, -5, 13, -1, 11,  0,  3,  6, 10, -1, 12, -1, 11,  0,  4,  6, 10, -1,
 12, -2, 13,  1, 11,  0,  2,  6, 10, -1, 11,  0,  3,  4, 10, -2, 12,  1, 11,
  0,  3,  6, 10, -2, 13,  1, 11,  0,  4,  4, 10, -1, 12,  2, 13, -1, 11,  0,
  3,  4, 10, -1, 12,  1, 11,  0,  3,  4, 10,  2, 13, -1, 11,  0,  4,  2, 10,
 -2, 12,  2, 13,  1, 11,  0,  2,  4, 10,  1, 11,  0,  3,  4, 10, -2, 13,  3,
 11,  0,  4,  2, 10, -1, 12,  2, 13,  1, 11,  0,  3,  3, 10,  1, 13,  1, 11,
  0,  3,  4, 10,  1, 12,  1, 11,  0,  3,  2, 10, -1, 12,  3, 11,  0,  3,  2,
 10,  4, 13, -1, 11,  0,  3,  2, 10,  2, 13,  1, 11,  0,  2,  2, 10,  3, 11,
  0,  3,  1, 12, -4, 13, -1, 11,  0,  3,  1, 10,  3, 13,  1, 11,  0,  4,  2,
 10,  1, 12,  2, 13,  1, 11,  0,  2,  4, 13,  1, 11,  0,  2,  2, 13,  3, 11,
  0,  1,  5, 11,  0,  3,  1, 12,  4, 13,  1, 11,  0,  4,  6, 10, -1, 12, -1,
 13,  1, 11,  0,  3,  6, 10,  1, 13, -1, 11,  0,  3,  6, 10, -1, 13,  1, 11,
  0,  4,  4, 10, -1, 12,  1, 13,  1, 11,  0,  3,  4, 10,  1, 13,  1, 11,  0,
  3,  4, 10, -1, 13,  3, 11,  0,  4,  2, 10, -1, 12,  3, 13,  1, 11,  0,  4,
  4, 10,  1, 12,  1, 13,  1, 11,  0,  3,  2, 10,  3, 13,  1, 11,  0,  3,  2,
 10,  1, 13,  3, 11,  0,  2,  5, 13,  1, 11,  0,  2,  3, 13,  3, 11,  0,  2,
  6, 10,  1, 11,  0,  3,  4, 10,  2, 13,  1, 11,  0,  3,  2, 10,  4, 13,  1,
 11,  0, -1);

mlrargs: array[0..5018] of shortint =
( 0,  3,  3,  4,  3, -8,  4,  3,  5,  1,  2,  2,  5, -5,  6,  2,  5, -1, 10,
  2, 13, -1, 11,  3,  3, -7,  4,  0,  3,  1, 13, -1, 11,  2,  5,  1,  2,  4,
  5,-10,  6,  0,  4,  2, 10, -2, 13, 14,  3,-23,  4,  1,  3,  3,  2, -7,  3,
  4,  4,  1,  3, -1, 13, 18,  2,-16,  3,  2,  2,  8,  2,-13,  3,  1,  5,  2,
 10, -2, 13,  2,  3, -3,  5,  1,  6,  0,  3, -1, 13, 26,  2,-29,  3,  0,  3,
  1, 10, -1, 11,  2,  4,  1,  4,  1, 10, -1, 13,  3,  2, -4,  3,  1,  4,  1,
 10, -1, 13,  3,  3, -4,  4,  0,  3, -1, 10, 15,  2,-12,  3,  0,  4,  2, 10,
 -3, 13, 24,  2,-24,  3,  0,  3, -1, 10, 23,  2,-25,  3,  0,  4,  1, 10, -1,
 11,  1,  3,  1,  6,  0,  4,  2, 10, -2, 11,  5,  2, -6,  3,  0,  4,  2, 10,
 -2, 13,  6,  2, -8,  3,  0,  4, -2, 10,  1, 13, 12,  2, -8,  3,  1,  5, -1,
 10,  1, 13, -1, 11, 20,  2,-20,  3,  1,  4, -2, 10,  1, 13,  3,  1, -1,  3,
  1,  5,  2, 10, -2, 13,  2,  3, -5,  5,  5,  6,  0,  4,  2, 10, -2, 13,  2,
  3, -3,  5,  1,  4,  2, 10, -2, 13,  6,  3, -8,  4,  0,  4, -2, 10,  1, 13,
 20,  2,-21,  3,  1,  4,  1, 10, -1, 11,  1,  3,  1,  5,  0,  1,  1,  6,  0,
  4,  2, 10, -2, 13,  5,  3, -6,  4,  0,  3,  3,  2, -5,  3,  2,  5,  0,  2,
 -1, 11,  1, 14,  1,  4,  2, 10, -2, 13,  2,  3, -2,  5,  0,  2,  1,  3, -2,
  4,  1,  4,  1, 10, -1, 11,  5,  2, -7,  3,  0,  1,  1,  5,  0,  2,  7,  3,
-13,  4,  0,  4, -2, 10,  1, 13, 15,  2,-13,  3,  0,  4,  2, 10, -2, 13,  3,
  2, -3,  3,  0,  2, -2, 11,  2, 14,  1,  3,  1, 10,  1, 12, -1, 13,  1,  3,
 -1, 13, 21,  2,-21,  3,  0,  2,  3,  2, -5,  3,  0,  2,  2,  3, -4,  4,  1,
  2,  5,  2, -8,  3,  0,  3, -1, 13, 23,  2,-24,  3,  0,  2,  6,  3,-11,  4,
  0,  1,  2,  5,  0,  2,  3,  3, -6,  4,  0,  2,  5,  3, -9,  4,  0,  4,  1,
 10, -1, 11,  1,  3, -2,  5,  0,  3,  2, 10,  2, 12, -2, 13,  1,  2,  2,  2,
 -3,  3,  2,  2,  4,  3, -7,  4,  0,  2,  2, 13, -2, 11,  0,  2,  3,  3, -5,
  4,  0,  2,  1,  2, -2,  3,  0,  2,  2,  3, -3,  4,  0,  4,  1, 10, -1, 11,
  4,  2, -5,  3,  0,  2,  1,  3, -1,  4,  0,  2,  4,  2, -6,  3,  0,  4,  2,
 10, -2, 13,  2,  2, -2,  3,  0,  3,  1, 10, -1, 11,  1,  2,  0,  2,  1,  2,
 -1,  3,  0,  3,  1, 12,  2, 13, -2, 11,  0,  2,  5,  3, -8,  4,  0,  2,  1,
  3, -3,  5,  0,  3,  2, 10,  1, 12, -2, 13,  1,  2,  4,  3, -6,  4,  0,  2,
  1,  3, -2,  5,  1,  2,  3,  3, -4,  4,  0,  2,  3,  2, -4,  3,  1,  2,  1,
 10, -1, 13,  0,  2,  1,  3, -1,  5,  0,  2,  1,  3, -2,  6,  0,  2,  2,  3,
 -2,  4,  0,  2,  1,  3, -1,  6,  0,  2,  8,  2,-14,  3,  0,  3,  1,  3,  2,
  5, -5,  6,  1,  3,  5,  3, -8,  4,  3,  5,  1,  1,  1, 12,  3,  3,  3,  3,
 -8,  4,  3,  5,  1,  3,  1,  3, -2,  5,  5,  6,  0,  2,  8,  2,-12,  3,  0,
  2,  1,  3,  1,  5,  0,  3,  2, 10,  1, 12, -2, 11,  1,  2,  5,  2, -7,  3,
  0,  3,  1, 10,  1, 13, -2, 11,  0,  2,  2,  2, -2,  3,  0,  2,  5,  3, -7,
  4,  0,  3,  1, 12, -2, 13,  2, 11,  0,  2,  4,  3, -5,  4,  0,  2,  3,  3,
 -3,  4,  0,  1,  1,  2,  0,  3,  3, 10,  1, 12, -3, 13,  0,  2,  2,  3, -4,
  5,  0,  2,  2,  3, -3,  5,  0,  2,  2, 10, -2, 13,  0,  2,  2,  3, -2,  5,
  0,  2,  3,  2, -3,  3,  0,  3,  1, 10, -1, 12, -1, 13,  1,  2,  2,  3, -1,
  5,  0,  2,  2,  3, -2,  6,  0,  1,  2, 12,  2,  3, -2, 10,  1, 11,  1, 14,
  0,  2,  2, 10, -2, 11,  0,  2,  2,  2, -1,  3,  0,  4, -2, 10,  2, 13,  1,
  2, -1,  3,  0,  2,  4,  2, -4,  3,  0,  2,  3, 10, -3, 13,  0,  4, -2, 10,
  2, 13,  1,  3, -1,  5,  0,  2,  3,  3, -3,  5,  0,  3,  2, 10, -1, 12, -2,
 13,  2,  3,  3, 10, -1, 13, -2, 11,  0,  1,  3, 12,  1,  4, -2, 10,  2, 13,
  2,  2, -2,  3,  0,  3,  2, 10, -1, 12, -2, 11,  1,  2,  5,  2, -5,  3,  0,
  2,  4, 10, -4, 13,  0,  2,  6,  2, -6,  3,  0,  3,  2, 10, -2, 12, -2, 13,
  1,  3,  4, 10, -2, 13, -2, 11,  0,  3,  2, 10, -2, 12, -2, 11,  0,  2,  7,
  2, -7,  3,  0,  3,  2, 10, -3, 12, -2, 13,  0,  2,  8,  2, -8,  3,  0,  2,
  9,  2, -9,  3,  0,  2, 10,  2,-10,  3,  0,  3,  2, 10, -4, 12, -1, 13,  0,
  3,  4, 10, -2, 12, -3, 13,  0,  4,  4, 10, -1, 12, -1, 13, -2, 11,  0,  3,
  2, 10, -3, 12, -1, 13,  1,  4, -2, 10,  1, 13,  3,  3, -2,  5,  0,  3,  4,
 10, -1, 12, -3, 13,  0,  4, -2, 10,  1, 13,  3,  3, -3,  5,  0,  4,  2, 10,
 -2, 12,  1, 13, -2, 11,  0,  4, -2, 10,  1, 13,  2,  2, -1,  3,  0,  3,  3,
 10, -1, 12, -2, 11,  0,  3,  4, 10, -1, 13, -2, 11,  0,  3,  2, 10, -2, 12,
 -1, 13,  2,  4, -2, 10,  1, 13,  2,  3, -1,  5,  0,  3,  3, 10, -1, 12, -2,
 13,  0,  4, -2, 10,  1, 13,  3,  2, -3,  3,  0,  4, -2, 10,  1, 13,  2,  3,
 -2,  5,  0,  2,  4, 10, -3, 13,  0,  4, -2, 10,  1, 13,  2,  3, -3,  5,  0,
  3, -2, 10,  1, 13,  1,  2,  0,  4,  2, 10, -1, 12,  1, 13, -2, 11,  1,  4,
 -2, 10,  1, 13,  2,  2, -2,  3,  0,  2,  3, 12, -1, 13,  0,  2,  3, 10, -2,
 11,  0,  2,  1, 10, -2, 12,  0,  4,  4, 10,  1, 12, -1, 13, -2, 11,  0,  3,
 -1, 13,  3,  2, -2,  3,  0,  3, -1, 13,  3,  3, -2,  5,  0,  3, -2, 10, 18,
  2,-15,  3,  0,  5,  2, 10, -1, 13,  3,  3, -8,  4,  3,  5,  0,  3,  2, 10,
 -1, 12, -1, 13,  2,  5, -2, 10,  1, 13,  5,  3, -8,  4,  3,  5,  0,  5, -2,
 10,  1, 13,  1,  3,  2,  5, -5,  6,  0,  4,  2, 10, -2, 13, 18,  2,-17,  3,
  0,  4, -2, 10,  1, 13,  1,  3, -1,  6,  0,  4, -2, 10,  1, 13,  2,  3, -2,
  4,  0,  4, -2, 10,  1, 13,  1,  3, -1,  5,  0,  2,  3, 10, -2, 13,  0,  4,
 -2, 10,  1, 13,  3,  2, -4,  3,  0,  4, -2, 10,  1, 13,  3,  3, -4,  4,  0,
  4, -2, 10,  1, 13,  1,  3, -2,  5,  0,  3,  4, 10,  1, 12, -3, 13,  0,  4,
 -2, 10,  1, 13,  1,  3, -3,  5,  0,  3, -1, 13,  4,  2, -4,  3,  0,  4, -2,
 10,  1, 13,  1,  2, -1,  3,  0,  4, -2, 10,  1, 13,  1,  3, -1,  4,  0,  4,
 -2, 10,  1, 13,  2,  3, -3,  4,  0,  4, -2, 10,  1, 13,  3,  3, -5,  4,  0,
  3,  2, 10,  1, 13, -2, 11,  0,  4, -2, 10, -1, 13,  1, 11,  1, 14,  0,  4,
 -2, 10,  1, 13,  2,  2, -3,  3,  1,  2,  2, 12, -1, 13,  1,  3,  3, 10,  1,
 12, -2, 11,  0,  4,  2, 10, -1, 13,  2,  3, -4,  4,  0,  4,  2, 10, -1, 13,
  3,  2, -5,  3,  0,  2,  1, 10, -1, 12,  1,  3, -1, 13,  3,  2, -3,  3,  0,
  3, -2, 10,  1, 13,  1,  5,  0,  4,  2, 10, -1, 13,  1,  3, -2,  4,  0,  3,
 -1, 13,  2,  3, -2,  5,  0,  4,  2, 10, -1, 13, -1, 11,  1, 14,  0,  3, -1,
 13,  5,  3, -6,  4,  0,  3, -2, 10,  1, 13,  1,  6,  0,  3, -1, 10,  1,  3,
 -1,  5,  0,  4, -2, 10,  1, 13,  8,  2,-13,  3,  1,  3, -2, 10, 18,  2,-16,
  3,  1,  5, -2, 10,  1, 13,  3,  2, -7,  3,  4,  4,  1,  4,  2, 10, -1, 13,
  2,  5, -5,  6,  1,  5,  2, 10, -1, 13,  4,  3, -8,  4,  3,  5,  1,  2,  2,
 10, -1, 13,  2,  5, -2, 10,  1, 13,  4,  3, -8,  4,  3,  5,  1,  4, -2, 10,
  1, 13,  2,  5, -5,  6,  1,  5,  2, 10, -1, 13,  3,  2, -7,  3,  4,  4,  0,
  4,  2, 10, -2, 13, 18,  2,-16,  3,  1,  4,  2, 10, -1, 13,  8,  2,-13,  3,
  1,  3, -1, 10,  3,  2, -4,  3,  0,  3, -1, 13,  6,  2, -8,  3,  0,  3, -1,
 13,  2,  3, -3,  5,  0,  3, -1, 13,  6,  3, -8,  4,  0,  3,  2, 10, -1, 13,
  1,  6,  0,  4, -2, 10,  1, 13, -1, 11,  1, 14,  0,  4, -2, 10,  1, 13,  1,
  3, -2,  4,  0,  3,  2, 10, -1, 13,  1,  5,  0,  3,  3, 10,  1, 12, -2, 13,
  0,  4, -2, 10,  1, 13,  3,  2, -5,  3,  0,  4, -2, 10,  1, 13,  2,  3, -4,
  4,  0,  2, -1, 13,  1,  2,  0,  4,  2, 10, -1, 13,  2,  2, -3,  3,  0,  3,
 -1, 10,  1,  2, -1,  3,  0,  3, -1, 13,  4,  2, -5,  3,  0,  3,  2, 10, -3,
 13,  2, 11,  0,  4,  2, 10, -1, 13,  2,  3, -3,  4,  0,  3, -1, 13,  2,  2,
 -2,  3,  0,  4,  2, 10, -1, 13,  1,  2, -1,  3,  0,  4,  2, 10,  1, 12,  1,
 13, -2, 11,  0,  3, -2, 13, 18,  2,-15,  3,  0,  2,  1, 12, -1, 13,  2,  3,
 -1, 13,  1,  3, -1,  6,  0,  4,  2, 10, -1, 13,  1,  3, -2,  5,  0,  3, -1,
 13,  2,  3, -2,  4,  0,  3, -1, 13,  1,  3, -1,  5,  0,  4,  2, 10, -1, 13,
  3,  3, -4,  4,  0,  1,  1, 10,  0,  3, -1, 13,  3,  2, -4,  3,  0,  3, -1,
 13,  3,  3, -4,  4,  0,  4,  2, 10, -1, 13,  1,  3, -1,  5,  0,  4,  2, 10,
 -1, 13,  2,  3, -2,  4,  0,  3, -1, 13,  1,  3, -2,  5,  0,  3,  2, 10,  1,
 12, -1, 13,  2,  3,  1, 12,  1, 13, -2, 11,  0,  3, -1, 13,  1,  2, -1,  3,
  0,  4,  2, 10, -1, 13,  2,  2, -2,  3,  0,  3, -1, 13,  4,  2, -6,  3,  0,
  3, -1, 13,  2,  3, -3,  4,  0,  3,  1, 13,  1,  2, -2,  3,  0,  4,  2, 10,
 -1, 13,  3,  3, -3,  4,  0,  2,  3, 13, -2, 11,  0,  4,  2, 10, -1, 13,  4,
  2, -5,  3,  0,  3,  1, 10,  1,  2, -1,  3,  0,  3, -1, 13,  2,  2, -3,  3,
  1,  3,  2, 10,  2, 12, -3, 13,  0,  3,  2, 10, -1, 13,  1,  2,  0,  3,  1,
 13,  2,  3, -4,  4,  0,  3,  1, 13,  3,  2, -5,  3,  0,  2, 21,  2,-21,  3,
  0,  3,  1, 10,  1, 12, -2, 13,  1,  4,  2, 10, -1, 13,  2,  3, -4,  5,  0,
  4,  2, 10, -1, 13,  7,  3,-10,  4,  0,  2, -1, 13,  1,  5,  0,  3,  1, 13,
  1,  3, -2,  4,  0,  4,  2, 10, -3, 13,  2,  3, -2,  5,  0,  3,  1, 10,  1,
  3, -2,  5,  0,  3,  1, 13, -1, 11,  1, 14,  1,  2, -1, 13,  1,  6,  0,  4,
  2, 10, -1, 13,  6,  3, -8,  4,  1,  4,  2, 10, -1, 13,  2,  3, -3,  5,  1,
  3, -1, 13,  8,  3,-15,  4,  0,  4,  2, 10, -1, 13,  6,  2, -8,  3,  0,  5,
  2, 10, -1, 13, -2, 11,  5,  2, -6,  3,  0,  3,  1, 10,  3,  3, -4,  4,  0,
  3,  1, 10,  3,  2, -4,  3,  1,  4,  1, 10, -1, 13, -1, 11,  2,  4,  0,  3,
 -2, 13, 26,  2,-29,  3,  0,  3, -1, 13,  8,  2,-13,  3,  0,  3, -2, 13, 18,
  2,-16,  3,  2,  4, -1, 13,  3,  2, -7,  3,  4,  4,  0,  3,  1, 13,  2,  5,
 -5,  6,  1,  4,  1, 13,  4,  3, -8,  4,  3,  5,  1,  1,  1, 13,  3,  4, -1,
 13,  4,  3, -8,  4,  3,  5,  1,  3, -1, 13,  2,  5, -5,  6,  1,  4,  1, 13,
  3,  2, -7,  3,  4,  4,  0,  2, 18,  2,-16,  3,  1,  3,  1, 13,  8,  2,-13,
  3,  2,  2, 26,  2,-29,  3,  0,  4,  1, 10,  1, 13, -1, 11,  2,  4,  0,  5,
  2, 10,  1, 13, -2, 11,  5,  2, -6,  3,  0,  3,  1, 13,  8,  3,-15,  4,  1,
  4,  2, 10, -3, 13,  2,  3, -3,  5,  0,  3,  1, 10,  1,  3, -1,  5,  0,  2,
  1, 13,  1,  6,  0,  4,  2, 10, -1, 13,  5,  3, -6,  4,  0,  3,  1, 10,  2,
  3, -2,  4,  0,  3, -1, 13, -1, 11,  1, 14,  1,  4,  2, 10, -1, 13,  2,  3,
 -5,  6,  0,  4,  2, 10, -1, 13,  2,  3, -2,  5,  0,  5,  2, 10, -1, 13,  2,
  3, -4,  5,  5,  6,  0,  3, -1, 13,  1,  3, -2,  4,  1,  2,  1, 13,  1,  5,
  0,  4,  2, 10, -1, 13,  4,  3, -4,  4,  0,  4,  2, 10, -1, 13,  3,  2, -3,
  3,  0,  4,  2, 10,  2, 12, -1, 13, -2, 11,  0,  2,  1, 10,  1, 12,  2,  3,
 -1, 13,  3,  2, -5,  3,  0,  3, -1, 13,  2,  3, -4,  4,  0,  4,  2, 10, -1,
 13,  2,  3, -1,  5,  0,  4,  2, 10, -1, 13,  2,  3, -2,  6,  0,  3,  1, 10,
  1, 12, -2, 11,  0,  3,  2, 10,  2, 12, -1, 13,  1,  3,  1, 13,  2,  2, -3,
  3,  1,  3, -1, 13,  1, 11,  1, 14,  0,  2,  1, 13, -2, 11,  0,  4,  2, 10,
 -1, 13,  5,  2, -6,  3,  0,  3, -1, 13,  1,  2, -2,  3,  0,  3,  1, 13,  2,
  3, -3,  4,  0,  3,  1, 13,  1,  2, -1,  3,  0,  4,  2, 10, -1, 13,  4,  2,
 -4,  3,  0,  3,  2, 10,  1, 12, -3, 13,  1,  3,  1, 13,  1,  3, -2,  5,  0,
  3,  1, 13,  3,  3, -4,  4,  0,  3,  1, 13,  3,  2, -4,  3,  0,  2,  1, 10,
 -2, 13,  0,  4,  2, 10, -1, 13,  3,  3, -4,  5,  0,  3,  1, 13,  1,  3, -1,
  5,  0,  3,  1, 13,  2,  3, -2,  4,  0,  3,  1, 13,  1,  3, -1,  6,  0,  4,
  2, 10, -1, 13,  3,  3, -3,  5,  0,  4,  2, 10, -1, 13,  6,  2, -7,  3,  0,
  2,  1, 12,  1, 13,  2,  4,  2, 10, -1, 13,  3,  3, -2,  5,  0,  4,  2, 10,
  1, 12, -1, 13, -2, 11,  0,  2,  1, 10,  2, 12,  0,  2,  1, 10, -2, 11,  0,
  3,  1, 13,  2,  2, -2,  3,  0,  3,  1, 12, -1, 13,  2, 11,  0,  4,  2, 10,
 -1, 13,  5,  2, -5,  3,  0,  3,  1, 13,  2,  3, -3,  5,  0,  2,  2, 10, -3,
 13,  0,  3,  1, 13,  2,  3, -2,  5,  0,  3,  1, 13,  3,  2, -3,  3,  0,  3,
  1, 10, -1, 12, -2, 13,  0,  4,  2, 10, -1, 13,  6,  2, -6,  3,  0,  2,  2,
 12,  1, 13,  1,  3,  2, 10, -1, 13, -2, 11,  0,  3,  1, 10, -1, 12, -2, 11,
  0,  3,  2, 10,  1, 13, -4, 11,  0,  3,  1, 13,  4,  2, -4,  3,  0,  4,  2,
 10, -1, 13,  7,  2, -7,  3,  0,  3,  2, 10, -1, 12, -3, 13,  1,  2,  3, 12,
  1, 13,  0,  4,  2, 10, -1, 12, -1, 13, -2, 11,  0,  3,  1, 13,  5,  2, -5,
  3,  0,  4,  2, 10, -1, 13,  8,  2, -8,  3,  0,  3,  2, 10, -2, 12, -3, 13,
  0,  4,  2, 10, -1, 13,  9,  2, -9,  3,  0,  3,  4, 10, -3, 12, -2, 13,  0,
  2,  2, 10, -4, 12,  0,  3,  4, 10, -2, 12, -2, 13,  1,  2,  6, 10, -4, 13,
  0,  3,  4, 10, -1, 12, -2, 11,  0,  2,  2, 10, -3, 12,  1,  3,  3, 10, -2,
 12, -1, 13,  0,  3, -2, 10,  3,  3, -2,  5,  0,  3,  4, 10, -1, 12, -2, 13,
  1,  3, -2, 10,  3,  3, -3,  5,  0,  2,  5, 10, -3, 13,  0,  3, -2, 10,  4,
  2, -4,  3,  0,  3, -2, 10,  2,  2, -1,  3,  0,  2,  4, 10, -2, 11,  0,  2,
  2, 10, -2, 12,  2,  3, -2, 10,  3,  3, -2,  4,  0,  3, -2, 10,  2,  3, -1,
  5,  0,  3,  3, 10, -1, 12, -1, 13,  1,  3, -2, 10,  3,  2, -3,  3,  0,  3,
 -2, 10,  2,  3, -2,  5,  0,  2,  4, 10, -2, 13,  0,  3, -2, 10,  2,  3, -3,
  5,  0,  2, -2, 10,  1,  2,  0,  4,  2, 10, -1, 12,  2, 13, -2, 11,  0,  3,
 -2, 10,  2,  2, -2,  3,  0,  3,  3, 10,  1, 13, -2, 11,  0,  3,  4, 10,  1,
 12, -2, 11,  0,  4,  2, 10, -1, 12, -1, 11,  1, 14,  0,  4, -2, 10, -1, 13,
 18,  2,-15,  3,  0,  4,  2, 10,  3,  3, -8,  4,  3,  5,  0,  2,  2, 10, -1,
 12,  2,  4, -2, 10,  5,  3, -8,  4,  3,  5,  0,  4,  2, 10, -1, 13, 18,  2,
-17,  3,  0,  3, -2, 10,  1,  3, -1,  6,  0,  3, -2, 10,  2,  3, -2,  4,  0,
  3, -2, 10,  1,  3, -1,  5,  0,  2,  3, 10, -1, 13,  0,  3, -2, 10,  3,  2,
 -4,  3,  0,  3, -2, 10,  3,  3, -4,  4,  0,  3, -2, 10,  1,  3, -2,  5,  0,
  3,  4, 10,  1, 12, -2, 13,  1,  4,  2, 10, -1, 12, -2, 13,  2, 11,  0,  3,
 -2, 10,  1,  2, -1,  3,  0,  3, -2, 10,  2,  3, -3,  4,  0,  3,  2, 10,  2,
 13, -2, 11,  0,  3, -2, 10,  2,  2, -3,  3,  0,  2,  2, 12, -2, 13,  1,  3,
  2, 10,  2,  3, -4,  4,  0,  3,  2, 10,  3,  2, -5,  3,  0,  3,  1, 10, -1,
 12,  1, 13,  1,  3, -2, 13,  3,  2, -3,  3,  0,  2, -2, 10,  1,  5,  0,  3,
  2, 10,  1,  3, -2,  4,  0,  3, -2, 13,  2,  3, -2,  5,  0,  3,  2, 10, -1,
 11,  1, 14,  0,  4,  4, 10, -2, 13,  2,  3, -3,  5,  0,  3, -2, 10,  8,  2,
-13,  3,  0,  4, -2, 10, -1, 13, 18,  2,-16,  3,  1,  4, -2, 10,  3,  2, -7,
  3,  4,  4,  0,  4,  2, 10,  4,  3, -8,  4,  3,  5,  1,  1,  2, 10,  3,  4,
 -2, 10,  4,  3, -8,  4,  3,  5,  1,  4,  2, 10,  3,  2, -7,  3,  4,  4,  0,
  4,  2, 10, -1, 13, 18,  2,-16,  3,  1,  3,  2, 10,  8,  2,-13,  3,  0,  3,
 -2, 10, -1, 11,  1, 14,  0,  4,  4, 10, -2, 13,  2,  3, -2,  5,  0,  3, -2,
 10,  1,  3, -2,  4,  0,  2,  2, 10,  1,  5,  0,  4,  4, 10, -2, 13,  3,  2,
 -3,  3,  0,  3,  3, 10,  1, 12, -1, 13,  1,  3, -2, 10,  3,  2, -5,  3,  0,
  3, -2, 10,  2,  3, -4,  4,  0,  3,  4, 10,  2, 12, -2, 13,  0,  3,  2, 10,
  2,  2, -3,  3,  0,  3,  2, 10, -2, 13,  2, 11,  0,  3,  2, 10,  1,  2, -1,
  3,  0,  4,  2, 10,  1, 12,  2, 13, -2, 11,  0,  2,  1, 12, -2, 13,  2,  3,
  2, 10,  1,  3, -2,  5,  0,  3, -2, 13,  1,  3, -1,  5,  0,  3,  2, 10,  3,
  2, -4,  3,  0,  2,  1, 10,  1, 13,  0,  3,  2, 10,  1,  3, -1,  5,  0,  3,
  2, 10,  2,  3, -2,  4,  0,  2,  2, 10,  1, 12,  2,  2,  1, 12, -2, 11,  0,
  3, -2, 13,  1,  2, -1,  3,  0,  3,  1, 10, -1, 13,  2, 11,  0,  3,  2, 10,
  2,  2, -2,  3,  0,  3,  1, 10,  1, 12, -3, 13,  0,  3,  2, 13, -1, 11,  1,
 14,  0,  3,  2, 10,  2,  3, -3,  5,  0,  3,  2, 10,  6,  2, -8,  3,  0,  3,
 -3, 13, 18,  2,-16,  3,  1,  3,  2, 13,  2,  5, -5,  6,  0,  4,  2, 13,  4,
  3, -8,  4,  3,  5,  0,  1,  2, 13,  0,  4, -2, 13,  4,  3, -8,  4,  3,  5,
  0,  3, -2, 13,  2,  5, -5,  6,  0,  3,  1, 13, 18,  2,-16,  3,  1,  3, -2,
 13, -1, 11,  1, 14,  0,  3,  2, 10,  2,  3, -2,  5,  0,  3,  2, 10,  3,  2,
 -3,  3,  0,  3,  1, 10,  1, 12,  1, 13,  1,  2,  2, 10,  2, 12,  1,  2,  1,
 11,  1, 14,  1,  4, -1, 13, -2, 11, 18,  2,-16,  3,  0,  1,  2, 11,  0,  4,
 -1, 13,  2, 11, 18,  2,-16,  3,  0,  2, -3, 11,  1, 14,  0,  3,  2, 13,  1,
  2, -1,  3,  0,  3,  2, 10,  4,  2, -4,  3,  0,  3,  2, 10,  1, 12, -4, 13,
  0,  2,  1, 10, -3, 13,  0,  3,  2, 13,  1,  3, -1,  5,  0,  2,  1, 12,  2,
 13,  2,  3,  1, 10,  2, 12,  1, 13,  0,  3,  1, 10, -1, 13, -2, 11,  0,  2,
  1, 12,  2, 11,  1,  3,  2, 10,  5,  2, -5,  3,  0,  2,  2, 10, -4, 13,  0,
  3,  2, 10,  6,  2, -6,  3,  0,  2,  2, 12,  2, 13,  0,  3,  2, 10, -2, 13,
 -2, 11,  0,  2,  2, 12,  2, 11,  0,  2,  2, 10, -4, 11,  0,  3,  2, 10,  7,
  2, -7,  3,  0,  3,  2, 10, -1, 12, -4, 13,  0,  4,  2, 10, -1, 12, -2, 13,
 -2, 11,  0,  3,  2, 10,  8,  2, -8,  3,  0,  3,  2, 10,  9,  2, -9,  3,  0,
  3,  4, 10, -3, 12, -1, 13,  0,  3,  6, 10, -1, 12, -3, 13,  0,  3,  4, 10,
 -2, 12, -1, 13,  1,  3,  5, 10, -1, 12, -2, 13,  0,  2,  6, 10, -3, 13,  0,
  4,  4, 10, -1, 12,  1, 13, -2, 11,  0,  3,  2, 10, -3, 12,  1, 13,  0,  2,
  3, 10, -2, 12,  0,  3,  4, 10, -1, 12, -1, 13,  1,  2,  5, 10, -2, 13,  0,
  3,  6, 10,  1, 12, -3, 13,  0,  3,  4, 10,  1, 13, -2, 11,  0,  3,  2, 10,
 -2, 12,  1, 13,  1,  2,  3, 10, -1, 12,  0,  4, -2, 10, -1, 13,  2,  3, -2,
  5,  0,  2,  4, 10, -1, 13,  0,  4,  2, 10, -2, 12, -1, 13,  2, 11,  0,  3,
  4, 10, -3, 13,  2, 11,  0,  4, -2, 10, -1, 13,  2,  2, -2,  3,  0,  3,  2,
 10, -1, 12,  1, 13,  2,  4, -2, 10, -1, 13,  1,  3, -1,  5,  0,  1,  3, 10,
  0,  3,  4, 10,  1, 12, -1, 13,  1,  4,  2, 10, -1, 12, -1, 13,  2, 11,  1,
  4, -2, 10, -1, 13,  1,  2, -1,  3,  0,  3,  2, 10,  3, 13, -2, 11,  0,  2,
  2, 12, -3, 13,  0,  3,  1, 10, -1, 12,  2, 13,  0,  4,  2, 10,  1, 13, -1,
 11,  1, 14,  0,  4, -2, 10, -2, 13, 18,  2,-16,  3,  0,  5,  2, 10,  1, 13,
  4,  3, -8,  4,  3,  5,  0,  2,  2, 10,  1, 13,  1,  5, -2, 10, -1, 13,  4,
  3, -8,  4,  3,  5,  0,  3,  2, 10, 18,  2,-16,  3,  0,  4, -2, 10, -1, 13,
 -1, 11,  1, 14,  0,  4,  4, 10, -1, 13,  2,  3, -2,  5,  0,  4,  4, 10, -1,
 13,  3,  2, -3,  3,  0,  2,  3, 10,  1, 12,  1,  3,  4, 10,  2, 12, -1, 13,
  0,  4,  2, 10, -1, 13,  1, 11,  1, 14,  0,  3,  2, 10, -1, 13,  2, 11,  0,
  2,  1, 12, -3, 13,  1,  2,  1, 10,  2, 13,  0,  3,  2, 10,  1, 12,  1, 13,
  1,  3,  1, 12, -1, 13, -2, 11,  1,  2,  1, 10,  2, 11,  0,  4,  2, 10,  1,
 12, -1, 13,  2, 11,  0,  1,  3, 13,  0,  4,  2, 10,  1, 13,  2,  3, -2,  5,
  0,  3,  1, 10,  1, 12,  2, 13,  0,  3,  2, 10,  2, 12,  1, 13,  0,  3,  1,
 13,  1, 11,  1, 14,  0,  2,  1, 13,  2, 11,  0,  3,  1, 10,  1, 12,  2, 11,
  0,  4,  2, 10,  2, 12, -1, 13,  2, 11,  0,  2,  1, 13, -4, 11,  0,  2,  1,
 10, -4, 13,  0,  2,  1, 12,  3, 13,  1,  3,  1, 12,  1, 13,  2, 11,  1,  2,
  2, 10, -5, 13,  0,  3,  2, 10, -3, 13, -2, 11,  0,  3,  2, 10, -1, 13, -4,
 11,  0,  3,  6, 10, -2, 12, -2, 13,  0,  2,  4, 10, -3, 12,  0,  3,  6, 10,
 -1, 12, -2, 13,  0,  2,  4, 10, -2, 12,  1,  2,  6, 10, -2, 13,  0,  2,  4,
 10, -1, 12,  1,  2,  5, 10, -1, 13,  0,  3,  6, 10,  1, 12, -2, 13,  0,  4,
  4, 10, -1, 12, -2, 13,  2, 11,  0,  3,  4, 10,  2, 13, -2, 11,  0,  3,  2,
 10, -2, 12,  2, 13,  0,  1,  4, 10,  0,  3,  2, 10, -2, 12,  2, 11,  0,  3,
  4, 10, -2, 13,  2, 11,  0,  3,  2, 10, -1, 12,  2, 13,  1,  2,  3, 10,  1,
 13,  0,  2,  4, 10,  1, 12,  1,  3,  2, 10, -1, 12,  2, 11,  1,  3,  3, 10,
 -1, 13,  2, 11,  0,  2,  2, 10,  2, 13,  0,  3,  3, 10,  1, 12,  1, 13,  0,
  3,  2, 10,  1, 11,  1, 14,  0,  2,  2, 10,  2, 11,  0,  2,  1, 12, -4, 13,
  0,  2,  1, 10,  3, 13,  0,  3,  2, 10,  1, 12,  2, 13,  1,  3,  1, 12, -2,
 13, -2, 11,  0,  3,  1, 10,  1, 13,  2, 11,  0,  3,  2, 10,  1, 12,  2, 11,
  0,  1,  4, 13,  0,  3,  1, 10,  1, 12,  3, 13,  0,  2,  2, 13,  2, 11,  0,
  4,  1, 10,  1, 12,  1, 13,  2, 11,  0,  1,  4, 11,  0,  2,  1, 12,  4, 13,
  0,  3,  1, 12,  2, 13,  2, 11,  0,  3,  2, 10, -4, 13, -2, 11,  0,  3,  6,
 10, -2, 12, -1, 13,  0,  2,  8, 10, -3, 13,  0,  3,  6, 10, -1, 12, -1, 13,
  0,  3,  4, 10, -2, 12,  1, 13,  0,  2,  6, 10, -1, 13,  0,  3,  4, 10, -1,
 12,  1, 13,  1,  3,  6, 10,  1, 12, -1, 13,  0,  4,  4, 10, -1, 12, -1, 13,
  2, 11,  0,  3,  2, 10, -2, 12,  3, 13,  0,  2,  4, 10,  1, 13,  0,  3,  4,
 10, -1, 13,  2, 11,  0,  3,  2, 10, -1, 12,  3, 13,  0,  3,  4, 10,  1, 12,
  1, 13,  0,  4,  2, 10, -1, 12,  1, 13,  2, 11,  0,  2,  2, 10,  3, 13,  0,
  3,  2, 10,  1, 13,  2, 11,  0,  3,  2, 10, -1, 13,  4, 11,  0,  3,  2, 10,
  1, 12,  3, 13,  0,  3,  1, 12, -3, 13, -2, 11,  0,  3,  1, 10,  2, 13,  2,
 11,  0,  4,  2, 10,  1, 12,  1, 13,  2, 11,  0,  1,  5, 13,  0,  2,  3, 13,
  2, 11,  0,  2,  1, 13,  4, 11,  0,  3,  1, 12,  3, 13,  2, 11,  0,  2,  8,
 10, -2, 13,  0,  2,  6, 10, -1, 12,  0,  1,  6, 10,  0,  3,  6, 10, -2, 13,
  2, 11,  0,  3,  4, 10, -1, 12,  2, 13,  0,  3,  4, 10, -1, 12,  2, 11,  0,
  2,  4, 10,  2, 13,  0,  2,  4, 10,  2, 11,  0,  3,  2, 10, -1, 12,  4, 13,
  0,  3,  4, 10,  1, 12,  2, 13,  0,  4,  2, 10, -1, 12,  2, 13,  2, 11,  0,
  2,  2, 10,  4, 13,  0,  3,  2, 10,  2, 13,  2, 11,  0,  2,  2, 10,  4, 11,
  0,  1,  6, 13,  0,  2,  4, 13,  2, 11,  0,  2,  2, 13,  4, 11,  0,  3,  6,
 10, -1, 12,  1, 13,  0,  2,  6, 10,  1, 13,  0,  2,  4, 10,  3, 13,  0,  3,
  4, 10,  1, 13,  2, 11,  0,  2,  2, 10,  5, 13,  0,  3,  2, 10,  3, 13,  2,
 11,  0, -1);

KX0 = 623;
KX1 = 379;
KX2 = 144;
KX3 = 23;
KX4 = 11;
KX5 = 4;
KY0 = 184;
KY1 = 134;
KY2 = 62;
KY3 = 14;
KY4 = 6;
KY5 = 2;
KZ0 = 523;
KZ1 = 290;
KZ2 = 134;
KZ3 = 20;
KZ4 = 9;
KZ5 = 2;

SX0: array[1..KX0,1..3] of double =
((1.75347045673,  0.00000000000,        0.00000000000),
 (0.03341656453,  4.66925680415,     6283.07584999140),
 (0.00034894275,  4.62610242189,    12566.15169998280),
 (0.00003417572,  2.82886579754,        3.52311834900),
 (0.00003497056,  2.74411783405,     5753.38488489680),
 (0.00003135899,  3.62767041756,    77713.77146812050),
 (0.00002676218,  4.41808345438,     7860.41939243920),
 (0.00002342691,  6.13516214446,     3930.20969621960),
 (0.00001273165,  2.03709657878,      529.69096509460),
 (0.00001324294,  0.74246341673,    11506.76976979360),
 (0.00000901854,  2.04505446477,       26.29831979980),
 (0.00001199167,  1.10962946234,     1577.34354244780),
 (0.00000857223,  3.50849152283,      398.14900340820),
 (0.00000779786,  1.17882681962,     5223.69391980220),
 (0.00000990250,  5.23268072088,     5884.92684658320),
 (0.00000753141,  2.53339052847,     5507.55323866740),
 (0.00000505267,  4.58292599973,    18849.22754997420),
 (0.00000492392,  4.20505711826,      775.52261132400),
 (0.00000356672,  2.91954114478,        0.06731030280),
 (0.00000284125,  1.89869240932,      796.29800681640),
 (0.00000242879,  0.34481445893,     5486.77784317500),
 (0.00000317087,  5.84901948512,    11790.62908865880),
 (0.00000271112,  0.31486255375,    10977.07880469900),
 (0.00000206217,  4.80646631478,     2544.31441988340),
 (0.00000205478,  1.86953770281,     5573.14280143310),
 (0.00000202318,  2.45767790232,     6069.77675455340),
 (0.00000126225,  1.08295459501,       20.77539549240),
 (0.00000155516,  0.83306084617,      213.29909543800),
 (0.00000115132,  0.64544911683,        0.98032106820),
 (0.00000102851,  0.63599845579,     4694.00295470760),
 (0.00000101724,  4.26679801980,        7.11354700080),
 (0.00000099206,  6.20992926918,     2146.16541647520),
 (0.00000132212,  3.41118292683,     2942.46342329160),
 (0.00000097607,  0.68101342359,      155.42039943420),
 (0.00000085128,  1.29870764804,     6275.96230299060),
 (0.00000074651,  1.75508913300,     5088.62883976680),
 (0.00000101895,  0.97569280312,    15720.83878487840),
 (0.00000084711,  3.67080093031,    71430.69561812909),
 (0.00000073547,  4.67926633877,      801.82093112380),
 (0.00000073874,  3.50319414955,     3154.68708489560),
 (0.00000078757,  3.03697458703,    12036.46073488820),
 (0.00000079637,  1.80791287082,    17260.15465469040),
 (0.00000085803,  5.98322631260,   161000.68573767410),
 (0.00000056963,  2.78430458592,     6286.59896834040),
 (0.00000061148,  1.81839892984,     7084.89678111520),
 (0.00000069627,  0.83297621398,     9437.76293488700),
 (0.00000056116,  4.38694865354,    14143.49524243060),
 (0.00000062449,  3.97763912806,     8827.39026987480),
 (0.00000051145,  0.28306832879,     5856.47765911540),
 (0.00000055577,  3.47006059924,     6279.55273164240),
 (0.00000041036,  5.36817592855,     8429.24126646660),
 (0.00000051605,  1.33282739866,     1748.01641306700),
 (0.00000051992,  0.18914947184,    12139.55350910680),
 (0.00000049000,  0.48735014197,     1194.44701022460),
 (0.00000039200,  6.16833020996,    10447.38783960440),
 (0.00000035570,  1.77596889200,     6812.76681508600),
 (0.00000036770,  6.04133863162,    10213.28554621100),
 (0.00000036596,  2.56957481827,     1059.38193018920),
 (0.00000033296,  0.59310278598,    17789.84561978500),
 (0.00000035954,  1.70875808777,     2352.86615377180),
 (0.00000040938,  2.39850938714,    19651.04848109800),
 (0.00000030047,  2.73975124088,     1349.86740965880),
 (0.00000030412,  0.44294464169,    83996.84731811189),
 (0.00000023663,  0.48473622521,     8031.09226305840),
 (0.00000023574,  2.06528133162,     3340.61242669980),
 (0.00000021089,  4.14825468851,      951.71840625060),
 (0.00000024738,  0.21484762138,        3.59042865180),
 (0.00000025352,  3.16470891653,     4690.47983635860),
 (0.00000022823,  5.22195230819,     4705.73230754360),
 (0.00000021419,  1.42563910473,    16730.46368959580),
 (0.00000021891,  5.55594302779,      553.56940284240),
 (0.00000017481,  4.56052900312,      135.06508003540),
 (0.00000019927,  5.22209149316,    12168.00269657460),
 (0.00000019860,  5.77470242235,     6309.37416979120),
 (0.00000020300,  0.37133792946,      283.85931886520),
 (0.00000014421,  4.19315052005,      242.72860397400),
 (0.00000016225,  5.98837767951,    11769.85369316640),
 (0.00000015077,  4.19567163370,     6256.77753019160),
 (0.00000019124,  3.82219958698,    23581.25817731760),
 (0.00000018888,  5.38626892076,   149854.40013480789),
 (0.00000014346,  3.72355084422,       38.02767263580),
 (0.00000017898,  2.21490566029,    13367.97263110660),
 (0.00000012054,  2.62229602614,      955.59974160860),
 (0.00000011287,  0.17739329984,     4164.31198961300),
 (0.00000013973,  4.40134615007,     6681.22485339960),
 (0.00000013621,  1.88934516495,     7632.94325965020),
 (0.00000012503,  1.13052412208,        5.52292430740),
 (0.00000010498,  5.35909979317,     1592.59601363280),
 (0.00000009803,  0.99948172646,    11371.70468975820),
 (0.00000009220,  4.57138585348,     4292.33083295040),
 (0.00000010327,  6.19982170609,     6438.49624942560),
 (0.00000012003,  1.00351462266,      632.78373931320),
 (0.00000010827,  0.32734523824,      103.09277421860),
 (0.00000008356,  4.53902748706,    25132.30339996560),
 (0.00000010005,  6.02914963280,     5746.27133789600),
 (0.00000008409,  3.29946177848,     7234.79425624200),
 (0.00000008006,  5.82145271855,       28.44918746780),
 (0.00000010523,  0.93870455544,    11926.25441366880),
 (0.00000007686,  3.12143640640,     7238.67559160000),
 (0.00000009378,  2.62413793196,     5760.49843189760),
 (0.00000008127,  6.11227839253,     4732.03062734340),
 (0.00000009232,  0.48344234496,      522.57741809380),
 (0.00000009802,  5.24413877132,    27511.46787353720),
 (0.00000007871,  0.99590133077,     5643.17856367740),
 (0.00000008123,  6.27053020099,      426.59819087600),
 (0.00000009048,  5.33686323585,     6386.16862421000),
 (0.00000008621,  4.16537179089,     7058.59846131540),
 (0.00000006297,  4.71723143652,     6836.64525283380),
 (0.00000007575,  3.97381357237,    11499.65622279280),
 (0.00000007756,  2.95728422442,    23013.53953958720),
 (0.00000007314,  0.60652522715,    11513.88331679440),
 (0.00000005955,  2.87641047954,     6283.14316029419),
 (0.00000006534,  5.79046406784,    18073.70493865020),
 (0.00000007188,  3.99831461988,       74.78159856730),
 (0.00000007346,  4.38582423903,      316.39186965660),
 (0.00000005413,  5.39199023275,      419.48464387520),
 (0.00000005127,  2.36059551778,    10973.55568635000),
 (0.00000007056,  0.32258442532,      263.08392337280),
 (0.00000006624,  3.66474165840,    17298.18232732620),
 (0.00000006762,  5.91131766896,    90955.55169449610),
 (0.00000004938,  5.73672172371,     9917.69687450980),
 (0.00000005547,  2.45152589382,    12352.85260454480),
 (0.00000005958,  3.32051344660,     6283.00853968860),
 (0.00000004471,  2.06386138131,     7079.37385680780),
 (0.00000006153,  1.45823347458,   233141.31440436149),
 (0.00000004348,  4.42338625285,     5216.58037280140),
 (0.00000006124,  1.07494838623,    19804.82729158280),
 (0.00000004488,  3.65285033073,      206.18554843720),
 (0.00000004020,  0.83995823171,       20.35531939880),
 (0.00000005188,  4.06503864016,     6208.29425142410),
 (0.00000005307,  0.38216728132,    31441.67756975680),
 (0.00000003785,  2.34369213733,        3.88133535800),
 (0.00000004497,  3.27230792447,    11015.10647733480),
 (0.00000004132,  0.92129851256,     3738.76143010800),
 (0.00000003521,  5.97844803610,     3894.18182954220),
 (0.00000004215,  1.90601721876,      245.83164622940),
 (0.00000003701,  5.03067498875,      536.80451209540),
 (0.00000003866,  1.82632980909,    11856.21865142450),
 (0.00000003652,  1.01840564429,    16200.77272450120),
 (0.00000003390,  0.97784870142,     8635.94200376320),
 (0.00000003737,  2.95378919570,     3128.38876509580),
 (0.00000003507,  3.71291946317,     6290.18939699220),
 (0.00000003086,  3.64646921512,       10.63666534980),
 (0.00000003397,  1.10589356888,    14712.31711645800),
 (0.00000003334,  0.83684903082,     6496.37494542940),
 (0.00000002805,  2.58503711584,    14314.16811304980),
 (0.00000003650,  1.08344142571,    88860.05707098669),
 (0.00000003388,  3.20182380957,     5120.60114558360),
 (0.00000003252,  3.47857474229,     6133.51265285680),
 (0.00000002553,  3.94869027260,     1990.74501704100),
 (0.00000003520,  2.05559692878,   244287.60000722769),
 (0.00000002565,  1.56072409371,    23543.23050468179),
 (0.00000002621,  3.85639359951,      266.60704172180),
 (0.00000002954,  3.39692614359,     9225.53927328300),
 (0.00000002876,  6.02633318445,   154717.60988768269),
 (0.00000002395,  1.16130078696,    10984.19235169980),
 (0.00000003161,  1.32798862116,    10873.98603048040),
 (0.00000003163,  5.08946546862,    21228.39202354580),
 (0.00000002361,  4.27212461943,     6040.34724601740),
 (0.00000003030,  1.80210001168,    35371.88726597640),
 (0.00000002343,  3.57688971514,    10969.96525769820),
 (0.00000002618,  2.57870151918,    22483.84857449259),
 (0.00000002113,  3.71711179417,    65147.61976813770),
 (0.00000002019,  0.81393923319,      170.67287061920),
 (0.00000002003,  0.38091017375,     6172.86952877200),
 (0.00000002506,  3.74378169126,    10575.40668294180),
 (0.00000002381,  0.10581361289,        7.04623669800),
 (0.00000001949,  4.86892513469,       36.02786667740),
 (0.00000002074,  4.22802468213,     5650.29211067820),
 (0.00000001924,  5.59460549844,     6282.09552892320),
 (0.00000001949,  1.06999605576,     5230.80746680300),
 (0.00000001988,  5.19734705445,     6262.30045449900),
 (0.00000001887,  3.74365662683,       23.87843774780),
 (0.00000001787,  1.25929659066,    12559.03815298200),
 (0.00000001883,  1.90364058477,       15.25247118500),
 (0.00000001816,  3.68083794819,    15110.46611986620),
 (0.00000001701,  4.41109562589,      110.20632121940),
 (0.00000001990,  3.93295788548,     6206.80977871580),
 (0.00000002103,  0.75354936681,    13521.75144159140),
 (0.00000001774,  0.48750515837,     1551.04522264800),
 (0.00000001882,  0.86685462305,    22003.91463486980),
 (0.00000001924,  1.22901099088,      709.93304855830),
 (0.00000002073,  4.62531597856,     6037.24420376200),
 (0.00000001924,  0.60231842492,     6284.05617105960),
 (0.00000001596,  3.98332879712,    13916.01910964160),
 (0.00000001664,  4.41947015623,     8662.24032356300),
 (0.00000001971,  1.04560686192,    18209.33026366019),
 (0.00000001942,  4.31335979989,     6244.94281435360),
 (0.00000001476,  0.93274523818,     2379.16447357160),
 (0.00000001810,  0.49112137707,        1.48447270830),
 (0.00000001346,  1.51574753411,     4136.91043351620),
 (0.00000001528,  5.61833568587,     6127.65545055720),
 (0.00000001791,  3.22191142746,    39302.09696219600),
 (0.00000001747,  3.05595292589,    18319.53658487960),
 (0.00000001432,  4.51123984264,    20426.57109242200),
 (0.00000001695,  0.22049418623,    25158.60171976540),
 (0.00000001242,  4.46665354536,    17256.63153634140),
 (0.00000001463,  4.69248613506,    14945.31617355440),
 (0.00000001205,  1.86911906771,     4590.91018048900),
 (0.00000001190,  2.74169967367,    12569.67481833180),
 (0.00000001222,  5.18120087481,     5333.90024102160),
 (0.00000001390,  5.42888623322,   143571.32428481648),
 (0.00000001473,  1.70487100866,    11712.95531823080),
 (0.00000001362,  2.61069503292,     6062.66320755260),
 (0.00000001148,  6.03008430610,     3634.62102451840),
 (0.00000001198,  5.15296117339,    10177.25767953360),
 (0.00000001266,  0.11422490557,    18422.62935909819),
 (0.00000001411,  1.09910890045,     3496.03282613400),
 (0.00000001349,  2.99804623019,    17654.78053974960),
 (0.00000001253,  2.79844902576,   167283.76158766549),
 (0.00000001311,  1.60941074300,     5481.25491886760),
 (0.00000001079,  6.20304501787,        3.28635741780),
 (0.00000001181,  1.20653777627,      131.54196168640),
 (0.00000001254,  5.45103277799,     6076.89030155420),
 (0.00000001036,  2.32136959491,     7342.45778018060),
 (0.00000001117,  0.38842340979,      949.17560896980),
 (0.00000000966,  3.18352079941,    11087.28512591840),
 (0.00000001171,  3.39635167732,    12562.62858163380),
 (0.00000001121,  0.72631814699,      220.41264243880),
 (0.00000001024,  2.19381113265,    11403.67699557500),
 (0.00000000888,  3.91167196431,     4686.88940770680),
 (0.00000000910,  1.98802695087,      735.87651353180),
 (0.00000000823,  0.48822202854,    24072.92146977640),
 (0.00000001096,  6.17377835617,     5436.99301524020),
 (0.00000000908,  0.44959148878,     7477.52286021600),
 (0.00000000974,  1.52996313552,     9623.68827669120),
 (0.00000000840,  1.79540573407,     5429.87946823940),
 (0.00000000778,  6.17703744517,       38.13303563780),
 (0.00000000776,  4.09859968447,       14.22709400160),
 (0.00000001068,  4.64209577648,    43232.30665841560),
 (0.00000000954,  1.49985885818,     1162.47470440780),
 (0.00000000907,  0.86986870809,    10344.29506538580),
 (0.00000000931,  4.06049877517,    28766.92442448400),
 (0.00000000739,  5.04368192034,      639.89728631400),
 (0.00000000965,  3.44286716197,     1589.07289528380),
 (0.00000000763,  5.86304776787,    16858.48253293320),
 (0.00000000953,  4.20801492835,    11190.37790013700),
 (0.00000000708,  1.72432323967,    13095.84266507740),
 (0.00000000969,  1.64437243011,    29088.81141598500),
 (0.00000000717,  0.16688678895,       11.72935283600),
 (0.00000000962,  3.53101876172,    12416.58850284820),
 (0.00000000745,  5.77741082302,    12592.45001978260),
 (0.00000000672,  1.91091228744,        3.93215326310),
 (0.00000000671,  5.46240758839,    18052.92954315780),
 (0.00000000675,  6.28311649798,     4535.05943692440),
 (0.00000000684,  0.39975011401,     5849.36411211460),
 (0.00000000799,  0.29859056777,    12132.43996210600),
 (0.00000000758,  0.96370719224,     1052.26838318840),
 (0.00000000782,  5.33875702541,    13517.87010623340),
 (0.00000000730,  1.70114998543,    17267.26820169119),
 (0.00000000749,  2.59607005624,    11609.86254401220),
 (0.00000000734,  2.78420497780,      640.87760738220),
 (0.00000000688,  5.15097673557,    16496.36139620240),
 (0.00000000770,  1.62459252416,     4701.11650170840),
 (0.00000000633,  2.20588443066,    25934.12433108940),
 (0.00000000760,  4.21317219403,      377.37360791580),
 (0.00000000584,  2.13420121623,    10557.59416082380),
 (0.00000000572,  0.24649745829,     9779.10867612540),
 (0.00000000573,  3.16435264609,      533.21408344360),
 (0.00000000685,  3.19344289472,    12146.66705610760),
 (0.00000000675,  0.96179234176,    10454.50138660520),
 (0.00000000648,  1.46327342554,     6268.84875598980),
 (0.00000000589,  2.50543543638,     3097.88382272579),
 (0.00000000551,  5.28106257475,     9388.00590941520),
 (0.00000000696,  3.65342155550,     4804.20927592700),
 (0.00000000669,  2.51030059260,     2388.89402044920),
 (0.00000000550,  0.06883090057,    20199.09495963300),
 (0.00000000629,  4.13350997495,    45892.73043315699),
 (0.00000000678,  6.09190163533,      135.62532501000),
 (0.00000000593,  1.50129499103,   226858.23855437008),
 (0.00000000542,  3.58582033525,     6148.01076995600),
 (0.00000000599,  6.12058050643,    18875.52586977400),
 (0.00000000682,  5.02213616830,    17253.04110768959),
 (0.00000000565,  4.29309214275,    11933.36796066960),
 (0.00000000486,  0.77746204893,       27.40155609680),
 (0.00000000503,  0.58974557727,    15671.08175940660),
 (0.00000000616,  4.06539884128,      227.47613278900),
 (0.00000000537,  2.15064382406,    21954.15760939799),
 (0.00000000669,  6.06995500278,    47162.51635463520),
 (0.00000000540,  2.83444221432,     5326.78669402080),
 (0.00000000474,  0.40346826846,     6915.85958930460),
 (0.00000000532,  5.26131065063,    10988.80815753500),
 (0.00000000582,  3.24533095664,      153.77881048480),
 (0.00000000641,  3.24711790399,     2107.03450754240),
 (0.00000000619,  3.08302108547,    33019.02111220460),
 (0.00000000466,  3.14982369789,    10440.27429260360),
 (0.00000000466,  0.90708835651,     5966.68398033480),
 (0.00000000528,  0.81926454470,      813.55028395980),
 (0.00000000603,  3.81378921927,   316428.22867391503),
 (0.00000000559,  1.81894985730,    17996.03116822220),
 (0.00000000437,  2.28631745987,     6303.85124548380),
 (0.00000000518,  4.86068318058,    20597.24396304120),
 (0.00000000424,  6.23520018697,     6489.26139842860),
 (0.00000000518,  6.17617826756,        0.24381748350),
 (0.00000000404,  5.72804304258,     5642.19824260920),
 (0.00000000458,  1.34117773914,     6287.00800325450),
 (0.00000000548,  5.68454458320,   155427.54293624099),
 (0.00000000547,  1.03391472434,     3646.35037735440),
 (0.00000000428,  4.69809687820,      846.08283475120),
 (0.00000000413,  6.02520699390,     6279.48542133960),
 (0.00000000534,  3.03030638223,    66567.48586525429),
 (0.00000000383,  1.49055588040,    19800.94595622480),
 (0.00000000411,  5.28384176408,    18451.07854656599),
 (0.00000000352,  4.68891600525,     4907.30205014560),
 (0.00000000480,  5.36572651091,      348.92442044800),
 (0.00000000344,  5.89157452889,     6546.15977336420),
 (0.00000000340,  0.37557440365,    13119.72110282519),
 (0.00000000434,  4.98417856239,     6702.56049386660),
 (0.00000000332,  2.68909344430,    29296.61538957860),
 (0.00000000448,  2.16478480251,     5905.70224207560),
 (0.00000000344,  2.06546633735,       49.75702547180),
 (0.00000000315,  1.24023810969,     4061.21921539440),
 (0.00000000324,  2.30897526929,     5017.50837136500),
 (0.00000000413,  0.17171692945,     6286.66627864320),
 (0.00000000431,  3.86601101380,    12489.88562870720),
 (0.00000000349,  4.55372493131,     4933.20844033260),
 (0.00000000323,  0.41971136084,    10770.89325626180),
 (0.00000000341,  2.68612860807,       11.04570026390),
 (0.00000000316,  3.52966641606,    17782.73207278420),
 (0.00000000315,  5.63357264999,      568.82187402740),
 (0.00000000340,  3.83571212349,    10660.68693504240),
 (0.00000000296,  0.62703270489,    20995.39296644940),
 (0.00000000405,  1.00084965393,    16460.33352952499),
 (0.00000000414,  1.21998752076,    51092.72605085480),
 (0.00000000336,  4.71465945215,     6179.98307577280),
 (0.00000000361,  3.71235613733,    28237.23345938940),
 (0.00000000327,  1.05606504715,    11919.14086666800),
 (0.00000000327,  6.14222420980,     6254.62666252360),
 (0.00000000268,  2.47224339737,      664.75604513000),
 (0.00000000269,  1.86210872453,    23141.55838292460),
 (0.00000000345,  0.93461290184,     6058.73105428950),
 (0.00000000353,  4.50033650657,    36949.23080842420),
 (0.00000000344,  6.26166140367,    24356.78078864160),
 (0.00000000300,  4.46964001975,     6418.14093002680),
 (0.00000000260,  4.04967464725,     6525.80445396540),
 (0.00000000298,  2.20018811054,   156137.47598479928),
 (0.00000000253,  3.49930797865,    29864.33402730900),
 (0.00000000254,  2.44883530154,     5331.35744374080),
 (0.00000000296,  0.84341183907,     5729.50644714900),
 (0.00000000241,  2.00721298729,    16737.57723659660),
 (0.00000000311,  1.23668016336,     6281.59137728310),
 (0.00000000332,  3.55576945724,     7668.63742494250),
 (0.00000000236,  2.47437156031,     6245.04817735560),
 (0.00000000264,  4.43924412283,    12964.30070339100),
 (0.00000000257,  1.79654471948,    11080.17157891760),
 (0.00000000260,  3.33077596060,     5888.44996493220),
 (0.00000000285,  0.30886361430,    11823.16163945020),
 (0.00000000290,  5.70141882483,       77.67377042800),
 (0.00000000255,  4.00939662024,     5881.40372823420),
 (0.00000000253,  4.73318512715,    16723.35014259500),
 (0.00000000228,  0.95333661324,     5540.08578945880),
 (0.00000000281,  1.29199646396,    22805.73556599360),
 (0.00000000319,  1.38633229189,   163096.18036118349),
 (0.00000000224,  1.65156322696,    10027.90319572920),
 (0.00000000226,  0.34125379653,    17796.95916678580),
 (0.00000000236,  4.19817431922,       19.66976089979),
 (0.00000000281,  4.14114899916,    12539.85338018300),
 (0.00000000275,  5.50306930248,       32.53255079140),
 (0.00000000223,  5.23334210294,       56.89837493560),
 (0.00000000217,  6.08598789777,     6805.65326808520),
 (0.00000000228,  5.17114391778,    11720.06886523160),
 (0.00000000274,  4.50716805713,     6016.46880826960),
 (0.00000000245,  3.96486270306,       22.77520145080),
 (0.00000000220,  4.72078081970,        6.62855890001),
 (0.00000000207,  5.71701403951,       41.55079098480),
 (0.00000000204,  3.91227411250,     2699.73481931760),
 (0.00000000209,  0.86881969024,     6321.10352262720),
 (0.00000000200,  2.11984442601,     4274.51831083240),
 (0.00000000200,  5.39839888151,     6019.99192661860),
 (0.00000000209,  5.67606291663,    11293.47067435560),
 (0.00000000252,  1.64965729350,     9380.95967271720),
 (0.00000000275,  5.04826903506,       73.29712585900),
 (0.00000000208,  1.88207277133,    11300.58422135640),
 (0.00000000206,  5.07284889330,     6277.55292568400),
 (0.00000000272,  0.74640924904,     1975.49254585600),
 (0.00000000199,  3.30813142103,    22743.40937951640),
 (0.00000000269,  4.48560812155,    64471.99124174489),
 (0.00000000192,  2.17463565107,     5863.59120611620),
 (0.00000000228,  5.85373115869,      128.01884333740),
 (0.00000000261,  2.64321183295,    55022.93574707440),
 (0.00000000196,  2.48537622320,    16062.18452611680),
 (0.00000000187,  1.31891760280,    29826.30635467320),
 (0.00000000220,  5.75012110079,       29.42950853600),
 (0.00000000187,  4.03230554718,      467.96499035440),
 (0.00000000200,  5.60555262896,     1066.49547719000),
 (0.00000000231,  1.09802712785,    12341.80690428090),
 (0.00000000198,  0.29474229005,      149.56319713460),
 (0.00000000249,  5.10477023170,     7875.67186362420),
 (0.00000000179,  0.87066197995,    12721.57209941700),
 (0.00000000203,  1.56914310573,    28286.99048486120),
 (0.00000000198,  3.54061588502,       30.91412563500),
 (0.00000000171,  3.45366018621,     5327.47610838280),
 (0.00000000183,  0.72325421604,     6272.03014972750),
 (0.00000000216,  2.97175184412,    19402.79695281660),
 (0.00000000168,  2.51559879907,    23937.85638974100),
 (0.00000000195,  0.09045393425,      156.40072050240),
 (0.00000000216,  0.42162375972,    23539.70738633280),
 (0.00000000189,  0.37542530191,     9814.60410029120),
 (0.00000000207,  2.01752547259,   238004.52415723629),
 (0.00000000218,  2.36835893645,    16627.37091537720),
 (0.00000000166,  4.23182960518,    16840.67001081519),
 (0.00000000200,  2.02153258098,    16097.67995028260),
 (0.00000000169,  0.91318727000,       95.97922721780),
 (0.00000000211,  5.73370637657,      151.89728108520),
 (0.00000000204,  0.42643085174,      515.46387109300),
 (0.00000000212,  3.00223140894,    12043.57428188900),
 (0.00000000192,  5.46153589821,     6379.05507720920),
 (0.00000000160,  6.23798383332,      202.25339517410),
 (0.00000000215,  0.20889073407,     5621.84292321040),
 (0.00000000150,  3.12999753018,      799.82112516540),
 (0.00000000187,  2.12345787867,      491.66329245880),
 (0.00000000192,  1.33928820063,      394.62588505920),
 (0.00000000149,  2.65697593276,       21.33564046700),
 (0.00000000146,  5.58021191726,      412.37109687440),
 (0.00000000156,  3.75657676380,    12323.42309600880),
 (0.00000000143,  3.28248547724,       29.82143814880),
 (0.00000000144,  1.07862546598,     1265.56747862640),
 (0.00000000148,  0.23386631090,    10021.83728009940),
 (0.00000000164,  0.94288727597,    14919.01785375460),
 (0.00000000193,  5.92751083827,    40879.44050464380),
 (0.00000000140,  4.97612440269,      158.94351778320),
 (0.00000000148,  2.61651818006,    17157.06188047180),
 (0.00000000140,  3.66947933935,    26084.02180621620),
 (0.00000000147,  5.09968173403,      661.23292678100),
 (0.00000000147,  1.36976712162,     4171.42553661380),
 (0.00000000134,  4.79432636012,      111.18664228760),
 (0.00000000140,  1.27748013377,      107.66352393860),
 (0.00000000171,  2.77586207403,    26735.94526221320),
 (0.00000000183,  5.43418358741,      369.69981594040),
 (0.00000000134,  3.09132862833,       17.81252211800),
 (0.00000000132,  3.05633896779,    22490.96212149340),
 (0.00000000181,  4.22950689891,      966.97087743560),
 (0.00000000166,  3.67660435776,    15508.61512327440),
 (0.00000000152,  5.28885813387,    12669.24447420140),
 (0.00000000150,  5.86819430895,    97238.62754448749),
 (0.00000000145,  5.07330784304,       87.30820453981),
 (0.00000000133,  5.65471067133,       31.97230581680),
 (0.00000000124,  2.83326216907,    12566.21901028560),
 (0.00000000140,  5.84212721453,    22476.73502749179),
 (0.00000000134,  3.12858101887,    32217.20018108080),
 (0.00000000137,  0.86487461904,     9924.81042151060),
 (0.00000000172,  1.98369595114,   174242.46596404970),
 (0.00000000170,  4.41115280254,   327574.51427678125),
 (0.00000000128,  4.49087631612,    31415.37924995700),
 (0.00000000151,  0.46542092001,    39609.65458316560),
 (0.00000000153,  3.78801830344,    17363.24742890899),
 (0.00000000165,  5.31654110459,    16943.76278503380),
 (0.00000000165,  4.06747587817,    58953.14544329400),
 (0.00000000118,  0.63846333239,        6.06591562980),
 (0.00000000159,  0.86086959274,   221995.02880149524),
 (0.00000000119,  5.96432932413,     1385.89527633620),
 (0.00000000114,  5.16516114595,    25685.87280280800),
 (0.00000000112,  4.92889233335,       56.80326216980),
 (0.00000000119,  2.40626699328,    18635.92845453620),
 (0.00000000115,  0.23374479051,      418.92439890060),
 (0.00000000113,  2.79387576740,     6272.43918464160),
 (0.00000000122,  0.93694072400,    24492.40611365159),
 (0.00000000133,  4.87155573413,    22345.26037610820),
 (0.00000000113,  3.80362889046,     6293.71251534120),
 (0.00000000130,  3.72996018683,    12573.26524698360),
 (0.00000000107,  3.40227152756,    21393.54196985760),
 (0.00000000122,  1.00385670948,    95143.13292097810),
 (0.00000000140,  1.09413075700,    44809.65020086340),
 (0.00000000112,  6.05462382871,      433.71173787680),
 (0.00000000123,  4.55640196386,   239424.39025435288),
 (0.00000000104,  1.54931540602,      127.95153303460),
 (0.00000000111,  3.04186517428,     8982.81066930900),
 (0.00000000102,  4.12448497391,    15664.03552270859),
 (0.00000000107,  4.67919356465,    77690.75950573849),
 (0.00000000118,  4.52320170120,    19004.64794940840),
 (0.00000000107,  5.71774478555,    77736.78343050249),
 (0.00000000103,  4.79332126649,    33794.54372352860),
 (0.00000000143,  1.81201813018,     4214.06901508480),
 (0.00000000102,  3.75817786570,    58864.54391814630),
 (0.00000000125,  1.14419195615,      625.67019231240),
 (0.00000000124,  3.27736513892,    12566.08438968000),
 (0.00000000110,  1.08705709966,     2787.04302385740),
 (0.00000000102,  4.75119578149,    12242.64628332540),
 (0.00000000101,  4.91289409429,      401.67212175720),
 (0.00000000138,  2.89578979744,     9411.46461508720),
 (0.00000000129,  1.23516042371,    12029.34718788740),
 (0.00000000138,  2.45654707076,     7576.56007357400),
 (0.00000000098,  5.44771765020,    29026.48522950779),
 (0.00000000134,  1.43105174912,    86464.61331683119),
 (0.00000000108,  0.98989774940,     5636.06501667660),
 (0.00000000117,  5.17362847134,    34520.30930938080),
 (0.00000000097,  3.34717130592,    16310.97904572060),
 (0.00000000107,  2.94547931851,    24602.61243487099),
 (0.00000000098,  4.37041908717,    34513.26307268280),
 (0.00000000125,  2.72182830814,    24065.80792277559),
 (0.00000000111,  0.58899131543,     6303.43116939020),
 (0.00000000102,  0.66938025772,    10239.58386601080),
 (0.00000000119,  1.21666517886,     1478.86657406440),
 (0.00000000111,  1.04321934681,    16522.65971600220),
 (0.00000000094,  4.31076339857,    26880.31981303260),
 (0.00000000098,  4.14248433763,     6599.46771964800),
 (0.00000000095,  2.89807657534,    34911.41207609100),
 (0.00000000097,  0.89642320201,    71980.63357473118),
 (0.00000000095,  0.65717727948,     6288.59877429880),
 (0.00000000116,  4.19967201116,      206.70073729660),
 (0.00000000095,  1.78315464297,    18139.29450141590),
 (0.00000000099,  1.37437847718,     1039.02661079040),
 (0.00000000126,  3.21642544972,   305281.94307104882),
 (0.00000000094,  0.68995031860,     7834.12107263940),
 (0.00000000095,  5.58111421744,     3104.93005942380),
 (0.00000000108,  0.52696637156,      276.74577186440),
 (0.00000000124,  3.43899862683,   172146.97134054029),
 (0.00000000087,  1.18764938806,    18842.11400297339),
 (0.00000000087,  0.09094166389,    15141.39079431200),
 (0.00000000108,  1.03363414379,    82576.98122099529),
 (0.00000000119,  2.86729109648,    90394.82301305079),
 (0.00000000104,  3.39218586218,      290.97286586600),
 (0.00000000094,  5.68284937444,    32367.09765620760),
 (0.00000000117,  0.78475956902,    83286.91426955358),
 (0.00000000105,  3.96551057233,     6357.85744855870),
 (0.00000000094,  4.03443174853,    13341.67431130680),
 (0.00000000096,  0.92742567538,     1062.90504853820),
 (0.00000000089,  4.45371820659,      792.77488846740),
 (0.00000000087,  0.40013481685,    90279.92316810328),
 (0.00000000113,  2.48165313368,    48739.85989708300),
 (0.00000000087,  3.43122851097,    27707.54249429480),
 (0.00000000101,  5.32081603011,     2301.58581590939),
 (0.00000000084,  0.67020912458,    28628.33622609960),
 (0.00000000082,  0.87060089842,    10241.20229116720),
 (0.00000000086,  4.62064792290,    36147.40987730040),
 (0.00000000080,  4.77649625396,     6819.88036208680),
 (0.00000000095,  2.87032913492,    23020.65308658799),
 (0.00000000107,  5.77864921649,    34115.11406927460),
 (0.00000000110,  3.32898859416,    72140.62866668739),
 (0.00000000087,  4.40657711727,      142.17862703620),
 (0.00000000103,  4.22506726810,    30666.15495843280),
 (0.00000000082,  3.89404392552,     5547.19933645960),
 (0.00000000109,  1.94546065204,    24279.10701821359),
 (0.00000000087,  4.32472045435,      742.99006053260),
 (0.00000000107,  4.91580912547,      277.03499374140),
 (0.00000000088,  2.10180817713,    26482.17080962440),
 (0.00000000086,  4.01895021483,    12491.37010141550),
 (0.00000000106,  5.49092372854,    62883.35513951360),
 (0.00000000080,  6.19785704950,     6709.67404086740),
 (0.00000000105,  2.44166529175,     6298.32832117640),
 (0.00000000083,  4.90662164029,       51.28033786241),
 (0.00000000074,  2.34622575625,     7018.95236352320),
 (0.00000000078,  6.06947270265,   148434.53403769129),
 (0.00000000079,  3.03048221644,      838.96928775040),
 (0.00000000073,  3.05008665738,      567.71863773040),
 (0.00000000102,  3.59223815483,    22380.75580027400),
 (0.00000000084,  0.46604373274,       45.14121963660),
 (0.00000000092,  4.12917744733,    18216.44381066100),
 (0.00000000091,  0.49382398887,     6453.74872061060),
 (0.00000000073,  1.72446569088,    21424.46664430340),
 (0.00000000069,  1.49372677730,    21548.96236929180),
 (0.00000000069,  4.73181018058,     8858.31494432060),
 (0.00000000077,  0.47683782532,    11520.99686379520),
 (0.00000000078,  5.43942630990,    15265.88651930040),
 (0.00000000077,  2.53773750372,       76.26607127560),
 (0.00000000069,  2.53932635192,     9910.58332750900),
 (0.00000000075,  0.15594729210,    23006.42599258639),
 (0.00000000078,  2.41004950269,     6393.28217121080),
 (0.00000000067,  5.05152846816,    57375.80190084620),
 (0.00000000077,  3.91075604860,    24383.07910844140),
 (0.00000000067,  0.78239147387,    12779.45079542080),
 (0.00000000071,  1.24817900687,    10419.98628350760),
 (0.00000000067,  5.77851227760,     6311.52503745920),
 (0.00000000061,  2.66705754411,    18852.75066832320),
 (0.00000000079,  1.89137330427,     6528.90749622080),
 (0.00000000084,  5.11523704221,    50317.20343953080),
 (0.00000000059,  3.38290426621,    35707.71008290740),
 (0.00000000065,  4.66767908854,    26709.64694241340),
 (0.00000000079,  5.59773848156,    71960.38658322369),
 (0.00000000061,  3.30733768968,    18845.70443162520),
 (0.00000000057,  3.90831298022,     5999.21653112620),
 (0.00000000058,  3.92572820333,    30348.88377276700),
 (0.00000000061,  0.05695045822,     7856.89627409019),
 (0.00000000061,  5.63297960691,     7863.94251078820),
 (0.00000000068,  2.53986117507,    20452.86941222180),
 (0.00000000053,  5.44021645443,    32370.97899156560),
 (0.00000000059,  4.95695131145,    11925.27409260060),
 (0.00000000059,  5.34668243273,   137288.24843482509),
 (0.00000000056,  4.05779957425,    17892.93839400359),
 (0.00000000053,  3.94182462468,    18624.88275427230),
 (0.00000000049,  2.11782803206,    22594.05489571199),
 (0.00000000062,  2.47154086715,    12345.73905754400),
 (0.00000000049,  5.76596937380,    18606.49894600020),
 (0.00000000052,  6.20902099741,    21947.11137270000),
 (0.00000000051,  3.13287981215,    33326.57873317420),
 (0.00000000057,  6.17003357597,    61306.01159706580),
 (0.00000000064,  5.66596451842,    34596.36465465240),
 (0.00000000066,  3.92262335500,    69853.35207568129),
 (0.00000000053,  5.51119362049,    77710.24834977149),
 (0.00000000053,  4.88573986965,    77717.29458646949),
 (0.00000000048,  2.71399112516,    20760.42703319140),
 (0.00000000046,  6.08376164442,    29822.78323632420),
 (0.00000000052,  0.31397481380,    37724.75341974820),
 (0.00000000045,  5.53587248663,     6262.72053059260),
 (0.00000000059,  2.45437896854,    69166.43098950500),
 (0.00000000060,  5.24261569842,    56600.27928952220),
 (0.00000000051,  6.15794342172,    11616.97609101300),
 (0.00000000060,  1.74758109828,    44034.12758953940),
 (0.00000000049,  5.08973141046,    33990.61834428620),
 (0.00000000044,  3.28270864884,    29424.63423291600),
 (0.00000000052,  5.34866947943,    28313.28880466100),
 (0.00000000059,  2.12384971916,    36173.70819710020),
 (0.00000000050,  0.46480931695,    25287.72379939980),
 (0.00000000044,  2.05503517210,    63658.87775083760),
 (0.00000000044,  1.71009200258,    13362.44970679920),
 (0.00000000041,  3.91721318316,     6279.19451463340),
 (0.00000000042,  1.52106001448,    23550.34405168259),
 (0.00000000042,  3.10938258068,    84672.47584450469),
 (0.00000000041,  3.78863023321,    35050.00027447539),
 (0.00000000042,  5.57543459263,    38500.27603107220),
 (0.00000000040,  5.55145719363,    12565.17137891460),
 (0.00000000054,  0.88935492100,    50290.90511973100),
 (0.00000000055,  2.50268487636,    77828.67131306800),
 (0.00000000054,  4.16257918787,    22910.44676536859),
 (0.00000000041,  2.32141215064,     6286.95718534940),
 (0.00000000045,  3.18590576311,    45585.17281218740),
 (0.00000000045,  2.24348941683,    23646.32327890039),
 (0.00000000043,  3.87892110950,     6549.68289171320),
 (0.00000000048,  2.11364139445,    31570.79964939120),
 (0.00000000043,  5.55099558987,    12359.96615154560),
 (0.00000000041,  4.88191569433,    23536.11695768099),
 (0.00000000049,  2.44790922235,    13613.80427733600),
 (0.00000000047,  3.58181693910,     4797.09572892620));
SX1: array[1..KX1,1..3] of double =
((6283.07584999140,    0.00000000000,   0.00000000000),
 (0.00206058863,  2.67823455808,     6283.07584999140),
 (0.00004303419,  2.63512233481,    12566.15169998280),
 (0.00000425264,  1.59046982018,        3.52311834900),
 (0.00000109017,  2.96631010675,     1577.34354244780),
 (0.00000093479,  2.59211109542,    18849.22754997420),
 (0.00000119305,  5.79555765566,       26.29831979980),
 (0.00000072121,  1.13840581212,      529.69096509460),
 (0.00000067784,  1.87453300345,      398.14900340820),
 (0.00000067350,  4.40932832004,     5507.55323866740),
 (0.00000059045,  2.88815790631,     5223.69391980220),
 (0.00000055976,  2.17471740035,      155.42039943420),
 (0.00000045411,  0.39799502896,      796.29800681640),
 (0.00000036298,  0.46875437227,      775.52261132400),
 (0.00000028962,  2.64732254645,        7.11354700080),
 (0.00000019097,  1.84628376049,     5486.77784317500),
 (0.00000020844,  5.34138275149,        0.98032106820),
 (0.00000018508,  4.96855179468,      213.29909543800),
 (0.00000016233,  0.03216587315,     2544.31441988340),
 (0.00000017293,  2.99116760630,     6275.96230299060),
 (0.00000015832,  1.43049301283,     2146.16541647520),
 (0.00000014608,  1.20469793690,    10977.07880469900),
 (0.00000011877,  3.25805082007,     5088.62883976680),
 (0.00000011514,  2.07502080082,     4694.00295470760),
 (0.00000009721,  4.23925865260,     1349.86740965880),
 (0.00000009969,  1.30263423409,     6286.59896834040),
 (0.00000009452,  2.69956827011,      242.72860397400),
 (0.00000012461,  2.83432282119,     1748.01641306700),
 (0.00000011808,  5.27379760438,     1194.44701022460),
 (0.00000008577,  5.64476085980,      951.71840625060),
 (0.00000010641,  0.76614722966,      553.56940284240),
 (0.00000007576,  5.30056172859,     2352.86615377180),
 (0.00000005764,  1.77228445837,     1059.38193018920),
 (0.00000006385,  2.65034514038,     9437.76293488700),
 (0.00000005223,  5.66135782131,    71430.69561812909),
 (0.00000005315,  0.91110018969,     3154.68708489560),
 (0.00000006101,  4.66633726278,     4690.47983635860),
 (0.00000004335,  0.23934560382,     6812.76681508600),
 (0.00000005041,  1.42489704722,     6438.49624942560),
 (0.00000004259,  0.77355543889,    10447.38783960440),
 (0.00000005200,  1.85528830215,      801.82093112380),
 (0.00000003744,  2.00119905572,     8031.09226305840),
 (0.00000003553,  2.42789590229,    14143.49524243060),
 (0.00000003372,  3.86210786421,     1592.59601363280),
 (0.00000003380,  0.88545388924,    12036.46073488820),
 (0.00000003196,  3.19713328141,     4705.73230754360),
 (0.00000003221,  0.61601048990,     8429.24126646660),
 (0.00000004132,  5.23992584671,     7084.89678111520),
 (0.00000002970,  6.07029819073,     4292.33083295040),
 (0.00000002900,  2.32464208411,       20.35531939880),
 (0.00000003504,  4.79976712702,     6279.55273164240),
 (0.00000002950,  1.43108874817,     5746.27133789600),
 (0.00000002697,  4.80365209201,     7234.79425624200),
 (0.00000002531,  6.22289990904,     6836.64525283380),
 (0.00000002745,  0.93466065396,     5760.49843189760),
 (0.00000003250,  3.39951915286,     7632.94325965020),
 (0.00000002278,  5.00339914806,    17789.84561978500),
 (0.00000002076,  3.95551309007,    10213.28554621100),
 (0.00000002061,  2.22407719190,     5856.47765911540),
 (0.00000002252,  5.67166717686,    11499.65622279280),
 (0.00000002148,  5.20182663314,    11513.88331679440),
 (0.00000001886,  0.53198539077,     3340.61242669980),
 (0.00000001875,  4.73511969924,    83996.84731811189),
 (0.00000002060,  2.54985307819,    25132.30339996560),
 (0.00000001794,  1.47435300254,     4164.31198961300),
 (0.00000001778,  3.02473091781,        5.52292430740),
 (0.00000002036,  0.90908165072,     6256.77753019160),
 (0.00000002064,  2.27051326957,      522.57741809380),
 (0.00000001773,  3.03090500693,     5753.38488489680),
 (0.00000001569,  6.12406216872,     5216.58037280140),
 (0.00000001590,  4.63713748247,        3.28635741780),
 (0.00000001533,  4.20305593883,    13367.97263110660),
 (0.00000001427,  1.19087535126,     3894.18182954220),
 (0.00000001376,  4.24955891338,      426.59819087600),
 (0.00000001375,  3.09301252193,      135.06508003540),
 (0.00000001308,  3.08492138890,     5643.17856367740),
 (0.00000001340,  5.76513167968,     6040.34724601740),
 (0.00000001250,  3.07748196332,    11926.25441366880),
 (0.00000001551,  3.07664090662,     6681.22485339960),
 (0.00000001148,  3.24144202282,    12168.00269657460),
 (0.00000001268,  2.09201189992,     6290.18939699220),
 (0.00000001248,  3.44506939791,      536.80451209540),
 (0.00000001118,  2.31830078762,    16730.46368959580),
 (0.00000001105,  5.31966001019,       23.87843774780),
 (0.00000001012,  3.74953487087,     7860.41939243920),
 (0.00000001025,  2.44683771610,     1990.74501704100),
 (0.00000000962,  0.81771017882,        3.88133535800),
 (0.00000000911,  0.41724352112,     7079.37385680780),
 (0.00000001091,  3.98233608618,    11506.76976979360),
 (0.00000000957,  4.07671436153,     6127.65545055720),
 (0.00000000835,  5.28348689371,    11790.62908865880),
 (0.00000000802,  3.88779080089,    10973.55568635000),
 (0.00000000773,  2.41044394817,     1589.07289528380),
 (0.00000000758,  1.30034365873,      103.09277421860),
 (0.00000000749,  4.96281442361,     6496.37494542940),
 (0.00000000765,  3.36312388424,       36.02786667740),
 (0.00000000915,  5.41549763095,      206.18554843720),
 (0.00000000776,  2.57589060224,    11371.70468975820),
 (0.00000000772,  3.98363364977,      955.59974160860),
 (0.00000000749,  5.17900231417,    10969.96525769820),
 (0.00000000806,  0.34226117299,     9917.69687450980),
 (0.00000000728,  5.20962563787,       38.02767263580),
 (0.00000000685,  2.77592961854,       20.77539549240),
 (0.00000000636,  4.28242193632,       28.44918746780),
 (0.00000000608,  5.63278510221,    10984.19235169980),
 (0.00000000704,  5.60739437733,     3738.76143010800),
 (0.00000000685,  0.38876148682,       15.25247118500),
 (0.00000000601,  0.73489602442,      419.48464387520),
 (0.00000000716,  2.65286869987,     6309.37416979120),
 (0.00000000584,  5.54508741381,    17298.18232732620),
 (0.00000000628,  1.11733054796,     7058.59846131540),
 (0.00000000688,  2.59684132401,     3496.03282613400),
 (0.00000000485,  0.44470714066,    12352.85260454480),
 (0.00000000562,  2.82510352358,     3930.20969621960),
 (0.00000000597,  5.27675789973,    10575.40668294180),
 (0.00000000583,  3.18931539860,     4732.03062734340),
 (0.00000000526,  5.01737745304,     5884.92684658320),
 (0.00000000540,  1.29182747488,      640.87760738220),
 (0.00000000481,  5.49721461067,     5230.80746680300),
 (0.00000000406,  5.21253018484,      220.41264243880),
 (0.00000000395,  1.87489912123,    16200.77272450120),
 (0.00000000367,  0.88533542945,     6283.14316029419),
 (0.00000000369,  3.84778078192,    18073.70493865020),
 (0.00000000379,  0.37991716505,    10177.25767953360),
 (0.00000000356,  3.84152910109,    11712.95531823080),
 (0.00000000374,  5.01577520608,        7.04623669800),
 (0.00000000381,  4.30250406634,     6062.66320755260),
 (0.00000000471,  0.86388942467,     6069.77675455340),
 (0.00000000367,  1.32943839930,     6283.00853968860),
 (0.00000000460,  5.19667219582,     6284.05617105960),
 (0.00000000333,  5.54250425107,     4686.88940770680),
 (0.00000000341,  4.36524495363,     7238.67559160000),
 (0.00000000336,  4.00205876835,     3097.88382272579),
 (0.00000000359,  6.22679790284,      245.83164622940),
 (0.00000000307,  2.35299010924,      170.67287061920),
 (0.00000000343,  3.77164927142,     6076.89030155420),
 (0.00000000296,  5.44138799494,    17260.15465469040),
 (0.00000000328,  0.13817705132,    11015.10647733480),
 (0.00000000269,  1.13308244952,    12569.67481833180),
 (0.00000000263,  0.00550737510,     4136.91043351620),
 (0.00000000282,  5.04399588559,     7477.52286021600),
 (0.00000000280,  3.13703211405,    12559.03815298200),
 (0.00000000259,  0.93882269388,     5642.19824260920),
 (0.00000000292,  1.98426314297,    12132.43996210600),
 (0.00000000247,  3.84244798673,     5429.87946823940),
 (0.00000000319,  5.04170148790,    90617.73743129970),
 (0.00000000245,  5.70469737024,    65147.61976813770),
 (0.00000000318,  1.35581968834,    78051.58573131690),
 (0.00000000241,  0.99469787369,     3634.62102451840),
 (0.00000000246,  3.06168069393,      110.20632121940),
 (0.00000000239,  6.11854529589,    11856.21865142450),
 (0.00000000267,  0.65297608414,    21228.39202354580),
 (0.00000000262,  1.51070507866,    12146.66705610760),
 (0.00000000230,  1.75923794017,     9779.10867612540),
 (0.00000000223,  2.00967043606,     6172.86952877200),
 (0.00000000246,  1.10411690861,     6282.09552892320),
 (0.00000000214,  4.03840492266,    14314.16811304980),
 (0.00000000212,  2.13695623228,     5849.36411211460),
 (0.00000000207,  3.07724246401,       11.72935283600),
 (0.00000000207,  6.10303325026,    23543.23050468179),
 (0.00000000266,  1.00720021877,     2388.89402044920),
 (0.00000000217,  6.27840212312,    17267.26820169119),
 (0.00000000231,  5.37372783468,    13916.01910964160),
 (0.00000000204,  2.34615348695,      266.60704172180),
 (0.00000000195,  5.55015549753,     6133.51265285680),
 (0.00000000203,  4.65616806503,    24072.92146977640),
 (0.00000000188,  2.52682282169,     6525.80445396540),
 (0.00000000177,  1.73426919199,   154717.60988768269),
 (0.00000000187,  4.76501318048,     4535.05943692440),
 (0.00000000186,  4.63080493407,    10440.27429260360),
 (0.00000000183,  3.20060840641,     8635.94200376320),
 (0.00000000172,  1.45551703877,     9225.53927328300),
 (0.00000000162,  3.30665137166,      639.89728631400),
 (0.00000000168,  2.17671416605,       27.40155609680),
 (0.00000000160,  1.68168712750,    15110.46611986620),
 (0.00000000194,  2.79243768345,     7342.45778018060),
 (0.00000000183,  0.56273524797,    13517.87010623340),
 (0.00000000172,  5.97039514134,     4701.11650170840),
 (0.00000000179,  3.58450811616,       87.30820453981),
 (0.00000000152,  2.84070476839,     5650.29211067820),
 (0.00000000156,  1.07156076421,    18319.53658487960),
 (0.00000000182,  0.44053620124,    17253.04110768959),
 (0.00000000142,  1.46290137520,    11087.28512591840),
 (0.00000000131,  5.40912137746,     2699.73481931760),
 (0.00000000144,  2.07312089638,    25158.60171976540),
 (0.00000000147,  6.15107800602,     9623.68827669120),
 (0.00000000141,  5.55739979498,    10454.50138660520),
 (0.00000000135,  0.06098129430,    16723.35014259500),
 (0.00000000123,  5.81194797368,    17256.63153634140),
 (0.00000000124,  2.36269386269,     4933.20844033260),
 (0.00000000126,  3.47483886466,    22483.84857449259),
 (0.00000000159,  5.63944722033,     5729.50644714900),
 (0.00000000137,  1.93811728826,    20426.57109242200),
 (0.00000000123,  3.92815962825,    17996.03116822220),
 (0.00000000148,  3.02542567608,     1551.04522264800),
 (0.00000000121,  0.05537321071,    13095.84266507740),
 (0.00000000120,  5.91904349732,     6206.80977871580),
 (0.00000000134,  3.11122937825,    21954.15760939799),
 (0.00000000119,  5.52143897201,      709.93304855830),
 (0.00000000122,  3.00840036775,    19800.94595622480),
 (0.00000000127,  1.37534182407,    14945.31617355440),
 (0.00000000141,  2.56886299638,     1052.26838318840),
 (0.00000000123,  2.83671175442,    11919.14086666800),
 (0.00000000118,  0.81918292547,     5331.35744374080),
 (0.00000000151,  2.68728567951,    11769.85369316640),
 (0.00000000119,  5.08654046247,     5481.25491886760),
 (0.00000000113,  4.42675663942,    18422.62935909819),
 (0.00000000153,  2.46021790779,    11933.36796066960),
 (0.00000000108,  1.04936452151,    11403.67699557500),
 (0.00000000128,  0.99810456461,     8827.39026987480),
 (0.00000000144,  2.54869747042,      227.47613278900),
 (0.00000000150,  4.50631437136,     2379.16447357160),
 (0.00000000109,  0.29269062317,    16737.57723659660),
 (0.00000000122,  4.23040027813,       29.42950853600),
 (0.00000000111,  5.16970710025,    17782.73207278420),
 (0.00000000105,  1.61738153441,    13119.72110282519),
 (0.00000000100,  3.52204690579,    18052.92954315780),
 (0.00000000108,  1.08493117155,    16858.48253293320),
 (0.00000000135,  3.20160616970,     6262.30045449900),
 (0.00000000106,  1.96085069786,       74.78159856730),
 (0.00000000129,  4.85949366504,    16496.36139620240),
 (0.00000000110,  2.30605777952,    16460.33352952499),
 (0.00000000097,  3.50918940210,     5333.90024102160),
 (0.00000000099,  3.56417337974,      735.87651353180),
 (0.00000000096,  3.40918487598,    15720.83878487840),
 (0.00000000094,  5.01601027363,     3128.38876509580),
 (0.00000000097,  1.65579893894,      533.21408344360),
 (0.00000000092,  0.89219199493,    29296.61538957860),
 (0.00000000123,  3.16062062663,     9380.95967271720),
 (0.00000000102,  1.20493500565,    23020.65308658799),
 (0.00000000088,  2.21265504437,    12721.57209941700),
 (0.00000000089,  1.54322669570,    20199.09495963300),
 (0.00000000121,  6.19860353182,     9388.00590941520),
 (0.00000000089,  4.08082274765,    22805.73556599360),
 (0.00000000098,  1.09176668094,    12043.57428188900),
 (0.00000000086,  1.13649001466,   143571.32428481648),
 (0.00000000088,  5.96980472191,      107.66352393860),
 (0.00000000082,  5.01561173481,    22003.91463486980),
 (0.00000000094,  1.69615700473,    23006.42599258639),
 (0.00000000081,  3.00664741995,     2118.76386037840),
 (0.00000000098,  1.39215287161,     8662.24032356300),
 (0.00000000080,  5.16340988714,    17796.95916678580),
 (0.00000000082,  5.86893959287,     2787.04302385740),
 (0.00000000077,  0.80723694712,   167283.76158766549),
 (0.00000000091,  5.74902425304,    21424.46664430340),
 (0.00000000076,  5.67183650604,       14.22709400160),
 (0.00000000081,  6.16619455699,     1039.02661079040),
 (0.00000000076,  3.21449884756,      111.18664228760),
 (0.00000000078,  1.37531518377,    21947.11137270000),
 (0.00000000074,  3.58814195051,    11609.86254401220),
 (0.00000000077,  4.84846488388,    22743.40937951640),
 (0.00000000090,  1.48869013606,    15671.08175940660),
 (0.00000000082,  3.48618398216,    29088.81141598500),
 (0.00000000071,  2.21591561190,    12029.34718788740),
 (0.00000000069,  1.93625656075,      135.62532501000),
 (0.00000000070,  2.66552760898,    18875.52586977400),
 (0.00000000069,  5.41478093731,    26735.94526221320),
 (0.00000000079,  5.15158156951,    12323.42309600880),
 (0.00000000078,  4.17014063638,     1066.49547719000),
 (0.00000000065,  5.64584720343,    12139.55350910680),
 (0.00000000071,  3.89804774037,    22779.43724619380),
 (0.00000000063,  4.53968787714,     8982.81066930900),
 (0.00000000076,  3.29088891716,     2942.46342329160),
 (0.00000000069,  0.94232113005,    14919.01785375460),
 (0.00000000063,  4.09186535490,    16062.18452611680),
 (0.00000000065,  3.34580407184,       51.28033786241),
 (0.00000000065,  5.75757544877,    52670.06959330260),
 (0.00000000057,  5.25050277534,    20995.39296644940),
 (0.00000000061,  1.92290673861,     6805.65326808520),
 (0.00000000061,  0.08878901558,    13362.44970679920),
 (0.00000000076,  1.86947679415,    25287.72379939980),
 (0.00000000056,  4.25396542622,     6709.67404086740),
 (0.00000000058,  4.79429715781,     6286.36220740920),
 (0.00000000073,  0.53299090807,     2301.58581590939),
 (0.00000000070,  4.31243357502,    19402.79695281660),
 (0.00000000067,  2.53852336668,      377.37360791580),
 (0.00000000056,  3.20816844695,    24889.57479599160),
 (0.00000000054,  5.17336469511,    26084.02180621620),
 (0.00000000053,  3.17675406016,    18451.07854656599),
 (0.00000000053,  3.61529270216,       77.67377042800),
 (0.00000000053,  0.45467549335,    30666.15495843280),
 (0.00000000053,  2.97761644192,    21548.96236929180),
 (0.00000000061,  0.14805728543,    23013.53953958720),
 (0.00000000051,  3.32803972907,       56.89837493560),
 (0.00000000052,  3.41304011355,    23141.55838292460),
 (0.00000000058,  3.13638677202,      309.27832265580),
 (0.00000000054,  1.60896548545,    13341.67431130680),
 (0.00000000053,  5.81426394852,    16193.65917750039),
 (0.00000000067,  6.27917920454,    22345.26037610820),
 (0.00000000050,  0.42577644151,    25685.87280280800),
 (0.00000000048,  0.70204553352,     1162.47470440780),
 (0.00000000066,  3.64350022359,    15265.88651930040),
 (0.00000000050,  5.74382917440,       19.66976089979),
 (0.00000000054,  1.97277370837,    23581.25817731760),
 (0.00000000051,  1.23713196525,    12539.85338018300),
 (0.00000000046,  5.41431704639,    33019.02111220460),
 (0.00000000046,  4.80640843261,    19651.04848109800),
 (0.00000000050,  1.23847511223,    22476.73502749179),
 (0.00000000051,  4.91913434178,    12592.45001978260),
 (0.00000000046,  2.41369976086,    98068.53671630539),
 (0.00000000045,  3.45227074337,    30774.50164257480),
 (0.00000000045,  4.39659083856,      433.71173787680),
 (0.00000000045,  3.71921056816,    18209.33026366019),
 (0.00000000044,  2.47683925106,    24356.78078864160),
 (0.00000000049,  2.17835058609,    13521.75144159140),
 (0.00000000046,  0.26142733448,       11.04570026390),
 (0.00000000045,  2.46230645202,    51868.24866217880),
 (0.00000000043,  4.29458463014,    28230.18722269139),
 (0.00000000048,  0.89551707131,    56600.27928952220),
 (0.00000000042,  3.63410684699,     4590.91018048900),
 (0.00000000049,  3.17757670967,     6303.85124548380),
 (0.00000000043,  4.93350349236,    10021.83728009940),
 (0.00000000052,  3.65410195699,     7872.14874527520),
 (0.00000000041,  4.82166756935,    10988.80815753500),
 (0.00000000040,  1.81891629936,    34596.36465465240),
 (0.00000000043,  1.94164978061,     1903.43681250120),
 (0.00000000041,  0.74461854136,    23937.85638974100),
 (0.00000000045,  5.45575017530,    60530.48898574180),
 (0.00000000050,  5.67355640472,    18216.44381066100),
 (0.00000000040,  0.04502010161,    38526.57435087200),
 (0.00000000053,  3.64807615995,    11925.27409260060),
 (0.00000000042,  5.19292937193,    19004.64794940840),
 (0.00000000041,  0.94309683296,     9924.81042151060),
 (0.00000000039,  4.61184303844,       95.97922721780),
 (0.00000000049,  2.05532526216,    12573.26524698360),
 (0.00000000045,  3.73717824543,     7875.67186362420),
 (0.00000000043,  1.14078465002,       49.75702547180),
 (0.00000000039,  1.70539366023,    32217.20018108080),
 (0.00000000037,  1.29390383811,      310.84079886840),
 (0.00000000038,  0.95970925950,      664.75604513000),
 (0.00000000039,  0.85957361635,    16522.65971600220),
 (0.00000000040,  1.00170796001,    36949.23080842420),
 (0.00000000040,  3.78164718776,    55798.45835839840),
 (0.00000000037,  5.42237070904,     6286.66627864320),
 (0.00000000036,  1.68167662194,    10344.29506538580),
 (0.00000000040,  5.13217319067,    15664.03552270859),
 (0.00000000049,  3.62741283878,    77713.77146812050),
 (0.00000000045,  6.15877872538,    28286.99048486120),
 (0.00000000036,  3.32158458257,    16207.88627150200),
 (0.00000000035,  5.83917764292,     6321.10352262720),
 (0.00000000036,  1.80784164083,     6279.78949257360),
 (0.00000000035,  4.60279245362,    28237.23345938940),
 (0.00000000033,  0.47301775923,    18635.92845453620),
 (0.00000000035,  4.36571027474,    48739.85989708300),
 (0.00000000031,  3.06828028412,     6819.88036208680),
 (0.00000000031,  2.40203198480,    28628.33622609960),
 (0.00000000034,  1.90096411242,    12964.30070339100),
 (0.00000000029,  6.09291010354,    18606.49894600020),
 (0.00000000028,  3.42046112698,     6288.59877429880),
 (0.00000000028,  3.43736140600,    34115.11406927460),
 (0.00000000029,  1.48920816078,     6489.26139842860),
 (0.00000000028,  3.07474749886,    29822.78323632420),
 (0.00000000038,  2.44608264663,    31415.37924995700),
 (0.00000000028,  2.98392582088,     6277.55292568400),
 (0.00000000027,  5.03556015623,    12779.45079542080),
 (0.00000000027,  5.40812977287,    26087.90314157420),
 (0.00000000038,  5.56439937893,    27832.03821928320),
 (0.00000000026,  3.87685883153,     6262.72053059260),
 (0.00000000027,  6.15565392840,    28759.81087748319),
 (0.00000000025,  5.17122153205,     6915.85958930460),
 (0.00000000027,  4.03132006944,     9910.58332750900),
 (0.00000000033,  3.97763407373,    12410.73130054860),
 (0.00000000024,  5.31307120044,    29026.48522950779),
 (0.00000000025,  0.81055213297,    36173.70819710020),
 (0.00000000024,  1.28706101310,    24491.42579258340),
 (0.00000000021,  2.02548478742,    28766.92442448400),
 (0.00000000021,  6.07545114034,    18139.29450141590),
 (0.00000000022,  2.31199937131,     6303.43116939020),
 (0.00000000023,  1.35235057478,    49515.38250840700),
 (0.00000000023,  2.92765926961,    65236.22129328540),
 (0.00000000019,  0.03636659763,    29864.33402730900),
 (0.00000000020,  0.91374066194,    45585.17281218740),
 (0.00000000021,  4.45003013294,    22490.96212149340),
 (0.00000000022,  1.97119365888,    34513.26307268280),
 (0.00000000020,  4.11682669951,    17157.06188047180),
 (0.00000000024,  1.40243942415,    14712.31711645800),
 (0.00000000022,  2.19759737115,    31570.79964939120),
 (0.00000000021,  1.48739821208,    61306.01159706580),
 (0.00000000025,  5.71465573409,    25934.12433108940));
SX2: array[1..KX2,1..3] of double =
((0.00008721859,  1.07253635559,     6283.07584999140),
 (0.00000990990,  3.14159265359,        0.00000000000),
 (0.00000294833,  0.43717350256,    12566.15169998280),
 (0.00000027338,  0.05295636147,        3.52311834900),
 (0.00000016333,  5.18820215724,       26.29831979980),
 (0.00000015745,  3.68504712183,      155.42039943420),
 (0.00000009425,  0.29667114694,    18849.22754997420),
 (0.00000008938,  2.05706319592,    77713.77146812050),
 (0.00000006940,  0.82691541038,      775.52261132400),
 (0.00000005061,  4.66243231680,     1577.34354244780),
 (0.00000004060,  1.03067032318,        7.11354700080),
 (0.00000003464,  5.14021224609,      796.29800681640),
 (0.00000003172,  6.05479318507,     5507.55323866740),
 (0.00000003020,  1.19240008524,      242.72860397400),
 (0.00000002885,  6.11705865396,      529.69096509460),
 (0.00000003809,  3.44043369494,     5573.14280143310),
 (0.00000002719,  0.30363248164,      398.14900340820),
 (0.00000002365,  4.37666117992,     5223.69391980220),
 (0.00000002538,  2.27966434314,      553.56940284240),
 (0.00000002078,  3.75435095487,        0.98032106820),
 (0.00000001675,  0.90149951436,      951.71840625060),
 (0.00000001534,  5.75895831192,     1349.86740965880),
 (0.00000001224,  2.97285792195,     2146.16541647520),
 (0.00000001449,  4.36401639552,     1748.01641306700),
 (0.00000001341,  3.72019379666,     1194.44701022460),
 (0.00000001253,  2.94888726310,     6438.49624942560),
 (0.00000000999,  5.98665341008,     6286.59896834040),
 (0.00000000917,  4.79722195184,     5088.62883976680),
 (0.00000000829,  3.31021398862,      213.29909543800),
 (0.00000001102,  1.27094359244,   161000.68573767410),
 (0.00000000764,  3.41231607038,     5486.77784317500),
 (0.00000001046,  0.60374190029,     3154.68708489560),
 (0.00000000887,  5.23364022595,     7084.89678111520),
 (0.00000000644,  1.59974355582,     2544.31441988340),
 (0.00000000681,  3.42742947469,     4694.00295470760),
 (0.00000000606,  2.47688996663,    10977.07880469900),
 (0.00000000706,  6.19369692903,     4690.47983635860),
 (0.00000000643,  1.98119869589,      801.82093112380),
 (0.00000000502,  1.44415463861,     6836.64525283380),
 (0.00000000490,  2.33889753806,     1592.59601363280),
 (0.00000000458,  1.30867922972,     4292.33083295040),
 (0.00000000431,  0.03542536476,     7234.79425624200),
 (0.00000000349,  0.98779272263,     6040.34724601740),
 (0.00000000385,  1.57065592218,    71430.69561812909),
 (0.00000000371,  3.16149051601,     6309.37416979120),
 (0.00000000348,  0.64980950594,     1059.38193018920),
 (0.00000000458,  3.81505682017,   149854.40013480789),
 (0.00000000302,  1.91723873447,    10447.38783960440),
 (0.00000000306,  3.55405857884,     8031.09226305840),
 (0.00000000395,  4.93742673052,     7632.94325965020),
 (0.00000000314,  3.18058352846,     2352.86615377180),
 (0.00000000281,  4.41751404023,     9437.76293488700),
 (0.00000000276,  2.71075791682,     3894.18182954220),
 (0.00000000298,  2.52045757001,     6127.65545055720),
 (0.00000000272,  0.24370191144,    25132.30339996560),
 (0.00000000251,  0.55449375765,     6279.55273164240),
 (0.00000000224,  1.40790249012,     4705.73230754360),
 (0.00000000258,  5.29510765044,     6812.76681508600),
 (0.00000000178,  0.92636669742,     1990.74501704100),
 (0.00000000217,  0.68543630022,     6256.77753019160),
 (0.00000000154,  0.77808632062,    14143.49524243060),
 (0.00000000150,  2.40636982736,      426.59819087600),
 (0.00000000196,  6.06877865012,      640.87760738220),
 (0.00000000137,  2.21947617717,     8429.24126646660),
 (0.00000000127,  5.47380312768,    12036.46073488820),
 (0.00000000121,  3.32740512021,    17789.84561978500),
 (0.00000000123,  2.16004509785,    10213.28554621100),
 (0.00000000116,  0.49705139709,     7058.59846131540),
 (0.00000000138,  2.36181661472,    11506.76976979360),
 (0.00000000101,  0.86299995919,     6290.18939699220),
 (0.00000000118,  5.82317768355,     7860.41939243920),
 (0.00000000092,  5.11639978593,     7079.37385680780),
 (0.00000000125,  2.65424538513,    88860.05707098669),
 (0.00000000088,  4.31188236160,    83996.84731811189),
 (0.00000000084,  3.57682769713,    16730.46368959580),
 (0.00000000097,  5.58011309774,    13367.97263110660),
 (0.00000000102,  2.05853060226,       87.30820453981),
 (0.00000000080,  4.73827128421,    11926.25441366880),
 (0.00000000080,  5.41344057121,    10973.55568635000),
 (0.00000000106,  4.10978997399,     3496.03282613400),
 (0.00000000075,  4.89166898876,     5643.17856367740),
 (0.00000000100,  3.62645659087,   244287.60000722769),
 (0.00000000096,  1.39443577787,     6681.22485339960),
 (0.00000000069,  1.88399189965,    10177.25767953360),
 (0.00000000087,  0.40842153208,    11015.10647733480),
 (0.00000000066,  0.99444831932,     6525.80445396540),
 (0.00000000066,  1.42471816453,     9917.69687450980),
 (0.00000000067,  5.51240997070,     3097.88382272579),
 (0.00000000076,  2.71564693510,     4164.31198961300),
 (0.00000000085,  0.49655523670,    10575.40668294180),
 (0.00000000077,  3.51693861509,    11856.21865142450),
 (0.00000000062,  3.62587628690,    16496.36139620240),
 (0.00000000054,  5.25957420065,     3340.61242669980),
 (0.00000000053,  1.10902178415,     8635.94200376320),
 (0.00000000049,  5.65761054625,    20426.57109242200),
 (0.00000000064,  5.79211164779,     2388.89402044920),
 (0.00000000046,  5.45092696155,     6275.96230299060),
 (0.00000000057,  4.97077155798,    14945.31617355440),
 (0.00000000043,  3.30685683359,     9779.10867612540),
 (0.00000000042,  1.61412785248,    12168.00269657460),
 (0.00000000049,  3.92715473768,     5729.50644714900),
 (0.00000000042,  0.63481258930,     2699.73481931760),
 (0.00000000056,  4.34038639086,    90955.55169449610),
 (0.00000000040,  5.66871428338,    11712.95531823080),
 (0.00000000039,  3.10911294009,    16200.77272450120),
 (0.00000000040,  5.71338386146,      709.93304855830),
 (0.00000000053,  6.17067257683,   233141.31440436149),
 (0.00000000037,  0.32095173508,    24356.78078864160),
 (0.00000000035,  0.95557073457,    17298.18232732620),
 (0.00000000035,  0.64913397996,    25158.60171976540),
 (0.00000000041,  1.53850422484,    65147.61976813770),
 (0.00000000035,  0.77655626359,    13916.01910964160),
 (0.00000000031,  5.35897350775,     5331.35744374080),
 (0.00000000030,  4.48114682755,    23543.23050468179),
 (0.00000000032,  3.45976963453,     7477.52286021600),
 (0.00000000029,  3.46648040769,    13119.72110282519),
 (0.00000000038,  2.90863974625,    12721.57209941700),
 (0.00000000029,  3.13390968321,     4136.91043351620),
 (0.00000000035,  3.79717126309,   143571.32428481648),
 (0.00000000027,  0.95726093828,    12559.03815298200),
 (0.00000000026,  4.95326877030,     5753.38488489680),
 (0.00000000032,  3.49943896928,     6284.05617105960),
 (0.00000000026,  4.59276256636,     5884.92684658320),
 (0.00000000026,  1.53958920253,   154717.60988768269),
 (0.00000000023,  4.88012908735,    13095.84266507740),
 (0.00000000023,  0.35935706511,    31415.37924995700),
 (0.00000000024,  5.11515116629,    18319.53658487960),
 (0.00000000021,  5.73872879912,    12569.67481833180),
 (0.00000000021,  1.32901200081,    10988.80815753500),
 (0.00000000019,  2.24263229491,    18073.70493865020),
 (0.00000000019,  3.14253175605,     6496.37494542940),
 (0.00000000021,  2.80122025076,     6282.09552892320),
 (0.00000000023,  0.14288760398,     6283.00853968860),
 (0.00000000019,  4.28209473754,     3930.20969621960),
 (0.00000000016,  0.25933207663,    11790.62908865880),
 (0.00000000015,  6.09623501240,    13517.87010623340),
 (0.00000000020,  5.06358906224,     6283.14316029419),
 (0.00000000015,  1.07680663150,     4933.20844033260),
 (0.00000000019,  5.74000581249,     3128.38876509580),
 (0.00000000016,  6.18924226747,     7342.45778018060),
 (0.00000000013,  1.69105044945,     4535.05943692440),
 (0.00000000015,  3.36968394452,    17260.15465469040),
 (0.00000000010,  3.78885035015,    22003.91463486980),
 (0.00000000011,  2.12851973876,     7875.67186362420));
SX3: array[1..KX3,1..3] of double =
((0.00000289058,  5.84173149732,     6283.07584999140),
 (0.00000020712,  6.04983939020,    12566.15169998280),
 (0.00000002962,  5.19560579570,      155.42039943420),
 (0.00000002527,  3.14159265359,        0.00000000000),
 (0.00000001288,  4.72197611970,        3.52311834900),
 (0.00000000635,  5.96904899168,      242.72860397400),
 (0.00000000570,  5.54182903238,    18849.22754997420),
 (0.00000000402,  3.78606612895,      553.56940284240),
 (0.00000000072,  4.37131884946,     6286.59896834040),
 (0.00000000067,  0.91133898967,     6127.65545055720),
 (0.00000000037,  5.28611190997,     6438.49624942560),
 (0.00000000021,  2.94917211527,     6309.37416979120),
 (0.00000000015,  3.63037493932,    71430.69561812909),
 (0.00000000011,  4.83261533939,    25132.30339996560),
 (0.00000000011,  5.84259014283,     6525.80445396540),
 (0.00000000012,  3.82296977522,     7058.59846131540),
 (0.00000000013,  2.39991715131,     5729.50644714900),
 (0.00000000008,  0.55390332094,     6040.34724601740),
 (0.00000000008,  1.46298993048,    11856.21865142450),
 (0.00000000008,  5.07535888338,     6256.77753019160),
 (0.00000000006,  2.88803526743,     5507.55323866740),
 (0.00000000005,  3.87019253131,    12036.46073488820),
 (0.00000000005,  2.70838853362,    83996.84731811189));
SX4: array[1..KX4,1..3] of double =
((0.00000007714,  4.14117321449,     6283.07584999140),
 (0.00000001016,  3.27573644241,    12566.15169998280),
 (0.00000000420,  0.41892851415,      155.42039943420),
 (0.00000000047,  3.50591071186,    18849.22754997420),
 (0.00000000041,  3.14032562331,        3.52311834900),
 (0.00000000035,  5.01110770000,     5573.14280143310),
 (0.00000000010,  5.64816633449,     6127.65545055720),
 (0.00000000013,  0.48609240774,    77713.77146812050),
 (0.00000000007,  2.84139222289,   161000.68573767410),
 (0.00000000004,  3.65509047070,    25132.30339996560),
 (0.00000000002,  0.54880603487,     6438.49624942560));
SX5: array[1..KX5,1..3] of double =
((0.00000000172,  2.74854172392,     6283.07584999140),
 (0.00000000050,  2.01352986713,      155.42039943420),
 (0.00000000028,  2.93369985477,    12566.15169998280),
 (0.00000000005,  1.93829214518,    18849.22754997420));

SY0: array[1..KY0,1..3] of double =
((0.00000279620,  3.19870156017,    84334.66158130829),
 (0.00000101643,  5.42248619256,     5507.55323866740),
 (0.00000080445,  3.88013204458,     5223.69391980220),
 (0.00000043806,  3.70444689759,     2352.86615377180),
 (0.00000031933,  4.00026369781,     1577.34354244780),
 (0.00000022724,  3.98473831560,     1047.74731175470),
 (0.00000016392,  3.56456119782,     5856.47765911540),
 (0.00000018141,  4.98367470262,     6283.07584999140),
 (0.00000014443,  3.70275614915,     9437.76293488700),
 (0.00000014304,  3.41117857526,    10213.28554621100),
 (0.00000011246,  4.82820690527,    14143.49524243060),
 (0.00000010900,  2.08574562329,     6812.76681508600),
 (0.00000009714,  3.47303947751,     4694.00295470760),
 (0.00000010367,  4.05663927945,    71092.88135493269),
 (0.00000008775,  4.44016515666,     5753.38488489680),
 (0.00000008366,  4.99251512183,     7084.89678111520),
 (0.00000006921,  4.32559054073,     6275.96230299060),
 (0.00000009145,  1.14182646613,     6620.89011318780),
 (0.00000007194,  3.60193205744,      529.69096509460),
 (0.00000007698,  5.55425745881,   167621.57585086189),
 (0.00000005285,  2.48446991536,     4705.73230754360),
 (0.00000005208,  6.24992674532,    18073.70493865020),
 (0.00000004529,  2.33827747356,     6309.37416979120),
 (0.00000005579,  4.41023653719,     7860.41939243920),
 (0.00000004743,  0.70995680136,     5884.92684658320),
 (0.00000004301,  1.10255777773,     6681.22485339960),
 (0.00000003849,  1.82229412532,     5486.77784317500),
 (0.00000004093,  5.11700141197,    13367.97263110660),
 (0.00000003681,  0.43793170336,     3154.68708489560),
 (0.00000003420,  5.42034800952,     6069.77675455340),
 (0.00000003617,  6.04641937568,     3930.20969621960),
 (0.00000003670,  4.58210192227,    12194.03291462090),
 (0.00000002918,  1.95463881136,    10977.07880469900),
 (0.00000002797,  5.61259274877,    11790.62908865880),
 (0.00000002502,  0.60499729368,     6496.37494542940),
 (0.00000002319,  5.01648216088,     1059.38193018920),
 (0.00000002684,  1.39470396487,    22003.91463486980),
 (0.00000002428,  3.24183056545,    78051.58573131690),
 (0.00000002120,  4.30691000285,     5643.17856367740),
 (0.00000002257,  3.15557225087,    90617.73743129970),
 (0.00000001813,  3.75574218286,     3340.61242669980),
 (0.00000002226,  2.79699346673,    12036.46073488820),
 (0.00000001888,  0.86991545944,     8635.94200376320),
 (0.00000001517,  1.95852055710,      398.14900340820),
 (0.00000001581,  3.19976230948,     5088.62883976680),
 (0.00000001421,  6.25530883828,     2544.31441988340),
 (0.00000001595,  0.25619915132,    17298.18232732620),
 (0.00000001391,  4.69964175574,     7058.59846131540),
 (0.00000001478,  2.81808207569,    25934.12433108940),
 (0.00000001481,  3.65823554610,    11506.76976979360),
 (0.00000001693,  4.95689385293,   156475.29024799570),
 (0.00000001183,  1.29343060777,      775.52261132400),
 (0.00000001114,  2.37889311847,     3738.76143010800),
 (0.00000000994,  4.30088900425,     9225.53927328300),
 (0.00000000924,  3.06451026809,     4164.31198961300),
 (0.00000000867,  0.55606931068,     8429.24126646660),
 (0.00000000988,  5.97286104208,     7079.37385680780),
 (0.00000000824,  1.50984806177,    10447.38783960440),
 (0.00000000915,  0.12635654605,    11015.10647733480),
 (0.00000000742,  1.99159139281,    26087.90314157420),
 (0.00000001039,  3.14159265359,        0.00000000000),
 (0.00000000850,  4.24120016095,    29864.33402730900),
 (0.00000000755,  2.89631873314,     4732.03062734340),
 (0.00000000714,  1.37548118605,     2146.16541647520),
 (0.00000000708,  1.91406542362,     8031.09226305840),
 (0.00000000746,  0.57893808622,      796.29800681640),
 (0.00000000802,  5.12339137235,     2942.46342329160),
 (0.00000000751,  1.67479850166,    21228.39202354580),
 (0.00000000602,  4.09976538900,    64809.80550494129),
 (0.00000000594,  3.49580704849,    16496.36139620240),
 (0.00000000592,  4.59481504319,     4690.47983635860),
 (0.00000000530,  5.73979295194,     8827.39026987480),
 (0.00000000503,  5.66433137112,    33794.54372352860),
 (0.00000000483,  1.57106522322,      801.82093112380),
 (0.00000000438,  0.06707733720,     3128.38876509580),
 (0.00000000423,  2.86944596145,    12566.15169998280),
 (0.00000000504,  3.26207669160,     7632.94325965020),
 (0.00000000552,  1.02926440457,   239762.20451754928),
 (0.00000000427,  3.67434378208,      213.29909543800),
 (0.00000000404,  1.46193297360,    15720.83878487840),
 (0.00000000503,  4.85802444134,     6290.18939699220),
 (0.00000000417,  0.81920713533,     5216.58037280140),
 (0.00000000365,  0.01002966145,    12168.00269657460),
 (0.00000000363,  1.28376436579,     6206.80977871580),
 (0.00000000353,  4.70059133110,     7234.79425624200),
 (0.00000000415,  0.96862624176,     4136.91043351620),
 (0.00000000387,  3.09145061418,    25158.60171976540),
 (0.00000000373,  2.65119262808,     7342.45778018060),
 (0.00000000361,  2.97762937735,     9623.68827669120),
 (0.00000000418,  3.75759994446,     5230.80746680300),
 (0.00000000396,  1.22507712354,     6438.49624942560),
 (0.00000000322,  1.21162178805,     8662.24032356300),
 (0.00000000284,  5.64170320179,     1589.07289528380),
 (0.00000000379,  1.72248432756,    14945.31617355440),
 (0.00000000320,  3.94161159658,     7330.82316174610),
 (0.00000000313,  5.47602376451,     1194.44701022460),
 (0.00000000292,  1.38971327568,    11769.85369316640),
 (0.00000000305,  0.80429352049,    37724.75341974820),
 (0.00000000257,  5.81382810029,      426.59819087600),
 (0.00000000265,  6.10358507671,     6836.64525283380),
 (0.00000000250,  4.56452895547,     7477.52286021600),
 (0.00000000266,  2.62926282354,     7238.67559160000),
 (0.00000000263,  6.22089501237,     6133.51265285680),
 (0.00000000306,  2.79682380532,     1748.01641306700),
 (0.00000000236,  2.46093023707,    11371.70468975820),
 (0.00000000316,  1.62662805006,   250908.49012041549),
 (0.00000000216,  3.68721275185,     5849.36411211460),
 (0.00000000230,  0.36165162947,     5863.59120611620),
 (0.00000000233,  5.03509933618,    20426.57109242200),
 (0.00000000200,  5.86073159059,     4535.05943692440),
 (0.00000000277,  4.65400292395,    82239.16695779889),
 (0.00000000209,  3.72323200803,    10973.55568635000),
 (0.00000000199,  5.05186622555,     5429.87946823940),
 (0.00000000256,  2.40923279886,    19651.04848109800),
 (0.00000000210,  4.50691909144,    29088.81141598500),
 (0.00000000181,  6.00294783127,     4292.33083295040),
 (0.00000000249,  0.12900984422,   154379.79562448629),
 (0.00000000209,  3.87759458541,    17789.84561978500),
 (0.00000000225,  3.18339652605,    18875.52586977400),
 (0.00000000191,  4.53897489216,    18477.10876461230),
 (0.00000000172,  2.09694182730,    13095.84266507740),
 (0.00000000182,  3.16107943487,    16730.46368959580),
 (0.00000000188,  2.22746128596,    41654.96311596780),
 (0.00000000164,  5.18686274999,     5481.25491886760),
 (0.00000000160,  2.49298855020,    12592.45001978260),
 (0.00000000155,  1.59595438224,    10021.83728009940),
 (0.00000000135,  0.21349051305,    10988.80815753500),
 (0.00000000178,  3.80375178044,    23581.25817731760),
 (0.00000000123,  1.66800739151,    15110.46611986620),
 (0.00000000122,  2.72678272224,    18849.22754997420),
 (0.00000000126,  1.17675512872,    14919.01785375460),
 (0.00000000142,  3.95053440992,      337.81426319640),
 (0.00000000116,  6.06340906212,     6709.67404086740),
 (0.00000000137,  3.52143246244,    12139.55350910680),
 (0.00000000136,  2.92179113491,    32217.20018108080),
 (0.00000000110,  3.51203379263,    18052.92954315780),
 (0.00000000147,  4.63371971408,    22805.73556599360),
 (0.00000000108,  5.45280815225,        7.11354700080),
 (0.00000000148,  0.65447253687,    95480.94718417450),
 (0.00000000119,  5.92110458985,    33019.02111220460),
 (0.00000000110,  5.34824206403,      639.89728631400),
 (0.00000000106,  3.71081682614,    14314.16811304980),
 (0.00000000139,  6.17607198262,    24356.78078864160),
 (0.00000000118,  5.59738712949,   161338.50000087050),
 (0.00000000117,  3.65065271640,    45585.17281218740),
 (0.00000000127,  4.74596574209,    49515.38250840700),
 (0.00000000120,  1.04211499785,     6915.85958930460),
 (0.00000000120,  5.60638811846,     5650.29211067820),
 (0.00000000115,  3.10668213303,    14712.31711645800),
 (0.00000000099,  0.69018939930,    12779.45079542080),
 (0.00000000097,  1.07908724794,     9917.69687450980),
 (0.00000000093,  2.62295197146,    17260.15465469040),
 (0.00000000099,  4.45774681732,     4933.20844033260),
 (0.00000000123,  1.37488921994,    28286.99048486120),
 (0.00000000121,  5.19767249869,    27511.46787353720),
 (0.00000000105,  0.87192268229,    77375.95720492408),
 (0.00000000087,  3.93637812950,    17654.78053974960),
 (0.00000000122,  2.23956068680,    83997.09113559539),
 (0.00000000087,  4.18201600921,    22779.43724619380),
 (0.00000000104,  4.59580877285,     1349.86740965880),
 (0.00000000102,  2.83545248595,    12352.85260454480),
 (0.00000000102,  3.97386522171,    10818.13528691580),
 (0.00000000101,  4.32892825818,    36147.40987730040),
 (0.00000000094,  5.00001709338,   150192.21439800429),
 (0.00000000077,  3.97199369300,     1592.59601363280),
 (0.00000000100,  6.07733097102,    26735.94526221320),
 (0.00000000086,  5.26029638250,    28313.28880466100),
 (0.00000000093,  4.31900620254,    44809.65020086340),
 (0.00000000076,  6.22743405935,    13521.75144159140),
 (0.00000000072,  1.55820597747,     6256.77753019160),
 (0.00000000082,  4.95202664555,    10575.40668294180),
 (0.00000000082,  1.69647647075,     1990.74501704100),
 (0.00000000075,  2.29836095644,     3634.62102451840),
 (0.00000000075,  2.66367876557,    16200.77272450120),
 (0.00000000087,  0.26630214764,    31441.67756975680),
 (0.00000000077,  2.25530952876,     5235.32853823670),
 (0.00000000076,  1.09869730334,    12903.96596317920),
 (0.00000000058,  4.28246137794,    12559.03815298200),
 (0.00000000064,  5.51112829602,   173904.65170085328),
 (0.00000000056,  2.60133794851,    73188.37597844210),
 (0.00000000055,  5.81483150022,   143233.51002162008),
 (0.00000000054,  3.38482031504,   323049.11878710288),
 (0.00000000039,  3.28500401937,    71768.50988132549),
 (0.00000000039,  3.11239910096,    96900.81328129109));
SY1: array[1..KY1,1..3] of double =
((0.00227777722,  3.41376620530,     6283.07584999140),
 (0.00003805678,  3.37063423795,    12566.15169998280),
 (0.00003619589,  0.00000000000,        0.00000000000),
 (0.00000071542,  3.32777549735,    18849.22754997420),
 (0.00000007655,  1.79489607186,     5223.69391980220),
 (0.00000008107,  3.89190403643,     5507.55323866740),
 (0.00000006456,  5.19789424750,     2352.86615377180),
 (0.00000003894,  2.15568517178,     6279.55273164240),
 (0.00000003892,  1.53021064904,     6286.59896834040),
 (0.00000003897,  4.87293945629,    10213.28554621100),
 (0.00000003812,  1.43523182316,    12036.46073488820),
 (0.00000003577,  2.32913869227,    83996.84731811189),
 (0.00000003570,  4.92637739003,    71430.69561812909),
 (0.00000003494,  2.20864641831,      529.69096509460),
 (0.00000002421,  6.22876183393,     7860.41939243920),
 (0.00000002056,  3.06747139741,    14143.49524243060),
 (0.00000001399,  0.50107877909,     6309.37416979120),
 (0.00000001417,  3.28454570977,    25132.30339996560),
 (0.00000001544,  1.82062047625,     5856.47765911540),
 (0.00000001457,  1.75339303307,     5884.92684658320),
 (0.00000001497,  2.19673914456,     9437.76293488700),
 (0.00000001549,  5.73650061398,    17789.84561978500),
 (0.00000001277,  3.96721717330,     4705.73230754360),
 (0.00000001038,  2.94818701170,     6256.77753019160),
 (0.00000001018,  2.24114547164,     6681.22485339960),
 (0.00000001021,  1.46795026130,    11790.62908865880),
 (0.00000000916,  3.72965830745,     1059.38193018920),
 (0.00000001156,  6.04591336669,      398.14900340820),
 (0.00000001240,  0.77195902957,     6812.76681508600),
 (0.00000001115,  3.92255876225,    12168.00269657460),
 (0.00000000908,  1.78447918237,     3930.20969621960),
 (0.00000000833,  0.09941579828,    11506.76976979360),
 (0.00000000790,  2.45555993228,      775.52261132400),
 (0.00000000666,  4.40761401665,     5753.38488489680),
 (0.00000000520,  1.60179602491,     4694.00295470760),
 (0.00000000382,  0.26754532042,     1577.34354244780),
 (0.00000000405,  1.97558286872,     6283.00853968860),
 (0.00000000405,  1.53147989887,     6283.14316029419),
 (0.00000000388,  2.59563818411,     7058.59846131540),
 (0.00000000341,  3.61275156842,    13367.97263110660),
 (0.00000000280,  4.63052251735,      796.29800681640),
 (0.00000000276,  0.43350778219,     7079.37385680780),
 (0.00000000311,  5.28219636656,    17260.15465469040),
 (0.00000000275,  5.27597553634,    11769.85369316640),
 (0.00000000286,  2.98639716345,     6275.96230299060),
 (0.00000000251,  2.81315684448,     6290.18939699220),
 (0.00000000239,  5.77837903893,    10977.07880469900),
 (0.00000000228,  0.14375973844,     3738.76143010800),
 (0.00000000227,  2.51020991853,     7084.89678111520),
 (0.00000000211,  4.72029465470,     6496.37494542940),
 (0.00000000234,  3.11535274010,      709.93304855830),
 (0.00000000234,  0.57075817620,    11856.21865142450),
 (0.00000000237,  2.38791907394,      213.29909543800),
 (0.00000000227,  1.12059781634,    12352.85260454480),
 (0.00000000169,  3.20148089605,     5486.77784317500),
 (0.00000000159,  3.14604135756,     8827.39026987480),
 (0.00000000160,  1.14784478002,     5643.17856367740),
 (0.00000000144,  5.23285657431,    78051.58573131690),
 (0.00000000144,  1.16454654602,    90617.73743129970),
 (0.00000000144,  3.81203756929,     6262.30045449900),
 (0.00000000143,  5.97809021355,     6303.85124548380),
 (0.00000000138,  4.29829933273,     1589.07289528380),
 (0.00000000161,  3.03298851492,    20426.57109242200),
 (0.00000000165,  5.09134896587,    17298.18232732620),
 (0.00000000128,  4.41590143012,     6127.65545055720),
 (0.00000000158,  2.00984506334,     5230.80746680300),
 (0.00000000130,  1.44170683802,    12569.67481833180),
 (0.00000000125,  1.69950379498,     3128.38876509580),
 (0.00000000152,  4.96946111415,    65147.61976813770),
 (0.00000000131,  4.24961399629,     6282.09552892320),
 (0.00000000131,  5.54051222995,     6284.05617105960),
 (0.00000000161,  3.32421999691,     6283.31966747490),
 (0.00000000123,  2.93221463795,    15720.83878487840),
 (0.00000000152,  1.56488157456,    18319.53658487960),
 (0.00000000114,  1.89110005546,    18073.70493865020),
 (0.00000000113,  4.95214866677,     4136.91043351620),
 (0.00000000111,  4.79699611405,     8429.24126646660),
 (0.00000000118,  3.06184958762,    22003.91463486980),
 (0.00000000128,  2.09693027395,    12562.62858163380),
 (0.00000000138,  0.84648544836,     6069.77675455340),
 (0.00000000100,  0.41938790104,     5481.25491886760),
 (0.00000000101,  4.43791289246,    19651.04848109800),
 (0.00000000116,  1.87002428935,    77713.77146812050),
 (0.00000000095,  0.68638183645,     3340.61242669980),
 (0.00000000104,  4.90822646457,     8635.94200376320),
 (0.00000000114,  0.36008214928,    23543.23050468179),
 (0.00000000091,  1.17611219310,     9225.53927328300),
 (0.00000000091,  2.74682631104,     5216.58037280140),
 (0.00000000086,  3.09315282195,     1194.44701022460),
 (0.00000000093,  6.27643513190,    12559.03815298200),
 (0.00000000087,  3.64926989547,        7.11354700080),
 (0.00000000083,  0.37008971174,    11371.70468975820),
 (0.00000000098,  4.68473306376,   167283.76158766549),
 (0.00000000098,  0.99865886857,   154717.60988768269),
 (0.00000000086,  4.41152307486,    25934.12433108940),
 (0.00000000098,  4.98209568932,    16496.36139620240),
 (0.00000000085,  2.35438163823,     3154.68708489560),
 (0.00000000083,  0.24859477658,    21228.39202354580),
 (0.00000000076,  5.46661600296,    29864.33402730900),
 (0.00000000069,  3.22045334237,      801.82093112380),
 (0.00000000068,  2.19928242745,    37724.75341974820),
 (0.00000000070,  5.33711014698,     2544.31441988340),
 (0.00000000055,  5.37872238211,    11015.10647733480),
 (0.00000000051,  5.03600618727,     5863.59120611620),
 (0.00000000059,  3.54984809612,     4535.05943692440),
 (0.00000000053,  1.50812064137,     7342.45778018060),
 (0.00000000044,  1.33712241647,     4164.31198961300),
 (0.00000000055,  5.38460045253,     7477.52286021600),
 (0.00000000049,  5.61844340512,    24072.92146977640),
 (0.00000000057,  6.17973522898,     8031.09226305840),
 (0.00000000052,  4.24379064407,     5088.62883976680),
 (0.00000000041,  3.41960196246,    26087.90314157420),
 (0.00000000052,  1.68150981131,    25158.60171976540),
 (0.00000000053,  0.11041408311,    29088.81141598500),
 (0.00000000043,  0.53354396923,     2146.16541647520),
 (0.00000000050,  0.60270799844,    33794.54372352860),
 (0.00000000045,  1.69577010458,     6702.56049386660),
 (0.00000000037,  6.09033460795,    64809.80550494129),
 (0.00000000044,  2.67993061247,    15110.46611986620),
 (0.00000000047,  3.62555676035,    41654.96311596780),
 (0.00000000036,  0.47219666269,    13095.84266507740),
 (0.00000000035,  5.99520523215,    23581.25817731760),
 (0.00000000043,  4.08726331262,   156137.47598479928),
 (0.00000000043,  5.17376496602,    18422.62935909819),
 (0.00000000034,  2.14460100274,     4933.20844033260),
 (0.00000000030,  4.12992793541,      426.59819087600),
 (0.00000000036,  2.28596930002,    90279.92316810328),
 (0.00000000032,  0.81117747619,       26.29831979980),
 (0.00000000028,  4.07036560467,    14712.31711645800),
 (0.00000000025,  1.92905243842,     1748.01641306700),
 (0.00000000024,  5.06152880842,    16730.46368959580),
 (0.00000000023,  3.24047012195,    31415.37924995700),
 (0.00000000027,  3.90672018305,    18451.07854656599),
 (0.00000000021,  3.51419811826,    10447.38783960440));
SY2: array[1..KY2,1..3] of double =
((0.00009721424,  5.15192809920,     6283.07584999140),
 (0.00000233002,  3.14159265359,        0.00000000000),
 (0.00000134188,  0.64406212977,    12566.15169998280),
 (0.00000006504,  1.07333397797,    18849.22754997420),
 (0.00000001662,  1.62746869551,    84334.66158130829),
 (0.00000000635,  3.51985338656,     6279.55273164240),
 (0.00000000492,  2.41382223971,     1047.74731175470),
 (0.00000000307,  6.10181422085,     5223.69391980220),
 (0.00000000322,  0.37660897389,     6286.59896834040),
 (0.00000000326,  2.35727931602,     5507.55323866740),
 (0.00000000274,  1.65307581765,     7860.41939243920),
 (0.00000000228,  1.14082932988,    25132.30339996560),
 (0.00000000202,  0.49836682530,     2352.86615377180),
 (0.00000000201,  0.15552765600,    10213.28554621100),
 (0.00000000167,  3.98005254015,      529.69096509460),
 (0.00000000170,  5.28668290523,     6256.77753019160),
 (0.00000000166,  3.04613930284,    12036.46073488820),
 (0.00000000153,  4.06779216239,    83996.84731811189),
 (0.00000000150,  3.18772213951,    71430.69561812909),
 (0.00000000120,  3.13558669517,     5884.92684658320),
 (0.00000000123,  4.17102530625,     6309.37416979120),
 (0.00000000100,  1.46356761368,    11506.76976979360),
 (0.00000000100,  3.00322421365,    11790.62908865880),
 (0.00000000077,  1.65643898948,     4705.73230754360),
 (0.00000000068,  6.03791904123,     6812.76681508600),
 (0.00000000075,  4.85191600582,    14143.49524243060),
 (0.00000000079,  4.12628805658,     5753.38488489680),
 (0.00000000064,  2.71944160460,     6127.65545055720),
 (0.00000000063,  0.78655326011,     6438.49624942560),
 (0.00000000075,  0.84213523741,   167621.57585086189),
 (0.00000000051,  4.55059044701,     5486.77784317500),
 (0.00000000050,  5.29314320585,     7079.37385680780),
 (0.00000000045,  0.33147576416,      775.52261132400),
 (0.00000000043,  3.61793711640,     1577.34354244780),
 (0.00000000057,  6.15295833679,    12194.03291462090),
 (0.00000000045,  1.18274698508,    17789.84561978500),
 (0.00000000047,  1.11643162773,      398.14900340820),
 (0.00000000047,  5.52984238430,    12168.00269657460),
 (0.00000000042,  2.64375300620,    10988.80815753500),
 (0.00000000037,  0.31226891972,     6681.22485339960),
 (0.00000000046,  3.38617099014,   156475.29024799570),
 (0.00000000033,  1.26266496002,     6290.18939699220),
 (0.00000000033,  2.25067065498,     6275.96230299060),
 (0.00000000027,  1.72859626293,     1059.38193018920),
 (0.00000000028,  2.88681054153,      796.29800681640),
 (0.00000000030,  5.52021264181,     7058.59846131540),
 (0.00000000021,  6.22275008403,     6069.77675455340),
 (0.00000000024,  5.83690442827,     6282.09552892320),
 (0.00000000024,  3.95322179797,     6284.05617105960),
 (0.00000000021,  4.87022458966,     3738.76143010800),
 (0.00000000021,  3.58048145762,     6496.37494542940),
 (0.00000000022,  1.97770318395,        7.11354700080),
 (0.00000000019,  3.45979888770,     4136.91043351620),
 (0.00000000015,  2.81379880771,     1589.07289528380),
 (0.00000000015,  1.61313151838,     1194.44701022460),
 (0.00000000015,  0.63083434831,    11769.85369316640),
 (0.00000000019,  0.28082047767,    17260.15465469040),
 (0.00000000017,  1.35165136146,    78051.58573131690),
 (0.00000000015,  2.30941599560,    11856.21865142450),
 (0.00000000012,  1.12997370513,    90617.73743129970),
 (0.00000000012,  0.00611601597,    18073.70493865020),
 (0.00000000012,  1.70058636365,    12559.03815298200));
SY3: array[1..KY3,1..3] of double =
((0.00000275993,  0.59480097092,     6283.07584999140),
 (0.00000017034,  3.14159265359,        0.00000000000),
 (0.00000003617,  0.11750575325,    12566.15169998280),
 (0.00000000339,  5.66087461682,    18849.22754997420),
 (0.00000000056,  5.02765554835,     6279.55273164240),
 (0.00000000019,  5.99007646261,     6256.77753019160),
 (0.00000000018,  3.80004734567,     6309.37416979120),
 (0.00000000018,  1.21049250774,     6127.65545055720),
 (0.00000000018,  2.29734567137,     6438.49624942560),
 (0.00000000015,  4.72881467263,     6286.59896834040),
 (0.00000000012,  0.41481671808,    83996.84731811189),
 (0.00000000013,  5.54637369296,    25132.30339996560),
 (0.00000000010,  2.91937214232,    71430.69561812909),
 (0.00000000006,  2.14173241210,    11856.21865142450));
SY4: array[1..KY4,1..3] of double =
((0.00000005745,  2.26734029843,     6283.07584999140),
 (0.00000000870,  0.00000000000,        0.00000000000),
 (0.00000000119,  4.26807972611,    12566.15169998280),
 (0.00000000017,  4.07422620440,    18849.22754997420),
 (0.00000000005,  0.84308705203,     1047.74731175470),
 (0.00000000005,  0.05711572303,    84334.66158130829));
SY5: array[1..KY5,1..3] of double =
((0.00000000114,  4.31455980099,     6283.07584999140),
 (0.00000000024,  0.00000000000,        0.00000000000));

SZ0: array[1..KZ0,1..3] of double =
((1.00013988784,  0.00000000000,        0.00000000000),
 (0.01670699632,  3.09846350258,     6283.07584999140),
 (0.00013956024,  3.05524609456,    12566.15169998280),
 (0.00003083720,  5.19846674381,    77713.77146812050),
 (0.00001628463,  1.17387558054,     5753.38488489680),
 (0.00001575572,  2.84685214877,     7860.41939243920),
 (0.00000924799,  5.45292236722,    11506.76976979360),
 (0.00000542439,  4.56409151453,     3930.20969621960),
 (0.00000472110,  3.66100022149,     5884.92684658320),
 (0.00000328780,  5.89983686142,     5223.69391980220),
 (0.00000345969,  0.96368627272,     5507.55323866740),
 (0.00000306784,  0.29867139512,     5573.14280143310),
 (0.00000174844,  3.01193636733,    18849.22754997420),
 (0.00000243181,  4.27349530790,    11790.62908865880),
 (0.00000211836,  5.84714461348,     1577.34354244780),
 (0.00000185740,  5.02199710705,    10977.07880469900),
 (0.00000109835,  5.05510635860,     5486.77784317500),
 (0.00000098316,  0.88681311278,     6069.77675455340),
 (0.00000086500,  5.68956418946,    15720.83878487840),
 (0.00000085831,  1.27079125277,   161000.68573767410),
 (0.00000062917,  0.92177053978,      529.69096509460),
 (0.00000057056,  2.01374292245,    83996.84731811189),
 (0.00000064908,  0.27251341435,    17260.15465469040),
 (0.00000049384,  3.24501240359,     2544.31441988340),
 (0.00000055736,  5.24159799170,    71430.69561812909),
 (0.00000042520,  6.01110257982,     6275.96230299060),
 (0.00000046966,  2.57799853213,      775.52261132400),
 (0.00000038963,  5.36063832897,     4694.00295470760),
 (0.00000044666,  5.53715663816,     9437.76293488700),
 (0.00000035661,  1.67447135798,    12036.46073488820),
 (0.00000031922,  0.18368299942,     5088.62883976680),
 (0.00000031846,  1.77775642078,      398.14900340820),
 (0.00000033193,  0.24370221704,     7084.89678111520),
 (0.00000038245,  2.39255343973,     8827.39026987480),
 (0.00000028468,  1.21344887533,     6286.59896834040),
 (0.00000037486,  0.82961281844,    19651.04848109800),
 (0.00000036957,  4.90107587287,    12139.55350910680),
 (0.00000034537,  1.84270693281,     2942.46342329160),
 (0.00000026275,  4.58896863104,    10447.38783960440),
 (0.00000024596,  3.78660838036,     8429.24126646660),
 (0.00000023587,  0.26866098169,      796.29800681640),
 (0.00000027795,  1.89934427832,     6279.55273164240),
 (0.00000023927,  4.99598548145,     5856.47765911540),
 (0.00000020345,  4.65282190725,     2146.16541647520),
 (0.00000023287,  2.80783632869,    14143.49524243060),
 (0.00000022099,  1.95002636847,     3154.68708489560),
 (0.00000019509,  5.38233922479,     2352.86615377180),
 (0.00000017958,  0.19871369960,     6812.76681508600),
 (0.00000017178,  4.43322156854,    10213.28554621100),
 (0.00000016190,  5.23159323213,    17789.84561978500),
 (0.00000017315,  6.15224075188,    16730.46368959580),
 (0.00000013814,  5.18962074032,     8031.09226305840),
 (0.00000018834,  0.67280058021,   149854.40013480789),
 (0.00000018330,  2.25348717053,    23581.25817731760),
 (0.00000013639,  3.68511810757,     4705.73230754360),
 (0.00000013142,  0.65267698994,    13367.97263110660),
 (0.00000010414,  4.33285688501,    11769.85369316640),
 (0.00000009978,  4.20126336356,     6309.37416979120),
 (0.00000010170,  1.59366684542,     4690.47983635860),
 (0.00000007564,  2.62560597391,     6256.77753019160),
 (0.00000009654,  3.67583728703,    27511.46787353720),
 (0.00000006743,  0.56269927047,     3340.61242669980),
 (0.00000008743,  6.06359123461,     1748.01641306700),
 (0.00000007786,  3.67371235367,    12168.00269657460),
 (0.00000006633,  5.66149277789,    11371.70468975820),
 (0.00000007712,  0.31242577788,     7632.94325965020),
 (0.00000006586,  3.13580054586,      801.82093112380),
 (0.00000007460,  5.64758066660,    11926.25441366880),
 (0.00000006933,  2.92384586372,     6681.22485339960),
 (0.00000006805,  1.42327153767,    23013.53953958720),
 (0.00000006118,  5.13395999022,     1194.44701022460),
 (0.00000006477,  2.64986648493,    19804.82729158280),
 (0.00000005233,  4.62432817299,     6438.49624942560),
 (0.00000006147,  3.02863936662,   233141.31440436149),
 (0.00000004608,  1.72194702724,     7234.79425624200),
 (0.00000004221,  1.55697533726,     7238.67559160000),
 (0.00000005310,  2.40821524293,    11499.65622279280),
 (0.00000005128,  5.32398965690,    11513.88331679440),
 (0.00000004770,  0.25554311730,    11856.21865142450),
 (0.00000005519,  2.09089153789,    17298.18232732620),
 (0.00000005625,  4.34052903053,    90955.55169449610),
 (0.00000004578,  4.46569641570,     5746.27133789600),
 (0.00000003788,  4.90728294810,     4164.31198961300),
 (0.00000005337,  5.09957905103,    31441.67756975680),
 (0.00000003967,  1.20054555175,     1349.86740965880),
 (0.00000004005,  3.02853885902,     1059.38193018920),
 (0.00000003480,  0.76066308841,    10973.55568635000),
 (0.00000004232,  1.05485713117,     5760.49843189760),
 (0.00000004582,  3.76570026763,     6386.16862421000),
 (0.00000003335,  3.13829943354,     6836.64525283380),
 (0.00000003420,  3.00043974511,     4292.33083295040),
 (0.00000003595,  5.70703236079,     5643.17856367740),
 (0.00000003236,  4.16387400645,     9917.69687450980),
 (0.00000004154,  2.59940749519,     7058.59846131540),
 (0.00000003362,  4.54577164994,     4732.03062734340),
 (0.00000002978,  1.30561268820,     6283.14316029419),
 (0.00000002765,  0.51311975671,       26.29831979980),
 (0.00000002807,  5.66230537649,     8635.94200376320),
 (0.00000002927,  5.73787834080,    16200.77272450120),
 (0.00000003167,  1.69181759900,    11015.10647733480),
 (0.00000002598,  2.96244118358,    25132.30339996560),
 (0.00000003519,  3.62639325753,   244287.60000722769),
 (0.00000002676,  4.20727719487,    18073.70493865020),
 (0.00000002978,  1.74971565805,     6283.00853968860),
 (0.00000002287,  1.06976449088,    14314.16811304980),
 (0.00000002863,  5.92838917309,    14712.31711645800),
 (0.00000003071,  0.23793217000,    35371.88726597640),
 (0.00000002656,  0.89959301615,    12352.85260454480),
 (0.00000002415,  2.79975176800,      709.93304855830),
 (0.00000002811,  3.51513864541,    21228.39202354580),
 (0.00000001977,  2.61358297551,      951.71840625060),
 (0.00000002548,  2.47684686575,     6208.29425142410),
 (0.00000001999,  0.56090396506,     7079.37385680780),
 (0.00000002305,  1.05376463592,    22483.84857449259),
 (0.00000001855,  2.86093570752,     5216.58037280140),
 (0.00000002157,  1.31395211105,   154717.60988768269),
 (0.00000001970,  4.36931551625,   167283.76158766549),
 (0.00000001754,  2.14452400686,     6290.18939699220),
 (0.00000001628,  5.85704450617,    10984.19235169980),
 (0.00000002154,  6.03828353794,    10873.98603048040),
 (0.00000001714,  3.70158195222,     1592.59601363280),
 (0.00000001541,  6.21599512982,    23543.23050468179),
 (0.00000001602,  1.99860679677,    10969.96525769820),
 (0.00000001712,  1.34295218697,     3128.38876509580),
 (0.00000001647,  5.54948299069,     6496.37494542940),
 (0.00000001495,  5.43980459648,      155.42039943420),
 (0.00000001827,  5.91227480351,     3738.76143010800),
 (0.00000001726,  2.16765465036,    10575.40668294180),
 (0.00000001532,  5.35683107063,    13521.75144159140),
 (0.00000001824,  1.66056145084,    39302.09696219600),
 (0.00000001605,  1.90930973224,     6133.51265285680),
 (0.00000001282,  2.46013372544,    13916.01910964160),
 (0.00000001211,  4.41360631550,     3894.18182954220),
 (0.00000001394,  1.77801929250,     9225.53927328300),
 (0.00000001571,  4.95512957606,    25158.60171976540),
 (0.00000001205,  1.19212756308,        3.52311834900),
 (0.00000001132,  2.69830084955,     6040.34724601740),
 (0.00000001504,  5.77577388271,    18209.33026366019),
 (0.00000001393,  1.62625077326,     5120.60114558360),
 (0.00000001081,  2.93726744446,    17256.63153634140),
 (0.00000001232,  0.71651766504,   143571.32428481648),
 (0.00000001087,  0.99769687961,      955.59974160860),
 (0.00000001068,  5.28472576591,    65147.61976813770),
 (0.00000001169,  3.11663802316,    14945.31617355440),
 (0.00000000975,  5.10887260780,     6172.86952877200),
 (0.00000001202,  4.02992510403,      553.56940284240),
 (0.00000000979,  2.00000879106,    15110.46611986620),
 (0.00000000962,  4.02380771400,     6282.09552892320),
 (0.00000000999,  3.62643002790,     6262.30045449900),
 (0.00000001030,  5.84987815239,      213.29909543800),
 (0.00000001014,  2.84227679965,     8662.24032356300),
 (0.00000001185,  1.51330629149,    17654.78053974960),
 (0.00000000967,  2.67081017562,     5650.29211067820),
 (0.00000001222,  2.65423784904,    88860.05707098669),
 (0.00000000986,  2.36212814824,     6206.80977871580),
 (0.00000001034,  0.13634950642,    11712.95531823080),
 (0.00000001103,  3.08477302937,    43232.30665841560),
 (0.00000000781,  2.53374971725,    16496.36139620240),
 (0.00000001019,  3.04569392376,     6037.24420376200),
 (0.00000000795,  5.80662989126,     5230.80746680300),
 (0.00000000813,  3.57702871938,    10177.25767953360),
 (0.00000000962,  5.31470594766,     6284.05617105960),
 (0.00000000717,  5.95797471837,    12559.03815298200),
 (0.00000000967,  2.74413738053,     6244.94281435360),
 (0.00000000921,  0.10160160830,    29088.81141598500),
 (0.00000000719,  5.91788189939,     4136.91043351620),
 (0.00000000688,  3.89489045092,     1589.07289528380),
 (0.00000000772,  4.05505380285,     6127.65545055720),
 (0.00000000706,  5.49323197725,    22003.91463486980),
 (0.00000000665,  1.60002747134,    11087.28512591840),
 (0.00000000690,  4.50539825729,      426.59819087600),
 (0.00000000854,  3.26104645060,    20426.57109242200),
 (0.00000000656,  4.32410182940,    16858.48253293320),
 (0.00000000840,  2.59572585212,    28766.92442448400),
 (0.00000000686,  0.61944033771,    11403.67699557500),
 (0.00000000700,  3.40901412473,        7.11354700080),
 (0.00000000728,  0.04050185963,     5481.25491886760),
 (0.00000000653,  1.03869451230,     6062.66320755260),
 (0.00000000559,  4.79221805695,    20199.09495963300),
 (0.00000000633,  5.70229959167,    45892.73043315699),
 (0.00000000591,  6.10986487621,     9623.68827669120),
 (0.00000000520,  3.62310356479,     5333.90024102160),
 (0.00000000602,  5.58381898589,    10344.29506538580),
 (0.00000000496,  2.21027756314,     1990.74501704100),
 (0.00000000691,  1.96733114988,    12416.58850284820),
 (0.00000000640,  1.59062417043,    18319.53658487960),
 (0.00000000625,  3.82358168221,    13517.87010623340),
 (0.00000000475,  1.17025904180,    12569.67481833180),
 (0.00000000660,  5.08498512995,      283.85931886520),
 (0.00000000664,  4.50029469969,    47162.51635463520),
 (0.00000000569,  0.16318535463,    17267.26820169119),
 (0.00000000568,  3.86100969474,     6076.89030155420),
 (0.00000000462,  0.26368763517,     4590.91018048900),
 (0.00000000535,  4.83225423196,    18422.62935909819),
 (0.00000000466,  0.75873879417,     7342.45778018060),
 (0.00000000541,  3.07212190556,   226858.23855437008),
 (0.00000000610,  1.53597089605,    33019.02111220460),
 (0.00000000617,  2.62356328726,    11190.37790013700),
 (0.00000000548,  4.55798855803,    18875.52586977400),
 (0.00000000633,  4.60110281228,    66567.48586525429),
 (0.00000000587,  5.78087907808,      632.78373931320),
 (0.00000000603,  5.38458554802,   316428.22867391503),
 (0.00000000525,  5.01522072363,    12132.43996210600),
 (0.00000000469,  0.59975173763,    21954.15760939799),
 (0.00000000548,  3.50627043672,    17253.04110768959),
 (0.00000000502,  0.98804327589,    11609.86254401220),
 (0.00000000568,  1.98497313089,     7668.63742494250),
 (0.00000000482,  1.62460405687,    12146.66705610760),
 (0.00000000391,  3.68718382972,    18052.92954315780),
 (0.00000000457,  3.77214896610,   156137.47598479928),
 (0.00000000401,  5.29221540240,    15671.08175940660),
 (0.00000000469,  1.80963351735,    12562.62858163380),
 (0.00000000514,  3.37031288919,    20597.24396304120),
 (0.00000000452,  5.66811219778,    10454.50138660520),
 (0.00000000375,  4.98528185039,     9779.10867612540),
 (0.00000000523,  0.97215560834,   155427.54293624099),
 (0.00000000403,  5.13948189770,     1551.04522264800),
 (0.00000000372,  3.69883738807,     9388.00590941520),
 (0.00000000367,  4.43875659833,     4535.05943692440),
 (0.00000000406,  4.20863156497,    12592.45001978260),
 (0.00000000362,  2.55099560446,      242.72860397400),
 (0.00000000471,  4.61907324819,     5436.99301524020),
 (0.00000000388,  4.96020928400,    24356.78078864160),
 (0.00000000441,  5.83872966262,     3496.03282613400),
 (0.00000000349,  6.16307810648,    19800.94595622480),
 (0.00000000356,  0.23819081240,     5429.87946823940),
 (0.00000000346,  5.60809622572,     2379.16447357160),
 (0.00000000380,  2.72105213132,    11933.36796066960),
 (0.00000000432,  0.24215988572,    17996.03116822220),
 (0.00000000378,  5.22516848076,     7477.52286021600),
 (0.00000000337,  5.10885555836,     5849.36411211460),
 (0.00000000315,  0.57827745123,    10557.59416082380),
 (0.00000000318,  4.49949007320,     3634.62102451840),
 (0.00000000323,  1.55850824803,    10440.27429260360),
 (0.00000000314,  5.77154773334,       20.77539549240),
 (0.00000000303,  2.34615580398,     4686.88940770680),
 (0.00000000414,  5.93237602310,    51092.72605085480),
 (0.00000000362,  2.17561997119,    28237.23345938940),
 (0.00000000288,  0.18377405421,    13095.84266507740),
 (0.00000000277,  5.12952205030,    13119.72110282519),
 (0.00000000325,  6.18608287927,     6268.84875598980),
 (0.00000000273,  0.30522428863,    23141.55838292460),
 (0.00000000267,  5.76152585786,     5966.68398033480),
 (0.00000000345,  2.94246040875,    36949.23080842420),
 (0.00000000253,  5.20994580359,    24072.92146977640),
 (0.00000000342,  5.76212804329,    16460.33352952499),
 (0.00000000307,  6.01039067183,    22805.73556599360),
 (0.00000000261,  2.00304796059,     6148.01076995600),
 (0.00000000238,  5.08241964961,     6915.85958930460),
 (0.00000000249,  2.94762789744,      135.06508003540),
 (0.00000000306,  3.89765478921,    10988.80815753500),
 (0.00000000308,  0.05451027736,     4701.11650170840),
 (0.00000000319,  2.95712862064,   163096.18036118349),
 (0.00000000272,  2.07967681309,     4804.20927592700),
 (0.00000000209,  4.43768461442,     6546.15977336420),
 (0.00000000217,  0.73691592312,     6303.85124548380),
 (0.00000000203,  0.32033085531,    25934.12433108940),
 (0.00000000205,  5.22936478995,    20995.39296644940),
 (0.00000000213,  0.20671418919,    28286.99048486120),
 (0.00000000197,  0.48286131290,    16737.57723659660),
 (0.00000000230,  6.06567392849,     6287.00800325450),
 (0.00000000219,  1.29194216300,     5326.78669402080),
 (0.00000000201,  1.74700937253,    22743.40937951640),
 (0.00000000207,  4.45440927276,     6279.48542133960),
 (0.00000000269,  6.05640445030,    64471.99124174489),
 (0.00000000190,  0.99261116842,    29296.61538957860),
 (0.00000000194,  3.82656562755,      419.48464387520),
 (0.00000000262,  5.26961924126,      522.57741809380),
 (0.00000000210,  4.68618183158,     6254.62666252360),
 (0.00000000197,  2.80624554186,     4933.20844033260),
 (0.00000000252,  4.36220154620,    40879.44050464380),
 (0.00000000261,  1.07241516738,    55022.93574707440),
 (0.00000000233,  5.41751014958,    39609.65458316560),
 (0.00000000185,  4.14324541379,     5642.19824260920),
 (0.00000000247,  3.44855612987,     6702.56049386660),
 (0.00000000205,  4.04424043226,      536.80451209540),
 (0.00000000191,  3.15807087926,    16723.35014259500),
 (0.00000000222,  5.16259496507,    23539.70738633280),
 (0.00000000180,  4.56214752149,     6489.26139842860),
 (0.00000000227,  0.60156339452,     5905.70224207560),
 (0.00000000170,  0.93185903228,    16062.18452611680),
 (0.00000000159,  0.92751013112,    23937.85638974100),
 (0.00000000157,  4.69607868164,     6805.65326808520),
 (0.00000000218,  0.85533373430,    16627.37091537720),
 (0.00000000169,  0.94641052064,     3097.88382272579),
 (0.00000000207,  4.88410451334,     6286.66627864320),
 (0.00000000160,  4.95943826819,    10021.83728009940),
 (0.00000000175,  6.12762824563,   239424.39025435288),
 (0.00000000173,  3.13887234973,     6179.98307577280),
 (0.00000000157,  3.62822057807,    18451.07854656599),
 (0.00000000206,  5.74617821138,     3646.35037735440),
 (0.00000000157,  4.67695912207,     6709.67404086740),
 (0.00000000146,  3.09506069745,     4907.30205014560),
 (0.00000000165,  2.27139128760,    10660.68693504240),
 (0.00000000144,  3.96947747592,     6019.99192661860),
 (0.00000000171,  5.91302216729,     6058.73105428950),
 (0.00000000144,  2.13155655120,    26084.02180621620),
 (0.00000000151,  0.67417383565,     2388.89402044920),
 (0.00000000196,  1.67718461229,     2107.03450754240),
 (0.00000000146,  5.10373877968,    10770.89325626180),
 (0.00000000187,  1.23915444627,    19402.79695281660),
 (0.00000000137,  1.26247412216,    12566.21901028560),
 (0.00000000191,  5.03547476279,      263.08392337280),
 (0.00000000137,  3.52825454595,      639.89728631400),
 (0.00000000135,  0.73840670927,     5017.50837136500),
 (0.00000000164,  2.39195095081,     6357.85744855870),
 (0.00000000168,  0.05515907462,     9380.95967271720),
 (0.00000000161,  1.15721259392,    26735.94526221320),
 (0.00000000144,  1.76097645199,     5888.44996493220),
 (0.00000000131,  2.51859277344,     6599.46771964800),
 (0.00000000142,  2.43802911123,     5881.40372823420),
 (0.00000000159,  5.90325893762,     6281.59137728310),
 (0.00000000151,  3.72338532519,    12669.24447420140),
 (0.00000000132,  2.38417741883,     6525.80445396540),
 (0.00000000127,  0.00254936441,    10027.90319572920),
 (0.00000000148,  2.85102145528,     6418.14093002680),
 (0.00000000143,  5.74460279560,    26087.90314157420),
 (0.00000000172,  0.41289962240,   174242.46596404970),
 (0.00000000136,  4.15497742275,     6311.52503745920),
 (0.00000000170,  5.98194913129,   327574.51427678125),
 (0.00000000136,  2.48430537541,    13341.67431130680),
 (0.00000000149,  0.33002271275,      245.83164622940),
 (0.00000000165,  2.49667924600,    58953.14544329400),
 (0.00000000123,  1.67328384813,    32217.20018108080),
 (0.00000000123,  3.45660563754,     6277.55292568400),
 (0.00000000117,  0.86065134175,     6245.04817735560),
 (0.00000000149,  5.61358281003,     5729.50644714900),
 (0.00000000128,  0.71204006448,      103.09277421860),
 (0.00000000159,  2.43166592149,   221995.02880149524),
 (0.00000000137,  1.70657709200,    12566.08438968000),
 (0.00000000129,  2.80667872683,     6016.46880826960),
 (0.00000000113,  3.58302904101,    25685.87280280800),
 (0.00000000109,  3.26403795962,     6819.88036208680),
 (0.00000000122,  0.34120688202,     1162.47470440780),
 (0.00000000106,  1.59721172719,    17782.73207278420),
 (0.00000000144,  2.28891651774,    12489.88562870720),
 (0.00000000137,  5.82029768354,    44809.65020086340),
 (0.00000000134,  1.26539983018,     5331.35744374080),
 (0.00000000103,  5.96518130595,     6321.10352262720),
 (0.00000000109,  0.33808549034,    11300.58422135640),
 (0.00000000129,  5.89187277190,    12029.34718788740),
 (0.00000000122,  5.77325634636,    11919.14086666800),
 (0.00000000107,  6.24998989350,    77690.75950573849),
 (0.00000000107,  1.00535580713,    77736.78343050249),
 (0.00000000115,  5.86963518266,    12721.57209941700),
 (0.00000000102,  5.66283467269,     5540.08578945880),
 (0.00000000143,  0.24122178432,     4214.06901508480),
 (0.00000000143,  0.88529649733,     7576.56007357400),
 (0.00000000107,  2.92124030351,    31415.37924995700),
 (0.00000000100,  5.99485644501,     4061.21921539440),
 (0.00000000103,  2.41941934525,     5547.19933645960),
 (0.00000000104,  4.44106051277,     2118.76386037840),
 (0.00000000110,  0.37559635174,     5863.59120611620),
 (0.00000000124,  2.55619029611,    12539.85338018300),
 (0.00000000110,  3.66952094465,   238004.52415723629),
 (0.00000000112,  4.32512422724,    97238.62754448749),
 (0.00000000120,  1.26895630075,    12043.57428188900),
 (0.00000000097,  5.42612959752,     7834.12107263940),
 (0.00000000094,  2.56461130309,    19004.64794940840),
 (0.00000000105,  5.68272475301,    16522.65971600220),
 (0.00000000117,  3.65425622684,    34520.30930938080),
 (0.00000000108,  1.24206843948,    84672.47584450469),
 (0.00000000098,  0.13589994287,    11080.17157891760),
 (0.00000000097,  2.46722096722,    71980.63357473118),
 (0.00000000095,  5.36958330451,     6288.59877429880),
 (0.00000000096,  0.20796618776,    18139.29450141590),
 (0.00000000111,  5.01961920313,    11823.16163945020),
 (0.00000000090,  2.72355843779,    26880.31981303260),
 (0.00000000099,  0.90164266199,    18635.92845453620),
 (0.00000000126,  4.78722177847,   305281.94307104882),
 (0.00000000124,  5.00979495566,   172146.97134054029),
 (0.00000000090,  4.50544881196,    40077.61957352000),
 (0.00000000104,  5.63679680710,     2787.04302385740),
 (0.00000000091,  5.43564326147,     6272.03014972750),
 (0.00000000100,  2.00639461597,    12323.42309600880),
 (0.00000000117,  2.35555589778,    83286.91426955358),
 (0.00000000105,  2.59824000109,    30666.15495843280),
 (0.00000000090,  2.35779490026,    12491.37010141550),
 (0.00000000089,  3.57152453732,    11720.06886523160),
 (0.00000000095,  5.67015349858,    14919.01785375460),
 (0.00000000087,  1.86043406047,    27707.54249429480),
 (0.00000000106,  3.04150600352,    22345.26037610820),
 (0.00000000082,  5.58298993353,    10241.20229116720),
 (0.00000000083,  3.10607039533,    36147.40987730040),
 (0.00000000094,  5.47749711149,     9924.81042151060),
 (0.00000000082,  4.71988314145,    15141.39079431200),
 (0.00000000096,  3.89073946348,     6379.05507720920),
 (0.00000000110,  4.92131611151,     5621.84292321040),
 (0.00000000110,  4.89978492291,    72140.62866668739),
 (0.00000000097,  5.20764563059,     6303.43116939020),
 (0.00000000085,  1.61269222311,    33326.57873317420),
 (0.00000000093,  1.32651591333,    23020.65308658799),
 (0.00000000090,  0.57733016380,    26482.17080962440),
 (0.00000000078,  3.99588630754,    11293.47067435560),
 (0.00000000106,  3.92012705073,    62883.35513951360),
 (0.00000000098,  2.94397773524,      316.39186965660),
 (0.00000000076,  3.96310417608,    29026.48522950779),
 (0.00000000098,  0.95914722366,    48739.85989708300),
 (0.00000000078,  1.97068528043,    90279.92316810328),
 (0.00000000076,  0.23027966596,    21424.46664430340),
 (0.00000000079,  1.46227790922,     8982.81066930900),
 (0.00000000078,  2.28840998832,      266.60704172180),
 (0.00000000071,  1.51940765590,    33794.54372352860),
 (0.00000000076,  0.22880641443,    57375.80190084620),
 (0.00000000097,  0.39449562097,    24279.10701821359),
 (0.00000000075,  2.77638584795,    12964.30070339100),
 (0.00000000077,  5.18846946344,    11520.99686379520),
 (0.00000000068,  0.50006599129,     4274.51831083240),
 (0.00000000075,  2.07323762803,    15664.03552270859),
 (0.00000000077,  0.46665178780,    16207.88627150200),
 (0.00000000081,  4.10452219483,   161710.61878623239),
 (0.00000000071,  3.91415328513,     7875.67186362420),
 (0.00000000081,  0.91938383406,       74.78159856730),
 (0.00000000083,  4.69916218791,    23006.42599258639),
 (0.00000000069,  0.98999300277,     6393.28217121080),
 (0.00000000065,  5.41938745446,    28628.33622609960),
 (0.00000000073,  2.45564765251,    15508.61512327440),
 (0.00000000065,  3.02336771694,     5959.57043333400),
 (0.00000000064,  0.18375587635,     1066.49547719000),
 (0.00000000080,  5.81239171612,    12341.80690428090),
 (0.00000000066,  2.15105504851,       38.02767263580),
 (0.00000000067,  5.14047250153,     9814.60410029120),
 (0.00000000062,  2.43313614978,    10138.10951694860),
 (0.00000000068,  2.24442548639,    24383.07910844140),
 (0.00000000078,  1.39649333997,     9411.46461508720),
 (0.00000000059,  4.95362151577,    35707.71008290740),
 (0.00000000073,  1.35229143121,     5327.47610838280),
 (0.00000000057,  3.16018882154,     5490.30096152400),
 (0.00000000072,  5.91833527334,    10881.09957748120),
 (0.00000000067,  0.66414713064,    29864.33402730900),
 (0.00000000065,  0.30352816135,     7018.95236352320),
 (0.00000000059,  5.36231868425,    10239.58386601080),
 (0.00000000056,  3.22196331515,     2636.72547263700),
 (0.00000000068,  5.32086226658,     3116.65941225980),
 (0.00000000059,  1.63156134967,    61306.01159706580),
 (0.00000000054,  4.29491690425,    21947.11137270000),
 (0.00000000070,  0.29271565928,     6528.90749622080),
 (0.00000000057,  5.89190132575,    34513.26307268280),
 (0.00000000054,  2.51856815404,     6279.19451463340),
 (0.00000000074,  1.38235845304,     9967.45389998160),
 (0.00000000054,  0.92276712152,     6286.95718534940),
 (0.00000000070,  5.00933012248,     6453.74872061060),
 (0.00000000053,  3.86543309344,    32370.97899156560),
 (0.00000000055,  4.51794544854,    34911.41207609100),
 (0.00000000063,  5.41479412056,    11502.83761653050),
 (0.00000000063,  2.34416220742,    11510.70192305670),
 (0.00000000056,  0.91310629913,     9910.58332750900),
 (0.00000000067,  4.03308763854,    34596.36465465240),
 (0.00000000060,  5.57024703495,     5756.90800324580),
 (0.00000000072,  2.80863088166,    10866.87248347960),
 (0.00000000066,  6.12047940728,    12074.48840752400),
 (0.00000000051,  2.59519527563,    11396.56344857420),
 (0.00000000062,  5.14746754396,    25287.72379939980),
 (0.00000000054,  2.50994032776,     5999.21653112620),
 (0.00000000051,  4.51195861837,    29822.78323632420),
 (0.00000000059,  0.44167237876,   250570.67585721909),
 (0.00000000051,  3.68849066760,     6262.72053059260),
 (0.00000000049,  0.54704693048,    22594.05489571199),
 (0.00000000065,  2.38423614501,    52670.06959330260),
 (0.00000000069,  5.34363738671,    66813.56483573320),
 (0.00000000056,  2.67216180349,    17892.93839400359),
 (0.00000000049,  4.18361320516,    18606.49894600020),
 (0.00000000055,  0.83886167974,    20452.86941222180),
 (0.00000000050,  1.46327331958,    37455.72649597440),
 (0.00000000058,  3.34847975377,    33990.61834428620),
 (0.00000000065,  1.45522693982,    76251.32777062019),
 (0.00000000056,  2.35650664200,    37724.75341974820),
 (0.00000000048,  1.80689447612,      206.18554843720),
 (0.00000000056,  3.84224878744,     5483.25472482600),
 (0.00000000053,  0.17334326094,    77717.29458646949),
 (0.00000000053,  0.79879700631,    77710.24834977149),
 (0.00000000047,  0.43240779709,      735.87651353180),
 (0.00000000053,  4.58786566028,    11616.97609101300),
 (0.00000000048,  6.20230111054,     4171.42553661380),
 (0.00000000052,  2.91719053030,     6993.00889854970),
 (0.00000000057,  3.42008310383,    50317.20343953080),
 (0.00000000048,  0.12356889012,    13362.44970679920),
 (0.00000000060,  5.52056066934,      949.17560896980),
 (0.00000000045,  3.37963782356,    10763.77970926100),
 (0.00000000047,  5.50958184902,    12779.45079542080),
 (0.00000000052,  5.42770349015,   310145.15282392364),
 (0.00000000061,  2.93237974631,     5791.41255753260),
 (0.00000000044,  2.87440620802,     8584.66166590080),
 (0.00000000046,  4.03141796560,    10667.80048204320),
 (0.00000000044,  1.21579107625,     6272.43918464160),
 (0.00000000047,  2.57670800912,    11492.54267579200),
 (0.00000000044,  3.62570223167,    63658.87775083760),
 (0.00000000051,  0.84531181151,    12345.73905754400),
 (0.00000000046,  1.17584556517,      149.56319713460),
 (0.00000000043,  0.01524970172,    37853.87549938260),
 (0.00000000043,  0.79038834934,      640.87760738220),
 (0.00000000044,  2.22554419931,     6293.71251534120),
 (0.00000000049,  1.01528394907,   149144.46708624958),
 (0.00000000041,  3.27146326065,     8858.31494432060),
 (0.00000000045,  3.03765521215,    65236.22129328540),
 (0.00000000058,  5.45843180927,     1975.49254585600),
 (0.00000000041,  1.32190847146,     2547.83753823240),
 (0.00000000047,  3.67626039848,    28313.28880466100),
 (0.00000000047,  6.21438985953,    10991.30589870060),
 (0.00000000040,  2.37237751212,     8273.82086703240),
 (0.00000000056,  1.09773690181,    77376.20102240759),
 (0.00000000040,  2.35698541041,     2699.73481931760),
 (0.00000000043,  5.28030897946,    17796.95916678580),
 (0.00000000054,  2.59175932091,    22910.44676536859),
 (0.00000000055,  0.07988985505,    83467.15635301729),
 (0.00000000041,  4.47510694062,     5618.31980486140),
 (0.00000000040,  1.35670430524,    27177.85152920020),
 (0.00000000041,  2.48011323946,     6549.68289171320),
 (0.00000000050,  2.56387920528,    82576.98122099529),
 (0.00000000042,  4.78798367468,     7856.89627409019),
 (0.00000000047,  2.75482175292,    18202.21671665939),
 (0.00000000039,  1.97008298629,    24491.42579258340),
 (0.00000000042,  4.04346599946,     7863.94251078820),
 (0.00000000039,  3.01033936420,      853.19638175200),
 (0.00000000038,  0.49178679251,    38650.17350619900),
 (0.00000000044,  1.35931241699,    21393.54196985760),
 (0.00000000036,  4.86047906533,     4157.19844261220),
 (0.00000000043,  5.64354880978,     1062.90504853820),
 (0.00000000039,  3.92736779879,     3903.91137641980),
 (0.00000000040,  5.39694918320,     9498.21223063460),
 (0.00000000043,  2.40863861919,    29424.63423291600),
 (0.00000000046,  2.08022244271,    12573.26524698360),
 (0.00000000050,  6.15760345261,    78051.34191383338));
SZ1: array[1..KZ1,1..3] of double =
((0.00103018607,  1.10748968172,     6283.07584999140),
 (0.00001721238,  1.06442300386,    12566.15169998280),
 (0.00000702217,  3.14159265359,        0.00000000000),
 (0.00000032345,  1.02168583254,    18849.22754997420),
 (0.00000030801,  2.84358443952,     5507.55323866740),
 (0.00000024978,  1.31906570344,     5223.69391980220),
 (0.00000018487,  1.42428709076,     1577.34354244780),
 (0.00000010077,  5.91385248388,    10977.07880469900),
 (0.00000008635,  0.27158192945,     5486.77784317500),
 (0.00000008654,  1.42046854427,     6275.96230299060),
 (0.00000005069,  1.68613408916,     5088.62883976680),
 (0.00000004985,  6.01402338185,     6286.59896834040),
 (0.00000004667,  5.98749245692,      529.69096509460),
 (0.00000004395,  0.51800423445,     4694.00295470760),
 (0.00000003870,  4.74932206877,     2544.31441988340),
 (0.00000003755,  5.07053801166,      796.29800681640),
 (0.00000004100,  1.08424801084,     9437.76293488700),
 (0.00000003518,  0.02290216978,    83996.84731811189),
 (0.00000003436,  0.94937503872,    71430.69561812909),
 (0.00000003221,  6.15628775321,     2146.16541647520),
 (0.00000003418,  5.41151581880,      775.52261132400),
 (0.00000002863,  5.48433323746,    10447.38783960440),
 (0.00000002525,  0.24296913555,      398.14900340820),
 (0.00000002205,  4.94892172085,     6812.76681508600),
 (0.00000002186,  0.41991932164,     8031.09226305840),
 (0.00000002828,  3.41986300734,     2352.86615377180),
 (0.00000002554,  6.13241770582,     6438.49624942560),
 (0.00000001932,  5.31374587091,     8429.24126646660),
 (0.00000002427,  3.09118902115,     4690.47983635860),
 (0.00000001730,  1.53685999718,     4705.73230754360),
 (0.00000002250,  3.68836395620,     7084.89678111520),
 (0.00000002094,  1.28169060400,     1748.01641306700),
 (0.00000001483,  3.22226346483,     7234.79425624200),
 (0.00000001434,  0.81293662216,    14143.49524243060),
 (0.00000001754,  3.22883705112,     6279.55273164240),
 (0.00000001583,  4.09815978783,    11499.65622279280),
 (0.00000001575,  5.53890314149,     3154.68708489560),
 (0.00000001847,  1.82041234937,     7632.94325965020),
 (0.00000001499,  3.63177937611,    11513.88331679440),
 (0.00000001337,  4.64442556061,     6836.64525283380),
 (0.00000001275,  2.69329661394,     1349.86740965880),
 (0.00000001348,  6.15284035323,     5746.27133789600),
 (0.00000001126,  3.35676107739,    17789.84561978500),
 (0.00000001470,  3.65282991735,     1194.44701022460),
 (0.00000001101,  4.49747427670,     4292.33083295040),
 (0.00000001168,  2.58033028504,    13367.97263110660),
 (0.00000001236,  5.64980098028,     5760.49843189760),
 (0.00000000985,  0.65326301914,     5856.47765911540),
 (0.00000000928,  2.32555018290,    10213.28554621100),
 (0.00000001073,  5.82672338169,    12036.46073488820),
 (0.00000000918,  0.76907130762,    16730.46368959580),
 (0.00000000876,  1.50335727807,    11926.25441366880),
 (0.00000001023,  5.62071200879,     6256.77753019160),
 (0.00000000853,  0.65678134630,      155.42039943420),
 (0.00000000802,  4.10519132094,      951.71840625060),
 (0.00000000859,  1.42880883564,     5753.38488489680),
 (0.00000000992,  1.14238001610,     1059.38193018920),
 (0.00000000814,  1.63584008733,     6681.22485339960),
 (0.00000000664,  4.55039663226,     5216.58037280140),
 (0.00000000627,  1.50782904323,     5643.17856367740),
 (0.00000000644,  4.19480024859,     6040.34724601740),
 (0.00000000590,  6.18371704849,     4164.31198961300),
 (0.00000000635,  0.52423584770,     6290.18939699220),
 (0.00000000650,  0.97935492869,    25132.30339996560),
 (0.00000000568,  2.30121525349,    10973.55568635000),
 (0.00000000549,  5.26737827342,     3340.61242669980),
 (0.00000000547,  2.20143332641,     1592.59601363280),
 (0.00000000526,  0.92464258271,    11371.70468975820),
 (0.00000000493,  5.91036281399,     3894.18182954220),
 (0.00000000483,  1.66005711540,    12168.00269657460),
 (0.00000000514,  3.59683072524,    10969.96525769820),
 (0.00000000516,  3.97164781773,    17298.18232732620),
 (0.00000000529,  5.03538677680,     9917.69687450980),
 (0.00000000487,  2.50544745305,     6127.65545055720),
 (0.00000000419,  4.05235655996,    10984.19235169980),
 (0.00000000538,  5.54081539813,      553.56940284240),
 (0.00000000402,  2.16859478359,     7860.41939243920),
 (0.00000000552,  2.32219865498,    11506.76976979360),
 (0.00000000367,  3.39145698451,     6496.37494542940),
 (0.00000000360,  5.34467204596,     7079.37385680780),
 (0.00000000334,  3.61346365667,    11790.62908865880),
 (0.00000000454,  0.28755421898,      801.82093112380),
 (0.00000000419,  3.69613970002,    10575.40668294180),
 (0.00000000319,  0.30793759304,    16200.77272450120),
 (0.00000000376,  5.81560210508,     7058.59846131540),
 (0.00000000364,  1.08425056923,     6309.37416979120),
 (0.00000000294,  4.54798604178,    11856.21865142450),
 (0.00000000290,  1.26451946335,     8635.94200376320),
 (0.00000000394,  4.15683669084,       26.29831979980),
 (0.00000000260,  5.09424572996,    10177.25767953360),
 (0.00000000241,  2.25766000302,    11712.95531823080),
 (0.00000000239,  1.06936978753,      242.72860397400),
 (0.00000000276,  3.44260568764,     5884.92684658320),
 (0.00000000255,  5.38496803122,    21228.39202354580),
 (0.00000000307,  4.24313885601,     3738.76143010800),
 (0.00000000213,  3.44661200485,      213.29909543800),
 (0.00000000198,  0.69427265195,     1990.74501704100),
 (0.00000000195,  5.16563409007,    12352.85260454480),
 (0.00000000213,  3.89937836808,    13916.01910964160),
 (0.00000000214,  4.00445200772,     5230.80746680300),
 (0.00000000184,  5.59805976614,     6283.14316029419),
 (0.00000000184,  2.85275392124,     7238.67559160000),
 (0.00000000179,  2.54259058252,    14314.16811304980),
 (0.00000000236,  5.58826125715,     6069.77675455340),
 (0.00000000189,  2.72689937708,     6062.66320755260),
 (0.00000000184,  6.04216273598,     6283.00853968860),
 (0.00000000225,  1.66128561344,     4732.03062734340),
 (0.00000000230,  3.62591335086,     6284.05617105960),
 (0.00000000172,  0.97566476085,     3930.20969621960),
 (0.00000000162,  2.19467339429,    18073.70493865020),
 (0.00000000215,  1.04672844028,     3496.03282613400),
 (0.00000000182,  5.17782354566,    17253.04110768959),
 (0.00000000167,  2.17754938066,     6076.89030155420),
 (0.00000000167,  4.75672473773,    17267.26820169119),
 (0.00000000149,  0.80944185798,      709.93304855830),
 (0.00000000149,  0.17584214812,     9779.10867612540),
 (0.00000000192,  5.00680790235,    11015.10647733480),
 (0.00000000141,  4.38420380014,     4136.91043351620),
 (0.00000000158,  4.60969054283,     9623.68827669120),
 (0.00000000133,  3.30507062245,   154717.60988768269),
 (0.00000000166,  6.13191098325,        3.52311834900),
 (0.00000000181,  1.60715321141,        7.11354700080),
 (0.00000000150,  5.28136702046,    13517.87010623340),
 (0.00000000142,  0.49788089569,    25158.60171976540),
 (0.00000000124,  6.03440459813,     9225.53927328300),
 (0.00000000124,  0.99251562639,    65147.61976813770),
 (0.00000000128,  1.92032744711,    22483.84857449259),
 (0.00000000124,  3.99739675184,     4686.88940770680),
 (0.00000000121,  2.37814805239,   167283.76158766549),
 (0.00000000123,  5.62315112940,     5642.19824260920),
 (0.00000000117,  5.81755956156,    12569.67481833180),
 (0.00000000157,  3.40236948518,    16496.36139620240),
 (0.00000000130,  2.10499918142,     1589.07289528380),
 (0.00000000116,  0.55839966736,     5849.36411211460),
 (0.00000000123,  5.81645568991,     6282.09552892320),
 (0.00000000110,  0.42176497674,     6172.86952877200),
 (0.00000000150,  4.26279600865,     3128.38876509580),
 (0.00000000106,  2.27436561182,     5429.87946823940),
 (0.00000000114,  1.52894564202,    12559.03815298200),
 (0.00000000121,  0.39459045915,    12132.43996210600),
 (0.00000000104,  2.41845930933,      426.59819087600),
 (0.00000000109,  5.82786999856,    16858.48253293320),
 (0.00000000102,  4.46626484910,    23543.23050468179),
 (0.00000000100,  2.93812275274,     4535.05943692440),
 (0.00000000097,  3.97935904984,     6133.51265285680),
 (0.00000000098,  0.87616810121,     6525.80445396540),
 (0.00000000110,  6.22339014386,    12146.66705610760),
 (0.00000000098,  3.17344332543,    10440.27429260360),
 (0.00000000096,  2.44128701699,     3097.88382272579),
 (0.00000000099,  5.75642493267,     7342.45778018060),
 (0.00000000090,  0.18984343165,    13119.72110282519),
 (0.00000000099,  5.58884724219,     2388.89402044920),
 (0.00000000091,  6.04278320182,    20426.57109242200),
 (0.00000000080,  1.29028142103,     5650.29211067820),
 (0.00000000086,  3.94529200528,    10454.50138660520),
 (0.00000000085,  1.92836879835,    29088.81141598500),
 (0.00000000076,  2.70726317966,   143571.32428481648),
 (0.00000000091,  5.63859073351,     8827.39026987480),
 (0.00000000076,  1.80783856698,    28286.99048486120),
 (0.00000000075,  3.40858032804,     5481.25491886760),
 (0.00000000070,  4.53719487231,    17256.63153634140),
 (0.00000000089,  1.10064490942,    11769.85369316640),
 (0.00000000066,  2.78384937771,      536.80451209540),
 (0.00000000068,  3.88199295043,    17260.15465469040),
 (0.00000000088,  3.88075269535,     7477.52286021600),
 (0.00000000061,  6.17558202197,    11087.28512591840),
 (0.00000000060,  4.34824715818,     6206.80977871580),
 (0.00000000082,  4.59843208943,     9388.00590941520),
 (0.00000000079,  1.63139280394,     4933.20844033260),
 (0.00000000081,  1.55550779371,     9380.95967271720),
 (0.00000000078,  4.20905757519,     5729.50644714900),
 (0.00000000058,  5.76889633224,     3634.62102451840),
 (0.00000000060,  0.93813100594,    12721.57209941700),
 (0.00000000071,  6.11408885148,     8662.24032356300),
 (0.00000000057,  5.48112524468,    18319.53658487960),
 (0.00000000070,  0.01749174864,    14945.31617355440),
 (0.00000000074,  1.09976045820,    16460.33352952499),
 (0.00000000056,  1.63036186739,    15720.83878487840),
 (0.00000000055,  4.86788348404,    13095.84266507740),
 (0.00000000060,  5.93729841267,    12539.85338018300),
 (0.00000000054,  0.22608242982,    15110.46611986620),
 (0.00000000054,  2.30250047594,    16062.18452611680),
 (0.00000000064,  2.13513754101,     7875.67186362420),
 (0.00000000059,  5.87963500139,     5331.35744374080),
 (0.00000000058,  2.30546168615,      955.59974160860),
 (0.00000000049,  1.93839278478,     5333.90024102160),
 (0.00000000054,  5.80331607119,    12043.57428188900),
 (0.00000000054,  4.44671053809,     4701.11650170840),
 (0.00000000049,  0.30241161485,     6805.65326808520),
 (0.00000000046,  2.76898193028,     6709.67404086740),
 (0.00000000046,  3.98449608961,    98068.53671630539),
 (0.00000000049,  3.72022009896,    12323.42309600880),
 (0.00000000045,  3.30065998328,    22003.91463486980),
 (0.00000000048,  0.71071357303,     6303.43116939020),
 (0.00000000061,  1.66030429494,     6262.30045449900),
 (0.00000000047,  1.26317154881,    11919.14086666800),
 (0.00000000051,  1.08020906825,    10988.80815753500),
 (0.00000000045,  0.89150445122,    51868.24866217880),
 (0.00000000043,  0.57756724285,    24356.78078864160),
 (0.00000000043,  1.61526242998,     6277.55292568400),
 (0.00000000045,  2.96132920534,     8982.81066930900),
 (0.00000000043,  5.74295325645,    11403.67699557500),
 (0.00000000055,  3.14274403422,    33019.02111220460),
 (0.00000000057,  0.06379726305,    15671.08175940660),
 (0.00000000041,  2.53761820726,     6262.72053059260),
 (0.00000000040,  1.53130436944,    18451.07854656599),
 (0.00000000052,  1.71451922581,     1551.04522264800),
 (0.00000000055,  0.89439119424,    11933.36796066960),
 (0.00000000045,  3.88495384656,    60530.48898574180),
 (0.00000000040,  4.75740908001,    38526.57435087200),
 (0.00000000040,  3.77498297348,    26087.90314157420),
 (0.00000000039,  2.97113832621,     2118.76386037840),
 (0.00000000040,  3.36050962605,    10021.83728009940),
 (0.00000000047,  1.67051113434,     6303.85124548380),
 (0.00000000052,  5.21827368711,    77713.77146812050),
 (0.00000000047,  4.26356628717,    21424.46664430340),
 (0.00000000037,  1.66712389942,     6819.88036208680),
 (0.00000000037,  0.65746800933,    12029.34718788740),
 (0.00000000035,  3.36255650927,    24072.92146977640),
 (0.00000000036,  0.11087914947,    10344.29506538580),
 (0.00000000040,  4.14725582115,     2787.04302385740),
 (0.00000000035,  5.93650887012,    31570.79964939120),
 (0.00000000036,  2.15108874765,    30774.50164257480),
 (0.00000000036,  1.75078825382,    16207.88627150200),
 (0.00000000034,  2.75708224536,    12139.55350910680),
 (0.00000000034,  6.16891378800,    24491.42579258340),
 (0.00000000034,  2.31528650443,    55798.45835839840),
 (0.00000000032,  4.21446357042,    15664.03552270859),
 (0.00000000034,  3.19783054699,    32217.20018108080),
 (0.00000000039,  1.24979117796,     6418.14093002680),
 (0.00000000038,  5.89832942685,      640.87760738220),
 (0.00000000033,  4.80200120107,    16723.35014259500),
 (0.00000000032,  1.72442327688,    27433.88921587499),
 (0.00000000035,  4.44608896525,    18202.21671665939),
 (0.00000000031,  4.52790731280,     6702.56049386660),
 (0.00000000034,  3.96287980676,    18216.44381066100),
 (0.00000000030,  5.06259854444,   226858.23855437008),
 (0.00000000034,  1.43910280005,    49515.38250840700),
 (0.00000000030,  0.29303163371,    13521.75144159140),
 (0.00000000029,  2.02633840220,    11609.86254401220),
 (0.00000000030,  2.54923230240,     9924.81042151060),
 (0.00000000032,  4.91793198558,    11300.58422135640),
 (0.00000000030,  0.23284423547,    23581.25817731760),
 (0.00000000029,  1.62807736495,      639.89728631400),
 (0.00000000028,  3.84568936822,     2699.73481931760),
 (0.00000000029,  1.83149729794,    29822.78323632420),
 (0.00000000033,  4.60320094415,    19004.64794940840),
 (0.00000000027,  1.86151121799,     6288.59877429880),
 (0.00000000030,  4.46494072240,    36147.40987730040),
 (0.00000000028,  5.19684492912,     5863.59120611620),
 (0.00000000035,  4.52695674113,    36949.23080842420),
 (0.00000000027,  3.52528177609,    10770.89325626180),
 (0.00000000026,  1.48499438453,    11080.17157891760),
 (0.00000000035,  2.82154380962,    19402.79695281660),
 (0.00000000025,  2.46339998836,     6279.48542133960),
 (0.00000000026,  4.97688894643,    16737.57723659660),
 (0.00000000027,  0.40827112500,    12964.30070339100),
 (0.00000000029,  4.15148654061,    45892.73043315699),
 (0.00000000026,  4.56404104286,    17796.95916678580),
 (0.00000000025,  2.89309528854,     6286.66627864320),
 (0.00000000026,  4.82914580957,     1066.49547719000),
 (0.00000000031,  3.93096113738,    29864.33402730900),
 (0.00000000024,  6.14987193584,    18606.49894600020),
 (0.00000000024,  3.74225964547,    29026.48522950779),
 (0.00000000025,  5.70460621565,    27707.54249429480),
 (0.00000000025,  5.33928840652,    15141.39079431200),
 (0.00000000023,  2.37624087345,    17996.03116822220),
 (0.00000000026,  1.34231351782,    18875.52586977400),
 (0.00000000022,  5.50791626120,     6245.04817735560),
 (0.00000000024,  1.33998410121,    19800.94595622480),
 (0.00000000023,  0.22512280890,     6279.78949257360),
 (0.00000000022,  1.17576471775,    11925.27409260060),
 (0.00000000022,  3.58603606640,     6915.85958930460),
 (0.00000000023,  3.21621246666,     6286.36220740920),
 (0.00000000029,  2.09564449439,    15265.88651930040),
 (0.00000000022,  4.74660932338,    28230.18722269139),
 (0.00000000021,  2.30688751432,     5999.21653112620),
 (0.00000000028,  3.92087592807,    18208.34994259200),
 (0.00000000021,  3.22643339385,    25934.12433108940),
 (0.00000000021,  3.04956726238,     6566.93516885660),
 (0.00000000027,  5.35645770522,    33794.54372352860),
 (0.00000000025,  5.91542362188,     6489.26139842860),
 (0.00000000020,  1.52296293311,      135.06508003540),
 (0.00000000019,  1.78134428631,   156137.47598479928),
 (0.00000000019,  0.34388684087,     5327.47610838280),
 (0.00000000026,  3.41701003233,    25287.72379939980),
 (0.00000000019,  2.86664271911,    18422.62935909819),
 (0.00000000019,  4.71432851499,    77690.75950573849),
 (0.00000000019,  2.54227398241,    77736.78343050249),
 (0.00000000020,  5.91915117116,    48739.85989708300));
SZ2: array[1..KZ2,1..3] of double =
((0.00004359385,  5.78455133808,     6283.07584999140),
 (0.00000123633,  5.57935427994,    12566.15169998280),
 (0.00000012342,  3.14159265359,        0.00000000000),
 (0.00000008792,  3.62777893099,    77713.77146812050),
 (0.00000005689,  1.86958905084,     5573.14280143310),
 (0.00000003302,  5.47034879713,    18849.22754997420),
 (0.00000001471,  4.47964125007,     5507.55323866740),
 (0.00000001013,  2.81323115556,     5223.69391980220),
 (0.00000000854,  3.10776566900,     1577.34354244780),
 (0.00000001102,  2.84173992403,   161000.68573767410),
 (0.00000000648,  5.47348203398,      775.52261132400),
 (0.00000000608,  1.37894173533,     6438.49624942560),
 (0.00000000499,  4.41649242250,     6286.59896834040),
 (0.00000000416,  0.90332697974,    10977.07880469900),
 (0.00000000404,  3.20567269530,     5088.62883976680),
 (0.00000000351,  1.81081728907,     5486.77784317500),
 (0.00000000466,  3.65086758149,     7084.89678111520),
 (0.00000000458,  5.38585314743,   149854.40013480789),
 (0.00000000304,  3.51015066341,      796.29800681640),
 (0.00000000266,  6.17413982699,     6836.64525283380),
 (0.00000000281,  1.83874672540,     4694.00295470760),
 (0.00000000262,  1.41420110644,     2146.16541647520),
 (0.00000000264,  3.14103683911,    71430.69561812909),
 (0.00000000319,  5.35037932146,     3154.68708489560),
 (0.00000000238,  2.17695432424,      155.42039943420),
 (0.00000000229,  4.75969588070,     7234.79425624200),
 (0.00000000291,  4.61776401638,     4690.47983635860),
 (0.00000000211,  0.21864885298,     4705.73230754360),
 (0.00000000204,  4.22895113488,     1349.86740965880),
 (0.00000000195,  4.58550676556,      529.69096509460),
 (0.00000000255,  2.81442711144,     1748.01641306700),
 (0.00000000182,  5.70454011389,     6040.34724601740),
 (0.00000000180,  6.02147727878,     4292.33083295040),
 (0.00000000186,  1.58690991244,     6309.37416979120),
 (0.00000000167,  2.88802733052,     9437.76293488700),
 (0.00000000166,  1.99990574734,     8031.09226305840),
 (0.00000000160,  0.04412738495,     2544.31441988340),
 (0.00000000197,  2.01089431842,     1194.44701022460),
 (0.00000000165,  5.78372596774,    83996.84731811189),
 (0.00000000214,  3.38300910371,     7632.94325965020),
 (0.00000000140,  0.36669664351,    10447.38783960440),
 (0.00000000151,  0.95519595275,     6127.65545055720),
 (0.00000000136,  1.48417295645,     2352.86615377180),
 (0.00000000128,  5.48057748834,      951.71840625060),
 (0.00000000126,  5.26866506592,     6279.55273164240),
 (0.00000000127,  3.77552907014,     6812.76681508600),
 (0.00000000103,  4.95897533789,      398.14900340820),
 (0.00000000104,  0.70183576826,     1592.59601363280),
 (0.00000000101,  1.14481598642,     3894.18182954220),
 (0.00000000131,  0.76624310306,      553.56940284240),
 (0.00000000109,  5.41063597567,     6256.77753019160),
 (0.00000000078,  5.84775340741,      242.72860397400),
 (0.00000000097,  1.94685257714,    11856.21865142450),
 (0.00000000100,  5.19725292131,   244287.60000722769),
 (0.00000000076,  0.70480774041,     8429.24126646660),
 (0.00000000080,  6.18430772683,     1059.38193018920),
 (0.00000000068,  5.29561709093,    14143.49524243060),
 (0.00000000085,  5.39487308005,    25132.30339996560),
 (0.00000000055,  5.16874637579,     7058.59846131540),
 (0.00000000063,  0.48494730699,      801.82093112380),
 (0.00000000058,  4.07254840265,    13367.97263110660),
 (0.00000000051,  3.89696552232,    12036.46073488820),
 (0.00000000051,  5.56335232286,     1990.74501704100),
 (0.00000000060,  2.25046596710,     8635.94200376320),
 (0.00000000049,  5.58163417371,     6290.18939699220),
 (0.00000000051,  3.87240194908,       26.29831979980),
 (0.00000000051,  4.19300909995,     7860.41939243920),
 (0.00000000041,  3.97169191582,    10973.55568635000),
 (0.00000000041,  3.57080919230,     7079.37385680780),
 (0.00000000056,  2.76959005761,    90955.55169449610),
 (0.00000000042,  1.91461189163,     7477.52286021600),
 (0.00000000042,  0.42775891995,    10213.28554621100),
 (0.00000000042,  1.06925480488,      709.93304855830),
 (0.00000000038,  6.17935925345,     9917.69687450980),
 (0.00000000050,  0.81691517401,    11506.76976979360),
 (0.00000000053,  1.45828359397,   233141.31440436149),
 (0.00000000038,  3.32444534628,     5643.17856367740),
 (0.00000000047,  6.21543665927,     6681.22485339960),
 (0.00000000037,  0.36359309980,    10177.25767953360),
 (0.00000000045,  5.29587706357,    10575.40668294180),
 (0.00000000034,  5.63446915337,     6525.80445396540),
 (0.00000000034,  5.36385158519,     4933.20844033260),
 (0.00000000035,  5.36152295839,    25158.60171976540),
 (0.00000000042,  5.08837645072,    11015.10647733480),
 (0.00000000042,  4.22496037505,    88860.05707098669),
 (0.00000000039,  1.99171699618,     6284.05617105960),
 (0.00000000029,  3.19088628170,    11926.25441366880),
 (0.00000000029,  0.14996158324,    12168.00269657460),
 (0.00000000030,  1.58346276808,     9779.10867612540),
 (0.00000000026,  4.16210340581,    12569.67481833180),
 (0.00000000036,  2.74684637873,     3738.76143010800),
 (0.00000000026,  0.72824915320,     1589.07289528380),
 (0.00000000031,  5.34906371821,   143571.32428481648),
 (0.00000000025,  0.10240267494,    22483.84857449259),
 (0.00000000030,  3.47110495524,    14945.31617355440),
 (0.00000000026,  3.89359701125,     5753.38488489680),
 (0.00000000024,  1.18744224678,     4535.05943692440),
 (0.00000000033,  2.99317143244,     3930.20969621960),
 (0.00000000024,  1.57253767584,     6496.37494542940),
 (0.00000000024,  3.47434797542,     4136.91043351620),
 (0.00000000022,  3.91230073719,     6275.96230299060),
 (0.00000000025,  4.02978941287,     3128.38876509580),
 (0.00000000023,  1.07724492065,    12721.57209941700),
 (0.00000000021,  1.89591807148,    16730.46368959580),
 (0.00000000025,  2.42198937013,     5729.50644714900),
 (0.00000000020,  1.78163489101,    17789.84561978500),
 (0.00000000021,  0.49258939822,    29088.81141598500),
 (0.00000000026,  4.14947806747,     2388.89402044920),
 (0.00000000027,  2.54785812264,     3496.03282613400),
 (0.00000000020,  4.29944129273,    16858.48253293320),
 (0.00000000021,  5.97796936723,        7.11354700080),
 (0.00000000019,  0.80292033311,    16062.18452611680),
 (0.00000000024,  4.89894141052,    17260.15465469040),
 (0.00000000025,  1.37003752175,     6282.09552892320),
 (0.00000000022,  4.92663152168,    18875.52586977400),
 (0.00000000023,  5.68902059771,    16460.33352952499),
 (0.00000000023,  3.03021283729,    66567.48586525429),
 (0.00000000016,  3.89713736666,     5331.35744374080),
 (0.00000000016,  5.68562539832,    12559.03815298200),
 (0.00000000016,  3.95085099736,     3097.88382272579),
 (0.00000000016,  3.99041783945,     6283.14316029419),
 (0.00000000020,  6.10643919100,   167283.76158766549),
 (0.00000000015,  4.09775914607,    11712.95531823080),
 (0.00000000016,  5.71769940700,    17298.18232732620),
 (0.00000000016,  3.28894009404,     5884.92684658320),
 (0.00000000015,  4.42564243680,    13517.87010623340),
 (0.00000000016,  4.43452080930,     6283.00853968860),
 (0.00000000014,  1.44384279999,     4164.31198961300),
 (0.00000000014,  4.47380919159,    11790.62908865880),
 (0.00000000014,  4.77646531825,     7342.45778018060),
 (0.00000000011,  2.56768522896,     5481.25491886760),
 (0.00000000011,  1.51443332200,    16200.77272450120),
 (0.00000000011,  0.88708889185,    21228.39202354580),
 (0.00000000014,  4.50116508534,      640.87760738220));
SZ3: array[1..KZ3,1..3] of double =
((0.00000144595,  4.27319433901,     6283.07584999140),
 (0.00000006729,  3.91706261708,    12566.15169998280),
 (0.00000000774,  0.00000000000,        0.00000000000),
 (0.00000000247,  3.73021571217,    18849.22754997420),
 (0.00000000036,  2.80081409050,     6286.59896834040),
 (0.00000000033,  5.62990083112,     6127.65545055720),
 (0.00000000018,  3.72826142555,     6438.49624942560),
 (0.00000000016,  4.26011484232,     6525.80445396540),
 (0.00000000014,  3.47817116396,     6256.77753019160),
 (0.00000000012,  3.55747379482,    25132.30339996560),
 (0.00000000010,  4.43995693209,     4705.73230754360),
 (0.00000000010,  4.28045255470,    83996.84731811189),
 (0.00000000009,  5.36457057335,     6040.34724601740),
 (0.00000000008,  1.78458957263,     5507.55323866740),
 (0.00000000009,  0.47275199930,     6279.55273164240),
 (0.00000000009,  1.34741231639,     6309.37416979120),
 (0.00000000009,  0.77092900708,     5729.50644714900),
 (0.00000000007,  3.50146897332,     7058.59846131540),
 (0.00000000005,  2.89071061700,      775.52261132400),
 (0.00000000006,  2.36514111314,     6836.64525283380));
SZ4: array[1..KZ4,1..3] of double =
((0.00000003858,  2.56389016346,     6283.07584999140),
 (0.00000000306,  2.26911740541,    12566.15169998280),
 (0.00000000053,  3.44031471924,     5573.14280143310),
 (0.00000000015,  2.03136359366,    18849.22754997420),
 (0.00000000013,  2.05688873673,    77713.77146812050),
 (0.00000000007,  4.41218854480,   161000.68573767410),
 (0.00000000004,  5.33854414781,     6438.49624942560),
 (0.00000000006,  3.81514213664,   149854.40013480789),
 (0.00000000004,  4.26602478239,     6127.65545055720));
SZ5: array[1..KZ5,1..3] of double =
((0.00000000086,  1.21805304895,     6283.07584999140),
 (0.00000000012,  0.65572878044,    12566.15169998280));

RDA: double = 4.8481368110953599359e-6;
PI2: double = 6.2831853071795864769;
freqs: array[0..8] of double =
(53810162868.8982,21066413643.3548,12959774228.3429,6890507749.3988,
1092566037.7991,439960985.5372,154248119.3933,78655032.0744,52272245.1795);
phases: array[0..8] of double =
(908103.259872,655127.28306,361679.244588,1279558.798488,123665.467464,
180278.79948,1130598.018396,1095655.195728,860492.1546);
max_armonic: array[0..8,0..8] of byte =
((11, 14, 10, 11,  4,  5,  2,  0,  0),(  5, 14, 13,  8,  4,  5,  1,  0,  0),
(  1,  9, 14, 17,  5,  5,  2,  1,  0),(  0,  5, 12, 24,  9,  7,  3,  2,  0),
(  0,  0,  1,  0,  9, 16,  7,  5,  0),(  0,  0,  1,  0,  8, 18,  9,  5,  0),
(  0,  0,  0,  0,  5, 10,  9, 12,  0),(  0,  0,  0,  0,  3,  8,  7,  9,  0),
(  0,  0,  0,  0,  2,  2,  9, 13, 13));
max_armonic_mlr: array [0..13] of byte = (3,26,29,23,5,10,0,0,0,8,4,4,6,2);
max_armonic_mlat: array [0..13] of byte = (0,26,29,8,3,5,0,0,0,6,5,3,5,1);
distance: array[0..8] of double =
(3.8709830979999998e-01,7.2332982000000001e-01,1.5303348827100001e+00,
5.2026032092000003e+00,9.5575813548599999e+00,1.9218446061800002e+01,
3.0110386869399999e+01,3.9539999999999999e+01,2.5735686895300000e-03);

VAR
Args: array[0..13] of double;
ss: array[0..13,0..28] of double;
cc: array[0..13,0..28] of double;
acu,asu,acv,asv,s,su,cu,sv,cv,T,cul,cub,cur,sul,sub,sur,ta,sl,sb,sr: double;
lp_equinox,x,T2,temp: double;
sci,i,jp,k,m,k1,ip,np,nt: integer;
p,pl,pb,pr: longint;
mx0,mx1,mx2,mx3,mx4,mx5: extended;
my0,my1,my2,my3,my4,my5: extended;
mz0,mz1,mz2,mz3,mz4,mz5: extended;

FUNCTION mods3600(x: double): double;
BEGIN
if abs(x)<1.296e+6 then mods3600:=x
else begin
temp:=x-1.296e+6*int(x/1.296e+6);
if temp<0 then temp:=temp+1.296e+6;
mods3600:=temp;
end
END;

FUNCTION modl2pi(x: double): double;
BEGIN
if abs(x)<PI2 then temp:=x
else temp:=x-int(x/PI2)*PI2;
if temp<0 then temp:=temp+PI2;
modl2pi:=temp
END;

FUNCTION modb2pi(x: double): double;
BEGIN
if abs(x)<PI2 then modb2pi:=x
else modb2pi:=x-int(x/PI2)*PI2
END;

PROCEDURE mean_elements(J: double);
BEGIN
T:=(J-2451545.0)/36525.0;
T2:=T*T;
{mean longitudes of planets}
{Mercury}
x:=mods3600(538101628.6889819*T+908103.213);
x:=x+(6.39e-6*T-0.0192789)*T2;
args[0]:=RDA*x;
{Venus}
x:=mods3600(210664136.4335482*T+655127.236);
x:=x+(-6.27e-6*T+0.0059381)*T2;
args[1]:=RDA*x;
{Earth}
x:=mods3600(129597742.283429*T+361679.198);
x:=x+(-5.23e-6*T-2.04411e-2)*T2;
args[2]:=RDA*x;
{Mars}
x:=mods3600(68905077.493988*T+1279558.751);
x:=x+(-1.043e-5*T+0.0094264)*T2;
args[3]:=RDA*x;
{Jupiter}
x:=mods3600(10925660.377991*T+123665.420);
x:=x+((((-3.4e-10*T+5.91e-8)*T+4.667e-6)*T+5.706e-5)*T-3.060378e-1)*T2;
args[4]:=RDA*x;
{Saturn}
x:=mods3600(4399609.855372*T+180278.752);
x:=x+((((8.3e-10*T-1.452e-7)*T-1.1484e-5)*T-1.6618e-4)*T+7.561614E-1)*T2;
args[5]:=RDA*x;
{Uranus}
x:=mods3600(1542481.193933*T+1130597.971)+(0.00002156*T-0.0175083)*T2;
args[6]:=RDA*x;
{Neptune}
x:=mods3600(786550.320744*T+1095655.149)+(0.0021103-0.00000895*T)*T2;
args[7]:=RDA*x;
args[8]:=0.0;
{mean elongation of moon}
x:=mods3600(1.6029616009939659e+09*T+1.0722612202445078e+06);
x:=x+(((((-3.207663637426e-013*T+2.555243317839e-011)*T+2.560078201452e-009)*T
-3.702060118571e-005)*T+6.9492746836058421e-03)*T-6.7352202374457519e+00)*T2;
args[9]:=RDA*x;
{mean distance of moon from its ascending node}
x:=mods3600(1.7395272628437717e+09*T+3.3577951412884740e+05);
x:=x+(((((4.474984866301e-013*T+4.189032191814e-011)*T-2.790392351314e-009)*T
-2.165750777942e-006)*T-7.5311878482337989e-04)*T-1.3117809789650071e+01)*T2;
args[10]:=RDA*x;
{mean anomaly of sun}
x:=mods3600(1.2959658102304320e+08*T+1.2871027407441526e+06);
x:=x+((((((((1.62e-20*T-1.0390e-17)*T-3.83508e-15)*T+4.237343e-13)*T
+8.8555011e-11)*T-4.77258489e-8)*T-1.1297037031e-5)*T
+8.7473717367324703e-05)*T-5.5281306421783094e-01)*T2;
args[11]:=RDA*x;
{mean anomaly of moon}
x:=mods3600(1.7179159228846793e+09*T+4.8586817465825332e+05);
x:=x+(((((-1.755312760154e-012)*T+3.452144225877e-011*T-2.506365935364e-008)*T
-2.536291235258e-004)*T+5.2099641302735818e-02)*T+3.1501359071894147e+01)*T2;
args[12]:=RDA*x;
{mean longitude of moon}
x:=mods3600(1.7325643720442266e+09*T+7.8593980921052420e+05);
x:=x+(((((7.200592540556e-014*T+2.235210987108e-010)*T-1.024222633731e-008)*T
-6.073960534117e-005)*T+6.9017248528380490e-03)*T-5.6550460027471399e+00)*T2;
lp_equinox:=x;
args[13]:=RDA*x;
END;

PROCEDURE sscc(k: integer; arg: double; n: integer);
{calculates sine and cosine arrays for multiple angles}
BEGIN
asu:=sin(arg);
acu:=cos(arg);
ss[k][0]:=asu;
cc[k][0]:=acu;
asv:=2.0*asu*acu;
acv:=acu*acu-asu*asu;
ss[k][1]:=asv;
cc[k][1]:=acv;
for sci:=2 to n-1 do begin
s:=asu*acv+acu*asv;
acv:=acu*acv-asu*asv;
asv:=s;
ss[k][sci]:=asv;
cc[k][sci]:=acv;
end;
END;

PROCEDURE pos_mer (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[0,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=merargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=merargs[p];
inc(p);
cul:=mertabl[pl];
cub:=mertabb[pb];
cur:=mertabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+mertabl[pl];
cub:=cub*T+mertabb[pb];
cur:=cur*T+mertabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=merargs[p];
m:=merargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=merargs[p];
inc(p);
cul:=mertabl[pl];
sul:=mertabl[pl+1];
cub:=mertabb[pb];
sub:=mertabb[pb+1];
cur:=mertabr[pr];
sur:=mertabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+mertabl[pl];
sul:=sul*T+mertabl[pl+1];
cub:=cub*T+mertabb[pb];
sub:=sub*T+mertabb[pb+1];
cur:=cur*T+mertabr[pr];
sur:=sur*T+mertabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=merargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[0]*sr+distance[0];
end;

PROCEDURE pos_ven (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[1,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=venargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=venargs[p];
inc(p);
cul:=ventabl[pl];
cub:=ventabb[pb];
cur:=ventabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+ventabl[pl];
cub:=cub*T+ventabb[pb];
cur:=cur*T+ventabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=venargs[p];
m:=venargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=venargs[p];
inc(p);
cul:=ventabl[pl];
sul:=ventabl[pl+1];
cub:=ventabb[pb];
sub:=ventabb[pb+1];
cur:=ventabr[pr];
sur:=ventabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+ventabl[pl];
sul:=sul*T+ventabl[pl+1];
cub:=cub*T+ventabb[pb];
sub:=sub*T+ventabb[pb+1];
cur:=cur*T+ventabr[pr];
sur:=sur*T+ventabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=venargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[1]*sr+distance[1];
end;

PROCEDURE pos_mar (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[3,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=marargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=marargs[p];
inc(p);
cul:=martabl[pl];
cub:=martabb[pb];
cur:=martabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+martabl[pl];
cub:=cub*T+martabb[pb];
cur:=cur*T+martabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=marargs[p];
m:=marargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=marargs[p];
inc(p);
cul:=martabl[pl];
sul:=martabl[pl+1];
cub:=martabb[pb];
sub:=martabb[pb+1];
cur:=martabr[pr];
sur:=martabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+martabl[pl];
sul:=sul*T+martabl[pl+1];
cub:=cub*T+martabb[pb];
sub:=sub*T+martabb[pb+1];
cur:=cur*T+martabr[pr];
sur:=sur*T+martabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=marargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[2]*sr+distance[2];
end;

PROCEDURE pos_jup (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[4,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=jupargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=jupargs[p];
inc(p);
cul:=juptabl[pl];
cub:=juptabb[pb];
cur:=juptabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+juptabl[pl];
cub:=cub*T+juptabb[pb];
cur:=cur*T+juptabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=jupargs[p];
m:=jupargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=jupargs[p];
inc(p);
cul:=juptabl[pl];
sul:=juptabl[pl+1];
cub:=juptabb[pb];
sub:=juptabb[pb+1];
cur:=juptabr[pr];
sur:=juptabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+juptabl[pl];
sul:=sul*T+juptabl[pl+1];
cub:=cub*T+juptabb[pb];
sub:=sub*T+juptabb[pb+1];
cur:=cur*T+juptabr[pr];
sur:=sur*T+juptabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=jupargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[3]*sr+distance[3];
end;

PROCEDURE pos_sat (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[5,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=satargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=satargs[p];
inc(p);
cul:=sattabl[pl];
cub:=sattabb[pb];
cur:=sattabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+sattabl[pl];
cub:=cub*T+sattabb[pb];
cur:=cur*T+sattabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=satargs[p];
m:=satargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=satargs[p];
inc(p);
cul:=sattabl[pl];
sul:=sattabl[pl+1];
cub:=sattabb[pb];
sub:=sattabb[pb+1];
cur:=sattabr[pr];
sur:=sattabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+sattabl[pl];
sul:=sul*T+sattabl[pl+1];
cub:=cub*T+sattabb[pb];
sub:=sub*T+sattabb[pb+1];
cur:=cur*T+sattabr[pr];
sur:=sur*T+sattabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=satargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[4]*sr+distance[4];
end;

PROCEDURE pos_ura (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[6,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=uraargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=uraargs[p];
inc(p);
cul:=uratabl[pl];
cub:=uratabb[pb];
cur:=uratabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+uratabl[pl];
cub:=cub*T+uratabb[pb];
cur:=cur*T+uratabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=uraargs[p];
m:=uraargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=uraargs[p];
inc(p);
cul:=uratabl[pl];
sul:=uratabl[pl+1];
cub:=uratabb[pb];
sub:=uratabb[pb+1];
cur:=uratabr[pr];
sur:=uratabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+uratabl[pl];
sul:=sul*T+uratabl[pl+1];
cub:=cub*T+uratabb[pb];
sub:=sub*T+uratabb[pb+1];
cur:=cur*T+uratabr[pr];
sur:=sur*T+uratabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=uraargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[5]*sr+distance[5];
end;

PROCEDURE pos_nep (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[7,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=nepargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=nepargs[p];
inc(p);
cul:=neptabl[pl];
cub:=neptabb[pb];
cur:=neptabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+neptabl[pl];
cub:=cub*T+neptabb[pb];
cur:=cur*T+neptabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=nepargs[p];
m:=nepargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=nepargs[p];
inc(p);
cul:=neptabl[pl];
sul:=neptabl[pl+1];
cub:=neptabb[pb];
sub:=neptabb[pb+1];
cur:=neptabr[pr];
sur:=neptabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+neptabl[pl];
sul:=sul*T+neptabl[pl+1];
cub:=cub*T+neptabb[pb];
sub:=sub*T+neptabb[pb+1];
cur:=cur*T+neptabr[pr];
sur:=sur*T+neptabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=nepargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[6]*sr+distance[6];
end;

PROCEDURE pos_plu (j: double; var a,b,c: double);
BEGIN
T:=(j-2451545.0)/3652500.0;
for i:=0 to 8 do begin
jp:=max_armonic[8,i];
if jp>0 then begin
sr:=(mods3600(freqs[i]*T)+phases[i])*RDA;
sscc(i,sr,jp);
end;
end;
p:=0;
pl:=0;
pb:=0;
pr:=0;
sl:=0.0;
sb:=0.0;
sr:=0.0;
np:=pluargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=pluargs[p];
inc(p);
cul:=plutabl[pl];
cub:=plutabb[pb];
cur:=plutabr[pr];
inc(pl); inc(pb); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+plutabl[pl];
cub:=cub*T+plutabb[pb];
cur:=cur*T+plutabr[pr];
inc(pl); inc(pb); inc(pr);
end;
sl:=sl+mods3600(cul);
sb:=sb+cub;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=pluargs[p];
m:=pluargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=pluargs[p];
inc(p);
cul:=plutabl[pl];
sul:=plutabl[pl+1];
cub:=plutabb[pb];
sub:=plutabb[pb+1];
cur:=plutabr[pr];
sur:=plutabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+plutabl[pl];
sul:=sul*T+plutabl[pl+1];
cub:=cub*T+plutabb[pb];
sub:=sub*T+plutabb[pb+1];
cur:=cur*T+plutabr[pr];
sur:=sur*T+plutabr[pr+1];
inc(pl,2); inc(pb,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sb:=sb+cub*cv+sub*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=pluargs[p];
inc(p);
end;
a:=modl2pi(RDA*sl);
b:=modb2pi(RDA*sb);
c:=RDA*distance[7]*sr+distance[7];
end;

PROCEDURE pos_moo (j: double; var a,b,c: double);
BEGIN
mean_elements(j);
T:=(j-2451545.0)/3652500.0;
for i:=0 to 13 do begin
jp:=max_armonic_mlr[i];
if jp>0 then sscc(i,args[i],jp);
end;
p:=0;
pl:=0;
pr:=0;
sl:=0.0;
sr:=0.0;
np:=mlrargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=mlrargs[p];
inc(p);
cul:=mlrtabl[pl];
cur:=mlrtabr[pr];
inc(pl); inc(pr);
for ip:=0 to nt-1 do begin
cul:=cul*T+mlrtabl[pl];
cur:=cur*T+mlrtabr[pr];
inc(pl); inc(pr);
end;
sl:=sl+cul;
sr:=sr+cur;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=mlrargs[p];
m:=mlrargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=mlrargs[p];
inc(p);
cul:=mlrtabl[pl];
sul:=mlrtabl[pl+1];
cur:=mlrtabr[pr];
sur:=mlrtabr[pr+1];
inc(pl,2); inc(pr,2);
for ip:=0 to nt-1 do begin
cul:=cul*T+mlrtabl[pl];
sul:=sul*T+mlrtabl[pl+1];
cur:=cur*T+mlrtabr[pr];
sur:=sur*T+mlrtabr[pr+1];
inc(pl,2); inc(pr,2);
end;
sl:=sl+cul*cv+sul*sv;
sr:=sr+cur*cv+sur*sv;
end;
np:=mlrargs[p];
inc(p);
end;
sl:=sl/10000.0;
sr:=sr/10000.0;
for i:=0 to 13 do begin
jp:=max_armonic_mlat[i];
if jp>0 then sscc(i,args[i],jp);
end;
p:=0;
pb:=0;
sb:=0.0;
np:=mlatargs[p];
inc(p);
while np>=0 do begin
if np=0 then begin
nt:=mlatargs[p];
inc(p);
cub:=mlattabl[pb];
inc(pb);
for ip:=0 to nt-1 do begin
cub:=cub*T+mlattabl[pb];
inc(pb);
end;
sb:=sb+cub;
end
else begin
k1:=0;
cv:=0.0;
sv:=0.0;
for ip:=0 to np-1 do begin
jp:=mlatargs[p];
m:=mlatargs[p+1]-1;
inc(p,2);
if jp<>0 then begin
k:=jp;
if jp<0 then k:=-k;
dec(k);
su:=ss[m,k];
if jp<0 then su:=-su;
cu:=cc[m,k];
if k1=0 then begin
sv:=su;
cv:=cu;
k1:=1;
end
else begin
ta:=su*cv+cu*sv;
cv:=cu*cv-su*sv;
sv:=ta;
end;
end;
end;
nt:=mlatargs[p];
inc(p);
cub:=mlattabl[pb];
sub:=mlattabl[pb+1];
inc(pb,2);
for ip:=0 to nt-1 do begin
cub:=cub*T+mlattabl[pb];
sub:=sub*T+mlattabl[pb+1];
inc(pb,2);
end;
sb:=sb+cub*cv+sub*sv;
end;
np:=mlatargs[p];
inc(p);
end;
sb:=sb/10000.0;
x:=sl;
x:=x+LP_equinox;
if x<-6.45e5 then x:=x+1.296e6;
if x>6.45e5 then x:=x-1.296e6;
sl:=RDA*x;
sb:=RDA*sb;
x:=(1.0+RDA*sr)*distance[8];
a:=modl2pi(sl);
b:=modb2pi(sb);
c:=x;
END;

PROCEDURE pos_ear (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/365250.0;
mx0:=0; mx1:=0; mx2:=0; mx3:=0; mx4:=0; mx5:=0;
my0:=0; my1:=0; my2:=0; my3:=0; my4:=0; my5:=0;
mz0:=0; mz1:=0; mz2:=0; mz3:=0; mz4:=0; mz5:=0;
for i:=1 to kx0 do mx0:=mx0+sx0[i,1]*cos(sx0[i,2]+sx0[i,3]*t);
for i:=1 to kx1 do mx1:=mx1+sx1[i,1]*cos(sx1[i,2]+sx1[i,3]*t);
for i:=1 to kx2 do mx2:=mx2+sx2[i,1]*cos(sx2[i,2]+sx2[i,3]*t);
for i:=1 to kx3 do mx3:=mx3+sx3[i,1]*cos(sx3[i,2]+sx3[i,3]*t);
for i:=1 to kx4 do mx4:=mx4+sx4[i,1]*cos(sx4[i,2]+sx4[i,3]*t);
for i:=1 to kx5 do mx5:=mx5+sx5[i,1]*cos(sx5[i,2]+sx5[i,3]*t);
for i:=1 to ky0 do my0:=my0+sy0[i,1]*cos(sy0[i,2]+sy0[i,3]*t);
for i:=1 to ky1 do my1:=my1+sy1[i,1]*cos(sy1[i,2]+sy1[i,3]*t);
for i:=1 to ky2 do my2:=my2+sy2[i,1]*cos(sy2[i,2]+sy2[i,3]*t);
for i:=1 to ky3 do my3:=my3+sy3[i,1]*cos(sy3[i,2]+sy3[i,3]*t);
for i:=1 to ky4 do my4:=my4+sy4[i,1]*cos(sy4[i,2]+sy4[i,3]*t);
for i:=1 to ky5 do my5:=my5+sy5[i,1]*cos(sy5[i,2]+sy5[i,3]*t);
for i:=1 to kz0 do mz0:=mz0+sz0[i,1]*cos(sz0[i,2]+sz0[i,3]*t);
for i:=1 to kz1 do mz1:=mz1+sz1[i,1]*cos(sz1[i,2]+sz1[i,3]*t);
for i:=1 to kz2 do mz2:=mz2+sz2[i,1]*cos(sz2[i,2]+sz2[i,3]*t);
for i:=1 to kz3 do mz3:=mz3+sz3[i,1]*cos(sz3[i,2]+sz3[i,3]*t);
for i:=1 to kz4 do mz4:=mz4+sz4[i,1]*cos(sz4[i,2]+sz4[i,3]*t);
for i:=1 to kz5 do mz5:=mz5+sz5[i,1]*cos(sz5[i,2]+sz5[i,3]*t);
mx0:=mx0+((((mx5*t+mx4)*t+mx3)*t+mx2)*t+mx1)*t;
my0:=my0+((((my5*t+my4)*t+my3)*t+my2)*t+my1)*t;
a:=modl2pi(mx0);
b:=modb2pi(my0);
c:=mz0+((((mz5*t+mz4)*t+mz3)*t+mz2)*t+mz1)*t;
END;

PROCEDURE vel_ear (j: double; var a,b,c: double);
BEGIN
t:=(j-2451545.0)/365250.0;
mx0:=0; mx1:=0; mx2:=0; mx3:=0; mx4:=0; mx5:=0;
my0:=0; my1:=0; my2:=0; my3:=0; my4:=0; my5:=0;
mz0:=0; mz1:=0; mz2:=0; mz3:=0; mz4:=0; mz5:=0;
for i:=1 to kx0 do mx0:=mx0-sx0[i,1]*sx0[i,3]*sin(sx0[i,2]+sx0[i,3]*t);
for i:=1 to kx1 do mx1:=mx1-sx1[i,1]*sx1[i,3]*t*sin(sx1[i,2]+sx1[i,3]*t)
+sx1[i,1]*cos(sx1[i,2]+sx1[i,3]*t);
for i:=1 to kx2 do mx2:=mx2-sx2[i,1]*sx2[i,3]*t*sin(sx2[i,2]+sx2[i,3]*t)
+2*sx2[i,1]*cos(sx2[i,2]+sx2[i,3]*t);
for i:=1 to kx3 do mx3:=mx3-sx3[i,1]*sx3[i,3]*t*sin(sx3[i,2]+sx3[i,3]*t)
+3*sx3[i,1]*cos(sx3[i,2]+sx3[i,3]*t);
for i:=1 to kx4 do mx4:=mx4-sx4[i,1]*sx4[i,3]*t*sin(sx4[i,2]+sx4[i,3]*t)
+4*sx4[i,1]*cos(sx4[i,2]+sx4[i,3]*t);
for i:=1 to kx5 do mx5:=mx5-sx5[i,1]*sx5[i,3]*t*sin(sx5[i,2]+sx5[i,3]*t)
+5*sx5[i,1]*cos(sx5[i,2]+sx5[i,3]*t);
for i:=1 to ky0 do my0:=my0-sy0[i,1]*sy0[i,3]*sin(sy0[i,2]+sy0[i,3]*t);
for i:=1 to ky1 do my1:=my1-sy1[i,1]*sy1[i,3]*t*sin(sy1[i,2]+sy1[i,3]*t)
+sy1[i,1]*cos(sy1[i,2]+sy1[i,3]*t);
for i:=1 to ky2 do my2:=my2-sy2[i,1]*sy2[i,3]*t*sin(sy2[i,2]+sy2[i,3]*t)
+2*sy2[i,1]*cos(sy2[i,2]+sy2[i,3]*t);
for i:=1 to ky3 do my3:=my3-sy3[i,1]*sy3[i,3]*t*sin(sy3[i,2]+sy3[i,3]*t)
+3*sy3[i,1]*cos(sy3[i,2]+sy3[i,3]*t);
for i:=1 to ky4 do my4:=my4-sy4[i,1]*sy4[i,3]*t*sin(sy4[i,2]+sy4[i,3]*t)
+4*sy4[i,1]*cos(sy4[i,2]+sy4[i,3]*t);
for i:=1 to ky5 do my5:=my5-sy5[i,1]*sy5[i,3]*t*sin(sy5[i,2]+sy5[i,3]*t)
+5*sy5[i,1]*cos(sy5[i,2]+sy5[i,3]*t);
for i:=1 to kz0 do mz0:=mz0-sz0[i,1]*sz0[i,3]*sin(sz0[i,2]+sz0[i,3]*t);
for i:=1 to kz1 do mz1:=mz1-sz1[i,1]*sz1[i,3]*t*sin(sz1[i,2]+sz1[i,3]*t)
+sz1[i,1]*cos(sz1[i,2]+sz1[i,3]*t);
for i:=1 to kz2 do mz2:=mz2-sz2[i,1]*sz2[i,3]*t*sin(sz2[i,2]+sz2[i,3]*t)
+2*sz2[i,1]*cos(sz2[i,2]+sz2[i,3]*t);
for i:=1 to kz3 do mz3:=mz3-sz3[i,1]*sz3[i,3]*t*sin(sz3[i,2]+sz3[i,3]*t)
+3*sz3[i,1]*cos(sz3[i,2]+sz3[i,3]*t);
for i:=1 to kz4 do mz4:=mz4-sz4[i,1]*sz4[i,3]*t*sin(sz4[i,2]+sz4[i,3]*t)
+4*sz4[i,1]*cos(sz4[i,2]+sz4[i,3]*t);
for i:=1 to kz5 do mz5:=mz5-sz5[i,1]*sz5[i,3]*t*sin(sz5[i,2]+sz5[i,3]*t)
+5*sz5[i,1]*cos(sz5[i,2]+sz5[i,3]*t);
a:=(mx0+mx1+(((mx5*t+mx4)*t+mx3)*t+mx2)*t)/365250.0;
b:=(my0+my1+(((my5*t+my4)*t+my3)*t+my2)*t)/365250.0;
c:=(mz0+mz1+(((mz5*t+mz4)*t+mz3)*t+mz2)*t)/365250.0;
END;

END.
